## Symbols used:
# ydbar
# yd
# yeqPi7bar
# MPi7
# lambdaHatPi7
# yl
# yluPi7bar
# ylbar
# Coupling
# muH
# g1
# lambdaHatPrimePi7
# g2
# epsilonbar
# yluPi7
# invepsilonbar
# xRP
# mu
# lam
# yubar
# onelooporder
# g3
# yu
# yeqPi7

import sys
import os
import numpy as np

import lsme.numeric.matchingresult as matchingresult

class GranadaPi7MatchingResult(matchingresult.GenericMatchingResult):
    def __init__(self, name='Pi7'):
        super().__init__(name)
        self.MPi7 = 1
        self.yluPi7 = np.ones((3, 3))
        self.yluPi7bar = np.ones((3, 3))
        self.yeqPi7 = np.ones((3, 3))
        self.yeqPi7bar = np.ones((3, 3))
        self.lambdaHatPi7 = 1
        self.lambdaHatPi7bar = 1
        self.lambdaHatPrimePi7 = 1
        self.lambdaHatPrimePi7bar = 1
        self.nonvanishing = ['alphaO3G', 'alphaO3W', 'alphaOH', 'alphaOHB', 'alphaOHBox', 'alphaOHD', 'alphaOHG', 'alphaOHW', 'alphaOHWB', 'alphaOdB', 'alphaOdd', 'alphaOdG', 'alphaOdH', 'alphaOdW', 'alphaOeB', 'alphaOed', 'alphaOee', 'alphaOeH', 'alphaOeu', 'alphaOeW', 'alphaOHd', 'alphaOHe', 'alphaOHl1', 'alphaOHl3', 'alphaOHq1', 'alphaOHq3', 'alphaOHu', 'alphaOHud', 'alphaOld', 'alphaOle', 'alphaOledq', 'alphaOlequ1', 'alphaOlequ3', 'alphaOll', 'alphaOlq1', 'alphaOlq3', 'alphaOlu', 'alphaOqd1', 'alphaOqd8', 'alphaOqe', 'alphaOqq1', 'alphaOqq3', 'alphaOqu1', 'alphaOqu8', 'alphaOquqd1', 'alphaOuB', 'alphaOud1', 'alphaOud8', 'alphaOuG', 'alphaOuH', 'alphaOuu', 'alphaOuW']

    def alphaO3G(self, ):
        return 1/2880 * (self.g3)**(3) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2)

    def alphaO3Gt(self, ):
        return 0

    def alphaO3W(self, ):
        return 1/1920 * (self.g2)**(3) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2)

    def alphaO3Wt(self, ):
        return 0

    def alphaOH(self, ):
        return (-1/320 * (self.g2)**(4) * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) + 1/16 * (self.lambdaHatPi7)**(3) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) + 3/32 * (self.lambdaHatPi7)**(2) * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) + 1/16 * self.lam * (self.lambdaHatPrimePi7)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) + 3/32 * self.lambdaHatPi7 * (self.lambdaHatPrimePi7)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) + 1/32 * (self.lambdaHatPrimePi7)**(3) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2))

    def alphaOHB(self, ):
        return (-49/1152 * (self.g1)**(2) * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) + -49/2304 * (self.g1)**(2) * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2))

    def alphaOHBox(self, ):
        return (-49/23040 * (self.g1)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) + -3/2560 * (self.g2)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) + -1/32 * (self.lambdaHatPi7)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) + -1/32 * self.lambdaHatPi7 * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2))

    def alphaOHBt(self, ):
        return 0

    def alphaOHD(self, ):
        return (-49/5760 * (self.g1)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) + -1/32 * (self.lambdaHatPrimePi7)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2))

    def alphaOHG(self, ):
        return (-1/192 * (self.g3)**(2) * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) + -1/384 * (self.g3)**(2) * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2))

    def alphaOHGt(self, ):
        return 0

    def alphaOHW(self, ):
        return (-1/128 * (self.g2)**(2) * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) + -1/256 * (self.g2)**(2) * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2))

    def alphaOHWB(self, ):
        return -7/384 * self.g1 * self.g2 * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2)

    def alphaOHWBt(self, ):
        return 0

    def alphaOHWt(self, ):
        return 0

    def alphaWeinberg(self, mif1,mif2):
        return 0

    def alphaOdB(self, mif1,mif2):
        return (-19/2304 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[0,0] * self.yeqPi7bar[0,mif1] + -19/2304 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[0,1] * self.yeqPi7bar[0,mif1] + -19/2304 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[0,2] * self.yeqPi7bar[0,mif1] + -19/2304 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[1,0] * self.yeqPi7bar[1,mif1] + -19/2304 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[1,1] * self.yeqPi7bar[1,mif1] + -19/2304 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[1,2] * self.yeqPi7bar[1,mif1] + -19/2304 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[2,0] * self.yeqPi7bar[2,mif1] + -19/2304 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[2,1] * self.yeqPi7bar[2,mif1] + -19/2304 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[2,2] * self.yeqPi7bar[2,mif1])

    def alphaOdd(self, mif1,mif2,mif3,mif4):
        return (-1/1920 * (self.g3)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.kronecker_delta(mif2,mif3) + -49/51840 * (self.g1)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 1/5760 * (self.g3)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4))

    def alphaOdG(self, mif1,mif2):
        return (-1/384 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[0,0] * self.yeqPi7bar[0,mif1] + -1/384 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[0,1] * self.yeqPi7bar[0,mif1] + -1/384 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[0,2] * self.yeqPi7bar[0,mif1] + -1/384 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[1,0] * self.yeqPi7bar[1,mif1] + -1/384 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[1,1] * self.yeqPi7bar[1,mif1] + -1/384 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[1,2] * self.yeqPi7bar[1,mif1] + -1/384 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[2,0] * self.yeqPi7bar[2,mif1] + -1/384 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[2,1] * self.yeqPi7bar[2,mif1] + -1/384 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[2,2] * self.yeqPi7bar[2,mif1])

    def alphaOdH(self, mif1,mif2):
        return (-1/1280 * (self.g2)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,mif2] + 1/64 * (self.lambdaHatPrimePi7)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,mif2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yeqPi7[0,0] * self.yeqPi7bar[0,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yeqPi7[0,0] * self.yeqPi7bar[0,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yeqPi7[0,0] * self.yeqPi7bar[0,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yeqPi7[0,1] * self.yeqPi7bar[0,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yeqPi7[0,1] * self.yeqPi7bar[0,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yeqPi7[0,1] * self.yeqPi7bar[0,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yeqPi7[0,2] * self.yeqPi7bar[0,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yeqPi7[0,2] * self.yeqPi7bar[0,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yeqPi7[0,2] * self.yeqPi7bar[0,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yeqPi7[0,0] * self.yeqPi7bar[0,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yeqPi7[0,0] * self.yeqPi7bar[0,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yeqPi7[0,0] * self.yeqPi7bar[0,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yeqPi7[0,1] * self.yeqPi7bar[0,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yeqPi7[0,1] * self.yeqPi7bar[0,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yeqPi7[0,1] * self.yeqPi7bar[0,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yeqPi7[0,2] * self.yeqPi7bar[0,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yeqPi7[0,2] * self.yeqPi7bar[0,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yeqPi7[0,2] * self.yeqPi7bar[0,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yeqPi7[0,0] * self.yeqPi7bar[0,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yeqPi7[0,0] * self.yeqPi7bar[0,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yeqPi7[0,0] * self.yeqPi7bar[0,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yeqPi7[0,1] * self.yeqPi7bar[0,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yeqPi7[0,1] * self.yeqPi7bar[0,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yeqPi7[0,1] * self.yeqPi7bar[0,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yeqPi7[0,2] * self.yeqPi7bar[0,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yeqPi7[0,2] * self.yeqPi7bar[0,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yeqPi7[0,2] * self.yeqPi7bar[0,2] + 1/64 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[0,0] * self.yeqPi7bar[0,mif1] + 1/64 * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[0,0] * self.yeqPi7bar[0,mif1] + 1/64 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[0,1] * self.yeqPi7bar[0,mif1] + 1/64 * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[0,1] * self.yeqPi7bar[0,mif1] + 1/64 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[0,2] * self.yeqPi7bar[0,mif1] + 1/64 * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[0,2] * self.yeqPi7bar[0,mif1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yeqPi7[1,0] * self.yeqPi7bar[1,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yeqPi7[1,0] * self.yeqPi7bar[1,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yeqPi7[1,0] * self.yeqPi7bar[1,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yeqPi7[1,1] * self.yeqPi7bar[1,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yeqPi7[1,1] * self.yeqPi7bar[1,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yeqPi7[1,1] * self.yeqPi7bar[1,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yeqPi7[1,2] * self.yeqPi7bar[1,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yeqPi7[1,2] * self.yeqPi7bar[1,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yeqPi7[1,2] * self.yeqPi7bar[1,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yeqPi7[1,0] * self.yeqPi7bar[1,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yeqPi7[1,0] * self.yeqPi7bar[1,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yeqPi7[1,0] * self.yeqPi7bar[1,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yeqPi7[1,1] * self.yeqPi7bar[1,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yeqPi7[1,1] * self.yeqPi7bar[1,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yeqPi7[1,1] * self.yeqPi7bar[1,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yeqPi7[1,2] * self.yeqPi7bar[1,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yeqPi7[1,2] * self.yeqPi7bar[1,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yeqPi7[1,2] * self.yeqPi7bar[1,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yeqPi7[1,0] * self.yeqPi7bar[1,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yeqPi7[1,0] * self.yeqPi7bar[1,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yeqPi7[1,0] * self.yeqPi7bar[1,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yeqPi7[1,1] * self.yeqPi7bar[1,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yeqPi7[1,1] * self.yeqPi7bar[1,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yeqPi7[1,1] * self.yeqPi7bar[1,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yeqPi7[1,2] * self.yeqPi7bar[1,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yeqPi7[1,2] * self.yeqPi7bar[1,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yeqPi7[1,2] * self.yeqPi7bar[1,2] + 1/64 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[1,0] * self.yeqPi7bar[1,mif1] + 1/64 * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[1,0] * self.yeqPi7bar[1,mif1] + 1/64 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[1,1] * self.yeqPi7bar[1,mif1] + 1/64 * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[1,1] * self.yeqPi7bar[1,mif1] + 1/64 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[1,2] * self.yeqPi7bar[1,mif1] + 1/64 * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[1,2] * self.yeqPi7bar[1,mif1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yeqPi7[2,0] * self.yeqPi7bar[2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yeqPi7[2,0] * self.yeqPi7bar[2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yeqPi7[2,0] * self.yeqPi7bar[2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yeqPi7[2,1] * self.yeqPi7bar[2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yeqPi7[2,1] * self.yeqPi7bar[2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yeqPi7[2,1] * self.yeqPi7bar[2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yeqPi7[2,2] * self.yeqPi7bar[2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yeqPi7[2,2] * self.yeqPi7bar[2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yeqPi7[2,2] * self.yeqPi7bar[2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yeqPi7[2,0] * self.yeqPi7bar[2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yeqPi7[2,0] * self.yeqPi7bar[2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yeqPi7[2,0] * self.yeqPi7bar[2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yeqPi7[2,1] * self.yeqPi7bar[2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yeqPi7[2,1] * self.yeqPi7bar[2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yeqPi7[2,1] * self.yeqPi7bar[2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yeqPi7[2,2] * self.yeqPi7bar[2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yeqPi7[2,2] * self.yeqPi7bar[2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yeqPi7[2,2] * self.yeqPi7bar[2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yeqPi7[2,0] * self.yeqPi7bar[2,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yeqPi7[2,0] * self.yeqPi7bar[2,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yeqPi7[2,0] * self.yeqPi7bar[2,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yeqPi7[2,1] * self.yeqPi7bar[2,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yeqPi7[2,1] * self.yeqPi7bar[2,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yeqPi7[2,1] * self.yeqPi7bar[2,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yeqPi7[2,2] * self.yeqPi7bar[2,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yeqPi7[2,2] * self.yeqPi7bar[2,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yeqPi7[2,2] * self.yeqPi7bar[2,2] + 1/64 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[2,0] * self.yeqPi7bar[2,mif1] + 1/64 * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[2,0] * self.yeqPi7bar[2,mif1] + 1/64 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[2,1] * self.yeqPi7bar[2,mif1] + 1/64 * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[2,1] * self.yeqPi7bar[2,mif1] + 1/64 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[2,2] * self.yeqPi7bar[2,mif1] + 1/64 * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[2,2] * self.yeqPi7bar[2,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[0,0] * self.yeqPi7bar[0,mif1] * self.yl[0,0] * self.ylbar[0,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[0,1] * self.yeqPi7bar[0,mif1] * self.yl[0,0] * self.ylbar[0,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[0,2] * self.yeqPi7bar[0,mif1] * self.yl[0,0] * self.ylbar[0,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[1,0] * self.yeqPi7bar[0,mif1] * self.yl[0,1] * self.ylbar[0,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[1,1] * self.yeqPi7bar[0,mif1] * self.yl[0,1] * self.ylbar[0,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[1,2] * self.yeqPi7bar[0,mif1] * self.yl[0,1] * self.ylbar[0,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[2,0] * self.yeqPi7bar[0,mif1] * self.yl[0,2] * self.ylbar[0,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[2,1] * self.yeqPi7bar[0,mif1] * self.yl[0,2] * self.ylbar[0,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[2,2] * self.yeqPi7bar[0,mif1] * self.yl[0,2] * self.ylbar[0,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[0,0] * self.yeqPi7bar[1,mif1] * self.yl[0,0] * self.ylbar[0,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[0,1] * self.yeqPi7bar[1,mif1] * self.yl[0,0] * self.ylbar[0,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[0,2] * self.yeqPi7bar[1,mif1] * self.yl[0,0] * self.ylbar[0,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[1,0] * self.yeqPi7bar[1,mif1] * self.yl[0,1] * self.ylbar[0,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[1,1] * self.yeqPi7bar[1,mif1] * self.yl[0,1] * self.ylbar[0,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[1,2] * self.yeqPi7bar[1,mif1] * self.yl[0,1] * self.ylbar[0,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[2,0] * self.yeqPi7bar[1,mif1] * self.yl[0,2] * self.ylbar[0,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[2,1] * self.yeqPi7bar[1,mif1] * self.yl[0,2] * self.ylbar[0,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[2,2] * self.yeqPi7bar[1,mif1] * self.yl[0,2] * self.ylbar[0,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[0,0] * self.yeqPi7bar[2,mif1] * self.yl[0,0] * self.ylbar[0,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[0,1] * self.yeqPi7bar[2,mif1] * self.yl[0,0] * self.ylbar[0,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[0,2] * self.yeqPi7bar[2,mif1] * self.yl[0,0] * self.ylbar[0,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[1,0] * self.yeqPi7bar[2,mif1] * self.yl[0,1] * self.ylbar[0,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[1,1] * self.yeqPi7bar[2,mif1] * self.yl[0,1] * self.ylbar[0,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[1,2] * self.yeqPi7bar[2,mif1] * self.yl[0,1] * self.ylbar[0,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[2,0] * self.yeqPi7bar[2,mif1] * self.yl[0,2] * self.ylbar[0,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[2,1] * self.yeqPi7bar[2,mif1] * self.yl[0,2] * self.ylbar[0,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[2,2] * self.yeqPi7bar[2,mif1] * self.yl[0,2] * self.ylbar[0,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[0,0] * self.yeqPi7bar[0,mif1] * self.yl[1,0] * self.ylbar[1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[0,1] * self.yeqPi7bar[0,mif1] * self.yl[1,0] * self.ylbar[1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[0,2] * self.yeqPi7bar[0,mif1] * self.yl[1,0] * self.ylbar[1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[1,0] * self.yeqPi7bar[0,mif1] * self.yl[1,1] * self.ylbar[1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[1,1] * self.yeqPi7bar[0,mif1] * self.yl[1,1] * self.ylbar[1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[1,2] * self.yeqPi7bar[0,mif1] * self.yl[1,1] * self.ylbar[1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[2,0] * self.yeqPi7bar[0,mif1] * self.yl[1,2] * self.ylbar[1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[2,1] * self.yeqPi7bar[0,mif1] * self.yl[1,2] * self.ylbar[1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[2,2] * self.yeqPi7bar[0,mif1] * self.yl[1,2] * self.ylbar[1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[0,0] * self.yeqPi7bar[1,mif1] * self.yl[1,0] * self.ylbar[1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[0,1] * self.yeqPi7bar[1,mif1] * self.yl[1,0] * self.ylbar[1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[0,2] * self.yeqPi7bar[1,mif1] * self.yl[1,0] * self.ylbar[1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[1,0] * self.yeqPi7bar[1,mif1] * self.yl[1,1] * self.ylbar[1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[1,1] * self.yeqPi7bar[1,mif1] * self.yl[1,1] * self.ylbar[1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[1,2] * self.yeqPi7bar[1,mif1] * self.yl[1,1] * self.ylbar[1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[2,0] * self.yeqPi7bar[1,mif1] * self.yl[1,2] * self.ylbar[1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[2,1] * self.yeqPi7bar[1,mif1] * self.yl[1,2] * self.ylbar[1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[2,2] * self.yeqPi7bar[1,mif1] * self.yl[1,2] * self.ylbar[1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[0,0] * self.yeqPi7bar[2,mif1] * self.yl[1,0] * self.ylbar[1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[0,1] * self.yeqPi7bar[2,mif1] * self.yl[1,0] * self.ylbar[1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[0,2] * self.yeqPi7bar[2,mif1] * self.yl[1,0] * self.ylbar[1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[1,0] * self.yeqPi7bar[2,mif1] * self.yl[1,1] * self.ylbar[1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[1,1] * self.yeqPi7bar[2,mif1] * self.yl[1,1] * self.ylbar[1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[1,2] * self.yeqPi7bar[2,mif1] * self.yl[1,1] * self.ylbar[1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[2,0] * self.yeqPi7bar[2,mif1] * self.yl[1,2] * self.ylbar[1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[2,1] * self.yeqPi7bar[2,mif1] * self.yl[1,2] * self.ylbar[1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[2,2] * self.yeqPi7bar[2,mif1] * self.yl[1,2] * self.ylbar[1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[0,0] * self.yeqPi7bar[0,mif1] * self.yl[2,0] * self.ylbar[2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[0,1] * self.yeqPi7bar[0,mif1] * self.yl[2,0] * self.ylbar[2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[0,2] * self.yeqPi7bar[0,mif1] * self.yl[2,0] * self.ylbar[2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[1,0] * self.yeqPi7bar[0,mif1] * self.yl[2,1] * self.ylbar[2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[1,1] * self.yeqPi7bar[0,mif1] * self.yl[2,1] * self.ylbar[2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[1,2] * self.yeqPi7bar[0,mif1] * self.yl[2,1] * self.ylbar[2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[2,0] * self.yeqPi7bar[0,mif1] * self.yl[2,2] * self.ylbar[2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[2,1] * self.yeqPi7bar[0,mif1] * self.yl[2,2] * self.ylbar[2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[2,2] * self.yeqPi7bar[0,mif1] * self.yl[2,2] * self.ylbar[2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[0,0] * self.yeqPi7bar[1,mif1] * self.yl[2,0] * self.ylbar[2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[0,1] * self.yeqPi7bar[1,mif1] * self.yl[2,0] * self.ylbar[2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[0,2] * self.yeqPi7bar[1,mif1] * self.yl[2,0] * self.ylbar[2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[1,0] * self.yeqPi7bar[1,mif1] * self.yl[2,1] * self.ylbar[2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[1,1] * self.yeqPi7bar[1,mif1] * self.yl[2,1] * self.ylbar[2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[1,2] * self.yeqPi7bar[1,mif1] * self.yl[2,1] * self.ylbar[2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[2,0] * self.yeqPi7bar[1,mif1] * self.yl[2,2] * self.ylbar[2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[2,1] * self.yeqPi7bar[1,mif1] * self.yl[2,2] * self.ylbar[2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[2,2] * self.yeqPi7bar[1,mif1] * self.yl[2,2] * self.ylbar[2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[0,0] * self.yeqPi7bar[2,mif1] * self.yl[2,0] * self.ylbar[2,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[0,1] * self.yeqPi7bar[2,mif1] * self.yl[2,0] * self.ylbar[2,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[0,2] * self.yeqPi7bar[2,mif1] * self.yl[2,0] * self.ylbar[2,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[1,0] * self.yeqPi7bar[2,mif1] * self.yl[2,1] * self.ylbar[2,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[1,1] * self.yeqPi7bar[2,mif1] * self.yl[2,1] * self.ylbar[2,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[1,2] * self.yeqPi7bar[2,mif1] * self.yl[2,1] * self.ylbar[2,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[2,0] * self.yeqPi7bar[2,mif1] * self.yl[2,2] * self.ylbar[2,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[2,1] * self.yeqPi7bar[2,mif1] * self.yl[2,2] * self.ylbar[2,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[2,2] * self.yeqPi7bar[2,mif1] * self.yl[2,2] * self.ylbar[2,2])

    def alphaOdW(self, mif1,mif2):
        return (-1/768 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[0,0] * self.yeqPi7bar[0,mif1] + -1/768 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[0,1] * self.yeqPi7bar[0,mif1] + -1/768 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[0,2] * self.yeqPi7bar[0,mif1] + -1/768 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[1,0] * self.yeqPi7bar[1,mif1] + -1/768 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[1,1] * self.yeqPi7bar[1,mif1] + -1/768 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[1,2] * self.yeqPi7bar[1,mif1] + -1/768 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[2,0] * self.yeqPi7bar[2,mif1] + -1/768 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[2,1] * self.yeqPi7bar[2,mif1] + -1/768 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[2,2] * self.yeqPi7bar[2,mif1])

    def alphaOeB(self, mif1,mif2):
        return (3/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] + 3/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] + 3/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] + 3/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] + 3/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] + 3/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] + 3/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] + 3/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] + 3/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] + 5/256 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[0,0] + 5/256 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[0,1] + 5/256 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[0,2] + 5/256 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[1,0] + 5/256 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[1,1] + 5/256 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[1,2] + 5/256 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[2,0] + 5/256 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[2,1] + 5/256 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[2,2] + -11/256 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[0,0] + -5/128 * self.g1 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[0,0] + 5/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.xRP * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[0,0] + 5/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[0,0] + -11/256 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[0,1] + -5/128 * self.g1 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[0,1] + 5/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.xRP * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[0,1] + 5/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[0,1] + -11/256 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[0,2] + -5/128 * self.g1 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[0,2] + 5/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.xRP * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[0,2] + 5/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[0,2] + -11/256 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[1,0] + -5/128 * self.g1 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[1,0] + 5/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.xRP * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[1,0] + 5/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[1,0] + -11/256 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[1,1] + -5/128 * self.g1 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[1,1] + 5/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.xRP * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[1,1] + 5/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[1,1] + -11/256 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[1,2] + -5/128 * self.g1 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[1,2] + 5/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.xRP * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[1,2] + 5/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[1,2] + -11/256 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[2,0] + -5/128 * self.g1 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[2,0] + 5/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.xRP * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[2,0] + 5/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[2,0] + -11/256 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[2,1] + -5/128 * self.g1 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[2,1] + 5/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.xRP * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[2,1] + 5/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[2,1] + -11/256 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[2,2] + -5/128 * self.g1 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[2,2] + 5/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.xRP * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[2,2] + 5/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[2,2])

    def alphaOed(self, mif1,mif2,mif3,mif4):
        return (-49/8640 * (self.g1)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 5/288 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] + 1/144 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] + -1/144 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[0,mif3] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[0,mif3] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[0,mif4] * self.ydbar[0,mif3] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[0,mif3] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,0] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[0,mif3] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,0] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[1,mif4] * self.ydbar[0,mif3] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[0,mif3] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,0] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[0,mif3] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,0] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[2,mif4] * self.ydbar[0,mif3] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[1,mif3] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[1,mif3] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[0,mif4] * self.ydbar[1,mif3] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,1] + 5/288 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] + 1/144 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] + -1/144 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[1,mif3] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[1,mif3] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[1,mif4] * self.ydbar[1,mif3] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[1,mif3] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[1,mif3] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[2,mif4] * self.ydbar[1,mif3] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[2,mif3] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,2] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[2,mif3] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,2] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[0,mif4] * self.ydbar[2,mif3] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[2,mif3] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,2] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[2,mif3] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,2] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[1,mif4] * self.ydbar[2,mif3] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,2] + 5/288 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] + 1/144 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] + -1/144 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[2,mif3] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[2,mif3] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[2,mif4] * self.ydbar[2,mif3] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2])

    def alphaOee(self, mif1,mif2,mif3,mif4):
        return (-49/5760 * (self.g1)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 5/192 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] + 1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] + -1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] + 5/192 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] + 1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] + -1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] + 5/192 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] + 1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] + -1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] + 5/192 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[mif3,0] * self.yeqPi7bar[mif4,0] + 1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[mif3,0] * self.yeqPi7bar[mif4,0] + -1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif3,0] * self.yeqPi7bar[mif4,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7[mif3,0] * self.yeqPi7bar[mif2,0] * self.yeqPi7bar[mif4,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7[mif3,0] * self.yeqPi7bar[mif2,1] * self.yeqPi7bar[mif4,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7[mif3,0] * self.yeqPi7bar[mif2,2] * self.yeqPi7bar[mif4,0] + 5/192 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[mif3,1] * self.yeqPi7bar[mif4,1] + 1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[mif3,1] * self.yeqPi7bar[mif4,1] + -1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif3,1] * self.yeqPi7bar[mif4,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7[mif3,1] * self.yeqPi7bar[mif2,0] * self.yeqPi7bar[mif4,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7[mif3,1] * self.yeqPi7bar[mif2,1] * self.yeqPi7bar[mif4,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7[mif3,1] * self.yeqPi7bar[mif2,2] * self.yeqPi7bar[mif4,1] + 5/192 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[mif3,2] * self.yeqPi7bar[mif4,2] + 1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[mif3,2] * self.yeqPi7bar[mif4,2] + -1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif3,2] * self.yeqPi7bar[mif4,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7[mif3,2] * self.yeqPi7bar[mif2,0] * self.yeqPi7bar[mif4,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7[mif3,2] * self.yeqPi7bar[mif2,1] * self.yeqPi7bar[mif4,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7[mif3,2] * self.yeqPi7bar[mif2,2] * self.yeqPi7bar[mif4,2])

    def alphaOeH(self, mif1,mif2):
        return (3/32 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] + 3/64 * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,0] * self.yeqPi7[0,0] * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,1] * self.yeqPi7[0,0] * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,2] * self.yeqPi7[0,0] * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[0,0] * self.yeqPi7[0,1] * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[0,1] * self.yeqPi7[0,1] * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[0,2] * self.yeqPi7[0,1] * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[0,0] * self.yeqPi7[0,2] * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[0,1] * self.yeqPi7[0,2] * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[0,2] * self.yeqPi7[0,2] * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[1,0] * self.yeqPi7[0,0] * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[1,1] * self.yeqPi7[0,0] * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[1,2] * self.yeqPi7[0,0] * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] + 3/32 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] + 3/64 * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,0] * self.yeqPi7[0,1] * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,1] * self.yeqPi7[0,1] * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,2] * self.yeqPi7[0,1] * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[1,0] * self.yeqPi7[0,2] * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[1,1] * self.yeqPi7[0,2] * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[1,2] * self.yeqPi7[0,2] * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[2,0] * self.yeqPi7[0,0] * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[2,1] * self.yeqPi7[0,0] * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[2,2] * self.yeqPi7[0,0] * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[2,0] * self.yeqPi7[0,1] * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[2,1] * self.yeqPi7[0,1] * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[2,2] * self.yeqPi7[0,1] * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] + 3/32 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] + 3/64 * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,0] * self.yeqPi7[0,2] * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,1] * self.yeqPi7[0,2] * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,2] * self.yeqPi7[0,2] * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] + 3/32 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] + 3/64 * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,0] * self.yeqPi7[1,0] * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,1] * self.yeqPi7[1,0] * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,2] * self.yeqPi7[1,0] * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[0,0] * self.yeqPi7[1,1] * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[0,1] * self.yeqPi7[1,1] * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[0,2] * self.yeqPi7[1,1] * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[0,0] * self.yeqPi7[1,2] * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[0,1] * self.yeqPi7[1,2] * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[0,2] * self.yeqPi7[1,2] * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[1,0] * self.yeqPi7[1,0] * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[1,1] * self.yeqPi7[1,0] * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[1,2] * self.yeqPi7[1,0] * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] + 3/32 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] + 3/64 * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,0] * self.yeqPi7[1,1] * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,1] * self.yeqPi7[1,1] * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,2] * self.yeqPi7[1,1] * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[1,0] * self.yeqPi7[1,2] * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[1,1] * self.yeqPi7[1,2] * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[1,2] * self.yeqPi7[1,2] * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[2,0] * self.yeqPi7[1,0] * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[2,1] * self.yeqPi7[1,0] * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[2,2] * self.yeqPi7[1,0] * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[2,0] * self.yeqPi7[1,1] * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[2,1] * self.yeqPi7[1,1] * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[2,2] * self.yeqPi7[1,1] * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] + 3/32 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] + 3/64 * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,0] * self.yeqPi7[1,2] * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,1] * self.yeqPi7[1,2] * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,2] * self.yeqPi7[1,2] * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] + 3/32 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] + 3/64 * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,0] * self.yeqPi7[2,0] * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,1] * self.yeqPi7[2,0] * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,2] * self.yeqPi7[2,0] * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[0,0] * self.yeqPi7[2,1] * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[0,1] * self.yeqPi7[2,1] * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[0,2] * self.yeqPi7[2,1] * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[0,0] * self.yeqPi7[2,2] * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[0,1] * self.yeqPi7[2,2] * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[0,2] * self.yeqPi7[2,2] * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[1,0] * self.yeqPi7[2,0] * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[1,1] * self.yeqPi7[2,0] * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[1,2] * self.yeqPi7[2,0] * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] + 3/32 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] + 3/64 * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,0] * self.yeqPi7[2,1] * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,1] * self.yeqPi7[2,1] * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,2] * self.yeqPi7[2,1] * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[1,0] * self.yeqPi7[2,2] * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[1,1] * self.yeqPi7[2,2] * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[1,2] * self.yeqPi7[2,2] * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[2,0] * self.yeqPi7[2,0] * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[2,1] * self.yeqPi7[2,0] * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[2,2] * self.yeqPi7[2,0] * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[2,0] * self.yeqPi7[2,1] * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[2,1] * self.yeqPi7[2,1] * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[2,2] * self.yeqPi7[2,1] * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] + 3/32 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] + 3/64 * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,0] * self.yeqPi7[2,2] * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,1] * self.yeqPi7[2,2] * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,2] * self.yeqPi7[2,2] * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] + -1/1280 * (self.g2)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,mif2] + 1/64 * (self.lambdaHatPrimePi7)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,mif2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[0,0] * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[0,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[0,1] * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[0,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[0,2] * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[0,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[0,0] * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[0,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[0,1] * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[0,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[0,2] * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[0,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[0,0] * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[0,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[0,1] * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[0,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[0,2] * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[0,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[1,0] * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[0,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[1,1] * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[0,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[1,2] * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[0,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[1,0] * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[0,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[1,1] * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[0,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[1,2] * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[0,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[1,0] * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[0,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[1,1] * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[0,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[1,2] * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[0,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[2,0] * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[0,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[2,1] * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[0,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[2,2] * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[0,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[2,0] * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[0,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[2,1] * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[0,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[2,2] * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[0,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[2,0] * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[0,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[2,1] * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[0,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[2,2] * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[0,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[0,0] * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[1,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[0,1] * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[1,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[0,2] * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[1,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[0,0] * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[1,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[0,1] * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[1,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[0,2] * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[1,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[0,0] * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[1,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[0,1] * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[1,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[0,2] * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[1,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[1,0] * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[1,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[1,1] * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[1,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[1,2] * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[1,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[1,0] * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[1,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[1,1] * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[1,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[1,2] * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[1,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[1,0] * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[1,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[1,1] * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[1,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[1,2] * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[1,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[2,0] * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[1,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[2,1] * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[1,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[2,2] * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[1,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[2,0] * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[1,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[2,1] * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[1,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[2,2] * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[1,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[2,0] * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[1,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[2,1] * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[1,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[2,2] * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[1,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[0,0] * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[2,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[0,1] * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[2,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[0,2] * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[2,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[0,0] * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[2,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[0,1] * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[2,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[0,2] * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[2,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[0,0] * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[2,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[0,1] * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[2,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[0,2] * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[2,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[1,0] * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[2,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[1,1] * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[2,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[1,2] * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[2,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[1,0] * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[2,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[1,1] * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[2,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[1,2] * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[2,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[1,0] * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[2,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[1,1] * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[2,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[1,2] * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[2,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[2,0] * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[2,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[2,1] * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[2,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[2,2] * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[2,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[2,0] * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[2,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[2,1] * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[2,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[2,2] * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[2,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[2,0] * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[2,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[2,1] * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[2,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[2,2] * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[0,0] * self.yluPi7[0,0] * self.yluPi7bar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[0,1] * self.yluPi7[0,0] * self.yluPi7bar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[0,2] * self.yluPi7[0,0] * self.yluPi7bar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[1,0] * self.yluPi7[1,0] * self.yluPi7bar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[1,1] * self.yluPi7[1,0] * self.yluPi7bar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[1,2] * self.yluPi7[1,0] * self.yluPi7bar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[2,0] * self.yluPi7[2,0] * self.yluPi7bar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[2,1] * self.yluPi7[2,0] * self.yluPi7bar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[2,2] * self.yluPi7[2,0] * self.yluPi7bar[0,0] + 3/64 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[0,0] * self.yluPi7[0,1] * self.yluPi7bar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[0,1] * self.yluPi7[0,1] * self.yluPi7bar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[0,2] * self.yluPi7[0,1] * self.yluPi7bar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[1,0] * self.yluPi7[1,1] * self.yluPi7bar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[1,1] * self.yluPi7[1,1] * self.yluPi7bar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[1,2] * self.yluPi7[1,1] * self.yluPi7bar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[2,0] * self.yluPi7[2,1] * self.yluPi7bar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[2,1] * self.yluPi7[2,1] * self.yluPi7bar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[2,2] * self.yluPi7[2,1] * self.yluPi7bar[0,1] + 3/64 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[0,0] * self.yluPi7[0,2] * self.yluPi7bar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[0,1] * self.yluPi7[0,2] * self.yluPi7bar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[0,2] * self.yluPi7[0,2] * self.yluPi7bar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[1,0] * self.yluPi7[1,2] * self.yluPi7bar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[1,1] * self.yluPi7[1,2] * self.yluPi7bar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[1,2] * self.yluPi7[1,2] * self.yluPi7bar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[2,0] * self.yluPi7[2,2] * self.yluPi7bar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[2,1] * self.yluPi7[2,2] * self.yluPi7bar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[2,2] * self.yluPi7[2,2] * self.yluPi7bar[0,2] + 3/64 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[0,0] * self.yluPi7[0,0] * self.yluPi7bar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[0,1] * self.yluPi7[0,0] * self.yluPi7bar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[0,2] * self.yluPi7[0,0] * self.yluPi7bar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[1,0] * self.yluPi7[1,0] * self.yluPi7bar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[1,1] * self.yluPi7[1,0] * self.yluPi7bar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[1,2] * self.yluPi7[1,0] * self.yluPi7bar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[2,0] * self.yluPi7[2,0] * self.yluPi7bar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[2,1] * self.yluPi7[2,0] * self.yluPi7bar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[2,2] * self.yluPi7[2,0] * self.yluPi7bar[1,0] + 3/64 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[0,0] * self.yluPi7[0,1] * self.yluPi7bar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[0,1] * self.yluPi7[0,1] * self.yluPi7bar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[0,2] * self.yluPi7[0,1] * self.yluPi7bar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[1,0] * self.yluPi7[1,1] * self.yluPi7bar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[1,1] * self.yluPi7[1,1] * self.yluPi7bar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[1,2] * self.yluPi7[1,1] * self.yluPi7bar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[2,0] * self.yluPi7[2,1] * self.yluPi7bar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[2,1] * self.yluPi7[2,1] * self.yluPi7bar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[2,2] * self.yluPi7[2,1] * self.yluPi7bar[1,1] + 3/64 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[0,0] * self.yluPi7[0,2] * self.yluPi7bar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[0,1] * self.yluPi7[0,2] * self.yluPi7bar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[0,2] * self.yluPi7[0,2] * self.yluPi7bar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[1,0] * self.yluPi7[1,2] * self.yluPi7bar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[1,1] * self.yluPi7[1,2] * self.yluPi7bar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[1,2] * self.yluPi7[1,2] * self.yluPi7bar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[2,0] * self.yluPi7[2,2] * self.yluPi7bar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[2,1] * self.yluPi7[2,2] * self.yluPi7bar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[2,2] * self.yluPi7[2,2] * self.yluPi7bar[1,2] + 3/64 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[0,0] * self.yluPi7[0,0] * self.yluPi7bar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[0,1] * self.yluPi7[0,0] * self.yluPi7bar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[0,2] * self.yluPi7[0,0] * self.yluPi7bar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[1,0] * self.yluPi7[1,0] * self.yluPi7bar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[1,1] * self.yluPi7[1,0] * self.yluPi7bar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[1,2] * self.yluPi7[1,0] * self.yluPi7bar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[2,0] * self.yluPi7[2,0] * self.yluPi7bar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[2,1] * self.yluPi7[2,0] * self.yluPi7bar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[2,2] * self.yluPi7[2,0] * self.yluPi7bar[2,0] + 3/64 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[0,0] * self.yluPi7[0,1] * self.yluPi7bar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[0,1] * self.yluPi7[0,1] * self.yluPi7bar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[0,2] * self.yluPi7[0,1] * self.yluPi7bar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[1,0] * self.yluPi7[1,1] * self.yluPi7bar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[1,1] * self.yluPi7[1,1] * self.yluPi7bar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[1,2] * self.yluPi7[1,1] * self.yluPi7bar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[2,0] * self.yluPi7[2,1] * self.yluPi7bar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[2,1] * self.yluPi7[2,1] * self.yluPi7bar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[2,2] * self.yluPi7[2,1] * self.yluPi7bar[2,1] + 3/64 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[0,0] * self.yluPi7[0,2] * self.yluPi7bar[2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[0,1] * self.yluPi7[0,2] * self.yluPi7bar[2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[0,2] * self.yluPi7[0,2] * self.yluPi7bar[2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[1,0] * self.yluPi7[1,2] * self.yluPi7bar[2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[1,1] * self.yluPi7[1,2] * self.yluPi7bar[2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[1,2] * self.yluPi7[1,2] * self.yluPi7bar[2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[2,0] * self.yluPi7[2,2] * self.yluPi7bar[2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[2,1] * self.yluPi7[2,2] * self.yluPi7bar[2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[2,2] * self.yluPi7[2,2] * self.yluPi7bar[2,2] + 3/64 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[2,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] * self.ylbar[0,0] * self.yluPi7[0,0] * self.yubar[0,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] * self.ylbar[0,1] * self.yluPi7[0,0] * self.yubar[0,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] * self.ylbar[0,2] * self.yluPi7[0,0] * self.yubar[0,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] * self.ylbar[1,0] * self.yluPi7[1,0] * self.yubar[0,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] * self.ylbar[1,1] * self.yluPi7[1,0] * self.yubar[0,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] * self.ylbar[1,2] * self.yluPi7[1,0] * self.yubar[0,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] * self.ylbar[2,0] * self.yluPi7[2,0] * self.yubar[0,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] * self.ylbar[2,1] * self.yluPi7[2,0] * self.yubar[0,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] * self.ylbar[2,2] * self.yluPi7[2,0] * self.yubar[0,0] + -9/32 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[0,0] + -3/16 * self.invepsilonbar * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[0,0] + 3/16 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[0,0] + 3/16 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[0,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,0] * self.yl[0,mif2] * self.ylbar[0,0] * self.yluPi7[mif1,0] * self.yubar[0,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,0] * self.yl[0,mif2] * self.ylbar[0,1] * self.yluPi7[mif1,0] * self.yubar[0,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,0] * self.yl[0,mif2] * self.ylbar[0,2] * self.yluPi7[mif1,0] * self.yubar[0,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,0] * self.yl[1,mif2] * self.ylbar[1,0] * self.yluPi7[mif1,0] * self.yubar[0,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,0] * self.yl[1,mif2] * self.ylbar[1,1] * self.yluPi7[mif1,0] * self.yubar[0,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,0] * self.yl[1,mif2] * self.ylbar[1,2] * self.yluPi7[mif1,0] * self.yubar[0,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,0] * self.yl[2,mif2] * self.ylbar[2,0] * self.yluPi7[mif1,0] * self.yubar[0,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,0] * self.yl[2,mif2] * self.ylbar[2,1] * self.yluPi7[mif1,0] * self.yubar[0,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,0] * self.yl[2,mif2] * self.ylbar[2,2] * self.yluPi7[mif1,0] * self.yubar[0,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] * self.yu[0,0] * self.yubar[0,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] * self.yu[0,0] * self.yubar[0,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] * self.yu[0,0] * self.yubar[0,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[0,0] * self.yu[0,0] * self.yubar[0,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[1,0] * self.yu[0,0] * self.yubar[0,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[2,0] * self.yu[0,0] * self.yubar[0,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[0,1] * self.yu[0,1] * self.yubar[0,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[1,1] * self.yu[0,1] * self.yubar[0,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[2,1] * self.yu[0,1] * self.yubar[0,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[0,2] * self.yu[0,2] * self.yubar[0,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[1,2] * self.yu[0,2] * self.yubar[0,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[2,2] * self.yu[0,2] * self.yubar[0,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] * self.yu[1,0] * self.yubar[0,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] * self.yu[1,0] * self.yubar[0,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] * self.yu[1,0] * self.yubar[0,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] * self.yu[2,0] * self.yubar[0,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] * self.yu[2,0] * self.yubar[0,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] * self.yu[2,0] * self.yubar[0,0] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[0,0] * (self.yubar[0,0])**(2) + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[0,0] * (self.yubar[0,0])**(2) + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[0,0] * (self.yubar[0,0])**(2) + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] * self.ylbar[0,0] * self.yluPi7[0,1] * self.yubar[0,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] * self.ylbar[0,1] * self.yluPi7[0,1] * self.yubar[0,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] * self.ylbar[0,2] * self.yluPi7[0,1] * self.yubar[0,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] * self.ylbar[1,0] * self.yluPi7[1,1] * self.yubar[0,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] * self.ylbar[1,1] * self.yluPi7[1,1] * self.yubar[0,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] * self.ylbar[1,2] * self.yluPi7[1,1] * self.yubar[0,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] * self.ylbar[2,0] * self.yluPi7[2,1] * self.yubar[0,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] * self.ylbar[2,1] * self.yluPi7[2,1] * self.yubar[0,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] * self.ylbar[2,2] * self.yluPi7[2,1] * self.yubar[0,1] + -9/32 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[0,1] + -3/16 * self.invepsilonbar * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[0,1] + 3/16 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[0,1] + 3/16 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[0,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,0] * self.yl[0,mif2] * self.ylbar[0,0] * self.yluPi7[mif1,1] * self.yubar[0,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,0] * self.yl[0,mif2] * self.ylbar[0,1] * self.yluPi7[mif1,1] * self.yubar[0,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,0] * self.yl[0,mif2] * self.ylbar[0,2] * self.yluPi7[mif1,1] * self.yubar[0,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,0] * self.yl[1,mif2] * self.ylbar[1,0] * self.yluPi7[mif1,1] * self.yubar[0,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,0] * self.yl[1,mif2] * self.ylbar[1,1] * self.yluPi7[mif1,1] * self.yubar[0,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,0] * self.yl[1,mif2] * self.ylbar[1,2] * self.yluPi7[mif1,1] * self.yubar[0,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,0] * self.yl[2,mif2] * self.ylbar[2,0] * self.yluPi7[mif1,1] * self.yubar[0,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,0] * self.yl[2,mif2] * self.ylbar[2,1] * self.yluPi7[mif1,1] * self.yubar[0,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,0] * self.yl[2,mif2] * self.ylbar[2,2] * self.yluPi7[mif1,1] * self.yubar[0,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[0,0] * self.yu[0,0] * self.yubar[0,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[1,0] * self.yu[0,0] * self.yubar[0,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[2,0] * self.yu[0,0] * self.yubar[0,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] * self.yu[0,1] * self.yubar[0,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] * self.yu[0,1] * self.yubar[0,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] * self.yu[0,1] * self.yubar[0,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[0,1] * self.yu[0,1] * self.yubar[0,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[1,1] * self.yu[0,1] * self.yubar[0,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[2,1] * self.yu[0,1] * self.yubar[0,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[0,2] * self.yu[0,2] * self.yubar[0,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[1,2] * self.yu[0,2] * self.yubar[0,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[2,2] * self.yu[0,2] * self.yubar[0,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] * self.yu[1,1] * self.yubar[0,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] * self.yu[1,1] * self.yubar[0,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] * self.yu[1,1] * self.yubar[0,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] * self.yu[2,1] * self.yubar[0,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] * self.yu[2,1] * self.yubar[0,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] * self.yu[2,1] * self.yubar[0,1] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[0,0] * self.yubar[0,0] * self.yubar[0,1] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[0,0] * self.yubar[0,0] * self.yubar[0,1] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[0,0] * self.yubar[0,0] * self.yubar[0,1] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[0,1] * self.yubar[0,0] * self.yubar[0,1] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[0,1] * self.yubar[0,0] * self.yubar[0,1] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[0,1] * self.yubar[0,0] * self.yubar[0,1] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[0,1] * (self.yubar[0,1])**(2) + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[0,1] * (self.yubar[0,1])**(2) + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[0,1] * (self.yubar[0,1])**(2) + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] * self.ylbar[0,0] * self.yluPi7[0,2] * self.yubar[0,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] * self.ylbar[0,1] * self.yluPi7[0,2] * self.yubar[0,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] * self.ylbar[0,2] * self.yluPi7[0,2] * self.yubar[0,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] * self.ylbar[1,0] * self.yluPi7[1,2] * self.yubar[0,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] * self.ylbar[1,1] * self.yluPi7[1,2] * self.yubar[0,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] * self.ylbar[1,2] * self.yluPi7[1,2] * self.yubar[0,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] * self.ylbar[2,0] * self.yluPi7[2,2] * self.yubar[0,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] * self.ylbar[2,1] * self.yluPi7[2,2] * self.yubar[0,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] * self.ylbar[2,2] * self.yluPi7[2,2] * self.yubar[0,2] + -9/32 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[0,2] + -3/16 * self.invepsilonbar * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[0,2] + 3/16 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[0,2] + 3/16 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[0,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,0] * self.yl[0,mif2] * self.ylbar[0,0] * self.yluPi7[mif1,2] * self.yubar[0,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,0] * self.yl[0,mif2] * self.ylbar[0,1] * self.yluPi7[mif1,2] * self.yubar[0,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,0] * self.yl[0,mif2] * self.ylbar[0,2] * self.yluPi7[mif1,2] * self.yubar[0,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,0] * self.yl[1,mif2] * self.ylbar[1,0] * self.yluPi7[mif1,2] * self.yubar[0,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,0] * self.yl[1,mif2] * self.ylbar[1,1] * self.yluPi7[mif1,2] * self.yubar[0,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,0] * self.yl[1,mif2] * self.ylbar[1,2] * self.yluPi7[mif1,2] * self.yubar[0,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,0] * self.yl[2,mif2] * self.ylbar[2,0] * self.yluPi7[mif1,2] * self.yubar[0,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,0] * self.yl[2,mif2] * self.ylbar[2,1] * self.yluPi7[mif1,2] * self.yubar[0,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,0] * self.yl[2,mif2] * self.ylbar[2,2] * self.yluPi7[mif1,2] * self.yubar[0,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[0,0] * self.yu[0,0] * self.yubar[0,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[1,0] * self.yu[0,0] * self.yubar[0,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[2,0] * self.yu[0,0] * self.yubar[0,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[0,1] * self.yu[0,1] * self.yubar[0,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[1,1] * self.yu[0,1] * self.yubar[0,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[2,1] * self.yu[0,1] * self.yubar[0,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] * self.yu[0,2] * self.yubar[0,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] * self.yu[0,2] * self.yubar[0,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] * self.yu[0,2] * self.yubar[0,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[0,2] * self.yu[0,2] * self.yubar[0,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[1,2] * self.yu[0,2] * self.yubar[0,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[2,2] * self.yu[0,2] * self.yubar[0,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] * self.yu[1,2] * self.yubar[0,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] * self.yu[1,2] * self.yubar[0,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] * self.yu[1,2] * self.yubar[0,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] * self.yu[2,2] * self.yubar[0,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] * self.yu[2,2] * self.yubar[0,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] * self.yu[2,2] * self.yubar[0,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[0,0] * self.yubar[0,0] * self.yubar[0,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[0,0] * self.yubar[0,0] * self.yubar[0,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[0,0] * self.yubar[0,0] * self.yubar[0,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[0,2] * self.yubar[0,0] * self.yubar[0,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[0,2] * self.yubar[0,0] * self.yubar[0,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[0,2] * self.yubar[0,0] * self.yubar[0,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[0,1] * self.yubar[0,1] * self.yubar[0,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[0,1] * self.yubar[0,1] * self.yubar[0,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[0,1] * self.yubar[0,1] * self.yubar[0,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[0,2] * self.yubar[0,1] * self.yubar[0,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[0,2] * self.yubar[0,1] * self.yubar[0,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[0,2] * self.yubar[0,1] * self.yubar[0,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[0,2] * (self.yubar[0,2])**(2) + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[0,2] * (self.yubar[0,2])**(2) + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[0,2] * (self.yubar[0,2])**(2) + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] * self.ylbar[0,0] * self.yluPi7[0,0] * self.yubar[1,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] * self.ylbar[0,1] * self.yluPi7[0,0] * self.yubar[1,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] * self.ylbar[0,2] * self.yluPi7[0,0] * self.yubar[1,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] * self.ylbar[1,0] * self.yluPi7[1,0] * self.yubar[1,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] * self.ylbar[1,1] * self.yluPi7[1,0] * self.yubar[1,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] * self.ylbar[1,2] * self.yluPi7[1,0] * self.yubar[1,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] * self.ylbar[2,0] * self.yluPi7[2,0] * self.yubar[1,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] * self.ylbar[2,1] * self.yluPi7[2,0] * self.yubar[1,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] * self.ylbar[2,2] * self.yluPi7[2,0] * self.yubar[1,0] + -9/32 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[1,0] + -3/16 * self.invepsilonbar * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[1,0] + 3/16 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[1,0] + 3/16 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[1,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,1] * self.yl[0,mif2] * self.ylbar[0,0] * self.yluPi7[mif1,0] * self.yubar[1,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,1] * self.yl[0,mif2] * self.ylbar[0,1] * self.yluPi7[mif1,0] * self.yubar[1,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,1] * self.yl[0,mif2] * self.ylbar[0,2] * self.yluPi7[mif1,0] * self.yubar[1,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,1] * self.yl[1,mif2] * self.ylbar[1,0] * self.yluPi7[mif1,0] * self.yubar[1,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,1] * self.yl[1,mif2] * self.ylbar[1,1] * self.yluPi7[mif1,0] * self.yubar[1,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,1] * self.yl[1,mif2] * self.ylbar[1,2] * self.yluPi7[mif1,0] * self.yubar[1,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,1] * self.yl[2,mif2] * self.ylbar[2,0] * self.yluPi7[mif1,0] * self.yubar[1,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,1] * self.yl[2,mif2] * self.ylbar[2,1] * self.yluPi7[mif1,0] * self.yubar[1,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,1] * self.yl[2,mif2] * self.ylbar[2,2] * self.yluPi7[mif1,0] * self.yubar[1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] * self.yu[0,0] * self.yubar[1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] * self.yu[0,0] * self.yubar[1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] * self.yu[0,0] * self.yubar[1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] * self.yu[1,0] * self.yubar[1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] * self.yu[1,0] * self.yubar[1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] * self.yu[1,0] * self.yubar[1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[0,0] * self.yu[1,0] * self.yubar[1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[1,0] * self.yu[1,0] * self.yubar[1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[2,0] * self.yu[1,0] * self.yubar[1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[0,1] * self.yu[1,1] * self.yubar[1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[1,1] * self.yu[1,1] * self.yubar[1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[2,1] * self.yu[1,1] * self.yubar[1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[0,2] * self.yu[1,2] * self.yubar[1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[1,2] * self.yu[1,2] * self.yubar[1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[2,2] * self.yu[1,2] * self.yubar[1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] * self.yu[2,0] * self.yubar[1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] * self.yu[2,0] * self.yubar[1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] * self.yu[2,0] * self.yubar[1,0] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[0,0] * self.yubar[0,0] * self.yubar[1,0] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[0,0] * self.yubar[0,0] * self.yubar[1,0] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[0,0] * self.yubar[0,0] * self.yubar[1,0] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[1,0] * self.yubar[0,0] * self.yubar[1,0] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[1,0] * self.yubar[0,0] * self.yubar[1,0] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[1,0] * self.yubar[0,0] * self.yubar[1,0] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[0,0] * self.yubar[0,1] * self.yubar[1,0] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[0,0] * self.yubar[0,1] * self.yubar[1,0] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[0,0] * self.yubar[0,1] * self.yubar[1,0] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[1,1] * self.yubar[0,1] * self.yubar[1,0] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[1,1] * self.yubar[0,1] * self.yubar[1,0] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[1,1] * self.yubar[0,1] * self.yubar[1,0] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[0,0] * self.yubar[0,2] * self.yubar[1,0] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[0,0] * self.yubar[0,2] * self.yubar[1,0] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[0,0] * self.yubar[0,2] * self.yubar[1,0] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[1,2] * self.yubar[0,2] * self.yubar[1,0] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[1,2] * self.yubar[0,2] * self.yubar[1,0] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[1,2] * self.yubar[0,2] * self.yubar[1,0] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[1,0] * (self.yubar[1,0])**(2) + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[1,0] * (self.yubar[1,0])**(2) + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[1,0] * (self.yubar[1,0])**(2) + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] * self.ylbar[0,0] * self.yluPi7[0,1] * self.yubar[1,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] * self.ylbar[0,1] * self.yluPi7[0,1] * self.yubar[1,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] * self.ylbar[0,2] * self.yluPi7[0,1] * self.yubar[1,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] * self.ylbar[1,0] * self.yluPi7[1,1] * self.yubar[1,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] * self.ylbar[1,1] * self.yluPi7[1,1] * self.yubar[1,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] * self.ylbar[1,2] * self.yluPi7[1,1] * self.yubar[1,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] * self.ylbar[2,0] * self.yluPi7[2,1] * self.yubar[1,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] * self.ylbar[2,1] * self.yluPi7[2,1] * self.yubar[1,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] * self.ylbar[2,2] * self.yluPi7[2,1] * self.yubar[1,1] + -9/32 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[1,1] + -3/16 * self.invepsilonbar * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[1,1] + 3/16 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[1,1] + 3/16 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[1,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,1] * self.yl[0,mif2] * self.ylbar[0,0] * self.yluPi7[mif1,1] * self.yubar[1,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,1] * self.yl[0,mif2] * self.ylbar[0,1] * self.yluPi7[mif1,1] * self.yubar[1,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,1] * self.yl[0,mif2] * self.ylbar[0,2] * self.yluPi7[mif1,1] * self.yubar[1,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,1] * self.yl[1,mif2] * self.ylbar[1,0] * self.yluPi7[mif1,1] * self.yubar[1,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,1] * self.yl[1,mif2] * self.ylbar[1,1] * self.yluPi7[mif1,1] * self.yubar[1,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,1] * self.yl[1,mif2] * self.ylbar[1,2] * self.yluPi7[mif1,1] * self.yubar[1,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,1] * self.yl[2,mif2] * self.ylbar[2,0] * self.yluPi7[mif1,1] * self.yubar[1,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,1] * self.yl[2,mif2] * self.ylbar[2,1] * self.yluPi7[mif1,1] * self.yubar[1,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,1] * self.yl[2,mif2] * self.ylbar[2,2] * self.yluPi7[mif1,1] * self.yubar[1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] * self.yu[0,1] * self.yubar[1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] * self.yu[0,1] * self.yubar[1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] * self.yu[0,1] * self.yubar[1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[0,0] * self.yu[1,0] * self.yubar[1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[1,0] * self.yu[1,0] * self.yubar[1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[2,0] * self.yu[1,0] * self.yubar[1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] * self.yu[1,1] * self.yubar[1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] * self.yu[1,1] * self.yubar[1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] * self.yu[1,1] * self.yubar[1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[0,1] * self.yu[1,1] * self.yubar[1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[1,1] * self.yu[1,1] * self.yubar[1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[2,1] * self.yu[1,1] * self.yubar[1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[0,2] * self.yu[1,2] * self.yubar[1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[1,2] * self.yu[1,2] * self.yubar[1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[2,2] * self.yu[1,2] * self.yubar[1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] * self.yu[2,1] * self.yubar[1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] * self.yu[2,1] * self.yubar[1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] * self.yu[2,1] * self.yubar[1,1] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[0,1] * self.yubar[0,0] * self.yubar[1,1] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[0,1] * self.yubar[0,0] * self.yubar[1,1] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[0,1] * self.yubar[0,0] * self.yubar[1,1] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[1,0] * self.yubar[0,0] * self.yubar[1,1] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[1,0] * self.yubar[0,0] * self.yubar[1,1] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[1,0] * self.yubar[0,0] * self.yubar[1,1] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[0,1] * self.yubar[0,1] * self.yubar[1,1] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[0,1] * self.yubar[0,1] * self.yubar[1,1] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[0,1] * self.yubar[0,1] * self.yubar[1,1] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[1,1] * self.yubar[0,1] * self.yubar[1,1] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[1,1] * self.yubar[0,1] * self.yubar[1,1] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[1,1] * self.yubar[0,1] * self.yubar[1,1] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[0,1] * self.yubar[0,2] * self.yubar[1,1] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[0,1] * self.yubar[0,2] * self.yubar[1,1] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[0,1] * self.yubar[0,2] * self.yubar[1,1] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[1,2] * self.yubar[0,2] * self.yubar[1,1] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[1,2] * self.yubar[0,2] * self.yubar[1,1] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[1,2] * self.yubar[0,2] * self.yubar[1,1] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[1,0] * self.yubar[1,0] * self.yubar[1,1] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[1,0] * self.yubar[1,0] * self.yubar[1,1] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[1,0] * self.yubar[1,0] * self.yubar[1,1] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[1,1] * self.yubar[1,0] * self.yubar[1,1] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[1,1] * self.yubar[1,0] * self.yubar[1,1] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[1,1] * self.yubar[1,0] * self.yubar[1,1] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[1,1] * (self.yubar[1,1])**(2) + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[1,1] * (self.yubar[1,1])**(2) + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[1,1] * (self.yubar[1,1])**(2) + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] * self.ylbar[0,0] * self.yluPi7[0,2] * self.yubar[1,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] * self.ylbar[0,1] * self.yluPi7[0,2] * self.yubar[1,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] * self.ylbar[0,2] * self.yluPi7[0,2] * self.yubar[1,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] * self.ylbar[1,0] * self.yluPi7[1,2] * self.yubar[1,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] * self.ylbar[1,1] * self.yluPi7[1,2] * self.yubar[1,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] * self.ylbar[1,2] * self.yluPi7[1,2] * self.yubar[1,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] * self.ylbar[2,0] * self.yluPi7[2,2] * self.yubar[1,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] * self.ylbar[2,1] * self.yluPi7[2,2] * self.yubar[1,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] * self.ylbar[2,2] * self.yluPi7[2,2] * self.yubar[1,2] + -9/32 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[1,2] + -3/16 * self.invepsilonbar * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[1,2] + 3/16 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[1,2] + 3/16 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[1,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,1] * self.yl[0,mif2] * self.ylbar[0,0] * self.yluPi7[mif1,2] * self.yubar[1,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,1] * self.yl[0,mif2] * self.ylbar[0,1] * self.yluPi7[mif1,2] * self.yubar[1,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,1] * self.yl[0,mif2] * self.ylbar[0,2] * self.yluPi7[mif1,2] * self.yubar[1,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,1] * self.yl[1,mif2] * self.ylbar[1,0] * self.yluPi7[mif1,2] * self.yubar[1,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,1] * self.yl[1,mif2] * self.ylbar[1,1] * self.yluPi7[mif1,2] * self.yubar[1,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,1] * self.yl[1,mif2] * self.ylbar[1,2] * self.yluPi7[mif1,2] * self.yubar[1,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,1] * self.yl[2,mif2] * self.ylbar[2,0] * self.yluPi7[mif1,2] * self.yubar[1,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,1] * self.yl[2,mif2] * self.ylbar[2,1] * self.yluPi7[mif1,2] * self.yubar[1,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,1] * self.yl[2,mif2] * self.ylbar[2,2] * self.yluPi7[mif1,2] * self.yubar[1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] * self.yu[0,2] * self.yubar[1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] * self.yu[0,2] * self.yubar[1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] * self.yu[0,2] * self.yubar[1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[0,0] * self.yu[1,0] * self.yubar[1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[1,0] * self.yu[1,0] * self.yubar[1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[2,0] * self.yu[1,0] * self.yubar[1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[0,1] * self.yu[1,1] * self.yubar[1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[1,1] * self.yu[1,1] * self.yubar[1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[2,1] * self.yu[1,1] * self.yubar[1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] * self.yu[1,2] * self.yubar[1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] * self.yu[1,2] * self.yubar[1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] * self.yu[1,2] * self.yubar[1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[0,2] * self.yu[1,2] * self.yubar[1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[1,2] * self.yu[1,2] * self.yubar[1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[2,2] * self.yu[1,2] * self.yubar[1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] * self.yu[2,2] * self.yubar[1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] * self.yu[2,2] * self.yubar[1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] * self.yu[2,2] * self.yubar[1,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[0,2] * self.yubar[0,0] * self.yubar[1,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[0,2] * self.yubar[0,0] * self.yubar[1,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[0,2] * self.yubar[0,0] * self.yubar[1,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[1,0] * self.yubar[0,0] * self.yubar[1,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[1,0] * self.yubar[0,0] * self.yubar[1,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[1,0] * self.yubar[0,0] * self.yubar[1,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[0,2] * self.yubar[0,1] * self.yubar[1,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[0,2] * self.yubar[0,1] * self.yubar[1,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[0,2] * self.yubar[0,1] * self.yubar[1,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[1,1] * self.yubar[0,1] * self.yubar[1,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[1,1] * self.yubar[0,1] * self.yubar[1,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[1,1] * self.yubar[0,1] * self.yubar[1,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[0,2] * self.yubar[0,2] * self.yubar[1,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[0,2] * self.yubar[0,2] * self.yubar[1,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[0,2] * self.yubar[0,2] * self.yubar[1,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[1,2] * self.yubar[0,2] * self.yubar[1,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[1,2] * self.yubar[0,2] * self.yubar[1,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[1,2] * self.yubar[0,2] * self.yubar[1,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[1,0] * self.yubar[1,0] * self.yubar[1,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[1,0] * self.yubar[1,0] * self.yubar[1,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[1,0] * self.yubar[1,0] * self.yubar[1,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[1,2] * self.yubar[1,0] * self.yubar[1,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[1,2] * self.yubar[1,0] * self.yubar[1,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[1,2] * self.yubar[1,0] * self.yubar[1,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[1,1] * self.yubar[1,1] * self.yubar[1,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[1,1] * self.yubar[1,1] * self.yubar[1,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[1,1] * self.yubar[1,1] * self.yubar[1,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[1,2] * self.yubar[1,1] * self.yubar[1,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[1,2] * self.yubar[1,1] * self.yubar[1,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[1,2] * self.yubar[1,1] * self.yubar[1,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[1,2] * (self.yubar[1,2])**(2) + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[1,2] * (self.yubar[1,2])**(2) + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[1,2] * (self.yubar[1,2])**(2) + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] * self.ylbar[0,0] * self.yluPi7[0,0] * self.yubar[2,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] * self.ylbar[0,1] * self.yluPi7[0,0] * self.yubar[2,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] * self.ylbar[0,2] * self.yluPi7[0,0] * self.yubar[2,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] * self.ylbar[1,0] * self.yluPi7[1,0] * self.yubar[2,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] * self.ylbar[1,1] * self.yluPi7[1,0] * self.yubar[2,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] * self.ylbar[1,2] * self.yluPi7[1,0] * self.yubar[2,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] * self.ylbar[2,0] * self.yluPi7[2,0] * self.yubar[2,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] * self.ylbar[2,1] * self.yluPi7[2,0] * self.yubar[2,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] * self.ylbar[2,2] * self.yluPi7[2,0] * self.yubar[2,0] + -9/32 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[2,0] + -3/16 * self.invepsilonbar * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[2,0] + 3/16 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[2,0] + 3/16 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[2,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,2] * self.yl[0,mif2] * self.ylbar[0,0] * self.yluPi7[mif1,0] * self.yubar[2,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,2] * self.yl[0,mif2] * self.ylbar[0,1] * self.yluPi7[mif1,0] * self.yubar[2,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,2] * self.yl[0,mif2] * self.ylbar[0,2] * self.yluPi7[mif1,0] * self.yubar[2,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,2] * self.yl[1,mif2] * self.ylbar[1,0] * self.yluPi7[mif1,0] * self.yubar[2,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,2] * self.yl[1,mif2] * self.ylbar[1,1] * self.yluPi7[mif1,0] * self.yubar[2,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,2] * self.yl[1,mif2] * self.ylbar[1,2] * self.yluPi7[mif1,0] * self.yubar[2,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,2] * self.yl[2,mif2] * self.ylbar[2,0] * self.yluPi7[mif1,0] * self.yubar[2,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,2] * self.yl[2,mif2] * self.ylbar[2,1] * self.yluPi7[mif1,0] * self.yubar[2,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,2] * self.yl[2,mif2] * self.ylbar[2,2] * self.yluPi7[mif1,0] * self.yubar[2,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] * self.yu[0,0] * self.yubar[2,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] * self.yu[0,0] * self.yubar[2,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] * self.yu[0,0] * self.yubar[2,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] * self.yu[1,0] * self.yubar[2,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] * self.yu[1,0] * self.yubar[2,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] * self.yu[1,0] * self.yubar[2,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] * self.yu[2,0] * self.yubar[2,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] * self.yu[2,0] * self.yubar[2,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] * self.yu[2,0] * self.yubar[2,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[0,0] * self.yu[2,0] * self.yubar[2,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[1,0] * self.yu[2,0] * self.yubar[2,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[2,0] * self.yu[2,0] * self.yubar[2,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[0,1] * self.yu[2,1] * self.yubar[2,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[1,1] * self.yu[2,1] * self.yubar[2,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[2,1] * self.yu[2,1] * self.yubar[2,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[0,2] * self.yu[2,2] * self.yubar[2,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[1,2] * self.yu[2,2] * self.yubar[2,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[2,2] * self.yu[2,2] * self.yubar[2,0] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[0,0] * self.yubar[0,0] * self.yubar[2,0] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[0,0] * self.yubar[0,0] * self.yubar[2,0] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[0,0] * self.yubar[0,0] * self.yubar[2,0] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[2,0] * self.yubar[0,0] * self.yubar[2,0] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[2,0] * self.yubar[0,0] * self.yubar[2,0] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[2,0] * self.yubar[0,0] * self.yubar[2,0] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[0,0] * self.yubar[0,1] * self.yubar[2,0] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[0,0] * self.yubar[0,1] * self.yubar[2,0] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[0,0] * self.yubar[0,1] * self.yubar[2,0] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[2,1] * self.yubar[0,1] * self.yubar[2,0] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[2,1] * self.yubar[0,1] * self.yubar[2,0] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[2,1] * self.yubar[0,1] * self.yubar[2,0] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[0,0] * self.yubar[0,2] * self.yubar[2,0] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[0,0] * self.yubar[0,2] * self.yubar[2,0] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[0,0] * self.yubar[0,2] * self.yubar[2,0] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[2,2] * self.yubar[0,2] * self.yubar[2,0] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[2,2] * self.yubar[0,2] * self.yubar[2,0] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[2,2] * self.yubar[0,2] * self.yubar[2,0] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[1,0] * self.yubar[1,0] * self.yubar[2,0] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[1,0] * self.yubar[1,0] * self.yubar[2,0] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[1,0] * self.yubar[1,0] * self.yubar[2,0] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[2,0] * self.yubar[1,0] * self.yubar[2,0] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[2,0] * self.yubar[1,0] * self.yubar[2,0] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[2,0] * self.yubar[1,0] * self.yubar[2,0] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[1,0] * self.yubar[1,1] * self.yubar[2,0] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[1,0] * self.yubar[1,1] * self.yubar[2,0] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[1,0] * self.yubar[1,1] * self.yubar[2,0] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[2,1] * self.yubar[1,1] * self.yubar[2,0] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[2,1] * self.yubar[1,1] * self.yubar[2,0] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[2,1] * self.yubar[1,1] * self.yubar[2,0] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[1,0] * self.yubar[1,2] * self.yubar[2,0] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[1,0] * self.yubar[1,2] * self.yubar[2,0] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[1,0] * self.yubar[1,2] * self.yubar[2,0] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[2,2] * self.yubar[1,2] * self.yubar[2,0] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[2,2] * self.yubar[1,2] * self.yubar[2,0] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[2,2] * self.yubar[1,2] * self.yubar[2,0] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[2,0] * (self.yubar[2,0])**(2) + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[2,0] * (self.yubar[2,0])**(2) + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[2,0] * (self.yubar[2,0])**(2) + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] * self.ylbar[0,0] * self.yluPi7[0,1] * self.yubar[2,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] * self.ylbar[0,1] * self.yluPi7[0,1] * self.yubar[2,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] * self.ylbar[0,2] * self.yluPi7[0,1] * self.yubar[2,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] * self.ylbar[1,0] * self.yluPi7[1,1] * self.yubar[2,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] * self.ylbar[1,1] * self.yluPi7[1,1] * self.yubar[2,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] * self.ylbar[1,2] * self.yluPi7[1,1] * self.yubar[2,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] * self.ylbar[2,0] * self.yluPi7[2,1] * self.yubar[2,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] * self.ylbar[2,1] * self.yluPi7[2,1] * self.yubar[2,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] * self.ylbar[2,2] * self.yluPi7[2,1] * self.yubar[2,1] + -9/32 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[2,1] + -3/16 * self.invepsilonbar * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[2,1] + 3/16 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[2,1] + 3/16 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[2,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,2] * self.yl[0,mif2] * self.ylbar[0,0] * self.yluPi7[mif1,1] * self.yubar[2,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,2] * self.yl[0,mif2] * self.ylbar[0,1] * self.yluPi7[mif1,1] * self.yubar[2,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,2] * self.yl[0,mif2] * self.ylbar[0,2] * self.yluPi7[mif1,1] * self.yubar[2,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,2] * self.yl[1,mif2] * self.ylbar[1,0] * self.yluPi7[mif1,1] * self.yubar[2,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,2] * self.yl[1,mif2] * self.ylbar[1,1] * self.yluPi7[mif1,1] * self.yubar[2,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,2] * self.yl[1,mif2] * self.ylbar[1,2] * self.yluPi7[mif1,1] * self.yubar[2,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,2] * self.yl[2,mif2] * self.ylbar[2,0] * self.yluPi7[mif1,1] * self.yubar[2,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,2] * self.yl[2,mif2] * self.ylbar[2,1] * self.yluPi7[mif1,1] * self.yubar[2,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,2] * self.yl[2,mif2] * self.ylbar[2,2] * self.yluPi7[mif1,1] * self.yubar[2,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] * self.yu[0,1] * self.yubar[2,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] * self.yu[0,1] * self.yubar[2,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] * self.yu[0,1] * self.yubar[2,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] * self.yu[1,1] * self.yubar[2,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] * self.yu[1,1] * self.yubar[2,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] * self.yu[1,1] * self.yubar[2,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[0,0] * self.yu[2,0] * self.yubar[2,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[1,0] * self.yu[2,0] * self.yubar[2,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[2,0] * self.yu[2,0] * self.yubar[2,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] * self.yu[2,1] * self.yubar[2,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] * self.yu[2,1] * self.yubar[2,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] * self.yu[2,1] * self.yubar[2,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[0,1] * self.yu[2,1] * self.yubar[2,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[1,1] * self.yu[2,1] * self.yubar[2,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[2,1] * self.yu[2,1] * self.yubar[2,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[0,2] * self.yu[2,2] * self.yubar[2,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[1,2] * self.yu[2,2] * self.yubar[2,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[2,2] * self.yu[2,2] * self.yubar[2,1] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[0,1] * self.yubar[0,0] * self.yubar[2,1] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[0,1] * self.yubar[0,0] * self.yubar[2,1] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[0,1] * self.yubar[0,0] * self.yubar[2,1] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[2,0] * self.yubar[0,0] * self.yubar[2,1] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[2,0] * self.yubar[0,0] * self.yubar[2,1] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[2,0] * self.yubar[0,0] * self.yubar[2,1] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[0,1] * self.yubar[0,1] * self.yubar[2,1] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[0,1] * self.yubar[0,1] * self.yubar[2,1] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[0,1] * self.yubar[0,1] * self.yubar[2,1] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[2,1] * self.yubar[0,1] * self.yubar[2,1] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[2,1] * self.yubar[0,1] * self.yubar[2,1] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[2,1] * self.yubar[0,1] * self.yubar[2,1] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[0,1] * self.yubar[0,2] * self.yubar[2,1] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[0,1] * self.yubar[0,2] * self.yubar[2,1] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[0,1] * self.yubar[0,2] * self.yubar[2,1] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[2,2] * self.yubar[0,2] * self.yubar[2,1] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[2,2] * self.yubar[0,2] * self.yubar[2,1] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[2,2] * self.yubar[0,2] * self.yubar[2,1] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[1,1] * self.yubar[1,0] * self.yubar[2,1] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[1,1] * self.yubar[1,0] * self.yubar[2,1] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[1,1] * self.yubar[1,0] * self.yubar[2,1] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[2,0] * self.yubar[1,0] * self.yubar[2,1] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[2,0] * self.yubar[1,0] * self.yubar[2,1] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[2,0] * self.yubar[1,0] * self.yubar[2,1] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[1,1] * self.yubar[1,1] * self.yubar[2,1] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[1,1] * self.yubar[1,1] * self.yubar[2,1] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[1,1] * self.yubar[1,1] * self.yubar[2,1] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[2,1] * self.yubar[1,1] * self.yubar[2,1] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[2,1] * self.yubar[1,1] * self.yubar[2,1] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[2,1] * self.yubar[1,1] * self.yubar[2,1] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[1,1] * self.yubar[1,2] * self.yubar[2,1] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[1,1] * self.yubar[1,2] * self.yubar[2,1] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[1,1] * self.yubar[1,2] * self.yubar[2,1] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[2,2] * self.yubar[1,2] * self.yubar[2,1] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[2,2] * self.yubar[1,2] * self.yubar[2,1] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[2,2] * self.yubar[1,2] * self.yubar[2,1] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[2,0] * self.yubar[2,0] * self.yubar[2,1] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[2,0] * self.yubar[2,0] * self.yubar[2,1] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[2,0] * self.yubar[2,0] * self.yubar[2,1] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[2,1] * self.yubar[2,0] * self.yubar[2,1] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[2,1] * self.yubar[2,0] * self.yubar[2,1] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[2,1] * self.yubar[2,0] * self.yubar[2,1] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[2,1] * (self.yubar[2,1])**(2) + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[2,1] * (self.yubar[2,1])**(2) + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[2,1] * (self.yubar[2,1])**(2) + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] * self.ylbar[0,0] * self.yluPi7[0,2] * self.yubar[2,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] * self.ylbar[0,1] * self.yluPi7[0,2] * self.yubar[2,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] * self.ylbar[0,2] * self.yluPi7[0,2] * self.yubar[2,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] * self.ylbar[1,0] * self.yluPi7[1,2] * self.yubar[2,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] * self.ylbar[1,1] * self.yluPi7[1,2] * self.yubar[2,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] * self.ylbar[1,2] * self.yluPi7[1,2] * self.yubar[2,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] * self.ylbar[2,0] * self.yluPi7[2,2] * self.yubar[2,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] * self.ylbar[2,1] * self.yluPi7[2,2] * self.yubar[2,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] * self.ylbar[2,2] * self.yluPi7[2,2] * self.yubar[2,2] + -9/32 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[2,2] + -3/16 * self.invepsilonbar * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[2,2] + 3/16 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[2,2] + 3/16 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[2,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,2] * self.yl[0,mif2] * self.ylbar[0,0] * self.yluPi7[mif1,2] * self.yubar[2,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,2] * self.yl[0,mif2] * self.ylbar[0,1] * self.yluPi7[mif1,2] * self.yubar[2,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,2] * self.yl[0,mif2] * self.ylbar[0,2] * self.yluPi7[mif1,2] * self.yubar[2,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,2] * self.yl[1,mif2] * self.ylbar[1,0] * self.yluPi7[mif1,2] * self.yubar[2,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,2] * self.yl[1,mif2] * self.ylbar[1,1] * self.yluPi7[mif1,2] * self.yubar[2,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,2] * self.yl[1,mif2] * self.ylbar[1,2] * self.yluPi7[mif1,2] * self.yubar[2,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,2] * self.yl[2,mif2] * self.ylbar[2,0] * self.yluPi7[mif1,2] * self.yubar[2,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,2] * self.yl[2,mif2] * self.ylbar[2,1] * self.yluPi7[mif1,2] * self.yubar[2,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,2] * self.yl[2,mif2] * self.ylbar[2,2] * self.yluPi7[mif1,2] * self.yubar[2,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] * self.yu[0,2] * self.yubar[2,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] * self.yu[0,2] * self.yubar[2,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] * self.yu[0,2] * self.yubar[2,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] * self.yu[1,2] * self.yubar[2,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] * self.yu[1,2] * self.yubar[2,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] * self.yu[1,2] * self.yubar[2,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[0,0] * self.yu[2,0] * self.yubar[2,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[1,0] * self.yu[2,0] * self.yubar[2,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[2,0] * self.yu[2,0] * self.yubar[2,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[0,1] * self.yu[2,1] * self.yubar[2,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[1,1] * self.yu[2,1] * self.yubar[2,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[2,1] * self.yu[2,1] * self.yubar[2,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] * self.yu[2,2] * self.yubar[2,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] * self.yu[2,2] * self.yubar[2,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] * self.yu[2,2] * self.yubar[2,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[0,2] * self.yu[2,2] * self.yubar[2,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[1,2] * self.yu[2,2] * self.yubar[2,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[2,2] * self.yu[2,2] * self.yubar[2,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[0,2] * self.yubar[0,0] * self.yubar[2,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[0,2] * self.yubar[0,0] * self.yubar[2,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[0,2] * self.yubar[0,0] * self.yubar[2,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[2,0] * self.yubar[0,0] * self.yubar[2,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[2,0] * self.yubar[0,0] * self.yubar[2,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[2,0] * self.yubar[0,0] * self.yubar[2,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[0,2] * self.yubar[0,1] * self.yubar[2,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[0,2] * self.yubar[0,1] * self.yubar[2,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[0,2] * self.yubar[0,1] * self.yubar[2,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[2,1] * self.yubar[0,1] * self.yubar[2,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[2,1] * self.yubar[0,1] * self.yubar[2,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[2,1] * self.yubar[0,1] * self.yubar[2,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[0,2] * self.yubar[0,2] * self.yubar[2,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[0,2] * self.yubar[0,2] * self.yubar[2,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[0,2] * self.yubar[0,2] * self.yubar[2,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[2,2] * self.yubar[0,2] * self.yubar[2,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[2,2] * self.yubar[0,2] * self.yubar[2,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[2,2] * self.yubar[0,2] * self.yubar[2,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[1,2] * self.yubar[1,0] * self.yubar[2,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[1,2] * self.yubar[1,0] * self.yubar[2,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[1,2] * self.yubar[1,0] * self.yubar[2,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[2,0] * self.yubar[1,0] * self.yubar[2,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[2,0] * self.yubar[1,0] * self.yubar[2,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[2,0] * self.yubar[1,0] * self.yubar[2,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[1,2] * self.yubar[1,1] * self.yubar[2,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[1,2] * self.yubar[1,1] * self.yubar[2,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[1,2] * self.yubar[1,1] * self.yubar[2,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[2,1] * self.yubar[1,1] * self.yubar[2,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[2,1] * self.yubar[1,1] * self.yubar[2,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[2,1] * self.yubar[1,1] * self.yubar[2,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[1,2] * self.yubar[1,2] * self.yubar[2,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[1,2] * self.yubar[1,2] * self.yubar[2,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[1,2] * self.yubar[1,2] * self.yubar[2,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[2,2] * self.yubar[1,2] * self.yubar[2,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[2,2] * self.yubar[1,2] * self.yubar[2,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[2,2] * self.yubar[1,2] * self.yubar[2,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[2,0] * self.yubar[2,0] * self.yubar[2,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[2,0] * self.yubar[2,0] * self.yubar[2,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[2,0] * self.yubar[2,0] * self.yubar[2,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[2,2] * self.yubar[2,0] * self.yubar[2,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[2,2] * self.yubar[2,0] * self.yubar[2,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[2,2] * self.yubar[2,0] * self.yubar[2,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[2,1] * self.yubar[2,1] * self.yubar[2,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[2,1] * self.yubar[2,1] * self.yubar[2,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[2,1] * self.yubar[2,1] * self.yubar[2,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[2,2] * self.yubar[2,1] * self.yubar[2,2] + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[2,2] * self.yubar[2,1] * self.yubar[2,2] + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[2,2] * self.yubar[2,1] * self.yubar[2,2] + 3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[2,2] * (self.yubar[2,2])**(2) + 3/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[2,2] * (self.yubar[2,2])**(2) + -3/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[2,2] * (self.yubar[2,2])**(2))

    def alphaOeu(self, mif1,mif2,mif3,mif4):
        return (49/4320 * (self.g1)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + -5/144 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] + -1/72 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] + 1/72 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] + -5/144 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] + -1/72 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] + 1/72 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] + -5/144 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] + -1/72 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] + 1/72 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] + -31/864 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[0,mif4] * self.yluPi7bar[0,mif3] + -1/48 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[0,mif4] * self.yluPi7bar[0,mif3] + 1/48 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[0,mif4] * self.yluPi7bar[0,mif3] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] * self.yluPi7[0,mif4] * self.yluPi7bar[0,mif3] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] * self.yluPi7[0,mif4] * self.yluPi7bar[0,mif3] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] * self.yluPi7[0,mif4] * self.yluPi7bar[0,mif3] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.ylbar[0,mif1] * self.yluPi7[0,mif4] * self.yluPi7bar[0,mif3] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.ylbar[0,mif1] * self.yluPi7[0,mif4] * self.yluPi7bar[0,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[0,mif2] * self.ylbar[0,mif1] * self.yluPi7[0,mif4] * self.yluPi7bar[0,mif3] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.ylbar[1,mif1] * self.yluPi7[1,mif4] * self.yluPi7bar[0,mif3] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.ylbar[1,mif1] * self.yluPi7[1,mif4] * self.yluPi7bar[0,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[0,mif2] * self.ylbar[1,mif1] * self.yluPi7[1,mif4] * self.yluPi7bar[0,mif3] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.ylbar[2,mif1] * self.yluPi7[2,mif4] * self.yluPi7bar[0,mif3] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.ylbar[2,mif1] * self.yluPi7[2,mif4] * self.yluPi7bar[0,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[0,mif2] * self.ylbar[2,mif1] * self.yluPi7[2,mif4] * self.yluPi7bar[0,mif3] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.ylbar[0,mif1] * self.yluPi7[0,mif4] * self.yluPi7bar[1,mif3] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.ylbar[0,mif1] * self.yluPi7[0,mif4] * self.yluPi7bar[1,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[1,mif2] * self.ylbar[0,mif1] * self.yluPi7[0,mif4] * self.yluPi7bar[1,mif3] + -31/864 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[1,mif4] * self.yluPi7bar[1,mif3] + -1/48 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[1,mif4] * self.yluPi7bar[1,mif3] + 1/48 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[1,mif4] * self.yluPi7bar[1,mif3] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] * self.yluPi7[1,mif4] * self.yluPi7bar[1,mif3] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] * self.yluPi7[1,mif4] * self.yluPi7bar[1,mif3] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] * self.yluPi7[1,mif4] * self.yluPi7bar[1,mif3] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.ylbar[1,mif1] * self.yluPi7[1,mif4] * self.yluPi7bar[1,mif3] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.ylbar[1,mif1] * self.yluPi7[1,mif4] * self.yluPi7bar[1,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[1,mif2] * self.ylbar[1,mif1] * self.yluPi7[1,mif4] * self.yluPi7bar[1,mif3] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.ylbar[2,mif1] * self.yluPi7[2,mif4] * self.yluPi7bar[1,mif3] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.ylbar[2,mif1] * self.yluPi7[2,mif4] * self.yluPi7bar[1,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[1,mif2] * self.ylbar[2,mif1] * self.yluPi7[2,mif4] * self.yluPi7bar[1,mif3] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.ylbar[0,mif1] * self.yluPi7[0,mif4] * self.yluPi7bar[2,mif3] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.ylbar[0,mif1] * self.yluPi7[0,mif4] * self.yluPi7bar[2,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[2,mif2] * self.ylbar[0,mif1] * self.yluPi7[0,mif4] * self.yluPi7bar[2,mif3] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.ylbar[1,mif1] * self.yluPi7[1,mif4] * self.yluPi7bar[2,mif3] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.ylbar[1,mif1] * self.yluPi7[1,mif4] * self.yluPi7bar[2,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[2,mif2] * self.ylbar[1,mif1] * self.yluPi7[1,mif4] * self.yluPi7bar[2,mif3] + -31/864 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[2,mif4] * self.yluPi7bar[2,mif3] + -1/48 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[2,mif4] * self.yluPi7bar[2,mif3] + 1/48 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[2,mif4] * self.yluPi7bar[2,mif3] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] * self.yluPi7[2,mif4] * self.yluPi7bar[2,mif3] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] * self.yluPi7[2,mif4] * self.yluPi7bar[2,mif3] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] * self.yluPi7[2,mif4] * self.yluPi7bar[2,mif3] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.ylbar[2,mif1] * self.yluPi7[2,mif4] * self.yluPi7bar[2,mif3] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.ylbar[2,mif1] * self.yluPi7[2,mif4] * self.yluPi7bar[2,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[2,mif2] * self.ylbar[2,mif1] * self.yluPi7[2,mif4] * self.yluPi7bar[2,mif3] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yl[0,mif2] * self.yluPi7bar[0,mif3] * self.yu[0,mif4] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yl[0,mif2] * self.yluPi7bar[0,mif3] * self.yu[0,mif4] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,0] * self.yl[0,mif2] * self.yluPi7bar[0,mif3] * self.yu[0,mif4] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yl[1,mif2] * self.yluPi7bar[1,mif3] * self.yu[0,mif4] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yl[1,mif2] * self.yluPi7bar[1,mif3] * self.yu[0,mif4] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,0] * self.yl[1,mif2] * self.yluPi7bar[1,mif3] * self.yu[0,mif4] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yl[2,mif2] * self.yluPi7bar[2,mif3] * self.yu[0,mif4] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yl[2,mif2] * self.yluPi7bar[2,mif3] * self.yu[0,mif4] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,0] * self.yl[2,mif2] * self.yluPi7bar[2,mif3] * self.yu[0,mif4] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yl[0,mif2] * self.yluPi7bar[0,mif3] * self.yu[1,mif4] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yl[0,mif2] * self.yluPi7bar[0,mif3] * self.yu[1,mif4] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,1] * self.yl[0,mif2] * self.yluPi7bar[0,mif3] * self.yu[1,mif4] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yl[1,mif2] * self.yluPi7bar[1,mif3] * self.yu[1,mif4] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yl[1,mif2] * self.yluPi7bar[1,mif3] * self.yu[1,mif4] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,1] * self.yl[1,mif2] * self.yluPi7bar[1,mif3] * self.yu[1,mif4] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yl[2,mif2] * self.yluPi7bar[2,mif3] * self.yu[1,mif4] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yl[2,mif2] * self.yluPi7bar[2,mif3] * self.yu[1,mif4] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,1] * self.yl[2,mif2] * self.yluPi7bar[2,mif3] * self.yu[1,mif4] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yl[0,mif2] * self.yluPi7bar[0,mif3] * self.yu[2,mif4] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yl[0,mif2] * self.yluPi7bar[0,mif3] * self.yu[2,mif4] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,2] * self.yl[0,mif2] * self.yluPi7bar[0,mif3] * self.yu[2,mif4] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yl[1,mif2] * self.yluPi7bar[1,mif3] * self.yu[2,mif4] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yl[1,mif2] * self.yluPi7bar[1,mif3] * self.yu[2,mif4] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,2] * self.yl[1,mif2] * self.yluPi7bar[1,mif3] * self.yu[2,mif4] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yl[2,mif2] * self.yluPi7bar[2,mif3] * self.yu[2,mif4] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yl[2,mif2] * self.yluPi7bar[2,mif3] * self.yu[2,mif4] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,2] * self.yl[2,mif2] * self.yluPi7bar[2,mif3] * self.yu[2,mif4] + -5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.ylbar[0,mif1] * self.yluPi7[0,mif4] * self.yubar[0,mif3] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.ylbar[0,mif1] * self.yluPi7[0,mif4] * self.yubar[0,mif3] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.ylbar[0,mif1] * self.yluPi7[0,mif4] * self.yubar[0,mif3] + -5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.ylbar[1,mif1] * self.yluPi7[1,mif4] * self.yubar[0,mif3] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.ylbar[1,mif1] * self.yluPi7[1,mif4] * self.yubar[0,mif3] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.ylbar[1,mif1] * self.yluPi7[1,mif4] * self.yubar[0,mif3] + -5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.ylbar[2,mif1] * self.yluPi7[2,mif4] * self.yubar[0,mif3] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.ylbar[2,mif1] * self.yluPi7[2,mif4] * self.yubar[0,mif3] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.ylbar[2,mif1] * self.yluPi7[2,mif4] * self.yubar[0,mif3] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] * self.yu[0,mif4] * self.yubar[0,mif3] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] * self.yu[0,mif4] * self.yubar[0,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] * self.yu[0,mif4] * self.yubar[0,mif3] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,0] * self.yu[1,mif4] * self.yubar[0,mif3] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,0] * self.yu[1,mif4] * self.yubar[0,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,0] * self.yu[1,mif4] * self.yubar[0,mif3] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,0] * self.yu[2,mif4] * self.yubar[0,mif3] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,0] * self.yu[2,mif4] * self.yubar[0,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,0] * self.yu[2,mif4] * self.yubar[0,mif3] + -5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.ylbar[0,mif1] * self.yluPi7[0,mif4] * self.yubar[1,mif3] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.ylbar[0,mif1] * self.yluPi7[0,mif4] * self.yubar[1,mif3] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.ylbar[0,mif1] * self.yluPi7[0,mif4] * self.yubar[1,mif3] + -5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.ylbar[1,mif1] * self.yluPi7[1,mif4] * self.yubar[1,mif3] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.ylbar[1,mif1] * self.yluPi7[1,mif4] * self.yubar[1,mif3] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.ylbar[1,mif1] * self.yluPi7[1,mif4] * self.yubar[1,mif3] + -5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.ylbar[2,mif1] * self.yluPi7[2,mif4] * self.yubar[1,mif3] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.ylbar[2,mif1] * self.yluPi7[2,mif4] * self.yubar[1,mif3] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.ylbar[2,mif1] * self.yluPi7[2,mif4] * self.yubar[1,mif3] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,1] * self.yu[0,mif4] * self.yubar[1,mif3] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,1] * self.yu[0,mif4] * self.yubar[1,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,1] * self.yu[0,mif4] * self.yubar[1,mif3] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] * self.yu[1,mif4] * self.yubar[1,mif3] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] * self.yu[1,mif4] * self.yubar[1,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] * self.yu[1,mif4] * self.yubar[1,mif3] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,1] * self.yu[2,mif4] * self.yubar[1,mif3] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,1] * self.yu[2,mif4] * self.yubar[1,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,1] * self.yu[2,mif4] * self.yubar[1,mif3] + -5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.ylbar[0,mif1] * self.yluPi7[0,mif4] * self.yubar[2,mif3] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.ylbar[0,mif1] * self.yluPi7[0,mif4] * self.yubar[2,mif3] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.ylbar[0,mif1] * self.yluPi7[0,mif4] * self.yubar[2,mif3] + -5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.ylbar[1,mif1] * self.yluPi7[1,mif4] * self.yubar[2,mif3] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.ylbar[1,mif1] * self.yluPi7[1,mif4] * self.yubar[2,mif3] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.ylbar[1,mif1] * self.yluPi7[1,mif4] * self.yubar[2,mif3] + -5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.ylbar[2,mif1] * self.yluPi7[2,mif4] * self.yubar[2,mif3] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.ylbar[2,mif1] * self.yluPi7[2,mif4] * self.yubar[2,mif3] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.ylbar[2,mif1] * self.yluPi7[2,mif4] * self.yubar[2,mif3] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,2] * self.yu[0,mif4] * self.yubar[2,mif3] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,2] * self.yu[0,mif4] * self.yubar[2,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,2] * self.yu[0,mif4] * self.yubar[2,mif3] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,2] * self.yu[1,mif4] * self.yubar[2,mif3] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,2] * self.yu[1,mif4] * self.yubar[2,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,2] * self.yu[1,mif4] * self.yubar[2,mif3] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] * self.yu[2,mif4] * self.yubar[2,mif3] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] * self.yu[2,mif4] * self.yubar[2,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] * self.yu[2,mif4] * self.yubar[2,mif3])

    def alphaOeW(self, mif1,mif2):
        return (-1/256 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[0,0] + -1/256 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[0,1] + -1/256 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[0,2] + -1/256 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[1,0] + -1/256 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[1,1] + -1/256 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[1,2] + -1/256 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,0] * self.yluPi7bar[2,0] + -1/256 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,1] * self.yluPi7bar[2,1] + -1/256 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,2] * self.yluPi7bar[2,2] + 9/256 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[0,0] + 3/128 * self.g2 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[0,0] + -3/128 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.xRP * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[0,0] + -3/128 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[0,0] + 9/256 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[0,1] + 3/128 * self.g2 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[0,1] + -3/128 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.xRP * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[0,1] + -3/128 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[0,1] + 9/256 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[0,2] + 3/128 * self.g2 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[0,2] + -3/128 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.xRP * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[0,2] + -3/128 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[0,2] + 9/256 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[1,0] + 3/128 * self.g2 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[1,0] + -3/128 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.xRP * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[1,0] + -3/128 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[1,0] + 9/256 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[1,1] + 3/128 * self.g2 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[1,1] + -3/128 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.xRP * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[1,1] + -3/128 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[1,1] + 9/256 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[1,2] + 3/128 * self.g2 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[1,2] + -3/128 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.xRP * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[1,2] + -3/128 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[1,2] + 9/256 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[2,0] + 3/128 * self.g2 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[2,0] + -3/128 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.xRP * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[2,0] + -3/128 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[2,0] + 9/256 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[2,1] + 3/128 * self.g2 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[2,1] + -3/128 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.xRP * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[2,1] + -3/128 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[2,1] + 9/256 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[2,2] + 3/128 * self.g2 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[2,2] + -3/128 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.xRP * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[2,2] + -3/128 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[2,2])

    def alphaOHd(self, mif1,mif2):
        return (49/17280 * (self.g1)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.ydbar[0,mif1] * self.yeqPi7[0,0] * self.yeqPi7bar[0,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.ydbar[0,mif1] * self.yeqPi7[0,1] * self.yeqPi7bar[0,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.ydbar[0,mif1] * self.yeqPi7[0,2] * self.yeqPi7bar[0,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.ydbar[1,mif1] * self.yeqPi7[0,0] * self.yeqPi7bar[0,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.ydbar[1,mif1] * self.yeqPi7[0,1] * self.yeqPi7bar[0,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.ydbar[1,mif1] * self.yeqPi7[0,2] * self.yeqPi7bar[0,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.ydbar[2,mif1] * self.yeqPi7[0,0] * self.yeqPi7bar[0,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.ydbar[2,mif1] * self.yeqPi7[0,1] * self.yeqPi7bar[0,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.ydbar[2,mif1] * self.yeqPi7[0,2] * self.yeqPi7bar[0,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.ydbar[0,mif1] * self.yeqPi7[1,0] * self.yeqPi7bar[1,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.ydbar[0,mif1] * self.yeqPi7[1,1] * self.yeqPi7bar[1,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.ydbar[0,mif1] * self.yeqPi7[1,2] * self.yeqPi7bar[1,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.ydbar[1,mif1] * self.yeqPi7[1,0] * self.yeqPi7bar[1,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.ydbar[1,mif1] * self.yeqPi7[1,1] * self.yeqPi7bar[1,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.ydbar[1,mif1] * self.yeqPi7[1,2] * self.yeqPi7bar[1,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.ydbar[2,mif1] * self.yeqPi7[1,0] * self.yeqPi7bar[1,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.ydbar[2,mif1] * self.yeqPi7[1,1] * self.yeqPi7bar[1,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.ydbar[2,mif1] * self.yeqPi7[1,2] * self.yeqPi7bar[1,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.ydbar[0,mif1] * self.yeqPi7[2,0] * self.yeqPi7bar[2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.ydbar[0,mif1] * self.yeqPi7[2,1] * self.yeqPi7bar[2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.ydbar[0,mif1] * self.yeqPi7[2,2] * self.yeqPi7bar[2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.ydbar[1,mif1] * self.yeqPi7[2,0] * self.yeqPi7bar[2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.ydbar[1,mif1] * self.yeqPi7[2,1] * self.yeqPi7bar[2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.ydbar[1,mif1] * self.yeqPi7[2,2] * self.yeqPi7bar[2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.ydbar[2,mif1] * self.yeqPi7[2,0] * self.yeqPi7bar[2,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.ydbar[2,mif1] * self.yeqPi7[2,1] * self.yeqPi7bar[2,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.ydbar[2,mif1] * self.yeqPi7[2,2] * self.yeqPi7bar[2,2])

    def alphaOHe(self, mif1,mif2):
        return (49/5760 * (self.g1)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) + -5/192 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] + -1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] + 1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,0] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,0] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[0,0] * self.ydbar[0,0] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,1] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,1] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[0,1] * self.ydbar[0,1] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,2] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,2] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[0,2] * self.ydbar[0,2] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[0,0] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,0] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[0,0] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[1,0] * self.ydbar[0,0] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[0,1] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,0] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[0,1] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[1,1] * self.ydbar[0,1] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[0,2] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,0] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[0,2] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[1,2] * self.ydbar[0,2] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[0,0] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,0] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[0,0] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[2,0] * self.ydbar[0,0] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[0,1] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,0] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[0,1] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[2,1] * self.ydbar[0,1] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[0,2] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,0] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[0,2] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[2,2] * self.ydbar[0,2] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[1,0] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,1] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[1,0] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[0,0] * self.ydbar[1,0] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[1,1] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,1] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[1,1] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[0,1] * self.ydbar[1,1] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[1,2] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,1] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[1,2] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[0,2] * self.ydbar[1,2] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,1] + -5/192 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] + -1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] + 1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,0] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,0] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[1,0] * self.ydbar[1,0] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,1] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,1] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[1,1] * self.ydbar[1,1] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,2] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,2] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[1,2] * self.ydbar[1,2] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[1,0] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,1] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[1,0] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[2,0] * self.ydbar[1,0] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[1,1] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,1] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[1,1] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[2,1] * self.ydbar[1,1] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[1,2] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,1] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[1,2] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[2,2] * self.ydbar[1,2] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[2,0] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,2] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[2,0] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[0,0] * self.ydbar[2,0] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,2] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[2,1] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,2] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[2,1] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[0,1] * self.ydbar[2,1] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,2] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[2,2] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,2] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[2,2] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[0,2] * self.ydbar[2,2] * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,2] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[2,0] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,2] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[2,0] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[1,0] * self.ydbar[2,0] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,2] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[2,1] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,2] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[2,1] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[1,1] * self.ydbar[2,1] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,2] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[2,2] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,2] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[2,2] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[1,2] * self.ydbar[2,2] * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,2] + -5/192 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] + -1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] + 1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,0] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,0] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[2,0] * self.ydbar[2,0] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,1] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,1] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[2,1] * self.ydbar[2,1] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,2] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,2] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[2,2] * self.ydbar[2,2] * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.ylbar[0,mif1] * self.yluPi7[0,0] * self.yluPi7bar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.ylbar[1,mif1] * self.yluPi7[1,0] * self.yluPi7bar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.ylbar[2,mif1] * self.yluPi7[2,0] * self.yluPi7bar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.ylbar[0,mif1] * self.yluPi7[0,1] * self.yluPi7bar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.ylbar[1,mif1] * self.yluPi7[1,1] * self.yluPi7bar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.ylbar[2,mif1] * self.yluPi7[2,1] * self.yluPi7bar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.ylbar[0,mif1] * self.yluPi7[0,2] * self.yluPi7bar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.ylbar[1,mif1] * self.yluPi7[1,2] * self.yluPi7bar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.ylbar[2,mif1] * self.yluPi7[2,2] * self.yluPi7bar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.ylbar[0,mif1] * self.yluPi7[0,0] * self.yluPi7bar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.ylbar[1,mif1] * self.yluPi7[1,0] * self.yluPi7bar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.ylbar[2,mif1] * self.yluPi7[2,0] * self.yluPi7bar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.ylbar[0,mif1] * self.yluPi7[0,1] * self.yluPi7bar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.ylbar[1,mif1] * self.yluPi7[1,1] * self.yluPi7bar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.ylbar[2,mif1] * self.yluPi7[2,1] * self.yluPi7bar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.ylbar[0,mif1] * self.yluPi7[0,2] * self.yluPi7bar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.ylbar[1,mif1] * self.yluPi7[1,2] * self.yluPi7bar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.ylbar[2,mif1] * self.yluPi7[2,2] * self.yluPi7bar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.ylbar[0,mif1] * self.yluPi7[0,0] * self.yluPi7bar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.ylbar[1,mif1] * self.yluPi7[1,0] * self.yluPi7bar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.ylbar[2,mif1] * self.yluPi7[2,0] * self.yluPi7bar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.ylbar[0,mif1] * self.yluPi7[0,1] * self.yluPi7bar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.ylbar[1,mif1] * self.yluPi7[1,1] * self.yluPi7bar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.ylbar[2,mif1] * self.yluPi7[2,1] * self.yluPi7bar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.ylbar[0,mif1] * self.yluPi7[0,2] * self.yluPi7bar[2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.ylbar[1,mif1] * self.yluPi7[1,2] * self.yluPi7bar[2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.ylbar[2,mif1] * self.yluPi7[2,2] * self.yluPi7bar[2,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yl[0,mif2] * self.yluPi7bar[0,0] * self.yu[0,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yl[1,mif2] * self.yluPi7bar[1,0] * self.yu[0,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yl[2,mif2] * self.yluPi7bar[2,0] * self.yu[0,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yl[0,mif2] * self.yluPi7bar[0,1] * self.yu[0,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yl[1,mif2] * self.yluPi7bar[1,1] * self.yu[0,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yl[2,mif2] * self.yluPi7bar[2,1] * self.yu[0,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yl[0,mif2] * self.yluPi7bar[0,2] * self.yu[0,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yl[1,mif2] * self.yluPi7bar[1,2] * self.yu[0,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yl[2,mif2] * self.yluPi7bar[2,2] * self.yu[0,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yl[0,mif2] * self.yluPi7bar[0,0] * self.yu[1,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yl[1,mif2] * self.yluPi7bar[1,0] * self.yu[1,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yl[2,mif2] * self.yluPi7bar[2,0] * self.yu[1,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yl[0,mif2] * self.yluPi7bar[0,1] * self.yu[1,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yl[1,mif2] * self.yluPi7bar[1,1] * self.yu[1,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yl[2,mif2] * self.yluPi7bar[2,1] * self.yu[1,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yl[0,mif2] * self.yluPi7bar[0,2] * self.yu[1,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yl[1,mif2] * self.yluPi7bar[1,2] * self.yu[1,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yl[2,mif2] * self.yluPi7bar[2,2] * self.yu[1,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yl[0,mif2] * self.yluPi7bar[0,0] * self.yu[2,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yl[1,mif2] * self.yluPi7bar[1,0] * self.yu[2,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yl[2,mif2] * self.yluPi7bar[2,0] * self.yu[2,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yl[0,mif2] * self.yluPi7bar[0,1] * self.yu[2,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yl[1,mif2] * self.yluPi7bar[1,1] * self.yu[2,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yl[2,mif2] * self.yluPi7bar[2,1] * self.yu[2,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yl[0,mif2] * self.yluPi7bar[0,2] * self.yu[2,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yl[1,mif2] * self.yluPi7bar[1,2] * self.yu[2,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yl[2,mif2] * self.yluPi7bar[2,2] * self.yu[2,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.ylbar[0,mif1] * self.yluPi7[0,0] * self.yubar[0,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.ylbar[1,mif1] * self.yluPi7[1,0] * self.yubar[0,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.ylbar[2,mif1] * self.yluPi7[2,0] * self.yubar[0,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] * self.yu[0,0] * self.yubar[0,0] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] * self.yu[0,0] * self.yubar[0,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] * self.yu[0,0] * self.yubar[0,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,0] * self.yu[1,0] * self.yubar[0,0] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,0] * self.yu[1,0] * self.yubar[0,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,0] * self.yu[1,0] * self.yubar[0,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,0] * self.yu[2,0] * self.yubar[0,0] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,0] * self.yu[2,0] * self.yubar[0,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,0] * self.yu[2,0] * self.yubar[0,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.ylbar[0,mif1] * self.yluPi7[0,1] * self.yubar[0,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.ylbar[1,mif1] * self.yluPi7[1,1] * self.yubar[0,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.ylbar[2,mif1] * self.yluPi7[2,1] * self.yubar[0,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] * self.yu[0,1] * self.yubar[0,1] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] * self.yu[0,1] * self.yubar[0,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] * self.yu[0,1] * self.yubar[0,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,0] * self.yu[1,1] * self.yubar[0,1] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,0] * self.yu[1,1] * self.yubar[0,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,0] * self.yu[1,1] * self.yubar[0,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,0] * self.yu[2,1] * self.yubar[0,1] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,0] * self.yu[2,1] * self.yubar[0,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,0] * self.yu[2,1] * self.yubar[0,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.ylbar[0,mif1] * self.yluPi7[0,2] * self.yubar[0,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.ylbar[1,mif1] * self.yluPi7[1,2] * self.yubar[0,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.ylbar[2,mif1] * self.yluPi7[2,2] * self.yubar[0,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] * self.yu[0,2] * self.yubar[0,2] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] * self.yu[0,2] * self.yubar[0,2] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,0] * self.yu[0,2] * self.yubar[0,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,0] * self.yu[1,2] * self.yubar[0,2] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,0] * self.yu[1,2] * self.yubar[0,2] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,0] * self.yu[1,2] * self.yubar[0,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,0] * self.yu[2,2] * self.yubar[0,2] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,0] * self.yu[2,2] * self.yubar[0,2] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,0] * self.yu[2,2] * self.yubar[0,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.ylbar[0,mif1] * self.yluPi7[0,0] * self.yubar[1,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.ylbar[1,mif1] * self.yluPi7[1,0] * self.yubar[1,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.ylbar[2,mif1] * self.yluPi7[2,0] * self.yubar[1,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,1] * self.yu[0,0] * self.yubar[1,0] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,1] * self.yu[0,0] * self.yubar[1,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,1] * self.yu[0,0] * self.yubar[1,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] * self.yu[1,0] * self.yubar[1,0] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] * self.yu[1,0] * self.yubar[1,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] * self.yu[1,0] * self.yubar[1,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,1] * self.yu[2,0] * self.yubar[1,0] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,1] * self.yu[2,0] * self.yubar[1,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,1] * self.yu[2,0] * self.yubar[1,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.ylbar[0,mif1] * self.yluPi7[0,1] * self.yubar[1,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.ylbar[1,mif1] * self.yluPi7[1,1] * self.yubar[1,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.ylbar[2,mif1] * self.yluPi7[2,1] * self.yubar[1,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,1] * self.yu[0,1] * self.yubar[1,1] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,1] * self.yu[0,1] * self.yubar[1,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,1] * self.yu[0,1] * self.yubar[1,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] * self.yu[1,1] * self.yubar[1,1] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] * self.yu[1,1] * self.yubar[1,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] * self.yu[1,1] * self.yubar[1,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,1] * self.yu[2,1] * self.yubar[1,1] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,1] * self.yu[2,1] * self.yubar[1,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,1] * self.yu[2,1] * self.yubar[1,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.ylbar[0,mif1] * self.yluPi7[0,2] * self.yubar[1,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.ylbar[1,mif1] * self.yluPi7[1,2] * self.yubar[1,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.ylbar[2,mif1] * self.yluPi7[2,2] * self.yubar[1,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,1] * self.yu[0,2] * self.yubar[1,2] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,1] * self.yu[0,2] * self.yubar[1,2] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,1] * self.yu[0,2] * self.yubar[1,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] * self.yu[1,2] * self.yubar[1,2] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] * self.yu[1,2] * self.yubar[1,2] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,1] * self.yu[1,2] * self.yubar[1,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,1] * self.yu[2,2] * self.yubar[1,2] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,1] * self.yu[2,2] * self.yubar[1,2] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,1] * self.yu[2,2] * self.yubar[1,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.ylbar[0,mif1] * self.yluPi7[0,0] * self.yubar[2,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.ylbar[1,mif1] * self.yluPi7[1,0] * self.yubar[2,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.ylbar[2,mif1] * self.yluPi7[2,0] * self.yubar[2,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,2] * self.yu[0,0] * self.yubar[2,0] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,2] * self.yu[0,0] * self.yubar[2,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,2] * self.yu[0,0] * self.yubar[2,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,2] * self.yu[1,0] * self.yubar[2,0] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,2] * self.yu[1,0] * self.yubar[2,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,2] * self.yu[1,0] * self.yubar[2,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] * self.yu[2,0] * self.yubar[2,0] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] * self.yu[2,0] * self.yubar[2,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] * self.yu[2,0] * self.yubar[2,0] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.ylbar[0,mif1] * self.yluPi7[0,1] * self.yubar[2,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.ylbar[1,mif1] * self.yluPi7[1,1] * self.yubar[2,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.ylbar[2,mif1] * self.yluPi7[2,1] * self.yubar[2,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,2] * self.yu[0,1] * self.yubar[2,1] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,2] * self.yu[0,1] * self.yubar[2,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,2] * self.yu[0,1] * self.yubar[2,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,2] * self.yu[1,1] * self.yubar[2,1] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,2] * self.yu[1,1] * self.yubar[2,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,2] * self.yu[1,1] * self.yubar[2,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] * self.yu[2,1] * self.yubar[2,1] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] * self.yu[2,1] * self.yubar[2,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] * self.yu[2,1] * self.yubar[2,1] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.ylbar[0,mif1] * self.yluPi7[0,2] * self.yubar[2,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.ylbar[1,mif1] * self.yluPi7[1,2] * self.yubar[2,2] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.ylbar[2,mif1] * self.yluPi7[2,2] * self.yubar[2,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,2] * self.yu[0,2] * self.yubar[2,2] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,2] * self.yu[0,2] * self.yubar[2,2] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,0] * self.yeqPi7bar[mif2,2] * self.yu[0,2] * self.yubar[2,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,2] * self.yu[1,2] * self.yubar[2,2] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,2] * self.yu[1,2] * self.yubar[2,2] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,1] * self.yeqPi7bar[mif2,2] * self.yu[1,2] * self.yubar[2,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] * self.yu[2,2] * self.yubar[2,2] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] * self.yu[2,2] * self.yubar[2,2] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif1,2] * self.yeqPi7bar[mif2,2] * self.yu[2,2] * self.yubar[2,2])

    def alphaOHl1(self, mif1,mif2):
        return (49/11520 * (self.g1)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[0,0] * self.yl[mif1,0] * self.ylbar[mif2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[0,1] * self.yl[mif1,0] * self.ylbar[mif2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[0,2] * self.yl[mif1,0] * self.ylbar[mif2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[0,0] * self.yl[mif1,1] * self.ylbar[mif2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[0,1] * self.yl[mif1,1] * self.ylbar[mif2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[0,2] * self.yl[mif1,1] * self.ylbar[mif2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[0,0] * self.yl[mif1,2] * self.ylbar[mif2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[0,1] * self.yl[mif1,2] * self.ylbar[mif2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[0,2] * self.yl[mif1,2] * self.ylbar[mif2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[1,0] * self.yl[mif1,0] * self.ylbar[mif2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[1,1] * self.yl[mif1,0] * self.ylbar[mif2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[1,2] * self.yl[mif1,0] * self.ylbar[mif2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[1,0] * self.yl[mif1,1] * self.ylbar[mif2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[1,1] * self.yl[mif1,1] * self.ylbar[mif2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[1,2] * self.yl[mif1,1] * self.ylbar[mif2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[1,0] * self.yl[mif1,2] * self.ylbar[mif2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[1,1] * self.yl[mif1,2] * self.ylbar[mif2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[1,2] * self.yl[mif1,2] * self.ylbar[mif2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[2,0] * self.yl[mif1,0] * self.ylbar[mif2,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[2,1] * self.yl[mif1,0] * self.ylbar[mif2,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[2,2] * self.yl[mif1,0] * self.ylbar[mif2,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[2,0] * self.yl[mif1,1] * self.ylbar[mif2,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[2,1] * self.yl[mif1,1] * self.ylbar[mif2,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[2,2] * self.yl[mif1,1] * self.ylbar[mif2,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[2,0] * self.yl[mif1,2] * self.ylbar[mif2,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[2,1] * self.yl[mif1,2] * self.ylbar[mif2,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[2,2] * self.yl[mif1,2] * self.ylbar[mif2,2] + -13/384 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + -1/48 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + 1/48 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + -13/384 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + -1/48 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + 1/48 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + -13/384 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] + -1/48 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] + 1/48 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yl[mif1,0] * self.yluPi7bar[mif2,0] * self.yu[0,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yl[mif1,1] * self.yluPi7bar[mif2,0] * self.yu[0,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yl[mif1,2] * self.yluPi7bar[mif2,0] * self.yu[0,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yl[mif1,0] * self.yluPi7bar[mif2,1] * self.yu[0,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yl[mif1,1] * self.yluPi7bar[mif2,1] * self.yu[0,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yl[mif1,2] * self.yluPi7bar[mif2,1] * self.yu[0,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yl[mif1,0] * self.yluPi7bar[mif2,2] * self.yu[0,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yl[mif1,1] * self.yluPi7bar[mif2,2] * self.yu[0,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yl[mif1,2] * self.yluPi7bar[mif2,2] * self.yu[0,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yl[mif1,0] * self.yluPi7bar[mif2,0] * self.yu[1,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yl[mif1,1] * self.yluPi7bar[mif2,0] * self.yu[1,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yl[mif1,2] * self.yluPi7bar[mif2,0] * self.yu[1,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yl[mif1,0] * self.yluPi7bar[mif2,1] * self.yu[1,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yl[mif1,1] * self.yluPi7bar[mif2,1] * self.yu[1,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yl[mif1,2] * self.yluPi7bar[mif2,1] * self.yu[1,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yl[mif1,0] * self.yluPi7bar[mif2,2] * self.yu[1,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yl[mif1,1] * self.yluPi7bar[mif2,2] * self.yu[1,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yl[mif1,2] * self.yluPi7bar[mif2,2] * self.yu[1,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yl[mif1,0] * self.yluPi7bar[mif2,0] * self.yu[2,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yl[mif1,1] * self.yluPi7bar[mif2,0] * self.yu[2,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yl[mif1,2] * self.yluPi7bar[mif2,0] * self.yu[2,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yl[mif1,0] * self.yluPi7bar[mif2,1] * self.yu[2,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yl[mif1,1] * self.yluPi7bar[mif2,1] * self.yu[2,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yl[mif1,2] * self.yluPi7bar[mif2,1] * self.yu[2,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yl[mif1,0] * self.yluPi7bar[mif2,2] * self.yu[2,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yl[mif1,1] * self.yluPi7bar[mif2,2] * self.yu[2,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yl[mif1,2] * self.yluPi7bar[mif2,2] * self.yu[2,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,0] * self.ylbar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[0,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,0] * self.ylbar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[0,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,0] * self.ylbar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[0,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] * self.yu[0,0] * self.yubar[0,0] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] * self.yu[0,0] * self.yubar[0,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] * self.yu[0,0] * self.yubar[0,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,1] * self.yu[0,1] * self.yubar[0,0] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,1] * self.yu[0,1] * self.yubar[0,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,1] * self.yu[0,1] * self.yubar[0,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,2] * self.yu[0,2] * self.yubar[0,0] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,2] * self.yu[0,2] * self.yubar[0,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,2] * self.yu[0,2] * self.yubar[0,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,0] * self.ylbar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[0,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,0] * self.ylbar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[0,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,0] * self.ylbar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[0,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,0] * self.yu[0,0] * self.yubar[0,1] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,0] * self.yu[0,0] * self.yubar[0,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,0] * self.yu[0,0] * self.yubar[0,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] * self.yu[0,1] * self.yubar[0,1] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] * self.yu[0,1] * self.yubar[0,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] * self.yu[0,1] * self.yubar[0,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,2] * self.yu[0,2] * self.yubar[0,1] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,2] * self.yu[0,2] * self.yubar[0,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,2] * self.yu[0,2] * self.yubar[0,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,0] * self.ylbar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[0,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,0] * self.ylbar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[0,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,0] * self.ylbar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[0,2] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,0] * self.yu[0,0] * self.yubar[0,2] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,0] * self.yu[0,0] * self.yubar[0,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,0] * self.yu[0,0] * self.yubar[0,2] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,1] * self.yu[0,1] * self.yubar[0,2] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,1] * self.yu[0,1] * self.yubar[0,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,1] * self.yu[0,1] * self.yubar[0,2] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] * self.yu[0,2] * self.yubar[0,2] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] * self.yu[0,2] * self.yubar[0,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] * self.yu[0,2] * self.yubar[0,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,1] * self.ylbar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[1,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,1] * self.ylbar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[1,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,1] * self.ylbar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[1,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] * self.yu[1,0] * self.yubar[1,0] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] * self.yu[1,0] * self.yubar[1,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] * self.yu[1,0] * self.yubar[1,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,1] * self.yu[1,1] * self.yubar[1,0] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,1] * self.yu[1,1] * self.yubar[1,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,1] * self.yu[1,1] * self.yubar[1,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,2] * self.yu[1,2] * self.yubar[1,0] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,2] * self.yu[1,2] * self.yubar[1,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,2] * self.yu[1,2] * self.yubar[1,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,1] * self.ylbar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[1,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,1] * self.ylbar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[1,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,1] * self.ylbar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[1,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,0] * self.yu[1,0] * self.yubar[1,1] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,0] * self.yu[1,0] * self.yubar[1,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,0] * self.yu[1,0] * self.yubar[1,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] * self.yu[1,1] * self.yubar[1,1] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] * self.yu[1,1] * self.yubar[1,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] * self.yu[1,1] * self.yubar[1,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,2] * self.yu[1,2] * self.yubar[1,1] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,2] * self.yu[1,2] * self.yubar[1,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,2] * self.yu[1,2] * self.yubar[1,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,1] * self.ylbar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[1,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,1] * self.ylbar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[1,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,1] * self.ylbar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[1,2] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,0] * self.yu[1,0] * self.yubar[1,2] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,0] * self.yu[1,0] * self.yubar[1,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,0] * self.yu[1,0] * self.yubar[1,2] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,1] * self.yu[1,1] * self.yubar[1,2] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,1] * self.yu[1,1] * self.yubar[1,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,1] * self.yu[1,1] * self.yubar[1,2] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] * self.yu[1,2] * self.yubar[1,2] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] * self.yu[1,2] * self.yubar[1,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] * self.yu[1,2] * self.yubar[1,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,2] * self.ylbar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[2,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,2] * self.ylbar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[2,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,2] * self.ylbar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[2,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] * self.yu[2,0] * self.yubar[2,0] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] * self.yu[2,0] * self.yubar[2,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] * self.yu[2,0] * self.yubar[2,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,1] * self.yu[2,1] * self.yubar[2,0] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,1] * self.yu[2,1] * self.yubar[2,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,1] * self.yu[2,1] * self.yubar[2,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,2] * self.yu[2,2] * self.yubar[2,0] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,2] * self.yu[2,2] * self.yubar[2,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,2] * self.yu[2,2] * self.yubar[2,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,2] * self.ylbar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[2,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,2] * self.ylbar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[2,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,2] * self.ylbar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[2,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,0] * self.yu[2,0] * self.yubar[2,1] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,0] * self.yu[2,0] * self.yubar[2,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,0] * self.yu[2,0] * self.yubar[2,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] * self.yu[2,1] * self.yubar[2,1] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] * self.yu[2,1] * self.yubar[2,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] * self.yu[2,1] * self.yubar[2,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,2] * self.yu[2,2] * self.yubar[2,1] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,2] * self.yu[2,2] * self.yubar[2,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,2] * self.yu[2,2] * self.yubar[2,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,2] * self.ylbar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[2,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,2] * self.ylbar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[2,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,2] * self.ylbar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[2,2] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,0] * self.yu[2,0] * self.yubar[2,2] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,0] * self.yu[2,0] * self.yubar[2,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,0] * self.yu[2,0] * self.yubar[2,2] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,1] * self.yu[2,1] * self.yubar[2,2] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,1] * self.yu[2,1] * self.yubar[2,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,1] * self.yu[2,1] * self.yubar[2,2] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] * self.yu[2,2] * self.yubar[2,2] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] * self.yu[2,2] * self.yubar[2,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] * self.yu[2,2] * self.yubar[2,2])

    def alphaOHl3(self, mif1,mif2):
        return (-1/1280 * (self.g2)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[0,0] * self.yl[mif1,0] * self.ylbar[mif2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[0,1] * self.yl[mif1,0] * self.ylbar[mif2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[0,2] * self.yl[mif1,0] * self.ylbar[mif2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[0,0] * self.yl[mif1,1] * self.ylbar[mif2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[0,1] * self.yl[mif1,1] * self.ylbar[mif2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[0,2] * self.yl[mif1,1] * self.ylbar[mif2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[0,0] * self.yl[mif1,2] * self.ylbar[mif2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[0,1] * self.yl[mif1,2] * self.ylbar[mif2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[0,2] * self.yl[mif1,2] * self.ylbar[mif2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[1,0] * self.yl[mif1,0] * self.ylbar[mif2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[1,1] * self.yl[mif1,0] * self.ylbar[mif2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[1,2] * self.yl[mif1,0] * self.ylbar[mif2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[1,0] * self.yl[mif1,1] * self.ylbar[mif2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[1,1] * self.yl[mif1,1] * self.ylbar[mif2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[1,2] * self.yl[mif1,1] * self.ylbar[mif2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[1,0] * self.yl[mif1,2] * self.ylbar[mif2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[1,1] * self.yl[mif1,2] * self.ylbar[mif2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[1,2] * self.yl[mif1,2] * self.ylbar[mif2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[2,0] * self.yl[mif1,0] * self.ylbar[mif2,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[2,1] * self.yl[mif1,0] * self.ylbar[mif2,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[2,2] * self.yl[mif1,0] * self.ylbar[mif2,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[2,0] * self.yl[mif1,1] * self.ylbar[mif2,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[2,1] * self.yl[mif1,1] * self.ylbar[mif2,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[2,2] * self.yl[mif1,1] * self.ylbar[mif2,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[2,0] * self.yl[mif1,2] * self.ylbar[mif2,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[2,1] * self.yl[mif1,2] * self.ylbar[mif2,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[2,2] * self.yl[mif1,2] * self.ylbar[mif2,2] + 1/384 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + 1/384 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + 1/384 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yl[mif1,0] * self.yluPi7bar[mif2,0] * self.yu[0,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yl[mif1,1] * self.yluPi7bar[mif2,0] * self.yu[0,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yl[mif1,2] * self.yluPi7bar[mif2,0] * self.yu[0,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yl[mif1,0] * self.yluPi7bar[mif2,1] * self.yu[0,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yl[mif1,1] * self.yluPi7bar[mif2,1] * self.yu[0,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yl[mif1,2] * self.yluPi7bar[mif2,1] * self.yu[0,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yl[mif1,0] * self.yluPi7bar[mif2,2] * self.yu[0,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yl[mif1,1] * self.yluPi7bar[mif2,2] * self.yu[0,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yl[mif1,2] * self.yluPi7bar[mif2,2] * self.yu[0,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yl[mif1,0] * self.yluPi7bar[mif2,0] * self.yu[1,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yl[mif1,1] * self.yluPi7bar[mif2,0] * self.yu[1,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yl[mif1,2] * self.yluPi7bar[mif2,0] * self.yu[1,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yl[mif1,0] * self.yluPi7bar[mif2,1] * self.yu[1,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yl[mif1,1] * self.yluPi7bar[mif2,1] * self.yu[1,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yl[mif1,2] * self.yluPi7bar[mif2,1] * self.yu[1,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yl[mif1,0] * self.yluPi7bar[mif2,2] * self.yu[1,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yl[mif1,1] * self.yluPi7bar[mif2,2] * self.yu[1,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yl[mif1,2] * self.yluPi7bar[mif2,2] * self.yu[1,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yl[mif1,0] * self.yluPi7bar[mif2,0] * self.yu[2,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yl[mif1,1] * self.yluPi7bar[mif2,0] * self.yu[2,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yl[mif1,2] * self.yluPi7bar[mif2,0] * self.yu[2,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yl[mif1,0] * self.yluPi7bar[mif2,1] * self.yu[2,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yl[mif1,1] * self.yluPi7bar[mif2,1] * self.yu[2,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yl[mif1,2] * self.yluPi7bar[mif2,1] * self.yu[2,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yl[mif1,0] * self.yluPi7bar[mif2,2] * self.yu[2,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yl[mif1,1] * self.yluPi7bar[mif2,2] * self.yu[2,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yl[mif1,2] * self.yluPi7bar[mif2,2] * self.yu[2,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,0] * self.ylbar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[0,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,0] * self.ylbar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[0,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,0] * self.ylbar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[0,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,0] * self.ylbar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[0,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,0] * self.ylbar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[0,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,0] * self.ylbar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[0,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,0] * self.ylbar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[0,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,0] * self.ylbar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[0,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,0] * self.ylbar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[0,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,1] * self.ylbar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[1,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,1] * self.ylbar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[1,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,1] * self.ylbar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[1,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,1] * self.ylbar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[1,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,1] * self.ylbar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[1,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,1] * self.ylbar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[1,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,1] * self.ylbar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[1,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,1] * self.ylbar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[1,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,1] * self.ylbar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[1,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,2] * self.ylbar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[2,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,2] * self.ylbar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[2,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,2] * self.ylbar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[2,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,2] * self.ylbar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[2,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,2] * self.ylbar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[2,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,2] * self.ylbar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[2,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,2] * self.ylbar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[2,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,2] * self.ylbar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[2,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,2] * self.ylbar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[2,2])

    def alphaOHq1(self, mif1,mif2):
        return (-49/34560 * (self.g1)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) + 55/3456 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] + 1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] + -1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] + 55/3456 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] + 1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] + -1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] + 55/3456 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] + 1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] + -1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] * self.yl[0,0] * self.ylbar[0,0] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] * self.yl[0,0] * self.ylbar[0,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] * self.yl[0,0] * self.ylbar[0,0] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7bar[0,mif1] * self.yl[0,1] * self.ylbar[0,0] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7bar[0,mif1] * self.yl[0,1] * self.ylbar[0,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif2] * self.yeqPi7bar[0,mif1] * self.yl[0,1] * self.ylbar[0,0] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7bar[0,mif1] * self.yl[0,2] * self.ylbar[0,0] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7bar[0,mif1] * self.yl[0,2] * self.ylbar[0,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif2] * self.yeqPi7bar[0,mif1] * self.yl[0,2] * self.ylbar[0,0] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7bar[1,mif1] * self.yl[0,0] * self.ylbar[0,1] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7bar[1,mif1] * self.yl[0,0] * self.ylbar[0,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif2] * self.yeqPi7bar[1,mif1] * self.yl[0,0] * self.ylbar[0,1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] * self.yl[0,1] * self.ylbar[0,1] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] * self.yl[0,1] * self.ylbar[0,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] * self.yl[0,1] * self.ylbar[0,1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7bar[1,mif1] * self.yl[0,2] * self.ylbar[0,1] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7bar[1,mif1] * self.yl[0,2] * self.ylbar[0,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif2] * self.yeqPi7bar[1,mif1] * self.yl[0,2] * self.ylbar[0,1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7bar[2,mif1] * self.yl[0,0] * self.ylbar[0,2] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7bar[2,mif1] * self.yl[0,0] * self.ylbar[0,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif2] * self.yeqPi7bar[2,mif1] * self.yl[0,0] * self.ylbar[0,2] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7bar[2,mif1] * self.yl[0,1] * self.ylbar[0,2] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7bar[2,mif1] * self.yl[0,1] * self.ylbar[0,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif2] * self.yeqPi7bar[2,mif1] * self.yl[0,1] * self.ylbar[0,2] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] * self.yl[0,2] * self.ylbar[0,2] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] * self.yl[0,2] * self.ylbar[0,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] * self.yl[0,2] * self.ylbar[0,2] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] * self.yl[1,0] * self.ylbar[1,0] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] * self.yl[1,0] * self.ylbar[1,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] * self.yl[1,0] * self.ylbar[1,0] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7bar[0,mif1] * self.yl[1,1] * self.ylbar[1,0] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7bar[0,mif1] * self.yl[1,1] * self.ylbar[1,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif2] * self.yeqPi7bar[0,mif1] * self.yl[1,1] * self.ylbar[1,0] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7bar[0,mif1] * self.yl[1,2] * self.ylbar[1,0] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7bar[0,mif1] * self.yl[1,2] * self.ylbar[1,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif2] * self.yeqPi7bar[0,mif1] * self.yl[1,2] * self.ylbar[1,0] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7bar[1,mif1] * self.yl[1,0] * self.ylbar[1,1] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7bar[1,mif1] * self.yl[1,0] * self.ylbar[1,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif2] * self.yeqPi7bar[1,mif1] * self.yl[1,0] * self.ylbar[1,1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] * self.yl[1,1] * self.ylbar[1,1] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] * self.yl[1,1] * self.ylbar[1,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] * self.yl[1,1] * self.ylbar[1,1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7bar[1,mif1] * self.yl[1,2] * self.ylbar[1,1] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7bar[1,mif1] * self.yl[1,2] * self.ylbar[1,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif2] * self.yeqPi7bar[1,mif1] * self.yl[1,2] * self.ylbar[1,1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7bar[2,mif1] * self.yl[1,0] * self.ylbar[1,2] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7bar[2,mif1] * self.yl[1,0] * self.ylbar[1,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif2] * self.yeqPi7bar[2,mif1] * self.yl[1,0] * self.ylbar[1,2] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7bar[2,mif1] * self.yl[1,1] * self.ylbar[1,2] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7bar[2,mif1] * self.yl[1,1] * self.ylbar[1,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif2] * self.yeqPi7bar[2,mif1] * self.yl[1,1] * self.ylbar[1,2] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] * self.yl[1,2] * self.ylbar[1,2] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] * self.yl[1,2] * self.ylbar[1,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] * self.yl[1,2] * self.ylbar[1,2] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] * self.yl[2,0] * self.ylbar[2,0] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] * self.yl[2,0] * self.ylbar[2,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] * self.yl[2,0] * self.ylbar[2,0] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7bar[0,mif1] * self.yl[2,1] * self.ylbar[2,0] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7bar[0,mif1] * self.yl[2,1] * self.ylbar[2,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif2] * self.yeqPi7bar[0,mif1] * self.yl[2,1] * self.ylbar[2,0] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7bar[0,mif1] * self.yl[2,2] * self.ylbar[2,0] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7bar[0,mif1] * self.yl[2,2] * self.ylbar[2,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif2] * self.yeqPi7bar[0,mif1] * self.yl[2,2] * self.ylbar[2,0] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7bar[1,mif1] * self.yl[2,0] * self.ylbar[2,1] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7bar[1,mif1] * self.yl[2,0] * self.ylbar[2,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif2] * self.yeqPi7bar[1,mif1] * self.yl[2,0] * self.ylbar[2,1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] * self.yl[2,1] * self.ylbar[2,1] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] * self.yl[2,1] * self.ylbar[2,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] * self.yl[2,1] * self.ylbar[2,1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7bar[1,mif1] * self.yl[2,2] * self.ylbar[2,1] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7bar[1,mif1] * self.yl[2,2] * self.ylbar[2,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif2] * self.yeqPi7bar[1,mif1] * self.yl[2,2] * self.ylbar[2,1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7bar[2,mif1] * self.yl[2,0] * self.ylbar[2,2] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7bar[2,mif1] * self.yl[2,0] * self.ylbar[2,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif2] * self.yeqPi7bar[2,mif1] * self.yl[2,0] * self.ylbar[2,2] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7bar[2,mif1] * self.yl[2,1] * self.ylbar[2,2] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7bar[2,mif1] * self.yl[2,1] * self.ylbar[2,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif2] * self.yeqPi7bar[2,mif1] * self.yl[2,1] * self.ylbar[2,2] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] * self.yl[2,2] * self.ylbar[2,2] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] * self.yl[2,2] * self.ylbar[2,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] * self.yl[2,2] * self.ylbar[2,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[0,0] * self.yluPi7bar[0,0] * self.yu[mif1,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[0,1] * self.yluPi7bar[0,0] * self.yu[mif1,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[0,2] * self.yluPi7bar[0,0] * self.yu[mif1,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[1,0] * self.yluPi7bar[1,0] * self.yu[mif1,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[1,1] * self.yluPi7bar[1,0] * self.yu[mif1,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[1,2] * self.yluPi7bar[1,0] * self.yu[mif1,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[2,0] * self.yluPi7bar[2,0] * self.yu[mif1,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[2,1] * self.yluPi7bar[2,0] * self.yu[mif1,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[2,2] * self.yluPi7bar[2,0] * self.yu[mif1,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[0,0] * self.yluPi7bar[0,1] * self.yu[mif1,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[0,1] * self.yluPi7bar[0,1] * self.yu[mif1,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[0,2] * self.yluPi7bar[0,1] * self.yu[mif1,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[1,0] * self.yluPi7bar[1,1] * self.yu[mif1,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[1,1] * self.yluPi7bar[1,1] * self.yu[mif1,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[1,2] * self.yluPi7bar[1,1] * self.yu[mif1,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[2,0] * self.yluPi7bar[2,1] * self.yu[mif1,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[2,1] * self.yluPi7bar[2,1] * self.yu[mif1,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[2,2] * self.yluPi7bar[2,1] * self.yu[mif1,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[0,0] * self.yluPi7bar[0,2] * self.yu[mif1,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[0,1] * self.yluPi7bar[0,2] * self.yu[mif1,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[0,2] * self.yluPi7bar[0,2] * self.yu[mif1,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[1,0] * self.yluPi7bar[1,2] * self.yu[mif1,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[1,1] * self.yluPi7bar[1,2] * self.yu[mif1,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[1,2] * self.yluPi7bar[1,2] * self.yu[mif1,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[2,0] * self.yluPi7bar[2,2] * self.yu[mif1,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[2,1] * self.yluPi7bar[2,2] * self.yu[mif1,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[2,2] * self.yluPi7bar[2,2] * self.yu[mif1,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,0] * self.yubar[mif2,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,0] * self.yubar[mif2,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,0] * self.yubar[mif2,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,0] * self.yubar[mif2,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,0] * self.yubar[mif2,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,0] * self.yubar[mif2,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,0] * self.yubar[mif2,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,0] * self.yubar[mif2,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,0] * self.yubar[mif2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,0] * self.yluPi7bar[0,0] * self.yu[mif1,0] * self.yubar[mif2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,0] * self.yluPi7bar[1,0] * self.yu[mif1,0] * self.yubar[mif2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,0] * self.yluPi7bar[2,0] * self.yu[mif1,0] * self.yubar[mif2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,0] * self.yluPi7bar[0,1] * self.yu[mif1,1] * self.yubar[mif2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,0] * self.yluPi7bar[1,1] * self.yu[mif1,1] * self.yubar[mif2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,0] * self.yluPi7bar[2,1] * self.yu[mif1,1] * self.yubar[mif2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,0] * self.yluPi7bar[0,2] * self.yu[mif1,2] * self.yubar[mif2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,0] * self.yluPi7bar[1,2] * self.yu[mif1,2] * self.yubar[mif2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,0] * self.yluPi7bar[2,2] * self.yu[mif1,2] * self.yubar[mif2,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,1] * self.yubar[mif2,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,1] * self.yubar[mif2,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,1] * self.yubar[mif2,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,1] * self.yubar[mif2,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,1] * self.yubar[mif2,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,1] * self.yubar[mif2,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,1] * self.yubar[mif2,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,1] * self.yubar[mif2,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,1] * self.yubar[mif2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,1] * self.yluPi7bar[0,0] * self.yu[mif1,0] * self.yubar[mif2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,1] * self.yluPi7bar[1,0] * self.yu[mif1,0] * self.yubar[mif2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,1] * self.yluPi7bar[2,0] * self.yu[mif1,0] * self.yubar[mif2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,1] * self.yluPi7bar[0,1] * self.yu[mif1,1] * self.yubar[mif2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,1] * self.yluPi7bar[1,1] * self.yu[mif1,1] * self.yubar[mif2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,1] * self.yluPi7bar[2,1] * self.yu[mif1,1] * self.yubar[mif2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,1] * self.yluPi7bar[0,2] * self.yu[mif1,2] * self.yubar[mif2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,1] * self.yluPi7bar[1,2] * self.yu[mif1,2] * self.yubar[mif2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,1] * self.yluPi7bar[2,2] * self.yu[mif1,2] * self.yubar[mif2,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,2] * self.yubar[mif2,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,2] * self.yubar[mif2,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,2] * self.yubar[mif2,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,2] * self.yubar[mif2,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,2] * self.yubar[mif2,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,2] * self.yubar[mif2,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,2] * self.yubar[mif2,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,2] * self.yubar[mif2,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,2] * self.yubar[mif2,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,2] * self.yluPi7bar[0,0] * self.yu[mif1,0] * self.yubar[mif2,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,2] * self.yluPi7bar[1,0] * self.yu[mif1,0] * self.yubar[mif2,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,2] * self.yluPi7bar[2,0] * self.yu[mif1,0] * self.yubar[mif2,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,2] * self.yluPi7bar[0,1] * self.yu[mif1,1] * self.yubar[mif2,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,2] * self.yluPi7bar[1,1] * self.yu[mif1,1] * self.yubar[mif2,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,2] * self.yluPi7bar[2,1] * self.yu[mif1,1] * self.yubar[mif2,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,2] * self.yluPi7bar[0,2] * self.yu[mif1,2] * self.yubar[mif2,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,2] * self.yluPi7bar[1,2] * self.yu[mif1,2] * self.yubar[mif2,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,2] * self.yluPi7bar[2,2] * self.yu[mif1,2] * self.yubar[mif2,2])

    def alphaOHq3(self, mif1,mif2):
        return (-1/1280 * (self.g2)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) + 1/1152 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] + 1/1152 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] + 1/1152 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[0,0] * self.yluPi7bar[0,0] * self.yu[mif1,0] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[0,1] * self.yluPi7bar[0,0] * self.yu[mif1,0] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[0,2] * self.yluPi7bar[0,0] * self.yu[mif1,0] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[1,0] * self.yluPi7bar[1,0] * self.yu[mif1,0] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[1,1] * self.yluPi7bar[1,0] * self.yu[mif1,0] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[1,2] * self.yluPi7bar[1,0] * self.yu[mif1,0] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[2,0] * self.yluPi7bar[2,0] * self.yu[mif1,0] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[2,1] * self.yluPi7bar[2,0] * self.yu[mif1,0] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[2,2] * self.yluPi7bar[2,0] * self.yu[mif1,0] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[0,0] * self.yluPi7bar[0,1] * self.yu[mif1,1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[0,1] * self.yluPi7bar[0,1] * self.yu[mif1,1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[0,2] * self.yluPi7bar[0,1] * self.yu[mif1,1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[1,0] * self.yluPi7bar[1,1] * self.yu[mif1,1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[1,1] * self.yluPi7bar[1,1] * self.yu[mif1,1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[1,2] * self.yluPi7bar[1,1] * self.yu[mif1,1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[2,0] * self.yluPi7bar[2,1] * self.yu[mif1,1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[2,1] * self.yluPi7bar[2,1] * self.yu[mif1,1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[2,2] * self.yluPi7bar[2,1] * self.yu[mif1,1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[0,0] * self.yluPi7bar[0,2] * self.yu[mif1,2] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[0,1] * self.yluPi7bar[0,2] * self.yu[mif1,2] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[0,2] * self.yluPi7bar[0,2] * self.yu[mif1,2] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[1,0] * self.yluPi7bar[1,2] * self.yu[mif1,2] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[1,1] * self.yluPi7bar[1,2] * self.yu[mif1,2] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[1,2] * self.yluPi7bar[1,2] * self.yu[mif1,2] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[2,0] * self.yluPi7bar[2,2] * self.yu[mif1,2] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[2,1] * self.yluPi7bar[2,2] * self.yu[mif1,2] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[2,2] * self.yluPi7bar[2,2] * self.yu[mif1,2] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,0] * self.yubar[mif2,0] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,0] * self.yubar[mif2,0] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,0] * self.yubar[mif2,0] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,0] * self.yubar[mif2,0] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,0] * self.yubar[mif2,0] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,0] * self.yubar[mif2,0] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,0] * self.yubar[mif2,0] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,0] * self.yubar[mif2,0] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,0] * self.yubar[mif2,0] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,0] * self.yluPi7bar[0,0] * self.yu[mif1,0] * self.yubar[mif2,0] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,0] * self.yluPi7bar[1,0] * self.yu[mif1,0] * self.yubar[mif2,0] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,0] * self.yluPi7bar[2,0] * self.yu[mif1,0] * self.yubar[mif2,0] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,0] * self.yluPi7bar[0,1] * self.yu[mif1,1] * self.yubar[mif2,0] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,0] * self.yluPi7bar[1,1] * self.yu[mif1,1] * self.yubar[mif2,0] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,0] * self.yluPi7bar[2,1] * self.yu[mif1,1] * self.yubar[mif2,0] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,0] * self.yluPi7bar[0,2] * self.yu[mif1,2] * self.yubar[mif2,0] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,0] * self.yluPi7bar[1,2] * self.yu[mif1,2] * self.yubar[mif2,0] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,0] * self.yluPi7bar[2,2] * self.yu[mif1,2] * self.yubar[mif2,0] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,1] * self.yubar[mif2,1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,1] * self.yubar[mif2,1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,1] * self.yubar[mif2,1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,1] * self.yubar[mif2,1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,1] * self.yubar[mif2,1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,1] * self.yubar[mif2,1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,1] * self.yubar[mif2,1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,1] * self.yubar[mif2,1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,1] * self.yubar[mif2,1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,1] * self.yluPi7bar[0,0] * self.yu[mif1,0] * self.yubar[mif2,1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,1] * self.yluPi7bar[1,0] * self.yu[mif1,0] * self.yubar[mif2,1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,1] * self.yluPi7bar[2,0] * self.yu[mif1,0] * self.yubar[mif2,1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,1] * self.yluPi7bar[0,1] * self.yu[mif1,1] * self.yubar[mif2,1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,1] * self.yluPi7bar[1,1] * self.yu[mif1,1] * self.yubar[mif2,1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,1] * self.yluPi7bar[2,1] * self.yu[mif1,1] * self.yubar[mif2,1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,1] * self.yluPi7bar[0,2] * self.yu[mif1,2] * self.yubar[mif2,1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,1] * self.yluPi7bar[1,2] * self.yu[mif1,2] * self.yubar[mif2,1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,1] * self.yluPi7bar[2,2] * self.yu[mif1,2] * self.yubar[mif2,1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,2] * self.yubar[mif2,2] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,2] * self.yubar[mif2,2] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,2] * self.yubar[mif2,2] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,2] * self.yubar[mif2,2] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,2] * self.yubar[mif2,2] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,2] * self.yubar[mif2,2] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,2] * self.yubar[mif2,2] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,2] * self.yubar[mif2,2] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,2] * self.yubar[mif2,2] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,2] * self.yluPi7bar[0,0] * self.yu[mif1,0] * self.yubar[mif2,2] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,2] * self.yluPi7bar[1,0] * self.yu[mif1,0] * self.yubar[mif2,2] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,2] * self.yluPi7bar[2,0] * self.yu[mif1,0] * self.yubar[mif2,2] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,2] * self.yluPi7bar[0,1] * self.yu[mif1,1] * self.yubar[mif2,2] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,2] * self.yluPi7bar[1,1] * self.yu[mif1,1] * self.yubar[mif2,2] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,2] * self.yluPi7bar[2,1] * self.yu[mif1,1] * self.yubar[mif2,2] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,2] * self.yluPi7bar[0,2] * self.yu[mif1,2] * self.yubar[mif2,2] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,2] * self.yluPi7bar[1,2] * self.yu[mif1,2] * self.yubar[mif2,2] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,2] * self.yluPi7bar[2,2] * self.yu[mif1,2] * self.yubar[mif2,2])

    def alphaOHu(self, mif1,mif2):
        return (-49/8640 * (self.g1)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) + 31/1728 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,mif2] * self.yluPi7bar[0,mif1] + 1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,mif2] * self.yluPi7bar[0,mif1] + -1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[0,mif2] * self.yluPi7bar[0,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yluPi7bar[0,mif1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yluPi7bar[0,mif1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[0,0] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yluPi7bar[0,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yluPi7bar[0,mif1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yluPi7bar[0,mif1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[0,1] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yluPi7bar[0,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yluPi7bar[0,mif1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yluPi7bar[0,mif1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[0,2] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yluPi7bar[0,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yluPi7bar[0,mif1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yluPi7bar[0,mif1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[0,0] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yluPi7bar[0,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yluPi7bar[0,mif1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yluPi7bar[0,mif1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[0,1] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yluPi7bar[0,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yluPi7bar[0,mif1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yluPi7bar[0,mif1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[0,2] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yluPi7bar[0,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yluPi7bar[0,mif1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yluPi7bar[0,mif1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[0,0] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yluPi7bar[0,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yluPi7bar[0,mif1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yluPi7bar[0,mif1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[0,1] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yluPi7bar[0,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yluPi7bar[0,mif1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yluPi7bar[0,mif1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[0,2] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yluPi7bar[0,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yluPi7bar[1,mif1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yluPi7bar[1,mif1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[1,0] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yluPi7bar[1,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yluPi7bar[1,mif1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yluPi7bar[1,mif1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[1,1] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yluPi7bar[1,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yluPi7bar[1,mif1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yluPi7bar[1,mif1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[1,2] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yluPi7bar[1,mif1] + 31/1728 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,mif2] * self.yluPi7bar[1,mif1] + 1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,mif2] * self.yluPi7bar[1,mif1] + -1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[1,mif2] * self.yluPi7bar[1,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yluPi7bar[1,mif1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yluPi7bar[1,mif1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[1,0] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yluPi7bar[1,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yluPi7bar[1,mif1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yluPi7bar[1,mif1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[1,1] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yluPi7bar[1,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yluPi7bar[1,mif1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yluPi7bar[1,mif1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[1,2] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yluPi7bar[1,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yluPi7bar[1,mif1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yluPi7bar[1,mif1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[1,0] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yluPi7bar[1,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yluPi7bar[1,mif1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yluPi7bar[1,mif1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[1,1] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yluPi7bar[1,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yluPi7bar[1,mif1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yluPi7bar[1,mif1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[1,2] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yluPi7bar[1,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yluPi7bar[2,mif1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yluPi7bar[2,mif1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[2,0] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yluPi7bar[2,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yluPi7bar[2,mif1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yluPi7bar[2,mif1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[2,1] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yluPi7bar[2,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yluPi7bar[2,mif1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yluPi7bar[2,mif1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[2,2] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yluPi7bar[2,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yluPi7bar[2,mif1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yluPi7bar[2,mif1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[2,0] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yluPi7bar[2,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yluPi7bar[2,mif1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yluPi7bar[2,mif1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[2,1] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yluPi7bar[2,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yluPi7bar[2,mif1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yluPi7bar[2,mif1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[2,2] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yluPi7bar[2,mif1] + 31/1728 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,mif2] * self.yluPi7bar[2,mif1] + 1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,mif2] * self.yluPi7bar[2,mif1] + -1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[2,mif2] * self.yluPi7bar[2,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yluPi7bar[2,mif1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yluPi7bar[2,mif1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[2,0] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yluPi7bar[2,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yluPi7bar[2,mif1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yluPi7bar[2,mif1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[2,1] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yluPi7bar[2,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yluPi7bar[2,mif1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yluPi7bar[2,mif1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yl[2,2] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yluPi7bar[2,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yl[0,0] * self.yluPi7bar[0,mif1] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yl[0,1] * self.yluPi7bar[0,mif1] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yl[0,2] * self.yluPi7bar[0,mif1] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yl[1,0] * self.yluPi7bar[1,mif1] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yl[1,1] * self.yluPi7bar[1,mif1] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yl[1,2] * self.yluPi7bar[1,mif1] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yl[2,0] * self.yluPi7bar[2,mif1] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yl[2,1] * self.yluPi7bar[2,mif1] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yl[2,2] * self.yluPi7bar[2,mif1] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yl[0,0] * self.yluPi7bar[0,mif1] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yl[0,1] * self.yluPi7bar[0,mif1] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yl[0,2] * self.yluPi7bar[0,mif1] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yl[1,0] * self.yluPi7bar[1,mif1] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yl[1,1] * self.yluPi7bar[1,mif1] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yl[1,2] * self.yluPi7bar[1,mif1] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yl[2,0] * self.yluPi7bar[2,mif1] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yl[2,1] * self.yluPi7bar[2,mif1] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yl[2,2] * self.yluPi7bar[2,mif1] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yl[0,0] * self.yluPi7bar[0,mif1] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yl[0,1] * self.yluPi7bar[0,mif1] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yl[0,2] * self.yluPi7bar[0,mif1] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yl[1,0] * self.yluPi7bar[1,mif1] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yl[1,1] * self.yluPi7bar[1,mif1] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yl[1,2] * self.yluPi7bar[1,mif1] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yl[2,0] * self.yluPi7bar[2,mif1] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yl[2,1] * self.yluPi7bar[2,mif1] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yl[2,2] * self.yluPi7bar[2,mif1] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,0] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yubar[0,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,0] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yubar[0,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,0] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yubar[0,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,0] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yubar[0,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,0] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yubar[0,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,0] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yubar[0,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,0] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yubar[0,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,0] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yubar[0,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,0] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yubar[0,mif1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[0,0] * self.yu[0,mif2] * self.yubar[0,mif1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[1,0] * self.yu[0,mif2] * self.yubar[0,mif1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[2,0] * self.yu[0,mif2] * self.yubar[0,mif1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[0,0] * self.yu[1,mif2] * self.yubar[0,mif1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[1,0] * self.yu[1,mif2] * self.yubar[0,mif1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[2,0] * self.yu[1,mif2] * self.yubar[0,mif1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[0,0] * self.yu[2,mif2] * self.yubar[0,mif1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[1,0] * self.yu[2,mif2] * self.yubar[0,mif1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[2,0] * self.yu[2,mif2] * self.yubar[0,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,1] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yubar[1,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,1] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yubar[1,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,1] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yubar[1,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,1] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yubar[1,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,1] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yubar[1,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,1] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yubar[1,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,1] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yubar[1,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,1] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yubar[1,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,1] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yubar[1,mif1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[0,1] * self.yu[0,mif2] * self.yubar[1,mif1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[1,1] * self.yu[0,mif2] * self.yubar[1,mif1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[2,1] * self.yu[0,mif2] * self.yubar[1,mif1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[0,1] * self.yu[1,mif2] * self.yubar[1,mif1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[1,1] * self.yu[1,mif2] * self.yubar[1,mif1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[2,1] * self.yu[1,mif2] * self.yubar[1,mif1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[0,1] * self.yu[2,mif2] * self.yubar[1,mif1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[1,1] * self.yu[2,mif2] * self.yubar[1,mif1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[2,1] * self.yu[2,mif2] * self.yubar[1,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,2] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yubar[2,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,2] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yubar[2,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,2] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yubar[2,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,2] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yubar[2,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,2] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yubar[2,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,2] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yubar[2,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,2] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yubar[2,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,2] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yubar[2,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,2] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yubar[2,mif1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[0,2] * self.yu[0,mif2] * self.yubar[2,mif1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[1,2] * self.yu[0,mif2] * self.yubar[2,mif1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[2,2] * self.yu[0,mif2] * self.yubar[2,mif1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[0,2] * self.yu[1,mif2] * self.yubar[2,mif1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[1,2] * self.yu[1,mif2] * self.yubar[2,mif1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[2,2] * self.yu[1,mif2] * self.yubar[2,mif1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[0,2] * self.yu[2,mif2] * self.yubar[2,mif1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[1,2] * self.yu[2,mif2] * self.yubar[2,mif1] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[2,2] * self.yu[2,mif2] * self.yubar[2,mif1])

    def alphaOHud(self, mif1,mif2):
        return (1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[0,0] * self.yl[0,0] * self.yluPi7bar[0,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[0,1] * self.yl[0,0] * self.yluPi7bar[0,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[0,2] * self.yl[0,0] * self.yluPi7bar[0,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[1,0] * self.yl[0,1] * self.yluPi7bar[0,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[1,1] * self.yl[0,1] * self.yluPi7bar[0,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[1,2] * self.yl[0,1] * self.yluPi7bar[0,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[2,0] * self.yl[0,2] * self.yluPi7bar[0,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[2,1] * self.yl[0,2] * self.yluPi7bar[0,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[2,2] * self.yl[0,2] * self.yluPi7bar[0,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[0,0] * self.yl[1,0] * self.yluPi7bar[1,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[0,1] * self.yl[1,0] * self.yluPi7bar[1,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[0,2] * self.yl[1,0] * self.yluPi7bar[1,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[1,0] * self.yl[1,1] * self.yluPi7bar[1,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[1,1] * self.yl[1,1] * self.yluPi7bar[1,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[1,2] * self.yl[1,1] * self.yluPi7bar[1,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[2,0] * self.yl[1,2] * self.yluPi7bar[1,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[2,1] * self.yl[1,2] * self.yluPi7bar[1,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[2,2] * self.yl[1,2] * self.yluPi7bar[1,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[0,0] * self.yl[2,0] * self.yluPi7bar[2,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[0,1] * self.yl[2,0] * self.yluPi7bar[2,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[0,2] * self.yl[2,0] * self.yluPi7bar[2,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[1,0] * self.yl[2,1] * self.yluPi7bar[2,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[1,1] * self.yl[2,1] * self.yluPi7bar[2,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[1,2] * self.yl[2,1] * self.yluPi7bar[2,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[2,0] * self.yl[2,2] * self.yluPi7bar[2,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[2,1] * self.yl[2,2] * self.yluPi7bar[2,mif1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[2,2] * self.yl[2,2] * self.yluPi7bar[2,mif1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[0,0] * self.yeqPi7bar[0,0] * self.yubar[0,mif1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[0,1] * self.yeqPi7bar[0,0] * self.yubar[0,mif1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[0,2] * self.yeqPi7bar[0,0] * self.yubar[0,mif1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[1,0] * self.yeqPi7bar[1,0] * self.yubar[0,mif1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[1,1] * self.yeqPi7bar[1,0] * self.yubar[0,mif1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[1,2] * self.yeqPi7bar[1,0] * self.yubar[0,mif1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[2,0] * self.yeqPi7bar[2,0] * self.yubar[0,mif1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[2,1] * self.yeqPi7bar[2,0] * self.yubar[0,mif1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[2,2] * self.yeqPi7bar[2,0] * self.yubar[0,mif1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[0,0] * self.yeqPi7bar[0,1] * self.yubar[1,mif1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[0,1] * self.yeqPi7bar[0,1] * self.yubar[1,mif1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[0,2] * self.yeqPi7bar[0,1] * self.yubar[1,mif1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[1,0] * self.yeqPi7bar[1,1] * self.yubar[1,mif1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[1,1] * self.yeqPi7bar[1,1] * self.yubar[1,mif1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[1,2] * self.yeqPi7bar[1,1] * self.yubar[1,mif1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[2,0] * self.yeqPi7bar[2,1] * self.yubar[1,mif1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[2,1] * self.yeqPi7bar[2,1] * self.yubar[1,mif1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[2,2] * self.yeqPi7bar[2,1] * self.yubar[1,mif1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[0,0] * self.yeqPi7bar[0,2] * self.yubar[2,mif1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[0,1] * self.yeqPi7bar[0,2] * self.yubar[2,mif1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[0,2] * self.yeqPi7bar[0,2] * self.yubar[2,mif1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[1,0] * self.yeqPi7bar[1,2] * self.yubar[2,mif1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[1,1] * self.yeqPi7bar[1,2] * self.yubar[2,mif1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[1,2] * self.yeqPi7bar[1,2] * self.yubar[2,mif1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yeqPi7[2,0] * self.yeqPi7bar[2,2] * self.yubar[2,mif1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yeqPi7[2,1] * self.yeqPi7bar[2,2] * self.yubar[2,mif1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yeqPi7[2,2] * self.yeqPi7bar[2,2] * self.yubar[2,mif1])

    def alphaOld(self, mif1,mif2,mif3,mif4):
        return (-49/17280 * (self.g1)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 13/576 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + 1/72 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + -1/72 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + 13/576 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + 1/72 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + -1/72 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + 13/576 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] + 1/72 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] + -1/72 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2])

    def alphaOle(self, mif1,mif2,mif3,mif4):
        return (-49/5760 * (self.g1)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 5/192 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[mif3,0] * self.yeqPi7bar[mif4,0] + 1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[mif3,0] * self.yeqPi7bar[mif4,0] + -1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif3,0] * self.yeqPi7bar[mif4,0] + 5/192 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[mif3,1] * self.yeqPi7bar[mif4,1] + 1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[mif3,1] * self.yeqPi7bar[mif4,1] + -1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif3,1] * self.yeqPi7bar[mif4,1] + 5/192 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[mif3,2] * self.yeqPi7bar[mif4,2] + 1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[mif3,2] * self.yeqPi7bar[mif4,2] + -1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif3,2] * self.yeqPi7bar[mif4,2] + 13/192 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + 1/24 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + -1/24 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,0] * self.yeqPi7bar[mif4,0] * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,1] * self.yeqPi7bar[mif4,1] * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,2] * self.yeqPi7bar[mif4,2] * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + 13/192 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + 1/24 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + -1/24 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,0] * self.yeqPi7bar[mif4,0] * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,1] * self.yeqPi7bar[mif4,1] * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,2] * self.yeqPi7bar[mif4,2] * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + 13/192 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] + 1/24 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] + -1/24 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,0] * self.yeqPi7bar[mif4,0] * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,1] * self.yeqPi7bar[mif4,1] * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,2] * self.yeqPi7bar[mif4,2] * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] + 9/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,0] * self.yl[mif1,mif4] * self.yluPi7bar[mif2,0] * self.yu[0,0] + 3/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,0] * self.yl[mif1,mif4] * self.yluPi7bar[mif2,0] * self.yu[0,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif3,0] * self.yl[mif1,mif4] * self.yluPi7bar[mif2,0] * self.yu[0,0] + 9/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,0] * self.yl[mif1,mif4] * self.yluPi7bar[mif2,1] * self.yu[0,1] + 3/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,0] * self.yl[mif1,mif4] * self.yluPi7bar[mif2,1] * self.yu[0,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif3,0] * self.yl[mif1,mif4] * self.yluPi7bar[mif2,1] * self.yu[0,1] + 9/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,0] * self.yl[mif1,mif4] * self.yluPi7bar[mif2,2] * self.yu[0,2] + 3/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,0] * self.yl[mif1,mif4] * self.yluPi7bar[mif2,2] * self.yu[0,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif3,0] * self.yl[mif1,mif4] * self.yluPi7bar[mif2,2] * self.yu[0,2] + 9/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,1] * self.yl[mif1,mif4] * self.yluPi7bar[mif2,0] * self.yu[1,0] + 3/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,1] * self.yl[mif1,mif4] * self.yluPi7bar[mif2,0] * self.yu[1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif3,1] * self.yl[mif1,mif4] * self.yluPi7bar[mif2,0] * self.yu[1,0] + 9/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,1] * self.yl[mif1,mif4] * self.yluPi7bar[mif2,1] * self.yu[1,1] + 3/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,1] * self.yl[mif1,mif4] * self.yluPi7bar[mif2,1] * self.yu[1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif3,1] * self.yl[mif1,mif4] * self.yluPi7bar[mif2,1] * self.yu[1,1] + 9/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,1] * self.yl[mif1,mif4] * self.yluPi7bar[mif2,2] * self.yu[1,2] + 3/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,1] * self.yl[mif1,mif4] * self.yluPi7bar[mif2,2] * self.yu[1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif3,1] * self.yl[mif1,mif4] * self.yluPi7bar[mif2,2] * self.yu[1,2] + 9/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,2] * self.yl[mif1,mif4] * self.yluPi7bar[mif2,0] * self.yu[2,0] + 3/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,2] * self.yl[mif1,mif4] * self.yluPi7bar[mif2,0] * self.yu[2,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif3,2] * self.yl[mif1,mif4] * self.yluPi7bar[mif2,0] * self.yu[2,0] + 9/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,2] * self.yl[mif1,mif4] * self.yluPi7bar[mif2,1] * self.yu[2,1] + 3/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,2] * self.yl[mif1,mif4] * self.yluPi7bar[mif2,1] * self.yu[2,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif3,2] * self.yl[mif1,mif4] * self.yluPi7bar[mif2,1] * self.yu[2,1] + 9/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,2] * self.yl[mif1,mif4] * self.yluPi7bar[mif2,2] * self.yu[2,2] + 3/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,2] * self.yl[mif1,mif4] * self.yluPi7bar[mif2,2] * self.yu[2,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif3,2] * self.yl[mif1,mif4] * self.yluPi7bar[mif2,2] * self.yu[2,2] + 9/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif4,0] * self.ylbar[mif2,mif3] * self.yluPi7[mif1,0] * self.yubar[0,0] + 3/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif4,0] * self.ylbar[mif2,mif3] * self.yluPi7[mif1,0] * self.yubar[0,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif4,0] * self.ylbar[mif2,mif3] * self.yluPi7[mif1,0] * self.yubar[0,0] + 9/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif4,0] * self.ylbar[mif2,mif3] * self.yluPi7[mif1,1] * self.yubar[0,1] + 3/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif4,0] * self.ylbar[mif2,mif3] * self.yluPi7[mif1,1] * self.yubar[0,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif4,0] * self.ylbar[mif2,mif3] * self.yluPi7[mif1,1] * self.yubar[0,1] + 9/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif4,0] * self.ylbar[mif2,mif3] * self.yluPi7[mif1,2] * self.yubar[0,2] + 3/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif4,0] * self.ylbar[mif2,mif3] * self.yluPi7[mif1,2] * self.yubar[0,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif4,0] * self.ylbar[mif2,mif3] * self.yluPi7[mif1,2] * self.yubar[0,2] + 9/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif4,1] * self.ylbar[mif2,mif3] * self.yluPi7[mif1,0] * self.yubar[1,0] + 3/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif4,1] * self.ylbar[mif2,mif3] * self.yluPi7[mif1,0] * self.yubar[1,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif4,1] * self.ylbar[mif2,mif3] * self.yluPi7[mif1,0] * self.yubar[1,0] + 9/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif4,1] * self.ylbar[mif2,mif3] * self.yluPi7[mif1,1] * self.yubar[1,1] + 3/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif4,1] * self.ylbar[mif2,mif3] * self.yluPi7[mif1,1] * self.yubar[1,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif4,1] * self.ylbar[mif2,mif3] * self.yluPi7[mif1,1] * self.yubar[1,1] + 9/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif4,1] * self.ylbar[mif2,mif3] * self.yluPi7[mif1,2] * self.yubar[1,2] + 3/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif4,1] * self.ylbar[mif2,mif3] * self.yluPi7[mif1,2] * self.yubar[1,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif4,1] * self.ylbar[mif2,mif3] * self.yluPi7[mif1,2] * self.yubar[1,2] + 9/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif4,2] * self.ylbar[mif2,mif3] * self.yluPi7[mif1,0] * self.yubar[2,0] + 3/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif4,2] * self.ylbar[mif2,mif3] * self.yluPi7[mif1,0] * self.yubar[2,0] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif4,2] * self.ylbar[mif2,mif3] * self.yluPi7[mif1,0] * self.yubar[2,0] + 9/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif4,2] * self.ylbar[mif2,mif3] * self.yluPi7[mif1,1] * self.yubar[2,1] + 3/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif4,2] * self.ylbar[mif2,mif3] * self.yluPi7[mif1,1] * self.yubar[2,1] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif4,2] * self.ylbar[mif2,mif3] * self.yluPi7[mif1,1] * self.yubar[2,1] + 9/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif4,2] * self.ylbar[mif2,mif3] * self.yluPi7[mif1,2] * self.yubar[2,2] + 3/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif4,2] * self.ylbar[mif2,mif3] * self.yluPi7[mif1,2] * self.yubar[2,2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif4,2] * self.ylbar[mif2,mif3] * self.yluPi7[mif1,2] * self.yubar[2,2])

    def alphaOledq(self, mif1,mif2,mif3,mif4):
        return (5/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[0,mif3] * self.yeqPi7[0,mif4] * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[0,mif3] * self.yeqPi7[0,mif4] * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.ydbar[0,mif3] * self.yeqPi7[0,mif4] * self.yeqPi7bar[mif2,0] * self.yl[mif1,0] + 5/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[1,mif3] * self.yeqPi7[0,mif4] * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[1,mif3] * self.yeqPi7[0,mif4] * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.ydbar[1,mif3] * self.yeqPi7[0,mif4] * self.yeqPi7bar[mif2,1] * self.yl[mif1,0] + 5/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[2,mif3] * self.yeqPi7[0,mif4] * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[2,mif3] * self.yeqPi7[0,mif4] * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.ydbar[2,mif3] * self.yeqPi7[0,mif4] * self.yeqPi7bar[mif2,2] * self.yl[mif1,0] + 5/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[0,mif3] * self.yeqPi7[1,mif4] * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[0,mif3] * self.yeqPi7[1,mif4] * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.ydbar[0,mif3] * self.yeqPi7[1,mif4] * self.yeqPi7bar[mif2,0] * self.yl[mif1,1] + 5/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[1,mif3] * self.yeqPi7[1,mif4] * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[1,mif3] * self.yeqPi7[1,mif4] * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.ydbar[1,mif3] * self.yeqPi7[1,mif4] * self.yeqPi7bar[mif2,1] * self.yl[mif1,1] + 5/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[2,mif3] * self.yeqPi7[1,mif4] * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[2,mif3] * self.yeqPi7[1,mif4] * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.ydbar[2,mif3] * self.yeqPi7[1,mif4] * self.yeqPi7bar[mif2,2] * self.yl[mif1,1] + 5/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[0,mif3] * self.yeqPi7[2,mif4] * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[0,mif3] * self.yeqPi7[2,mif4] * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.ydbar[0,mif3] * self.yeqPi7[2,mif4] * self.yeqPi7bar[mif2,0] * self.yl[mif1,2] + 5/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[1,mif3] * self.yeqPi7[2,mif4] * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[1,mif3] * self.yeqPi7[2,mif4] * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.ydbar[1,mif3] * self.yeqPi7[2,mif4] * self.yeqPi7bar[mif2,1] * self.yl[mif1,2] + 5/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[2,mif3] * self.yeqPi7[2,mif4] * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[2,mif3] * self.yeqPi7[2,mif4] * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.ydbar[2,mif3] * self.yeqPi7[2,mif4] * self.yeqPi7bar[mif2,2] * self.yl[mif1,2] + -9/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[mif4,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[0,0] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[mif4,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[0,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.ydbar[mif4,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[0,0] + -9/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[mif4,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[0,1] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[mif4,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[0,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.ydbar[mif4,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[0,1] + -9/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[mif4,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[0,2] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[mif4,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[0,2] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.ydbar[mif4,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[0,2] + -9/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[mif4,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[1,0] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[mif4,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[1,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.ydbar[mif4,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[1,0] + -9/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[mif4,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[1,1] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[mif4,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[1,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.ydbar[mif4,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[1,1] + -9/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[mif4,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[1,2] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[mif4,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[1,2] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.ydbar[mif4,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[1,2] + -9/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[mif4,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[2,0] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[mif4,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[2,0] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.ydbar[mif4,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[2,0] + -9/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[mif4,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[2,1] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[mif4,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[2,1] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.ydbar[mif4,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[2,1] + -9/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[mif4,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[2,2] + -3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[mif4,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[2,2] + 3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.ydbar[mif4,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[2,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[0,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[mif4,0] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[0,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[mif4,0] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.ydbar[0,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[mif4,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[1,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[mif4,0] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[1,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[mif4,0] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.ydbar[1,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[mif4,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[2,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[mif4,0] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[2,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[mif4,0] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.ydbar[2,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[mif4,0] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[0,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[mif4,1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[0,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[mif4,1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.ydbar[0,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[mif4,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[1,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[mif4,1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[1,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[mif4,1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.ydbar[1,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[mif4,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[2,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[mif4,1] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[2,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[mif4,1] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.ydbar[2,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[mif4,1] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[0,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[mif4,2] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[0,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[mif4,2] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.ydbar[0,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[mif4,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[1,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[mif4,2] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[1,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[mif4,2] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.ydbar[1,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[mif4,2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[2,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[mif4,2] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[2,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[mif4,2] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.ydbar[2,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[mif4,2])

    def alphaOlequ1(self, mif1,mif2,mif3,mif4):
        return (3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif3] * self.yl[mif1,mif2] * self.ylbar[0,0] * self.yluPi7[0,mif4] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif3] * self.yl[mif1,mif2] * self.ylbar[0,0] * self.yluPi7[0,mif4] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif3] * self.yl[mif1,mif2] * self.ylbar[0,0] * self.yluPi7[0,mif4] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif3] * self.yl[mif1,mif2] * self.ylbar[0,1] * self.yluPi7[0,mif4] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif3] * self.yl[mif1,mif2] * self.ylbar[0,1] * self.yluPi7[0,mif4] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif3] * self.yl[mif1,mif2] * self.ylbar[0,1] * self.yluPi7[0,mif4] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif3] * self.yl[mif1,mif2] * self.ylbar[0,2] * self.yluPi7[0,mif4] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif3] * self.yl[mif1,mif2] * self.ylbar[0,2] * self.yluPi7[0,mif4] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif3] * self.yl[mif1,mif2] * self.ylbar[0,2] * self.yluPi7[0,mif4] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif3] * self.yl[mif1,mif2] * self.ylbar[1,0] * self.yluPi7[1,mif4] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif3] * self.yl[mif1,mif2] * self.ylbar[1,0] * self.yluPi7[1,mif4] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif3] * self.yl[mif1,mif2] * self.ylbar[1,0] * self.yluPi7[1,mif4] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif3] * self.yl[mif1,mif2] * self.ylbar[1,1] * self.yluPi7[1,mif4] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif3] * self.yl[mif1,mif2] * self.ylbar[1,1] * self.yluPi7[1,mif4] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif3] * self.yl[mif1,mif2] * self.ylbar[1,1] * self.yluPi7[1,mif4] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif3] * self.yl[mif1,mif2] * self.ylbar[1,2] * self.yluPi7[1,mif4] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif3] * self.yl[mif1,mif2] * self.ylbar[1,2] * self.yluPi7[1,mif4] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif3] * self.yl[mif1,mif2] * self.ylbar[1,2] * self.yluPi7[1,mif4] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif3] * self.yl[mif1,mif2] * self.ylbar[2,0] * self.yluPi7[2,mif4] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif3] * self.yl[mif1,mif2] * self.ylbar[2,0] * self.yluPi7[2,mif4] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif3] * self.yl[mif1,mif2] * self.ylbar[2,0] * self.yluPi7[2,mif4] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif3] * self.yl[mif1,mif2] * self.ylbar[2,1] * self.yluPi7[2,mif4] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif3] * self.yl[mif1,mif2] * self.ylbar[2,1] * self.yluPi7[2,mif4] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif3] * self.yl[mif1,mif2] * self.ylbar[2,1] * self.yluPi7[2,mif4] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif3] * self.yl[mif1,mif2] * self.ylbar[2,2] * self.yluPi7[2,mif4] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif3] * self.yl[mif1,mif2] * self.ylbar[2,2] * self.yluPi7[2,mif4] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif3] * self.yl[mif1,mif2] * self.ylbar[2,2] * self.yluPi7[2,mif4] + -7/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[0,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,mif4] + -7/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[0,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,mif4] + 7/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,0] * self.yeqPi7bar[0,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,mif4] + -7/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[1,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,mif4] + -7/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[1,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,mif4] + 7/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,0] * self.yeqPi7bar[1,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,mif4] + -7/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[2,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,mif4] + -7/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[2,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,mif4] + 7/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,0] * self.yeqPi7bar[2,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,mif4] + -7/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[0,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,mif4] + -7/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[0,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,mif4] + 7/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,1] * self.yeqPi7bar[0,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,mif4] + -7/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[1,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,mif4] + -7/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[1,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,mif4] + 7/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,1] * self.yeqPi7bar[1,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,mif4] + -7/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[2,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,mif4] + -7/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[2,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,mif4] + 7/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,1] * self.yeqPi7bar[2,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,mif4] + -7/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[0,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,mif4] + -7/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[0,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,mif4] + 7/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,2] * self.yeqPi7bar[0,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,mif4] + -7/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[1,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,mif4] + -7/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[1,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,mif4] + 7/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,2] * self.yeqPi7bar[1,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,mif4] + -7/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[2,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,mif4] + -7/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[2,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,mif4] + 7/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,2] * self.yeqPi7bar[2,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,mif4] + 1/2 * (self.MPi7)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + -65/1152 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + -5/768 * self.epsilonbar * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + -3/128 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + -9/256 * self.epsilonbar * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + -1/48 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + 1/16 * self.epsilonbar * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + 5/384 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + -5/1152 * self.epsilonbar * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + 9/128 * (self.g2)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + -3/128 * self.epsilonbar * (self.g2)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + -1/8 * (self.g3)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + 1/24 * self.epsilonbar * (self.g3)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + -5/384 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + 5/1152 * self.epsilonbar * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + -9/128 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + 3/128 * self.epsilonbar * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + 1/8 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + -1/24 * self.epsilonbar * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + -5/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[0,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[0,0] + -5/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[0,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[0,0] + 5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[0,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[0,0] + -5/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[0,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[0,1] + -5/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[0,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[0,1] + 5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[0,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[0,1] + -5/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[0,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[0,2] + -5/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[0,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[0,2] + 5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[0,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[0,2] + -5/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[1,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[1,0] + -5/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[1,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[1,0] + 5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[1,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[1,0] + -5/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[1,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[1,1] + -5/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[1,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[1,1] + 5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[1,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[1,1] + -5/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[1,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[1,2] + -5/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[1,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[1,2] + 5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[1,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[1,2] + -5/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[2,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[2,0] + -5/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[2,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[2,0] + 5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[2,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[2,0] + -5/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[2,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[2,1] + -5/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[2,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[2,1] + 5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[2,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[2,1] + -5/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[2,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[2,2] + -5/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[2,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[2,2] + 5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[2,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[2,2] + 9/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[mif3,mif4] * self.yubar[0,0] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[mif3,mif4] * self.yubar[0,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,0] * self.yu[mif3,mif4] * self.yubar[0,0] + 9/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[mif3,mif4] * self.yubar[0,1] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[mif3,mif4] * self.yubar[0,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,1] * self.yu[mif3,mif4] * self.yubar[0,1] + 9/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[mif3,mif4] * self.yubar[0,2] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[mif3,mif4] * self.yubar[0,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,2] * self.yu[mif3,mif4] * self.yubar[0,2] + 9/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[mif3,mif4] * self.yubar[1,0] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[mif3,mif4] * self.yubar[1,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,0] * self.yu[mif3,mif4] * self.yubar[1,0] + 9/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[mif3,mif4] * self.yubar[1,1] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[mif3,mif4] * self.yubar[1,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,1] * self.yu[mif3,mif4] * self.yubar[1,1] + 9/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[mif3,mif4] * self.yubar[1,2] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[mif3,mif4] * self.yubar[1,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,2] * self.yu[mif3,mif4] * self.yubar[1,2] + 9/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[mif3,mif4] * self.yubar[2,0] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[mif3,mif4] * self.yubar[2,0] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,0] * self.yu[mif3,mif4] * self.yubar[2,0] + 9/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[mif3,mif4] * self.yubar[2,1] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[mif3,mif4] * self.yubar[2,1] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,1] * self.yu[mif3,mif4] * self.yubar[2,1] + 9/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[mif3,mif4] * self.yubar[2,2] + 3/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[mif3,mif4] * self.yubar[2,2] + -3/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,2] * self.yu[mif3,mif4] * self.yubar[2,2])

    def alphaOlequ3(self, mif1,mif2,mif3,mif4):
        return (-7/1024 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[0,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,mif4] + -7/512 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[0,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,mif4] + 7/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,0] * self.yeqPi7bar[0,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,mif4] + -7/1024 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[1,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,mif4] + -7/512 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[1,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,mif4] + 7/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,0] * self.yeqPi7bar[1,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,mif4] + -7/1024 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[2,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,mif4] + -7/512 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[2,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,mif4] + 7/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,0] * self.yeqPi7bar[2,mif3] * self.yeqPi7bar[mif2,0] * self.yluPi7[mif1,mif4] + -7/1024 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[0,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,mif4] + -7/512 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[0,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,mif4] + 7/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,1] * self.yeqPi7bar[0,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,mif4] + -7/1024 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[1,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,mif4] + -7/512 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[1,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,mif4] + 7/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,1] * self.yeqPi7bar[1,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,mif4] + -7/1024 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[2,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,mif4] + -7/512 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[2,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,mif4] + 7/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,1] * self.yeqPi7bar[2,mif3] * self.yeqPi7bar[mif2,1] * self.yluPi7[mif1,mif4] + -7/1024 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[0,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,mif4] + -7/512 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[0,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,mif4] + 7/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,2] * self.yeqPi7bar[0,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,mif4] + -7/1024 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[1,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,mif4] + -7/512 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[1,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,mif4] + 7/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,2] * self.yeqPi7bar[1,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,mif4] + -7/1024 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[2,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,mif4] + -7/512 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[2,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,mif4] + 7/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,2] * self.yeqPi7bar[2,mif3] * self.yeqPi7bar[mif2,2] * self.yluPi7[mif1,mif4] + 1/8 * (self.MPi7)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + 5/1536 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + 5/6144 * self.epsilonbar * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + -3/512 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + 9/2048 * self.epsilonbar * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + 1/64 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + -1/128 * self.epsilonbar * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + -5/4608 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + 5/9216 * self.epsilonbar * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + -3/512 * (self.g2)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + 3/1024 * self.epsilonbar * (self.g2)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + 1/96 * (self.g3)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + -1/192 * self.epsilonbar * (self.g3)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + 5/4608 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + -5/9216 * self.epsilonbar * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + 3/512 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + -3/1024 * self.epsilonbar * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + -1/96 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + 1/192 * self.epsilonbar * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[mif1,mif4] + -5/1024 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[0,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[0,0] + -5/512 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[0,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[0,0] + 5/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[0,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[0,0] + -5/1024 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[0,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[0,1] + -5/512 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[0,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[0,1] + 5/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[0,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[0,1] + -5/1024 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[0,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[0,2] + -5/512 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[0,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[0,2] + 5/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[0,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[0,2] + -5/1024 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[1,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[1,0] + -5/512 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[1,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[1,0] + 5/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[1,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[1,0] + -5/1024 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[1,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[1,1] + -5/512 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[1,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[1,1] + 5/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[1,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[1,1] + -5/1024 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[1,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[1,2] + -5/512 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[1,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[1,2] + 5/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[1,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[1,2] + -5/1024 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[2,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[2,0] + -5/512 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[2,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[2,0] + 5/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[2,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[2,0] + -5/1024 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[2,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[2,1] + -5/512 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[2,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[2,1] + 5/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[2,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[2,1] + -5/1024 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[2,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[2,2] + -5/512 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[2,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[2,2] + 5/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[mif2,mif3] * self.yluPi7[2,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[2,2] + 1/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[mif2,mif3] * self.yl[mif1,0] * self.yu[0,mif4] + 1/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[mif2,mif3] * self.yl[mif1,1] * self.yu[0,mif4] + 1/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[mif2,mif3] * self.yl[mif1,2] * self.yu[0,mif4] + 1/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[mif2,mif3] * self.yl[mif1,0] * self.yu[1,mif4] + 1/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[mif2,mif3] * self.yl[mif1,1] * self.yu[1,mif4] + 1/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[mif2,mif3] * self.yl[mif1,2] * self.yu[1,mif4] + 1/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[mif2,mif3] * self.yl[mif1,0] * self.yu[2,mif4] + 1/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[mif2,mif3] * self.yl[mif1,1] * self.yu[2,mif4] + 1/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[mif2,mif3] * self.yl[mif1,2] * self.yu[2,mif4] + 1/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,mif4] * self.yluPi7bar[0,0] * self.yu[mif3,0] + 1/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,mif4] * self.yluPi7bar[1,0] * self.yu[mif3,0] + 1/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,mif4] * self.yluPi7bar[2,0] * self.yu[mif3,0] + 1/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,mif4] * self.yluPi7bar[0,1] * self.yu[mif3,1] + 1/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,mif4] * self.yluPi7bar[1,1] * self.yu[mif3,1] + 1/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,mif4] * self.yluPi7bar[2,1] * self.yu[mif3,1] + 1/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yluPi7[mif1,mif4] * self.yluPi7bar[0,2] * self.yu[mif3,2] + 1/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yluPi7[mif1,mif4] * self.yluPi7bar[1,2] * self.yu[mif3,2] + 1/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yluPi7[mif1,mif4] * self.yluPi7bar[2,2] * self.yu[mif3,2])

    def alphaOll(self, mif1,mif2,mif3,mif4):
        return (-1/1280 * (self.g2)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.kronecker_delta(mif2,mif3) + -49/23040 * (self.g1)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 1/2560 * (self.g2)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 13/768 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + -1/768 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + 1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + -1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + 1/384 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yluPi7[mif3,0] * self.yluPi7bar[mif2,0] + 13/768 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + -1/768 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + 1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + -1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + 1/384 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yluPi7[mif3,1] * self.yluPi7bar[mif2,1] + 13/768 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] + -1/768 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] + 1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] + -1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] + 1/384 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yluPi7[mif3,2] * self.yluPi7bar[mif2,2] + 1/384 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yluPi7[mif1,0] * self.yluPi7bar[mif4,0] + 13/768 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[mif3,0] * self.yluPi7bar[mif4,0] + -1/768 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[mif3,0] * self.yluPi7bar[mif4,0] + 1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[mif3,0] * self.yluPi7bar[mif4,0] + -1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif3,0] * self.yluPi7bar[mif4,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7[mif3,0] * self.yluPi7bar[mif2,0] * self.yluPi7bar[mif4,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7[mif3,1] * self.yluPi7bar[mif2,1] * self.yluPi7bar[mif4,0] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7[mif3,2] * self.yluPi7bar[mif2,2] * self.yluPi7bar[mif4,0] + 1/384 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yluPi7[mif1,1] * self.yluPi7bar[mif4,1] + 13/768 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[mif3,1] * self.yluPi7bar[mif4,1] + -1/768 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[mif3,1] * self.yluPi7bar[mif4,1] + 1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[mif3,1] * self.yluPi7bar[mif4,1] + -1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif3,1] * self.yluPi7bar[mif4,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7[mif3,0] * self.yluPi7bar[mif2,0] * self.yluPi7bar[mif4,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7[mif3,1] * self.yluPi7bar[mif2,1] * self.yluPi7bar[mif4,1] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7[mif3,2] * self.yluPi7bar[mif2,2] * self.yluPi7bar[mif4,1] + 1/384 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yluPi7[mif1,2] * self.yluPi7bar[mif4,2] + 13/768 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[mif3,2] * self.yluPi7bar[mif4,2] + -1/768 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[mif3,2] * self.yluPi7bar[mif4,2] + 1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[mif3,2] * self.yluPi7bar[mif4,2] + -1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif3,2] * self.yluPi7bar[mif4,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7[mif3,0] * self.yluPi7bar[mif2,0] * self.yluPi7bar[mif4,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7[mif3,1] * self.yluPi7bar[mif2,1] * self.yluPi7bar[mif4,2] + -3/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7[mif3,2] * self.yluPi7bar[mif2,2] * self.yluPi7bar[mif4,2])

    def alphaOlq1(self, mif1,mif2,mif3,mif4):
        return (49/34560 * (self.g1)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + -55/3456 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[0,mif4] * self.yeqPi7bar[0,mif3] + -1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[0,mif4] * self.yeqPi7bar[0,mif3] + 1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif4] * self.yeqPi7bar[0,mif3] + -55/3456 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[1,mif4] * self.yeqPi7bar[1,mif3] + -1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[1,mif4] * self.yeqPi7bar[1,mif3] + 1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif4] * self.yeqPi7bar[1,mif3] + -55/3456 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[2,mif4] * self.yeqPi7bar[2,mif3] + -1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[2,mif4] * self.yeqPi7bar[2,mif3] + 1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif4] * self.yeqPi7bar[2,mif3] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif4] * self.yeqPi7bar[0,mif3] * self.yl[mif1,0] * self.ylbar[mif2,0] + 1/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif4] * self.yeqPi7bar[0,mif3] * self.yl[mif1,0] * self.ylbar[mif2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif4] * self.yeqPi7bar[0,mif3] * self.yl[mif1,0] * self.ylbar[mif2,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif4] * self.yeqPi7bar[0,mif3] * self.yl[mif1,1] * self.ylbar[mif2,0] + 1/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif4] * self.yeqPi7bar[0,mif3] * self.yl[mif1,1] * self.ylbar[mif2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif4] * self.yeqPi7bar[0,mif3] * self.yl[mif1,1] * self.ylbar[mif2,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif4] * self.yeqPi7bar[0,mif3] * self.yl[mif1,2] * self.ylbar[mif2,0] + 1/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif4] * self.yeqPi7bar[0,mif3] * self.yl[mif1,2] * self.ylbar[mif2,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif4] * self.yeqPi7bar[0,mif3] * self.yl[mif1,2] * self.ylbar[mif2,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif4] * self.yeqPi7bar[1,mif3] * self.yl[mif1,0] * self.ylbar[mif2,1] + 1/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif4] * self.yeqPi7bar[1,mif3] * self.yl[mif1,0] * self.ylbar[mif2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif4] * self.yeqPi7bar[1,mif3] * self.yl[mif1,0] * self.ylbar[mif2,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif4] * self.yeqPi7bar[1,mif3] * self.yl[mif1,1] * self.ylbar[mif2,1] + 1/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif4] * self.yeqPi7bar[1,mif3] * self.yl[mif1,1] * self.ylbar[mif2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif4] * self.yeqPi7bar[1,mif3] * self.yl[mif1,1] * self.ylbar[mif2,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif4] * self.yeqPi7bar[1,mif3] * self.yl[mif1,2] * self.ylbar[mif2,1] + 1/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif4] * self.yeqPi7bar[1,mif3] * self.yl[mif1,2] * self.ylbar[mif2,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif4] * self.yeqPi7bar[1,mif3] * self.yl[mif1,2] * self.ylbar[mif2,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif4] * self.yeqPi7bar[2,mif3] * self.yl[mif1,0] * self.ylbar[mif2,2] + 1/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif4] * self.yeqPi7bar[2,mif3] * self.yl[mif1,0] * self.ylbar[mif2,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif4] * self.yeqPi7bar[2,mif3] * self.yl[mif1,0] * self.ylbar[mif2,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif4] * self.yeqPi7bar[2,mif3] * self.yl[mif1,1] * self.ylbar[mif2,2] + 1/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif4] * self.yeqPi7bar[2,mif3] * self.yl[mif1,1] * self.ylbar[mif2,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif4] * self.yeqPi7bar[2,mif3] * self.yl[mif1,1] * self.ylbar[mif2,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif4] * self.yeqPi7bar[2,mif3] * self.yl[mif1,2] * self.ylbar[mif2,2] + 1/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif4] * self.yeqPi7bar[2,mif3] * self.yl[mif1,2] * self.ylbar[mif2,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif4] * self.yeqPi7bar[2,mif3] * self.yl[mif1,2] * self.ylbar[mif2,2] + -13/1152 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + -1/144 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + 1/144 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif4] * self.yeqPi7bar[0,mif3] * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif4] * self.yeqPi7bar[1,mif3] * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif4] * self.yeqPi7bar[2,mif3] * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + -13/1152 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + -1/144 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + 1/144 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif4] * self.yeqPi7bar[0,mif3] * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif4] * self.yeqPi7bar[1,mif3] * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif4] * self.yeqPi7bar[2,mif3] * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + -13/1152 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] + -1/144 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] + 1/144 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif4] * self.yeqPi7bar[0,mif3] * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif4] * self.yeqPi7bar[1,mif3] * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif4] * self.yeqPi7bar[2,mif3] * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] + -3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif4] * self.yl[mif1,0] * self.yluPi7bar[mif2,0] * self.yu[mif3,0] + -1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif4] * self.yl[mif1,0] * self.yluPi7bar[mif2,0] * self.yu[mif3,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif4] * self.yl[mif1,0] * self.yluPi7bar[mif2,0] * self.yu[mif3,0] + -3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif4] * self.yl[mif1,1] * self.yluPi7bar[mif2,0] * self.yu[mif3,0] + -1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif4] * self.yl[mif1,1] * self.yluPi7bar[mif2,0] * self.yu[mif3,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif4] * self.yl[mif1,1] * self.yluPi7bar[mif2,0] * self.yu[mif3,0] + -3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif4] * self.yl[mif1,2] * self.yluPi7bar[mif2,0] * self.yu[mif3,0] + -1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif4] * self.yl[mif1,2] * self.yluPi7bar[mif2,0] * self.yu[mif3,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif4] * self.yl[mif1,2] * self.yluPi7bar[mif2,0] * self.yu[mif3,0] + -3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif4] * self.yl[mif1,0] * self.yluPi7bar[mif2,1] * self.yu[mif3,1] + -1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif4] * self.yl[mif1,0] * self.yluPi7bar[mif2,1] * self.yu[mif3,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif4] * self.yl[mif1,0] * self.yluPi7bar[mif2,1] * self.yu[mif3,1] + -3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif4] * self.yl[mif1,1] * self.yluPi7bar[mif2,1] * self.yu[mif3,1] + -1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif4] * self.yl[mif1,1] * self.yluPi7bar[mif2,1] * self.yu[mif3,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif4] * self.yl[mif1,1] * self.yluPi7bar[mif2,1] * self.yu[mif3,1] + -3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif4] * self.yl[mif1,2] * self.yluPi7bar[mif2,1] * self.yu[mif3,1] + -1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif4] * self.yl[mif1,2] * self.yluPi7bar[mif2,1] * self.yu[mif3,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif4] * self.yl[mif1,2] * self.yluPi7bar[mif2,1] * self.yu[mif3,1] + -3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif4] * self.yl[mif1,0] * self.yluPi7bar[mif2,2] * self.yu[mif3,2] + -1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif4] * self.yl[mif1,0] * self.yluPi7bar[mif2,2] * self.yu[mif3,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif4] * self.yl[mif1,0] * self.yluPi7bar[mif2,2] * self.yu[mif3,2] + -3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif4] * self.yl[mif1,1] * self.yluPi7bar[mif2,2] * self.yu[mif3,2] + -1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif4] * self.yl[mif1,1] * self.yluPi7bar[mif2,2] * self.yu[mif3,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif4] * self.yl[mif1,1] * self.yluPi7bar[mif2,2] * self.yu[mif3,2] + -3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif4] * self.yl[mif1,2] * self.yluPi7bar[mif2,2] * self.yu[mif3,2] + -1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif4] * self.yl[mif1,2] * self.yluPi7bar[mif2,2] * self.yu[mif3,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif4] * self.yl[mif1,2] * self.yluPi7bar[mif2,2] * self.yu[mif3,2] + -5/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif3] * self.ylbar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[mif4,0] + -1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif3] * self.ylbar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[mif4,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif3] * self.ylbar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[mif4,0] + -5/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif3] * self.ylbar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[mif4,0] + -1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif3] * self.ylbar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[mif4,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif3] * self.ylbar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[mif4,0] + -5/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif3] * self.ylbar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[mif4,0] + -1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif3] * self.ylbar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[mif4,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif3] * self.ylbar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[mif4,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] * self.yu[mif3,0] * self.yubar[mif4,0] + 1/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] * self.yu[mif3,0] * self.yubar[mif4,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] * self.yu[mif3,0] * self.yubar[mif4,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,1] * self.yu[mif3,1] * self.yubar[mif4,0] + 1/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,1] * self.yu[mif3,1] * self.yubar[mif4,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,1] * self.yu[mif3,1] * self.yubar[mif4,0] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,2] * self.yu[mif3,2] * self.yubar[mif4,0] + 1/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,2] * self.yu[mif3,2] * self.yubar[mif4,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,2] * self.yu[mif3,2] * self.yubar[mif4,0] + -5/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif3] * self.ylbar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[mif4,1] + -1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif3] * self.ylbar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[mif4,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif3] * self.ylbar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[mif4,1] + -5/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif3] * self.ylbar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[mif4,1] + -1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif3] * self.ylbar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[mif4,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif3] * self.ylbar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[mif4,1] + -5/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif3] * self.ylbar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[mif4,1] + -1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif3] * self.ylbar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[mif4,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif3] * self.ylbar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[mif4,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,0] * self.yu[mif3,0] * self.yubar[mif4,1] + 1/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,0] * self.yu[mif3,0] * self.yubar[mif4,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,0] * self.yu[mif3,0] * self.yubar[mif4,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] * self.yu[mif3,1] * self.yubar[mif4,1] + 1/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] * self.yu[mif3,1] * self.yubar[mif4,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] * self.yu[mif3,1] * self.yubar[mif4,1] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,2] * self.yu[mif3,2] * self.yubar[mif4,1] + 1/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,2] * self.yu[mif3,2] * self.yubar[mif4,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,2] * self.yu[mif3,2] * self.yubar[mif4,1] + -5/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif3] * self.ylbar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[mif4,2] + -1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif3] * self.ylbar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[mif4,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif3] * self.ylbar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[mif4,2] + -5/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif3] * self.ylbar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[mif4,2] + -1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif3] * self.ylbar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[mif4,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif3] * self.ylbar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[mif4,2] + -5/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif3] * self.ylbar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[mif4,2] + -1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif3] * self.ylbar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[mif4,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif3] * self.ylbar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[mif4,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,0] * self.yu[mif3,0] * self.yubar[mif4,2] + 1/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,0] * self.yu[mif3,0] * self.yubar[mif4,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,0] * self.yu[mif3,0] * self.yubar[mif4,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,1] * self.yu[mif3,1] * self.yubar[mif4,2] + 1/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,1] * self.yu[mif3,1] * self.yubar[mif4,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,1] * self.yu[mif3,1] * self.yubar[mif4,2] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] * self.yu[mif3,2] * self.yubar[mif4,2] + 1/64 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] * self.yu[mif3,2] * self.yubar[mif4,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] * self.yu[mif3,2] * self.yubar[mif4,2])

    def alphaOlq3(self, mif1,mif2,mif3,mif4):
        return (-1/1280 * (self.g2)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 1/1152 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[0,mif4] * self.yeqPi7bar[0,mif3] + 1/1152 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[1,mif4] * self.yeqPi7bar[1,mif3] + 1/1152 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[2,mif4] * self.yeqPi7bar[2,mif3] + 1/384 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif4] * self.yeqPi7bar[0,mif3] * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif4] * self.yeqPi7bar[1,mif3] * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif4] * self.yeqPi7bar[2,mif3] * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + 1/384 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif4] * self.yeqPi7bar[0,mif3] * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif4] * self.yeqPi7bar[1,mif3] * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif4] * self.yeqPi7bar[2,mif3] * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + 1/384 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif4] * self.yeqPi7bar[0,mif3] * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif4] * self.yeqPi7bar[1,mif3] * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif4] * self.yeqPi7bar[2,mif3] * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] + 3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif4] * self.yl[mif1,0] * self.yluPi7bar[mif2,0] * self.yu[mif3,0] + 1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif4] * self.yl[mif1,0] * self.yluPi7bar[mif2,0] * self.yu[mif3,0] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif4] * self.yl[mif1,0] * self.yluPi7bar[mif2,0] * self.yu[mif3,0] + 3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif4] * self.yl[mif1,1] * self.yluPi7bar[mif2,0] * self.yu[mif3,0] + 1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif4] * self.yl[mif1,1] * self.yluPi7bar[mif2,0] * self.yu[mif3,0] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif4] * self.yl[mif1,1] * self.yluPi7bar[mif2,0] * self.yu[mif3,0] + 3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif4] * self.yl[mif1,2] * self.yluPi7bar[mif2,0] * self.yu[mif3,0] + 1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif4] * self.yl[mif1,2] * self.yluPi7bar[mif2,0] * self.yu[mif3,0] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif4] * self.yl[mif1,2] * self.yluPi7bar[mif2,0] * self.yu[mif3,0] + 3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif4] * self.yl[mif1,0] * self.yluPi7bar[mif2,1] * self.yu[mif3,1] + 1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif4] * self.yl[mif1,0] * self.yluPi7bar[mif2,1] * self.yu[mif3,1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif4] * self.yl[mif1,0] * self.yluPi7bar[mif2,1] * self.yu[mif3,1] + 3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif4] * self.yl[mif1,1] * self.yluPi7bar[mif2,1] * self.yu[mif3,1] + 1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif4] * self.yl[mif1,1] * self.yluPi7bar[mif2,1] * self.yu[mif3,1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif4] * self.yl[mif1,1] * self.yluPi7bar[mif2,1] * self.yu[mif3,1] + 3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif4] * self.yl[mif1,2] * self.yluPi7bar[mif2,1] * self.yu[mif3,1] + 1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif4] * self.yl[mif1,2] * self.yluPi7bar[mif2,1] * self.yu[mif3,1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif4] * self.yl[mif1,2] * self.yluPi7bar[mif2,1] * self.yu[mif3,1] + 3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif4] * self.yl[mif1,0] * self.yluPi7bar[mif2,2] * self.yu[mif3,2] + 1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif4] * self.yl[mif1,0] * self.yluPi7bar[mif2,2] * self.yu[mif3,2] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif4] * self.yl[mif1,0] * self.yluPi7bar[mif2,2] * self.yu[mif3,2] + 3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif4] * self.yl[mif1,1] * self.yluPi7bar[mif2,2] * self.yu[mif3,2] + 1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif4] * self.yl[mif1,1] * self.yluPi7bar[mif2,2] * self.yu[mif3,2] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif4] * self.yl[mif1,1] * self.yluPi7bar[mif2,2] * self.yu[mif3,2] + 3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif4] * self.yl[mif1,2] * self.yluPi7bar[mif2,2] * self.yu[mif3,2] + 1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif4] * self.yl[mif1,2] * self.yluPi7bar[mif2,2] * self.yu[mif3,2] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif4] * self.yl[mif1,2] * self.yluPi7bar[mif2,2] * self.yu[mif3,2] + 5/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif3] * self.ylbar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[mif4,0] + 1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif3] * self.ylbar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[mif4,0] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif3] * self.ylbar[mif2,0] * self.yluPi7[mif1,0] * self.yubar[mif4,0] + 5/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif3] * self.ylbar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[mif4,0] + 1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif3] * self.ylbar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[mif4,0] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif3] * self.ylbar[mif2,1] * self.yluPi7[mif1,0] * self.yubar[mif4,0] + 5/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif3] * self.ylbar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[mif4,0] + 1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif3] * self.ylbar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[mif4,0] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif3] * self.ylbar[mif2,2] * self.yluPi7[mif1,0] * self.yubar[mif4,0] + 5/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif3] * self.ylbar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[mif4,1] + 1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif3] * self.ylbar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[mif4,1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif3] * self.ylbar[mif2,0] * self.yluPi7[mif1,1] * self.yubar[mif4,1] + 5/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif3] * self.ylbar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[mif4,1] + 1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif3] * self.ylbar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[mif4,1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif3] * self.ylbar[mif2,1] * self.yluPi7[mif1,1] * self.yubar[mif4,1] + 5/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif3] * self.ylbar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[mif4,1] + 1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif3] * self.ylbar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[mif4,1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif3] * self.ylbar[mif2,2] * self.yluPi7[mif1,1] * self.yubar[mif4,1] + 5/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif3] * self.ylbar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[mif4,2] + 1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif3] * self.ylbar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[mif4,2] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif3] * self.ylbar[mif2,0] * self.yluPi7[mif1,2] * self.yubar[mif4,2] + 5/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif3] * self.ylbar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[mif4,2] + 1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif3] * self.ylbar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[mif4,2] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif3] * self.ylbar[mif2,1] * self.yluPi7[mif1,2] * self.yubar[mif4,2] + 5/512 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif3] * self.ylbar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[mif4,2] + 1/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif3] * self.ylbar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[mif4,2] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif3] * self.ylbar[mif2,2] * self.yluPi7[mif1,2] * self.yubar[mif4,2])

    def alphaOlu(self, mif1,mif2,mif3,mif4):
        return (49/8640 * (self.g1)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + -31/1728 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[0,mif4] * self.yluPi7bar[0,mif3] + -1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[0,mif4] * self.yluPi7bar[0,mif3] + 1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[0,mif4] * self.yluPi7bar[0,mif3] + -31/1728 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[1,mif4] * self.yluPi7bar[1,mif3] + -1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[1,mif4] * self.yluPi7bar[1,mif3] + 1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[1,mif4] * self.yluPi7bar[1,mif3] + -31/1728 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[2,mif4] * self.yluPi7bar[2,mif3] + -1/96 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[2,mif4] * self.yluPi7bar[2,mif3] + 1/96 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[2,mif4] * self.yluPi7bar[2,mif3] + -13/288 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + -1/36 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + 1/36 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,0] * self.yluPi7bar[mif2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[0,mif3] * self.yluPi7bar[mif2,0] + 5/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,0] * self.yluPi7[mif1,mif4] * self.yluPi7bar[0,mif3] * self.yluPi7bar[mif2,0] + 5/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,0] * self.yluPi7[mif1,mif4] * self.yluPi7bar[0,mif3] * self.yluPi7bar[mif2,0] + -5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[0,0] * self.yluPi7[mif1,mif4] * self.yluPi7bar[0,mif3] * self.yluPi7bar[mif2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[1,mif3] * self.yluPi7bar[mif2,0] + 5/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,0] * self.yluPi7[mif1,mif4] * self.yluPi7bar[1,mif3] * self.yluPi7bar[mif2,0] + 5/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,0] * self.yluPi7[mif1,mif4] * self.yluPi7bar[1,mif3] * self.yluPi7bar[mif2,0] + -5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[1,0] * self.yluPi7[mif1,mif4] * self.yluPi7bar[1,mif3] * self.yluPi7bar[mif2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[2,mif3] * self.yluPi7bar[mif2,0] + 5/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,0] * self.yluPi7[mif1,mif4] * self.yluPi7bar[2,mif3] * self.yluPi7bar[mif2,0] + 5/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,0] * self.yluPi7[mif1,mif4] * self.yluPi7bar[2,mif3] * self.yluPi7bar[mif2,0] + -5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[2,0] * self.yluPi7[mif1,mif4] * self.yluPi7bar[2,mif3] * self.yluPi7bar[mif2,0] + -13/288 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + -1/36 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + 1/36 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,1] * self.yluPi7bar[mif2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[0,mif3] * self.yluPi7bar[mif2,1] + 5/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,1] * self.yluPi7[mif1,mif4] * self.yluPi7bar[0,mif3] * self.yluPi7bar[mif2,1] + 5/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,1] * self.yluPi7[mif1,mif4] * self.yluPi7bar[0,mif3] * self.yluPi7bar[mif2,1] + -5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[0,1] * self.yluPi7[mif1,mif4] * self.yluPi7bar[0,mif3] * self.yluPi7bar[mif2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[1,mif3] * self.yluPi7bar[mif2,1] + 5/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,1] * self.yluPi7[mif1,mif4] * self.yluPi7bar[1,mif3] * self.yluPi7bar[mif2,1] + 5/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,1] * self.yluPi7[mif1,mif4] * self.yluPi7bar[1,mif3] * self.yluPi7bar[mif2,1] + -5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[1,1] * self.yluPi7[mif1,mif4] * self.yluPi7bar[1,mif3] * self.yluPi7bar[mif2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[2,mif3] * self.yluPi7bar[mif2,1] + 5/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,1] * self.yluPi7[mif1,mif4] * self.yluPi7bar[2,mif3] * self.yluPi7bar[mif2,1] + 5/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,1] * self.yluPi7[mif1,mif4] * self.yluPi7bar[2,mif3] * self.yluPi7bar[mif2,1] + -5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[2,1] * self.yluPi7[mif1,mif4] * self.yluPi7bar[2,mif3] * self.yluPi7bar[mif2,1] + -13/288 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] + -1/36 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] + 1/36 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,2] * self.yluPi7bar[mif2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[0,mif3] * self.yluPi7bar[mif2,2] + 5/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,2] * self.yluPi7[mif1,mif4] * self.yluPi7bar[0,mif3] * self.yluPi7bar[mif2,2] + 5/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,2] * self.yluPi7[mif1,mif4] * self.yluPi7bar[0,mif3] * self.yluPi7bar[mif2,2] + -5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[0,2] * self.yluPi7[mif1,mif4] * self.yluPi7bar[0,mif3] * self.yluPi7bar[mif2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[1,mif3] * self.yluPi7bar[mif2,2] + 5/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,2] * self.yluPi7[mif1,mif4] * self.yluPi7bar[1,mif3] * self.yluPi7bar[mif2,2] + 5/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,2] * self.yluPi7[mif1,mif4] * self.yluPi7bar[1,mif3] * self.yluPi7bar[mif2,2] + -5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[1,2] * self.yluPi7[mif1,mif4] * self.yluPi7bar[1,mif3] * self.yluPi7bar[mif2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[2,mif3] * self.yluPi7bar[mif2,2] + 5/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,2] * self.yluPi7[mif1,mif4] * self.yluPi7bar[2,mif3] * self.yluPi7bar[mif2,2] + 5/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,2] * self.yluPi7[mif1,mif4] * self.yluPi7bar[2,mif3] * self.yluPi7bar[mif2,2] + -5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[2,2] * self.yluPi7[mif1,mif4] * self.yluPi7bar[2,mif3] * self.yluPi7bar[mif2,2] + -1/2 * (self.MPi7)**(-2) * self.yluPi7[mif1,mif4] * self.yluPi7bar[mif2,mif3] + -1/2304 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,mif4] * self.yluPi7bar[mif2,mif3] + -1/768 * self.epsilonbar * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,mif4] * self.yluPi7bar[mif2,mif3] + -3/256 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,mif4] * self.yluPi7bar[mif2,mif3] + -9/256 * self.epsilonbar * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,mif4] * self.yluPi7bar[mif2,mif3] + -1/48 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,mif4] * self.yluPi7bar[mif2,mif3] + -1/16 * self.epsilonbar * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,mif4] * self.yluPi7bar[mif2,mif3] + -1/1152 * self.epsilonbar * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,mif4] * self.yluPi7bar[mif2,mif3] + -3/128 * self.epsilonbar * (self.g2)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,mif4] * self.yluPi7bar[mif2,mif3] + -1/24 * self.epsilonbar * (self.g3)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[mif1,mif4] * self.yluPi7bar[mif2,mif3] + 1/1152 * self.epsilonbar * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,mif4] * self.yluPi7bar[mif2,mif3] + 3/128 * self.epsilonbar * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,mif4] * self.yluPi7bar[mif2,mif3] + 1/24 * self.epsilonbar * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[mif1,mif4] * self.yluPi7bar[mif2,mif3] + 5/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[0,0] * self.yluPi7bar[mif2,mif3] + 5/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[0,0] * self.yluPi7bar[mif2,mif3] + -5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[0,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[0,0] * self.yluPi7bar[mif2,mif3] + 5/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[0,1] * self.yluPi7bar[mif2,mif3] + 5/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[0,1] * self.yluPi7bar[mif2,mif3] + -5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[0,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[0,1] * self.yluPi7bar[mif2,mif3] + 5/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[0,2] * self.yluPi7bar[mif2,mif3] + 5/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[0,2] * self.yluPi7bar[mif2,mif3] + -5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[0,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[0,2] * self.yluPi7bar[mif2,mif3] + 5/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[1,0] * self.yluPi7bar[mif2,mif3] + 5/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[1,0] * self.yluPi7bar[mif2,mif3] + -5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[1,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[1,0] * self.yluPi7bar[mif2,mif3] + 5/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[1,1] * self.yluPi7bar[mif2,mif3] + 5/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[1,1] * self.yluPi7bar[mif2,mif3] + -5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[1,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[1,1] * self.yluPi7bar[mif2,mif3] + 5/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[1,2] * self.yluPi7bar[mif2,mif3] + 5/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[1,2] * self.yluPi7bar[mif2,mif3] + -5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[1,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[1,2] * self.yluPi7bar[mif2,mif3] + 5/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[2,0] * self.yluPi7bar[mif2,mif3] + 5/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[2,0] * self.yluPi7bar[mif2,mif3] + -5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[2,mif4] * self.yluPi7[mif1,0] * self.yluPi7bar[2,0] * self.yluPi7bar[mif2,mif3] + 5/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[2,1] * self.yluPi7bar[mif2,mif3] + 5/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[2,1] * self.yluPi7bar[mif2,mif3] + -5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[2,mif4] * self.yluPi7[mif1,1] * self.yluPi7bar[2,1] * self.yluPi7bar[mif2,mif3] + 5/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[2,2] * self.yluPi7bar[mif2,mif3] + 5/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[2,2] * self.yluPi7bar[mif2,mif3] + -5/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[2,mif4] * self.yluPi7[mif1,2] * self.yluPi7bar[2,2] * self.yluPi7bar[mif2,mif3] + 3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,0] * self.ylbar[mif2,0] * self.yluPi7[mif1,mif4] * self.yubar[0,mif3] + 3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,0] * self.ylbar[mif2,1] * self.yluPi7[mif1,mif4] * self.yubar[0,mif3] + 3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,0] * self.ylbar[mif2,2] * self.yluPi7[mif1,mif4] * self.yubar[0,mif3] + 3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,1] * self.ylbar[mif2,0] * self.yluPi7[mif1,mif4] * self.yubar[1,mif3] + 3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,1] * self.ylbar[mif2,1] * self.yluPi7[mif1,mif4] * self.yubar[1,mif3] + 3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,1] * self.ylbar[mif2,2] * self.yluPi7[mif1,mif4] * self.yubar[1,mif3] + 3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,2] * self.ylbar[mif2,0] * self.yluPi7[mif1,mif4] * self.yubar[2,mif3] + 3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,2] * self.ylbar[mif2,1] * self.yluPi7[mif1,mif4] * self.yubar[2,mif3] + 3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,2] * self.ylbar[mif2,2] * self.yluPi7[mif1,mif4] * self.yubar[2,mif3])

    def alphaOqd1(self, mif1,mif2,mif3,mif4):
        return (49/51840 * (self.g1)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + -55/5184 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] + -1/144 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] + 1/144 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] + -55/5184 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] + -1/144 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] + 1/144 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] + -55/5184 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] + -1/144 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] + 1/144 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1])

    def alphaOqd8(self, mif1,mif2,mif3,mif4):
        return (-1/480 * (self.g3)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 1/288 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] + 1/288 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] + 1/288 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1])

    def alphaOqe(self, mif1,mif2,mif3,mif4):
        return (49/17280 * (self.g1)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + -55/1728 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] + -1/48 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] + 1/48 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] + -55/1728 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] + -1/48 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] + 1/48 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] + -55/1728 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] + -1/48 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] + 1/48 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] + -5/576 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[mif3,0] * self.yeqPi7bar[mif4,0] + -1/288 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[mif3,0] * self.yeqPi7bar[mif4,0] + 1/288 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif3,0] * self.yeqPi7bar[mif4,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7[mif3,0] * self.yeqPi7bar[0,mif1] * self.yeqPi7bar[mif4,0] + 7/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[0,mif1] * self.yeqPi7bar[mif4,0] + 7/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[0,mif1] * self.yeqPi7bar[mif4,0] + -7/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,0] * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[0,mif1] * self.yeqPi7bar[mif4,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7[mif3,0] * self.yeqPi7bar[1,mif1] * self.yeqPi7bar[mif4,0] + 7/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[1,mif1] * self.yeqPi7bar[mif4,0] + 7/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[1,mif1] * self.yeqPi7bar[mif4,0] + -7/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,0] * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[1,mif1] * self.yeqPi7bar[mif4,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7[mif3,0] * self.yeqPi7bar[2,mif1] * self.yeqPi7bar[mif4,0] + 7/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[2,mif1] * self.yeqPi7bar[mif4,0] + 7/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[2,mif1] * self.yeqPi7bar[mif4,0] + -7/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,0] * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[2,mif1] * self.yeqPi7bar[mif4,0] + -5/576 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[mif3,1] * self.yeqPi7bar[mif4,1] + -1/288 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[mif3,1] * self.yeqPi7bar[mif4,1] + 1/288 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif3,1] * self.yeqPi7bar[mif4,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7[mif3,1] * self.yeqPi7bar[0,mif1] * self.yeqPi7bar[mif4,1] + 7/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[0,mif1] * self.yeqPi7bar[mif4,1] + 7/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[0,mif1] * self.yeqPi7bar[mif4,1] + -7/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,1] * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[0,mif1] * self.yeqPi7bar[mif4,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7[mif3,1] * self.yeqPi7bar[1,mif1] * self.yeqPi7bar[mif4,1] + 7/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[1,mif1] * self.yeqPi7bar[mif4,1] + 7/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[1,mif1] * self.yeqPi7bar[mif4,1] + -7/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,1] * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[1,mif1] * self.yeqPi7bar[mif4,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7[mif3,1] * self.yeqPi7bar[2,mif1] * self.yeqPi7bar[mif4,1] + 7/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[2,mif1] * self.yeqPi7bar[mif4,1] + 7/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[2,mif1] * self.yeqPi7bar[mif4,1] + -7/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,1] * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[2,mif1] * self.yeqPi7bar[mif4,1] + -5/576 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[mif3,2] * self.yeqPi7bar[mif4,2] + -1/288 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[mif3,2] * self.yeqPi7bar[mif4,2] + 1/288 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif3,2] * self.yeqPi7bar[mif4,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7[mif3,2] * self.yeqPi7bar[0,mif1] * self.yeqPi7bar[mif4,2] + 7/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[0,mif1] * self.yeqPi7bar[mif4,2] + 7/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[0,mif1] * self.yeqPi7bar[mif4,2] + -7/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,2] * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[0,mif1] * self.yeqPi7bar[mif4,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7[mif3,2] * self.yeqPi7bar[1,mif1] * self.yeqPi7bar[mif4,2] + 7/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[1,mif1] * self.yeqPi7bar[mif4,2] + 7/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[1,mif1] * self.yeqPi7bar[mif4,2] + -7/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,2] * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[1,mif1] * self.yeqPi7bar[mif4,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7[mif3,2] * self.yeqPi7bar[2,mif1] * self.yeqPi7bar[mif4,2] + 7/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[2,mif1] * self.yeqPi7bar[mif4,2] + 7/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[2,mif1] * self.yeqPi7bar[mif4,2] + -7/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,2] * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[2,mif1] * self.yeqPi7bar[mif4,2] + -1/2 * (self.MPi7)**(-2) * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[mif4,mif1] + -25/2304 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[mif4,mif1] + -25/768 * self.epsilonbar * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[mif4,mif1] + -3/256 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[mif4,mif1] + -9/256 * self.epsilonbar * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[mif4,mif1] + -1/48 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[mif4,mif1] + -1/16 * self.epsilonbar * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[mif4,mif1] + -25/1152 * self.epsilonbar * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[mif4,mif1] + -3/128 * self.epsilonbar * (self.g2)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[mif4,mif1] + -1/24 * self.epsilonbar * (self.g3)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[mif4,mif1] + 25/1152 * self.epsilonbar * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[mif4,mif1] + 3/128 * self.epsilonbar * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[mif4,mif1] + 1/24 * self.epsilonbar * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[mif3,mif2] * self.yeqPi7bar[mif4,mif1] + 7/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7[mif3,0] * self.yeqPi7bar[0,0] * self.yeqPi7bar[mif4,mif1] + 7/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7[mif3,0] * self.yeqPi7bar[0,0] * self.yeqPi7bar[mif4,mif1] + -7/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif2] * self.yeqPi7[mif3,0] * self.yeqPi7bar[0,0] * self.yeqPi7bar[mif4,mif1] + 7/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7[mif3,1] * self.yeqPi7bar[0,1] * self.yeqPi7bar[mif4,mif1] + 7/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7[mif3,1] * self.yeqPi7bar[0,1] * self.yeqPi7bar[mif4,mif1] + -7/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif2] * self.yeqPi7[mif3,1] * self.yeqPi7bar[0,1] * self.yeqPi7bar[mif4,mif1] + 7/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7[mif3,2] * self.yeqPi7bar[0,2] * self.yeqPi7bar[mif4,mif1] + 7/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7[mif3,2] * self.yeqPi7bar[0,2] * self.yeqPi7bar[mif4,mif1] + -7/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif2] * self.yeqPi7[mif3,2] * self.yeqPi7bar[0,2] * self.yeqPi7bar[mif4,mif1] + 7/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7[mif3,0] * self.yeqPi7bar[1,0] * self.yeqPi7bar[mif4,mif1] + 7/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7[mif3,0] * self.yeqPi7bar[1,0] * self.yeqPi7bar[mif4,mif1] + -7/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif2] * self.yeqPi7[mif3,0] * self.yeqPi7bar[1,0] * self.yeqPi7bar[mif4,mif1] + 7/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7[mif3,1] * self.yeqPi7bar[1,1] * self.yeqPi7bar[mif4,mif1] + 7/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7[mif3,1] * self.yeqPi7bar[1,1] * self.yeqPi7bar[mif4,mif1] + -7/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif2] * self.yeqPi7[mif3,1] * self.yeqPi7bar[1,1] * self.yeqPi7bar[mif4,mif1] + 7/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7[mif3,2] * self.yeqPi7bar[1,2] * self.yeqPi7bar[mif4,mif1] + 7/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7[mif3,2] * self.yeqPi7bar[1,2] * self.yeqPi7bar[mif4,mif1] + -7/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif2] * self.yeqPi7[mif3,2] * self.yeqPi7bar[1,2] * self.yeqPi7bar[mif4,mif1] + 7/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7[mif3,0] * self.yeqPi7bar[2,0] * self.yeqPi7bar[mif4,mif1] + 7/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7[mif3,0] * self.yeqPi7bar[2,0] * self.yeqPi7bar[mif4,mif1] + -7/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif2] * self.yeqPi7[mif3,0] * self.yeqPi7bar[2,0] * self.yeqPi7bar[mif4,mif1] + 7/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7[mif3,1] * self.yeqPi7bar[2,1] * self.yeqPi7bar[mif4,mif1] + 7/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7[mif3,1] * self.yeqPi7bar[2,1] * self.yeqPi7bar[mif4,mif1] + -7/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif2] * self.yeqPi7[mif3,1] * self.yeqPi7bar[2,1] * self.yeqPi7bar[mif4,mif1] + 7/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7[mif3,2] * self.yeqPi7bar[2,2] * self.yeqPi7bar[mif4,mif1] + 7/128 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7[mif3,2] * self.yeqPi7bar[2,2] * self.yeqPi7bar[mif4,mif1] + -7/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif2] * self.yeqPi7[mif3,2] * self.yeqPi7bar[2,2] * self.yeqPi7bar[mif4,mif1] + 3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif4,mif1] * self.ylbar[0,mif3] * self.yluPi7[0,0] * self.yubar[mif2,0] + 3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif4,mif1] * self.ylbar[1,mif3] * self.yluPi7[1,0] * self.yubar[mif2,0] + 3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif4,mif1] * self.ylbar[2,mif3] * self.yluPi7[2,0] * self.yubar[mif2,0] + 3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif4,mif1] * self.ylbar[0,mif3] * self.yluPi7[0,1] * self.yubar[mif2,1] + 3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif4,mif1] * self.ylbar[1,mif3] * self.yluPi7[1,1] * self.yubar[mif2,1] + 3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif4,mif1] * self.ylbar[2,mif3] * self.yluPi7[2,1] * self.yubar[mif2,1] + 3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif4,mif1] * self.ylbar[0,mif3] * self.yluPi7[0,2] * self.yubar[mif2,2] + 3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif4,mif1] * self.ylbar[1,mif3] * self.yluPi7[1,2] * self.yubar[mif2,2] + 3/256 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[mif4,mif1] * self.ylbar[2,mif3] * self.yluPi7[2,2] * self.yubar[mif2,2])

    def alphaOqq1(self, mif1,mif2,mif3,mif4):
        return (-1/3840 * (self.g3)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.kronecker_delta(mif2,mif3) + -49/207360 * (self.g1)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 1/5760 * (self.g3)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 55/20736 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] + -1/3456 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] + 1/576 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] + -1/576 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] + 1/2304 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yeqPi7[0,mif4] * self.yeqPi7bar[0,mif1] + 1/2304 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif3] + 55/20736 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[0,mif4] * self.yeqPi7bar[0,mif3] + -1/3456 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[0,mif4] * self.yeqPi7bar[0,mif3] + 1/576 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[0,mif4] * self.yeqPi7bar[0,mif3] + -1/576 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif4] * self.yeqPi7bar[0,mif3] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7[0,mif4] * self.yeqPi7bar[0,mif1] * self.yeqPi7bar[0,mif3] + 55/20736 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] + -1/3456 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] + 1/576 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] + -1/576 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] + 1/2304 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yeqPi7[1,mif4] * self.yeqPi7bar[1,mif1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7[1,mif4] * self.yeqPi7bar[0,mif3] * self.yeqPi7bar[1,mif1] + 1/2304 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif3] + 55/20736 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[1,mif4] * self.yeqPi7bar[1,mif3] + -1/3456 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[1,mif4] * self.yeqPi7bar[1,mif3] + 1/576 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[1,mif4] * self.yeqPi7bar[1,mif3] + -1/576 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif4] * self.yeqPi7bar[1,mif3] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif4] * self.yeqPi7[1,mif2] * self.yeqPi7bar[0,mif1] * self.yeqPi7bar[1,mif3] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7[1,mif4] * self.yeqPi7bar[1,mif1] * self.yeqPi7bar[1,mif3] + 55/20736 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] + -1/3456 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] + 1/576 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] + -1/576 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] + 1/2304 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yeqPi7[2,mif4] * self.yeqPi7bar[2,mif1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7[2,mif4] * self.yeqPi7bar[0,mif3] * self.yeqPi7bar[2,mif1] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7[2,mif4] * self.yeqPi7bar[1,mif3] * self.yeqPi7bar[2,mif1] + 1/2304 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif3] + 55/20736 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[2,mif4] * self.yeqPi7bar[2,mif3] + -1/3456 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[2,mif4] * self.yeqPi7bar[2,mif3] + 1/576 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[2,mif4] * self.yeqPi7bar[2,mif3] + -1/576 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif4] * self.yeqPi7bar[2,mif3] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif4] * self.yeqPi7[2,mif2] * self.yeqPi7bar[0,mif1] * self.yeqPi7bar[2,mif3] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif4] * self.yeqPi7[2,mif2] * self.yeqPi7bar[1,mif1] * self.yeqPi7bar[2,mif3] + -1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7[2,mif4] * self.yeqPi7bar[2,mif1] * self.yeqPi7bar[2,mif3])

    def alphaOqq3(self, mif1,mif2,mif3,mif4):
        return (-1/3840 * (self.g3)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.kronecker_delta(mif2,mif3) + -1/2560 * (self.g2)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 1/2304 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] + 1/2304 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yeqPi7[0,mif4] * self.yeqPi7bar[0,mif1] + 1/2304 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif3] + 1/2304 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[0,mif4] * self.yeqPi7bar[0,mif3] + 1/2304 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] + 1/2304 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yeqPi7[1,mif4] * self.yeqPi7bar[1,mif1] + 1/2304 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif3] + 1/2304 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[1,mif4] * self.yeqPi7bar[1,mif3] + 1/2304 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] + 1/2304 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yeqPi7[2,mif4] * self.yeqPi7bar[2,mif1] + 1/2304 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif3] + 1/2304 * (self.g2)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yeqPi7[2,mif4] * self.yeqPi7bar[2,mif3])

    def alphaOqu1(self, mif1,mif2,mif3,mif4):
        return (-49/25920 * (self.g1)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 55/2592 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] + 1/72 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] + -1/72 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] + 55/2592 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] + 1/72 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] + -1/72 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] + 55/2592 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] + 1/72 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] + -1/72 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] + 31/5184 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[0,mif4] * self.yluPi7bar[0,mif3] + 1/288 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[0,mif4] * self.yluPi7bar[0,mif3] + -1/288 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[0,mif4] * self.yluPi7bar[0,mif3] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] * self.yluPi7[0,mif4] * self.yluPi7bar[0,mif3] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] * self.yluPi7[0,mif4] * self.yluPi7bar[0,mif3] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] * self.yluPi7[0,mif4] * self.yluPi7bar[0,mif3] + 31/5184 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[1,mif4] * self.yluPi7bar[1,mif3] + 1/288 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[1,mif4] * self.yluPi7bar[1,mif3] + -1/288 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[1,mif4] * self.yluPi7bar[1,mif3] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] * self.yluPi7[1,mif4] * self.yluPi7bar[1,mif3] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] * self.yluPi7[1,mif4] * self.yluPi7bar[1,mif3] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] * self.yluPi7[1,mif4] * self.yluPi7bar[1,mif3] + 31/5184 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[2,mif4] * self.yluPi7bar[2,mif3] + 1/288 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[2,mif4] * self.yluPi7bar[2,mif3] + -1/288 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[2,mif4] * self.yluPi7bar[2,mif3] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] * self.yluPi7[2,mif4] * self.yluPi7bar[2,mif3] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] * self.yluPi7[2,mif4] * self.yluPi7bar[2,mif3] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] * self.yluPi7[2,mif4] * self.yluPi7bar[2,mif3] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[0,0] * self.yluPi7bar[0,mif3] * self.yu[mif1,mif4] + 1/192 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[0,0] * self.yluPi7bar[0,mif3] * self.yu[mif1,mif4] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif2] * self.yl[0,0] * self.yluPi7bar[0,mif3] * self.yu[mif1,mif4] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[0,1] * self.yluPi7bar[0,mif3] * self.yu[mif1,mif4] + 1/192 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[0,1] * self.yluPi7bar[0,mif3] * self.yu[mif1,mif4] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif2] * self.yl[0,1] * self.yluPi7bar[0,mif3] * self.yu[mif1,mif4] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[0,2] * self.yluPi7bar[0,mif3] * self.yu[mif1,mif4] + 1/192 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[0,2] * self.yluPi7bar[0,mif3] * self.yu[mif1,mif4] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif2] * self.yl[0,2] * self.yluPi7bar[0,mif3] * self.yu[mif1,mif4] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[1,0] * self.yluPi7bar[1,mif3] * self.yu[mif1,mif4] + 1/192 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[1,0] * self.yluPi7bar[1,mif3] * self.yu[mif1,mif4] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif2] * self.yl[1,0] * self.yluPi7bar[1,mif3] * self.yu[mif1,mif4] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[1,1] * self.yluPi7bar[1,mif3] * self.yu[mif1,mif4] + 1/192 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[1,1] * self.yluPi7bar[1,mif3] * self.yu[mif1,mif4] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif2] * self.yl[1,1] * self.yluPi7bar[1,mif3] * self.yu[mif1,mif4] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[1,2] * self.yluPi7bar[1,mif3] * self.yu[mif1,mif4] + 1/192 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[1,2] * self.yluPi7bar[1,mif3] * self.yu[mif1,mif4] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif2] * self.yl[1,2] * self.yluPi7bar[1,mif3] * self.yu[mif1,mif4] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[2,0] * self.yluPi7bar[2,mif3] * self.yu[mif1,mif4] + 1/192 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[2,0] * self.yluPi7bar[2,mif3] * self.yu[mif1,mif4] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif2] * self.yl[2,0] * self.yluPi7bar[2,mif3] * self.yu[mif1,mif4] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[2,1] * self.yluPi7bar[2,mif3] * self.yu[mif1,mif4] + 1/192 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[2,1] * self.yluPi7bar[2,mif3] * self.yu[mif1,mif4] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif2] * self.yl[2,1] * self.yluPi7bar[2,mif3] * self.yu[mif1,mif4] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[2,2] * self.yluPi7bar[2,mif3] * self.yu[mif1,mif4] + 1/192 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[2,2] * self.yluPi7bar[2,mif3] * self.yu[mif1,mif4] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif2] * self.yl[2,2] * self.yluPi7bar[2,mif3] * self.yu[mif1,mif4] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,mif4] * self.yubar[mif2,mif3] + 1/192 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,mif4] * self.yubar[mif2,mif3] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,mif4] * self.yubar[mif2,mif3] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,mif4] * self.yubar[mif2,mif3] + 1/192 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,mif4] * self.yubar[mif2,mif3] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,mif4] * self.yubar[mif2,mif3] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,mif4] * self.yubar[mif2,mif3] + 1/192 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,mif4] * self.yubar[mif2,mif3] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,mif4] * self.yubar[mif2,mif3] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,mif4] * self.yubar[mif2,mif3] + 1/192 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,mif4] * self.yubar[mif2,mif3] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,mif4] * self.yubar[mif2,mif3] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,mif4] * self.yubar[mif2,mif3] + 1/192 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,mif4] * self.yubar[mif2,mif3] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,mif4] * self.yubar[mif2,mif3] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,mif4] * self.yubar[mif2,mif3] + 1/192 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,mif4] * self.yubar[mif2,mif3] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,mif4] * self.yubar[mif2,mif3] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,mif4] * self.yubar[mif2,mif3] + 1/192 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,mif4] * self.yubar[mif2,mif3] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,mif4] * self.yubar[mif2,mif3] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,mif4] * self.yubar[mif2,mif3] + 1/192 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,mif4] * self.yubar[mif2,mif3] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,mif4] * self.yubar[mif2,mif3] + 1/128 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,mif4] * self.yubar[mif2,mif3] + 1/192 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,mif4] * self.yubar[mif2,mif3] + -1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,mif4] * self.yubar[mif2,mif3])

    def alphaOqu8(self, mif1,mif2,mif3,mif4):
        return (-1/480 * (self.g3)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 1/288 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] + 1/288 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] + 1/288 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] + 1/144 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[0,mif4] * self.yluPi7bar[0,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] * self.yluPi7[0,mif4] * self.yluPi7bar[0,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] * self.yluPi7[0,mif4] * self.yluPi7bar[0,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] * self.yluPi7[0,mif4] * self.yluPi7bar[0,mif3] + 1/144 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[1,mif4] * self.yluPi7bar[1,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] * self.yluPi7[1,mif4] * self.yluPi7bar[1,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] * self.yluPi7[1,mif4] * self.yluPi7bar[1,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] * self.yluPi7[1,mif4] * self.yluPi7bar[1,mif3] + 1/144 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[2,mif4] * self.yluPi7bar[2,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yeqPi7bar[0,mif1] * self.yluPi7[2,mif4] * self.yluPi7bar[2,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yeqPi7bar[1,mif1] * self.yluPi7[2,mif4] * self.yluPi7bar[2,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yeqPi7bar[2,mif1] * self.yluPi7[2,mif4] * self.yluPi7bar[2,mif3] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[0,0] * self.yluPi7bar[0,mif3] * self.yu[mif1,mif4] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[0,0] * self.yluPi7bar[0,mif3] * self.yu[mif1,mif4] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif2] * self.yl[0,0] * self.yluPi7bar[0,mif3] * self.yu[mif1,mif4] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[0,1] * self.yluPi7bar[0,mif3] * self.yu[mif1,mif4] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[0,1] * self.yluPi7bar[0,mif3] * self.yu[mif1,mif4] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif2] * self.yl[0,1] * self.yluPi7bar[0,mif3] * self.yu[mif1,mif4] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[0,2] * self.yluPi7bar[0,mif3] * self.yu[mif1,mif4] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[0,2] * self.yluPi7bar[0,mif3] * self.yu[mif1,mif4] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif2] * self.yl[0,2] * self.yluPi7bar[0,mif3] * self.yu[mif1,mif4] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[1,0] * self.yluPi7bar[1,mif3] * self.yu[mif1,mif4] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[1,0] * self.yluPi7bar[1,mif3] * self.yu[mif1,mif4] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif2] * self.yl[1,0] * self.yluPi7bar[1,mif3] * self.yu[mif1,mif4] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[1,1] * self.yluPi7bar[1,mif3] * self.yu[mif1,mif4] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[1,1] * self.yluPi7bar[1,mif3] * self.yu[mif1,mif4] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif2] * self.yl[1,1] * self.yluPi7bar[1,mif3] * self.yu[mif1,mif4] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[1,2] * self.yluPi7bar[1,mif3] * self.yu[mif1,mif4] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[1,2] * self.yluPi7bar[1,mif3] * self.yu[mif1,mif4] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif2] * self.yl[1,2] * self.yluPi7bar[1,mif3] * self.yu[mif1,mif4] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[2,0] * self.yluPi7bar[2,mif3] * self.yu[mif1,mif4] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,mif2] * self.yl[2,0] * self.yluPi7bar[2,mif3] * self.yu[mif1,mif4] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[0,mif2] * self.yl[2,0] * self.yluPi7bar[2,mif3] * self.yu[mif1,mif4] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[2,1] * self.yluPi7bar[2,mif3] * self.yu[mif1,mif4] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,mif2] * self.yl[2,1] * self.yluPi7bar[2,mif3] * self.yu[mif1,mif4] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[1,mif2] * self.yl[2,1] * self.yluPi7bar[2,mif3] * self.yu[mif1,mif4] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[2,2] * self.yluPi7bar[2,mif3] * self.yu[mif1,mif4] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,mif2] * self.yl[2,2] * self.yluPi7bar[2,mif3] * self.yu[mif1,mif4] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7[2,mif2] * self.yl[2,2] * self.yluPi7bar[2,mif3] * self.yu[mif1,mif4] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,mif4] * self.yubar[mif2,mif3] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,mif4] * self.yubar[mif2,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,mif4] * self.yubar[mif2,mif3] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,mif4] * self.yubar[mif2,mif3] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,mif4] * self.yubar[mif2,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,mif4] * self.yubar[mif2,mif3] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,mif4] * self.yubar[mif2,mif3] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,mif4] * self.yubar[mif2,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,mif4] * self.yubar[mif2,mif3] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,mif4] * self.yubar[mif2,mif3] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,mif4] * self.yubar[mif2,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,mif4] * self.yubar[mif2,mif3] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,mif4] * self.yubar[mif2,mif3] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,mif4] * self.yubar[mif2,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,mif4] * self.yubar[mif2,mif3] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,mif4] * self.yubar[mif2,mif3] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,mif4] * self.yubar[mif2,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,mif4] * self.yubar[mif2,mif3] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,mif4] * self.yubar[mif2,mif3] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,mif4] * self.yubar[mif2,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,mif4] * self.yubar[mif2,mif3] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,mif4] * self.yubar[mif2,mif3] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,mif4] * self.yubar[mif2,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,mif4] * self.yubar[mif2,mif3] + 3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,mif4] * self.yubar[mif2,mif3] + 1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,mif4] * self.yubar[mif2,mif3] + -1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,mif4] * self.yubar[mif2,mif3])

    def alphaOquqd1(self, mif1,mif2,mif3,mif4):
        return (-3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif3,mif4] * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,mif2] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif3,mif4] * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,mif2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[mif3,mif4] * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,mif2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif3,mif4] * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,mif2] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif3,mif4] * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,mif2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[mif3,mif4] * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,mif2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif3,mif4] * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,mif2] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif3,mif4] * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,mif2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[mif3,mif4] * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,mif2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif3,mif4] * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,mif2] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif3,mif4] * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,mif2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[mif3,mif4] * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,mif2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif3,mif4] * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,mif2] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif3,mif4] * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,mif2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[mif3,mif4] * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,mif2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif3,mif4] * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,mif2] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif3,mif4] * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,mif2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[mif3,mif4] * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,mif2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif3,mif4] * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,mif2] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif3,mif4] * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,mif2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[mif3,mif4] * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,mif2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif3,mif4] * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,mif2] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif3,mif4] * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,mif2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[mif3,mif4] * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,mif2] + -3/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif3,mif4] * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,mif2] + -1/32 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif3,mif4] * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,mif2] + 1/32 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yd[mif3,mif4] * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,mif2])

    def alphaOquqd8(self, mif1,mif2,mif3,mif4):
        return 0

    def alphaOuB(self, mif1,mif2):
        return (13/768 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,mif2] + 3/128 * self.g1 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,mif2] + -3/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,mif2] + 13/768 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,mif2] + 3/128 * self.g1 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,mif2] + -3/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,mif2] + 13/768 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,mif2] + 3/128 * self.g1 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,mif2] + -3/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,mif2] + 13/768 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,mif2] + 3/128 * self.g1 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,mif2] + -3/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,mif2] + 13/768 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,mif2] + 3/128 * self.g1 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,mif2] + -3/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,mif2] + 13/768 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,mif2] + 3/128 * self.g1 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,mif2] + -3/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,mif2] + 13/768 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,mif2] + 3/128 * self.g1 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,mif2] + -3/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,mif2] + 13/768 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,mif2] + 3/128 * self.g1 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,mif2] + -3/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,mif2] + 13/768 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,mif2] + 3/128 * self.g1 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,mif2] + -3/128 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,mif2] + -19/2304 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[0,mif1] * self.yu[0,mif2] + -19/2304 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[1,mif1] * self.yu[0,mif2] + -19/2304 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[2,mif1] * self.yu[0,mif2] + -19/2304 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[0,mif1] * self.yu[1,mif2] + -19/2304 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[1,mif1] * self.yu[1,mif2] + -19/2304 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[2,mif1] * self.yu[1,mif2] + -19/2304 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[0,mif1] * self.yu[2,mif2] + -19/2304 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[1,mif1] * self.yu[2,mif2] + -19/2304 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[2,mif1] * self.yu[2,mif2] + -13/1152 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,mif2] * self.yluPi7bar[0,0] * self.yu[mif1,0] + -13/1152 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,mif2] * self.yluPi7bar[1,0] * self.yu[mif1,0] + -13/1152 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,mif2] * self.yluPi7bar[2,0] * self.yu[mif1,0] + -13/1152 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,mif2] * self.yluPi7bar[0,1] * self.yu[mif1,1] + -13/1152 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,mif2] * self.yluPi7bar[1,1] * self.yu[mif1,1] + -13/1152 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,mif2] * self.yluPi7bar[2,1] * self.yu[mif1,1] + -13/1152 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,mif2] * self.yluPi7bar[0,2] * self.yu[mif1,2] + -13/1152 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,mif2] * self.yluPi7bar[1,2] * self.yu[mif1,2] + -13/1152 * self.g1 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,mif2] * self.yluPi7bar[2,2] * self.yu[mif1,2])

    def alphaOud1(self, mif1,mif2,mif3,mif4):
        return (49/12960 * (self.g1)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + -31/2592 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[0,mif2] * self.yluPi7bar[0,mif1] + -1/144 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[0,mif2] * self.yluPi7bar[0,mif1] + 1/144 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[0,mif2] * self.yluPi7bar[0,mif1] + -31/2592 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[1,mif2] * self.yluPi7bar[1,mif1] + -1/144 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[1,mif2] * self.yluPi7bar[1,mif1] + 1/144 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[1,mif2] * self.yluPi7bar[1,mif1] + -31/2592 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[2,mif2] * self.yluPi7bar[2,mif1] + -1/144 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[2,mif2] * self.yluPi7bar[2,mif1] + 1/144 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[2,mif2] * self.yluPi7bar[2,mif1])

    def alphaOud8(self, mif1,mif2,mif3,mif4):
        return (-1/480 * (self.g3)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 1/144 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[0,mif2] * self.yluPi7bar[0,mif1] + 1/144 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[1,mif2] * self.yluPi7bar[1,mif1] + 1/144 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[2,mif2] * self.yluPi7bar[2,mif1])

    def alphaOuG(self, mif1,mif2):
        return (-1/64 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,mif2] + -1/64 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,mif2] + -1/64 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,mif2] + -1/64 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,mif2] + -1/64 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,mif2] + -1/64 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,mif2] + -1/64 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,mif2] + -1/64 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,mif2] + -1/64 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,mif2] + -1/384 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[0,mif1] * self.yu[0,mif2] + -1/384 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[1,mif1] * self.yu[0,mif2] + -1/384 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[2,mif1] * self.yu[0,mif2] + -1/384 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[0,mif1] * self.yu[1,mif2] + -1/384 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[1,mif1] * self.yu[1,mif2] + -1/384 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[2,mif1] * self.yu[1,mif2] + -1/384 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[0,mif1] * self.yu[2,mif2] + -1/384 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[1,mif1] * self.yu[2,mif2] + -1/384 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[2,mif1] * self.yu[2,mif2] + -1/192 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,mif2] * self.yluPi7bar[0,0] * self.yu[mif1,0] + -1/192 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,mif2] * self.yluPi7bar[1,0] * self.yu[mif1,0] + -1/192 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,mif2] * self.yluPi7bar[2,0] * self.yu[mif1,0] + -1/192 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,mif2] * self.yluPi7bar[0,1] * self.yu[mif1,1] + -1/192 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,mif2] * self.yluPi7bar[1,1] * self.yu[mif1,1] + -1/192 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,mif2] * self.yluPi7bar[2,1] * self.yu[mif1,1] + -1/192 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,mif2] * self.yluPi7bar[0,2] * self.yu[mif1,2] + -1/192 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,mif2] * self.yluPi7bar[1,2] * self.yu[mif1,2] + -1/192 * self.g3 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,mif2] * self.yluPi7bar[2,2] * self.yu[mif1,2])

    def alphaOuH(self, mif1,mif2):
        return (-3/32 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,mif2] + -1/16 * self.invepsilonbar * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,mif2] + 1/16 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,mif2] + 1/16 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[0,0] * (self.ylbar[0,0])**(2) * self.yluPi7[0,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[0,0] * (self.ylbar[0,0])**(2) * self.yluPi7[0,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.yl[0,0] * (self.ylbar[0,0])**(2) * self.yluPi7[0,mif2] + -3/32 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,mif2] + -1/16 * self.invepsilonbar * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,mif2] + 1/16 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,mif2] + 1/16 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[0,0] * self.ylbar[0,0] * self.ylbar[0,1] * self.yluPi7[0,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[0,0] * self.ylbar[0,0] * self.ylbar[0,1] * self.yluPi7[0,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.yl[0,0] * self.ylbar[0,0] * self.ylbar[0,1] * self.yluPi7[0,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[0,1] * self.ylbar[0,0] * self.ylbar[0,1] * self.yluPi7[0,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[0,1] * self.ylbar[0,0] * self.ylbar[0,1] * self.yluPi7[0,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.yl[0,1] * self.ylbar[0,0] * self.ylbar[0,1] * self.yluPi7[0,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[0,1] * (self.ylbar[0,1])**(2) * self.yluPi7[0,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[0,1] * (self.ylbar[0,1])**(2) * self.yluPi7[0,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.yl[0,1] * (self.ylbar[0,1])**(2) * self.yluPi7[0,mif2] + -3/32 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,mif2] + -1/16 * self.invepsilonbar * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,mif2] + 1/16 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,mif2] + 1/16 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[0,0] * self.ylbar[0,0] * self.ylbar[0,2] * self.yluPi7[0,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[0,0] * self.ylbar[0,0] * self.ylbar[0,2] * self.yluPi7[0,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.yl[0,0] * self.ylbar[0,0] * self.ylbar[0,2] * self.yluPi7[0,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[0,2] * self.ylbar[0,0] * self.ylbar[0,2] * self.yluPi7[0,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[0,2] * self.ylbar[0,0] * self.ylbar[0,2] * self.yluPi7[0,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.yl[0,2] * self.ylbar[0,0] * self.ylbar[0,2] * self.yluPi7[0,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[0,1] * self.ylbar[0,1] * self.ylbar[0,2] * self.yluPi7[0,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[0,1] * self.ylbar[0,1] * self.ylbar[0,2] * self.yluPi7[0,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.yl[0,1] * self.ylbar[0,1] * self.ylbar[0,2] * self.yluPi7[0,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[0,2] * self.ylbar[0,1] * self.ylbar[0,2] * self.yluPi7[0,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[0,2] * self.ylbar[0,1] * self.ylbar[0,2] * self.yluPi7[0,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.yl[0,2] * self.ylbar[0,1] * self.ylbar[0,2] * self.yluPi7[0,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[0,2] * (self.ylbar[0,2])**(2) * self.yluPi7[0,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[0,2] * (self.ylbar[0,2])**(2) * self.yluPi7[0,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.yl[0,2] * (self.ylbar[0,2])**(2) * self.yluPi7[0,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[1,0] * self.ylbar[0,0] * self.ylbar[1,0] * self.yluPi7[0,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[1,0] * self.ylbar[0,0] * self.ylbar[1,0] * self.yluPi7[0,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.yl[1,0] * self.ylbar[0,0] * self.ylbar[1,0] * self.yluPi7[0,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[1,1] * self.ylbar[0,1] * self.ylbar[1,0] * self.yluPi7[0,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[1,1] * self.ylbar[0,1] * self.ylbar[1,0] * self.yluPi7[0,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.yl[1,1] * self.ylbar[0,1] * self.ylbar[1,0] * self.yluPi7[0,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[1,2] * self.ylbar[0,2] * self.ylbar[1,0] * self.yluPi7[0,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[1,2] * self.ylbar[0,2] * self.ylbar[1,0] * self.yluPi7[0,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.yl[1,2] * self.ylbar[0,2] * self.ylbar[1,0] * self.yluPi7[0,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[1,0] * self.ylbar[0,0] * self.ylbar[1,1] * self.yluPi7[0,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[1,0] * self.ylbar[0,0] * self.ylbar[1,1] * self.yluPi7[0,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.yl[1,0] * self.ylbar[0,0] * self.ylbar[1,1] * self.yluPi7[0,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[1,1] * self.ylbar[0,1] * self.ylbar[1,1] * self.yluPi7[0,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[1,1] * self.ylbar[0,1] * self.ylbar[1,1] * self.yluPi7[0,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.yl[1,1] * self.ylbar[0,1] * self.ylbar[1,1] * self.yluPi7[0,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[1,2] * self.ylbar[0,2] * self.ylbar[1,1] * self.yluPi7[0,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[1,2] * self.ylbar[0,2] * self.ylbar[1,1] * self.yluPi7[0,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.yl[1,2] * self.ylbar[0,2] * self.ylbar[1,1] * self.yluPi7[0,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[1,0] * self.ylbar[0,0] * self.ylbar[1,2] * self.yluPi7[0,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[1,0] * self.ylbar[0,0] * self.ylbar[1,2] * self.yluPi7[0,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.yl[1,0] * self.ylbar[0,0] * self.ylbar[1,2] * self.yluPi7[0,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[1,1] * self.ylbar[0,1] * self.ylbar[1,2] * self.yluPi7[0,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[1,1] * self.ylbar[0,1] * self.ylbar[1,2] * self.yluPi7[0,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.yl[1,1] * self.ylbar[0,1] * self.ylbar[1,2] * self.yluPi7[0,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[1,2] * self.ylbar[0,2] * self.ylbar[1,2] * self.yluPi7[0,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[1,2] * self.ylbar[0,2] * self.ylbar[1,2] * self.yluPi7[0,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.yl[1,2] * self.ylbar[0,2] * self.ylbar[1,2] * self.yluPi7[0,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[2,0] * self.ylbar[0,0] * self.ylbar[2,0] * self.yluPi7[0,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[2,0] * self.ylbar[0,0] * self.ylbar[2,0] * self.yluPi7[0,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.yl[2,0] * self.ylbar[0,0] * self.ylbar[2,0] * self.yluPi7[0,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[2,1] * self.ylbar[0,1] * self.ylbar[2,0] * self.yluPi7[0,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[2,1] * self.ylbar[0,1] * self.ylbar[2,0] * self.yluPi7[0,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.yl[2,1] * self.ylbar[0,1] * self.ylbar[2,0] * self.yluPi7[0,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[2,2] * self.ylbar[0,2] * self.ylbar[2,0] * self.yluPi7[0,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[2,2] * self.ylbar[0,2] * self.ylbar[2,0] * self.yluPi7[0,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.yl[2,2] * self.ylbar[0,2] * self.ylbar[2,0] * self.yluPi7[0,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[2,0] * self.ylbar[0,0] * self.ylbar[2,1] * self.yluPi7[0,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[2,0] * self.ylbar[0,0] * self.ylbar[2,1] * self.yluPi7[0,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.yl[2,0] * self.ylbar[0,0] * self.ylbar[2,1] * self.yluPi7[0,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[2,1] * self.ylbar[0,1] * self.ylbar[2,1] * self.yluPi7[0,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[2,1] * self.ylbar[0,1] * self.ylbar[2,1] * self.yluPi7[0,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.yl[2,1] * self.ylbar[0,1] * self.ylbar[2,1] * self.yluPi7[0,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[2,2] * self.ylbar[0,2] * self.ylbar[2,1] * self.yluPi7[0,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[2,2] * self.ylbar[0,2] * self.ylbar[2,1] * self.yluPi7[0,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.yl[2,2] * self.ylbar[0,2] * self.ylbar[2,1] * self.yluPi7[0,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[2,0] * self.ylbar[0,0] * self.ylbar[2,2] * self.yluPi7[0,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[2,0] * self.ylbar[0,0] * self.ylbar[2,2] * self.yluPi7[0,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.yl[2,0] * self.ylbar[0,0] * self.ylbar[2,2] * self.yluPi7[0,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[2,1] * self.ylbar[0,1] * self.ylbar[2,2] * self.yluPi7[0,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[2,1] * self.ylbar[0,1] * self.ylbar[2,2] * self.yluPi7[0,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.yl[2,1] * self.ylbar[0,1] * self.ylbar[2,2] * self.yluPi7[0,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[2,2] * self.ylbar[0,2] * self.ylbar[2,2] * self.yluPi7[0,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[2,2] * self.ylbar[0,2] * self.ylbar[2,2] * self.yluPi7[0,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.yl[2,2] * self.ylbar[0,2] * self.ylbar[2,2] * self.yluPi7[0,mif2] + -3/32 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,mif2] + -1/16 * self.invepsilonbar * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,mif2] + 1/16 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,mif2] + 1/16 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[0,0] * self.ylbar[0,0] * self.ylbar[1,0] * self.yluPi7[1,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[0,0] * self.ylbar[0,0] * self.ylbar[1,0] * self.yluPi7[1,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.yl[0,0] * self.ylbar[0,0] * self.ylbar[1,0] * self.yluPi7[1,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[0,0] * self.ylbar[0,1] * self.ylbar[1,0] * self.yluPi7[1,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[0,0] * self.ylbar[0,1] * self.ylbar[1,0] * self.yluPi7[1,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.yl[0,0] * self.ylbar[0,1] * self.ylbar[1,0] * self.yluPi7[1,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[0,0] * self.ylbar[0,2] * self.ylbar[1,0] * self.yluPi7[1,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[0,0] * self.ylbar[0,2] * self.ylbar[1,0] * self.yluPi7[1,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.yl[0,0] * self.ylbar[0,2] * self.ylbar[1,0] * self.yluPi7[1,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[1,0] * (self.ylbar[1,0])**(2) * self.yluPi7[1,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[1,0] * (self.ylbar[1,0])**(2) * self.yluPi7[1,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.yl[1,0] * (self.ylbar[1,0])**(2) * self.yluPi7[1,mif2] + -3/32 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,mif2] + -1/16 * self.invepsilonbar * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,mif2] + 1/16 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,mif2] + 1/16 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[0,1] * self.ylbar[0,0] * self.ylbar[1,1] * self.yluPi7[1,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[0,1] * self.ylbar[0,0] * self.ylbar[1,1] * self.yluPi7[1,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.yl[0,1] * self.ylbar[0,0] * self.ylbar[1,1] * self.yluPi7[1,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[0,1] * self.ylbar[0,1] * self.ylbar[1,1] * self.yluPi7[1,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[0,1] * self.ylbar[0,1] * self.ylbar[1,1] * self.yluPi7[1,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.yl[0,1] * self.ylbar[0,1] * self.ylbar[1,1] * self.yluPi7[1,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[0,1] * self.ylbar[0,2] * self.ylbar[1,1] * self.yluPi7[1,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[0,1] * self.ylbar[0,2] * self.ylbar[1,1] * self.yluPi7[1,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.yl[0,1] * self.ylbar[0,2] * self.ylbar[1,1] * self.yluPi7[1,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[1,0] * self.ylbar[1,0] * self.ylbar[1,1] * self.yluPi7[1,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[1,0] * self.ylbar[1,0] * self.ylbar[1,1] * self.yluPi7[1,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.yl[1,0] * self.ylbar[1,0] * self.ylbar[1,1] * self.yluPi7[1,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[1,1] * self.ylbar[1,0] * self.ylbar[1,1] * self.yluPi7[1,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[1,1] * self.ylbar[1,0] * self.ylbar[1,1] * self.yluPi7[1,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.yl[1,1] * self.ylbar[1,0] * self.ylbar[1,1] * self.yluPi7[1,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[1,1] * (self.ylbar[1,1])**(2) * self.yluPi7[1,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[1,1] * (self.ylbar[1,1])**(2) * self.yluPi7[1,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.yl[1,1] * (self.ylbar[1,1])**(2) * self.yluPi7[1,mif2] + -3/32 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,mif2] + -1/16 * self.invepsilonbar * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,mif2] + 1/16 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,mif2] + 1/16 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[0,2] * self.ylbar[0,0] * self.ylbar[1,2] * self.yluPi7[1,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[0,2] * self.ylbar[0,0] * self.ylbar[1,2] * self.yluPi7[1,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.yl[0,2] * self.ylbar[0,0] * self.ylbar[1,2] * self.yluPi7[1,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[0,2] * self.ylbar[0,1] * self.ylbar[1,2] * self.yluPi7[1,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[0,2] * self.ylbar[0,1] * self.ylbar[1,2] * self.yluPi7[1,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.yl[0,2] * self.ylbar[0,1] * self.ylbar[1,2] * self.yluPi7[1,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[0,2] * self.ylbar[0,2] * self.ylbar[1,2] * self.yluPi7[1,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[0,2] * self.ylbar[0,2] * self.ylbar[1,2] * self.yluPi7[1,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.yl[0,2] * self.ylbar[0,2] * self.ylbar[1,2] * self.yluPi7[1,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[1,0] * self.ylbar[1,0] * self.ylbar[1,2] * self.yluPi7[1,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[1,0] * self.ylbar[1,0] * self.ylbar[1,2] * self.yluPi7[1,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.yl[1,0] * self.ylbar[1,0] * self.ylbar[1,2] * self.yluPi7[1,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[1,2] * self.ylbar[1,0] * self.ylbar[1,2] * self.yluPi7[1,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[1,2] * self.ylbar[1,0] * self.ylbar[1,2] * self.yluPi7[1,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.yl[1,2] * self.ylbar[1,0] * self.ylbar[1,2] * self.yluPi7[1,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[1,1] * self.ylbar[1,1] * self.ylbar[1,2] * self.yluPi7[1,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[1,1] * self.ylbar[1,1] * self.ylbar[1,2] * self.yluPi7[1,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.yl[1,1] * self.ylbar[1,1] * self.ylbar[1,2] * self.yluPi7[1,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[1,2] * self.ylbar[1,1] * self.ylbar[1,2] * self.yluPi7[1,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[1,2] * self.ylbar[1,1] * self.ylbar[1,2] * self.yluPi7[1,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.yl[1,2] * self.ylbar[1,1] * self.ylbar[1,2] * self.yluPi7[1,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[1,2] * (self.ylbar[1,2])**(2) * self.yluPi7[1,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[1,2] * (self.ylbar[1,2])**(2) * self.yluPi7[1,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.yl[1,2] * (self.ylbar[1,2])**(2) * self.yluPi7[1,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[2,0] * self.ylbar[1,0] * self.ylbar[2,0] * self.yluPi7[1,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[2,0] * self.ylbar[1,0] * self.ylbar[2,0] * self.yluPi7[1,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.yl[2,0] * self.ylbar[1,0] * self.ylbar[2,0] * self.yluPi7[1,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[2,1] * self.ylbar[1,1] * self.ylbar[2,0] * self.yluPi7[1,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[2,1] * self.ylbar[1,1] * self.ylbar[2,0] * self.yluPi7[1,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.yl[2,1] * self.ylbar[1,1] * self.ylbar[2,0] * self.yluPi7[1,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[2,2] * self.ylbar[1,2] * self.ylbar[2,0] * self.yluPi7[1,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[2,2] * self.ylbar[1,2] * self.ylbar[2,0] * self.yluPi7[1,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.yl[2,2] * self.ylbar[1,2] * self.ylbar[2,0] * self.yluPi7[1,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[2,0] * self.ylbar[1,0] * self.ylbar[2,1] * self.yluPi7[1,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[2,0] * self.ylbar[1,0] * self.ylbar[2,1] * self.yluPi7[1,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.yl[2,0] * self.ylbar[1,0] * self.ylbar[2,1] * self.yluPi7[1,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[2,1] * self.ylbar[1,1] * self.ylbar[2,1] * self.yluPi7[1,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[2,1] * self.ylbar[1,1] * self.ylbar[2,1] * self.yluPi7[1,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.yl[2,1] * self.ylbar[1,1] * self.ylbar[2,1] * self.yluPi7[1,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[2,2] * self.ylbar[1,2] * self.ylbar[2,1] * self.yluPi7[1,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[2,2] * self.ylbar[1,2] * self.ylbar[2,1] * self.yluPi7[1,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.yl[2,2] * self.ylbar[1,2] * self.ylbar[2,1] * self.yluPi7[1,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[2,0] * self.ylbar[1,0] * self.ylbar[2,2] * self.yluPi7[1,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[2,0] * self.ylbar[1,0] * self.ylbar[2,2] * self.yluPi7[1,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.yl[2,0] * self.ylbar[1,0] * self.ylbar[2,2] * self.yluPi7[1,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[2,1] * self.ylbar[1,1] * self.ylbar[2,2] * self.yluPi7[1,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[2,1] * self.ylbar[1,1] * self.ylbar[2,2] * self.yluPi7[1,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.yl[2,1] * self.ylbar[1,1] * self.ylbar[2,2] * self.yluPi7[1,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[2,2] * self.ylbar[1,2] * self.ylbar[2,2] * self.yluPi7[1,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[2,2] * self.ylbar[1,2] * self.ylbar[2,2] * self.yluPi7[1,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.yl[2,2] * self.ylbar[1,2] * self.ylbar[2,2] * self.yluPi7[1,mif2] + -3/32 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,mif2] + -1/16 * self.invepsilonbar * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,mif2] + 1/16 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,mif2] + 1/16 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[0,0] * self.ylbar[0,0] * self.ylbar[2,0] * self.yluPi7[2,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[0,0] * self.ylbar[0,0] * self.ylbar[2,0] * self.yluPi7[2,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.yl[0,0] * self.ylbar[0,0] * self.ylbar[2,0] * self.yluPi7[2,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[0,0] * self.ylbar[0,1] * self.ylbar[2,0] * self.yluPi7[2,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[0,0] * self.ylbar[0,1] * self.ylbar[2,0] * self.yluPi7[2,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.yl[0,0] * self.ylbar[0,1] * self.ylbar[2,0] * self.yluPi7[2,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[0,0] * self.ylbar[0,2] * self.ylbar[2,0] * self.yluPi7[2,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[0,0] * self.ylbar[0,2] * self.ylbar[2,0] * self.yluPi7[2,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.yl[0,0] * self.ylbar[0,2] * self.ylbar[2,0] * self.yluPi7[2,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[1,0] * self.ylbar[1,0] * self.ylbar[2,0] * self.yluPi7[2,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[1,0] * self.ylbar[1,0] * self.ylbar[2,0] * self.yluPi7[2,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.yl[1,0] * self.ylbar[1,0] * self.ylbar[2,0] * self.yluPi7[2,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[1,0] * self.ylbar[1,1] * self.ylbar[2,0] * self.yluPi7[2,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[1,0] * self.ylbar[1,1] * self.ylbar[2,0] * self.yluPi7[2,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.yl[1,0] * self.ylbar[1,1] * self.ylbar[2,0] * self.yluPi7[2,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[1,0] * self.ylbar[1,2] * self.ylbar[2,0] * self.yluPi7[2,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[1,0] * self.ylbar[1,2] * self.ylbar[2,0] * self.yluPi7[2,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.yl[1,0] * self.ylbar[1,2] * self.ylbar[2,0] * self.yluPi7[2,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[2,0] * (self.ylbar[2,0])**(2) * self.yluPi7[2,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[2,0] * (self.ylbar[2,0])**(2) * self.yluPi7[2,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.yl[2,0] * (self.ylbar[2,0])**(2) * self.yluPi7[2,mif2] + -3/32 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,mif2] + -1/16 * self.invepsilonbar * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,mif2] + 1/16 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,mif2] + 1/16 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[0,1] * self.ylbar[0,0] * self.ylbar[2,1] * self.yluPi7[2,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[0,1] * self.ylbar[0,0] * self.ylbar[2,1] * self.yluPi7[2,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.yl[0,1] * self.ylbar[0,0] * self.ylbar[2,1] * self.yluPi7[2,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[0,1] * self.ylbar[0,1] * self.ylbar[2,1] * self.yluPi7[2,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[0,1] * self.ylbar[0,1] * self.ylbar[2,1] * self.yluPi7[2,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.yl[0,1] * self.ylbar[0,1] * self.ylbar[2,1] * self.yluPi7[2,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[0,1] * self.ylbar[0,2] * self.ylbar[2,1] * self.yluPi7[2,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[0,1] * self.ylbar[0,2] * self.ylbar[2,1] * self.yluPi7[2,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.yl[0,1] * self.ylbar[0,2] * self.ylbar[2,1] * self.yluPi7[2,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[1,1] * self.ylbar[1,0] * self.ylbar[2,1] * self.yluPi7[2,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[1,1] * self.ylbar[1,0] * self.ylbar[2,1] * self.yluPi7[2,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.yl[1,1] * self.ylbar[1,0] * self.ylbar[2,1] * self.yluPi7[2,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[1,1] * self.ylbar[1,1] * self.ylbar[2,1] * self.yluPi7[2,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[1,1] * self.ylbar[1,1] * self.ylbar[2,1] * self.yluPi7[2,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.yl[1,1] * self.ylbar[1,1] * self.ylbar[2,1] * self.yluPi7[2,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[1,1] * self.ylbar[1,2] * self.ylbar[2,1] * self.yluPi7[2,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[1,1] * self.ylbar[1,2] * self.ylbar[2,1] * self.yluPi7[2,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.yl[1,1] * self.ylbar[1,2] * self.ylbar[2,1] * self.yluPi7[2,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[2,0] * self.ylbar[2,0] * self.ylbar[2,1] * self.yluPi7[2,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[2,0] * self.ylbar[2,0] * self.ylbar[2,1] * self.yluPi7[2,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.yl[2,0] * self.ylbar[2,0] * self.ylbar[2,1] * self.yluPi7[2,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[2,1] * self.ylbar[2,0] * self.ylbar[2,1] * self.yluPi7[2,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[2,1] * self.ylbar[2,0] * self.ylbar[2,1] * self.yluPi7[2,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.yl[2,1] * self.ylbar[2,0] * self.ylbar[2,1] * self.yluPi7[2,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[2,1] * (self.ylbar[2,1])**(2) * self.yluPi7[2,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[2,1] * (self.ylbar[2,1])**(2) * self.yluPi7[2,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.yl[2,1] * (self.ylbar[2,1])**(2) * self.yluPi7[2,mif2] + -3/32 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,mif2] + -1/16 * self.invepsilonbar * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,mif2] + 1/16 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,mif2] + 1/16 * self.lam * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[0,2] * self.ylbar[0,0] * self.ylbar[2,2] * self.yluPi7[2,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[0,2] * self.ylbar[0,0] * self.ylbar[2,2] * self.yluPi7[2,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.yl[0,2] * self.ylbar[0,0] * self.ylbar[2,2] * self.yluPi7[2,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[0,2] * self.ylbar[0,1] * self.ylbar[2,2] * self.yluPi7[2,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[0,2] * self.ylbar[0,1] * self.ylbar[2,2] * self.yluPi7[2,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.yl[0,2] * self.ylbar[0,1] * self.ylbar[2,2] * self.yluPi7[2,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[0,2] * self.ylbar[0,2] * self.ylbar[2,2] * self.yluPi7[2,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[0,2] * self.ylbar[0,2] * self.ylbar[2,2] * self.yluPi7[2,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.yl[0,2] * self.ylbar[0,2] * self.ylbar[2,2] * self.yluPi7[2,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[1,2] * self.ylbar[1,0] * self.ylbar[2,2] * self.yluPi7[2,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[1,2] * self.ylbar[1,0] * self.ylbar[2,2] * self.yluPi7[2,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.yl[1,2] * self.ylbar[1,0] * self.ylbar[2,2] * self.yluPi7[2,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[1,2] * self.ylbar[1,1] * self.ylbar[2,2] * self.yluPi7[2,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[1,2] * self.ylbar[1,1] * self.ylbar[2,2] * self.yluPi7[2,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.yl[1,2] * self.ylbar[1,1] * self.ylbar[2,2] * self.yluPi7[2,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[1,2] * self.ylbar[1,2] * self.ylbar[2,2] * self.yluPi7[2,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[1,2] * self.ylbar[1,2] * self.ylbar[2,2] * self.yluPi7[2,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.yl[1,2] * self.ylbar[1,2] * self.ylbar[2,2] * self.yluPi7[2,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[2,0] * self.ylbar[2,0] * self.ylbar[2,2] * self.yluPi7[2,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[2,0] * self.ylbar[2,0] * self.ylbar[2,2] * self.yluPi7[2,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.yl[2,0] * self.ylbar[2,0] * self.ylbar[2,2] * self.yluPi7[2,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[2,2] * self.ylbar[2,0] * self.ylbar[2,2] * self.yluPi7[2,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.yl[2,2] * self.ylbar[2,0] * self.ylbar[2,2] * self.yluPi7[2,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.yl[2,2] * self.ylbar[2,0] * self.ylbar[2,2] * self.yluPi7[2,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[2,1] * self.ylbar[2,1] * self.ylbar[2,2] * self.yluPi7[2,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[2,1] * self.ylbar[2,1] * self.ylbar[2,2] * self.yluPi7[2,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.yl[2,1] * self.ylbar[2,1] * self.ylbar[2,2] * self.yluPi7[2,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[2,2] * self.ylbar[2,1] * self.ylbar[2,2] * self.yluPi7[2,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.yl[2,2] * self.ylbar[2,1] * self.ylbar[2,2] * self.yluPi7[2,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.yl[2,2] * self.ylbar[2,1] * self.ylbar[2,2] * self.yluPi7[2,mif2] + 1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[2,2] * (self.ylbar[2,2])**(2) * self.yluPi7[2,mif2] + 1/16 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.yl[2,2] * (self.ylbar[2,2])**(2) * self.yluPi7[2,mif2] + -1/16 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.yl[2,2] * (self.ylbar[2,2])**(2) * self.yluPi7[2,mif2] + 1/64 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[0,mif1] * self.yu[0,mif2] + 1/64 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[1,mif1] * self.yu[0,mif2] + 1/64 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[2,mif1] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[0,mif1] * self.yl[0,0] * self.ylbar[0,0] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[0,mif1] * self.yl[0,1] * self.ylbar[0,0] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[0,mif1] * self.yl[0,2] * self.ylbar[0,0] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[1,mif1] * self.yl[0,0] * self.ylbar[0,1] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[1,mif1] * self.yl[0,1] * self.ylbar[0,1] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[1,mif1] * self.yl[0,2] * self.ylbar[0,1] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[2,mif1] * self.yl[0,0] * self.ylbar[0,2] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[2,mif1] * self.yl[0,1] * self.ylbar[0,2] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[2,mif1] * self.yl[0,2] * self.ylbar[0,2] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[0,mif1] * self.yl[1,0] * self.ylbar[1,0] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[0,mif1] * self.yl[1,1] * self.ylbar[1,0] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[0,mif1] * self.yl[1,2] * self.ylbar[1,0] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[1,mif1] * self.yl[1,0] * self.ylbar[1,1] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[1,mif1] * self.yl[1,1] * self.ylbar[1,1] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[1,mif1] * self.yl[1,2] * self.ylbar[1,1] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[2,mif1] * self.yl[1,0] * self.ylbar[1,2] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[2,mif1] * self.yl[1,1] * self.ylbar[1,2] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[2,mif1] * self.yl[1,2] * self.ylbar[1,2] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[0,mif1] * self.yl[2,0] * self.ylbar[2,0] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[0,mif1] * self.yl[2,1] * self.ylbar[2,0] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[0,mif1] * self.yl[2,2] * self.ylbar[2,0] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[1,mif1] * self.yl[2,0] * self.ylbar[2,1] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[1,mif1] * self.yl[2,1] * self.ylbar[2,1] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[1,mif1] * self.yl[2,2] * self.ylbar[2,1] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[2,mif1] * self.yl[2,0] * self.ylbar[2,2] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[2,mif1] * self.yl[2,1] * self.ylbar[2,2] * self.yu[0,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[2,mif1] * self.yl[2,2] * self.ylbar[2,2] * self.yu[0,mif2] + 1/64 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[0,mif1] * self.yu[1,mif2] + 1/64 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[1,mif1] * self.yu[1,mif2] + 1/64 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[2,mif1] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[0,mif1] * self.yl[0,0] * self.ylbar[0,0] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[0,mif1] * self.yl[0,1] * self.ylbar[0,0] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[0,mif1] * self.yl[0,2] * self.ylbar[0,0] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[1,mif1] * self.yl[0,0] * self.ylbar[0,1] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[1,mif1] * self.yl[0,1] * self.ylbar[0,1] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[1,mif1] * self.yl[0,2] * self.ylbar[0,1] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[2,mif1] * self.yl[0,0] * self.ylbar[0,2] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[2,mif1] * self.yl[0,1] * self.ylbar[0,2] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[2,mif1] * self.yl[0,2] * self.ylbar[0,2] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[0,mif1] * self.yl[1,0] * self.ylbar[1,0] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[0,mif1] * self.yl[1,1] * self.ylbar[1,0] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[0,mif1] * self.yl[1,2] * self.ylbar[1,0] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[1,mif1] * self.yl[1,0] * self.ylbar[1,1] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[1,mif1] * self.yl[1,1] * self.ylbar[1,1] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[1,mif1] * self.yl[1,2] * self.ylbar[1,1] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[2,mif1] * self.yl[1,0] * self.ylbar[1,2] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[2,mif1] * self.yl[1,1] * self.ylbar[1,2] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[2,mif1] * self.yl[1,2] * self.ylbar[1,2] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[0,mif1] * self.yl[2,0] * self.ylbar[2,0] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[0,mif1] * self.yl[2,1] * self.ylbar[2,0] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[0,mif1] * self.yl[2,2] * self.ylbar[2,0] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[1,mif1] * self.yl[2,0] * self.ylbar[2,1] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[1,mif1] * self.yl[2,1] * self.ylbar[2,1] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[1,mif1] * self.yl[2,2] * self.ylbar[2,1] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[2,mif1] * self.yl[2,0] * self.ylbar[2,2] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[2,mif1] * self.yl[2,1] * self.ylbar[2,2] * self.yu[1,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[2,mif1] * self.yl[2,2] * self.ylbar[2,2] * self.yu[1,mif2] + 1/64 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[0,mif1] * self.yu[2,mif2] + 1/64 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[1,mif1] * self.yu[2,mif2] + 1/64 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[2,mif1] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[0,mif1] * self.yl[0,0] * self.ylbar[0,0] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[0,mif1] * self.yl[0,1] * self.ylbar[0,0] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[0,mif1] * self.yl[0,2] * self.ylbar[0,0] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[1,mif1] * self.yl[0,0] * self.ylbar[0,1] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[1,mif1] * self.yl[0,1] * self.ylbar[0,1] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[1,mif1] * self.yl[0,2] * self.ylbar[0,1] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[2,mif1] * self.yl[0,0] * self.ylbar[0,2] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[2,mif1] * self.yl[0,1] * self.ylbar[0,2] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[2,mif1] * self.yl[0,2] * self.ylbar[0,2] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[0,mif1] * self.yl[1,0] * self.ylbar[1,0] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[0,mif1] * self.yl[1,1] * self.ylbar[1,0] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[0,mif1] * self.yl[1,2] * self.ylbar[1,0] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[1,mif1] * self.yl[1,0] * self.ylbar[1,1] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[1,mif1] * self.yl[1,1] * self.ylbar[1,1] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[1,mif1] * self.yl[1,2] * self.ylbar[1,1] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[2,mif1] * self.yl[1,0] * self.ylbar[1,2] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[2,mif1] * self.yl[1,1] * self.ylbar[1,2] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[2,mif1] * self.yl[1,2] * self.ylbar[1,2] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[0,mif1] * self.yl[2,0] * self.ylbar[2,0] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[0,mif1] * self.yl[2,1] * self.ylbar[2,0] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[0,mif1] * self.yl[2,2] * self.ylbar[2,0] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[1,mif1] * self.yl[2,0] * self.ylbar[2,1] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[1,mif1] * self.yl[2,1] * self.ylbar[2,1] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[1,mif1] * self.yl[2,2] * self.ylbar[2,1] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[2,mif1] * self.yl[2,0] * self.ylbar[2,2] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[2,mif1] * self.yl[2,1] * self.ylbar[2,2] * self.yu[2,mif2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[2,mif1] * self.yl[2,2] * self.ylbar[2,2] * self.yu[2,mif2] + 1/32 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,mif2] * self.yluPi7bar[0,0] * self.yu[mif1,0] + 1/64 * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,mif2] * self.yluPi7bar[0,0] * self.yu[mif1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yluPi7bar[0,0] * self.yu[mif1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yluPi7bar[0,0] * self.yu[mif1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yluPi7bar[0,0] * self.yu[mif1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yluPi7bar[0,0] * self.yu[mif1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yluPi7bar[0,0] * self.yu[mif1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yluPi7bar[0,0] * self.yu[mif1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yluPi7bar[0,0] * self.yu[mif1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yluPi7bar[0,0] * self.yu[mif1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yluPi7bar[0,0] * self.yu[mif1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yluPi7bar[1,0] * self.yu[mif1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yluPi7bar[1,0] * self.yu[mif1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yluPi7bar[1,0] * self.yu[mif1,0] + 1/32 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,mif2] * self.yluPi7bar[1,0] * self.yu[mif1,0] + 1/64 * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,mif2] * self.yluPi7bar[1,0] * self.yu[mif1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yluPi7bar[1,0] * self.yu[mif1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yluPi7bar[1,0] * self.yu[mif1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yluPi7bar[1,0] * self.yu[mif1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yluPi7bar[1,0] * self.yu[mif1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yluPi7bar[1,0] * self.yu[mif1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yluPi7bar[1,0] * self.yu[mif1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yluPi7bar[2,0] * self.yu[mif1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yluPi7bar[2,0] * self.yu[mif1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yluPi7bar[2,0] * self.yu[mif1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yluPi7bar[2,0] * self.yu[mif1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yluPi7bar[2,0] * self.yu[mif1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yluPi7bar[2,0] * self.yu[mif1,0] + 1/32 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,mif2] * self.yluPi7bar[2,0] * self.yu[mif1,0] + 1/64 * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,mif2] * self.yluPi7bar[2,0] * self.yu[mif1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yluPi7bar[2,0] * self.yu[mif1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yluPi7bar[2,0] * self.yu[mif1,0] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yluPi7bar[2,0] * self.yu[mif1,0] + 1/32 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,mif2] * self.yluPi7bar[0,1] * self.yu[mif1,1] + 1/64 * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,mif2] * self.yluPi7bar[0,1] * self.yu[mif1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yluPi7bar[0,1] * self.yu[mif1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yluPi7bar[0,1] * self.yu[mif1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yluPi7bar[0,1] * self.yu[mif1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yluPi7bar[0,1] * self.yu[mif1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yluPi7bar[0,1] * self.yu[mif1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yluPi7bar[0,1] * self.yu[mif1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yluPi7bar[0,1] * self.yu[mif1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yluPi7bar[0,1] * self.yu[mif1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yluPi7bar[0,1] * self.yu[mif1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yluPi7bar[1,1] * self.yu[mif1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yluPi7bar[1,1] * self.yu[mif1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yluPi7bar[1,1] * self.yu[mif1,1] + 1/32 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,mif2] * self.yluPi7bar[1,1] * self.yu[mif1,1] + 1/64 * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,mif2] * self.yluPi7bar[1,1] * self.yu[mif1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yluPi7bar[1,1] * self.yu[mif1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yluPi7bar[1,1] * self.yu[mif1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yluPi7bar[1,1] * self.yu[mif1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yluPi7bar[1,1] * self.yu[mif1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yluPi7bar[1,1] * self.yu[mif1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yluPi7bar[1,1] * self.yu[mif1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yluPi7bar[2,1] * self.yu[mif1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yluPi7bar[2,1] * self.yu[mif1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yluPi7bar[2,1] * self.yu[mif1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yluPi7bar[2,1] * self.yu[mif1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yluPi7bar[2,1] * self.yu[mif1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yluPi7bar[2,1] * self.yu[mif1,1] + 1/32 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,mif2] * self.yluPi7bar[2,1] * self.yu[mif1,1] + 1/64 * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,mif2] * self.yluPi7bar[2,1] * self.yu[mif1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yluPi7bar[2,1] * self.yu[mif1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yluPi7bar[2,1] * self.yu[mif1,1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yluPi7bar[2,1] * self.yu[mif1,1] + 1/32 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,mif2] * self.yluPi7bar[0,2] * self.yu[mif1,2] + 1/64 * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,mif2] * self.yluPi7bar[0,2] * self.yu[mif1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yluPi7bar[0,2] * self.yu[mif1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yluPi7bar[0,2] * self.yu[mif1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yluPi7bar[0,2] * self.yu[mif1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yluPi7bar[0,2] * self.yu[mif1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yluPi7bar[0,2] * self.yu[mif1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yluPi7bar[0,2] * self.yu[mif1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yluPi7bar[0,2] * self.yu[mif1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yluPi7bar[0,2] * self.yu[mif1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yluPi7bar[0,2] * self.yu[mif1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yluPi7bar[1,2] * self.yu[mif1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yluPi7bar[1,2] * self.yu[mif1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yluPi7bar[1,2] * self.yu[mif1,2] + 1/32 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,mif2] * self.yluPi7bar[1,2] * self.yu[mif1,2] + 1/64 * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,mif2] * self.yluPi7bar[1,2] * self.yu[mif1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yluPi7bar[1,2] * self.yu[mif1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yluPi7bar[1,2] * self.yu[mif1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yluPi7bar[1,2] * self.yu[mif1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yluPi7bar[1,2] * self.yu[mif1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yluPi7bar[1,2] * self.yu[mif1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yluPi7bar[1,2] * self.yu[mif1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yluPi7bar[2,2] * self.yu[mif1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yluPi7bar[2,2] * self.yu[mif1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yluPi7bar[2,2] * self.yu[mif1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yluPi7bar[2,2] * self.yu[mif1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yluPi7bar[2,2] * self.yu[mif1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yluPi7bar[2,2] * self.yu[mif1,2] + 1/32 * self.lambdaHatPi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,mif2] * self.yluPi7bar[2,2] * self.yu[mif1,2] + 1/64 * self.lambdaHatPrimePi7 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,mif2] * self.yluPi7bar[2,2] * self.yu[mif1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yluPi7bar[2,2] * self.yu[mif1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yluPi7bar[2,2] * self.yu[mif1,2] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yluPi7bar[2,2] * self.yu[mif1,2] + -1/1280 * (self.g2)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yu[mif1,mif2] + 1/64 * (self.lambdaHatPrimePi7)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yu[mif1,mif2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,0] * self.yu[0,mif2] * self.yubar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,0] * self.yu[0,mif2] * self.yubar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,0] * self.yu[0,mif2] * self.yubar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,0] * self.yu[0,mif2] * self.yubar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,0] * self.yu[0,mif2] * self.yubar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,0] * self.yu[0,mif2] * self.yubar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,0] * self.yu[0,mif2] * self.yubar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,0] * self.yu[0,mif2] * self.yubar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,0] * self.yu[0,mif2] * self.yubar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,0] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,0] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,0] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,0] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,0] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,0] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,0] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,0] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,0] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[0,0] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[1,0] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[2,0] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,0] * self.yluPi7bar[0,0] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,0] * self.yluPi7bar[1,0] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,0] * self.yluPi7bar[2,0] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[0,0] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[1,0] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[2,0] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[0,0] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[1,0] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[2,0] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,0] * self.yluPi7bar[0,1] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[0,0] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,0] * self.yluPi7bar[1,1] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[0,0] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,0] * self.yluPi7bar[2,1] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[0,0] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,0] * self.yluPi7bar[0,2] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[0,0] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,0] * self.yluPi7bar[1,2] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[0,0] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,0] * self.yluPi7bar[2,2] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[0,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,1] * self.yu[0,mif2] * self.yubar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,1] * self.yu[0,mif2] * self.yubar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,1] * self.yu[0,mif2] * self.yubar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,1] * self.yu[0,mif2] * self.yubar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,1] * self.yu[0,mif2] * self.yubar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,1] * self.yu[0,mif2] * self.yubar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,1] * self.yu[0,mif2] * self.yubar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,1] * self.yu[0,mif2] * self.yubar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,1] * self.yu[0,mif2] * self.yubar[0,1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,1] * self.yluPi7bar[0,0] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[0,1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,1] * self.yluPi7bar[1,0] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[0,1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,1] * self.yluPi7bar[2,0] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,0] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,0] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,0] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,0] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,0] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,0] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,0] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,0] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,0] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[0,0] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[1,0] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[2,0] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,1] * self.yluPi7bar[0,1] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,1] * self.yluPi7bar[1,1] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,1] * self.yluPi7bar[2,1] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[0,0] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[1,0] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[2,0] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[0,0] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[1,0] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[2,0] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,1] * self.yluPi7bar[0,2] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[0,1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,1] * self.yluPi7bar[1,2] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[0,1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,1] * self.yluPi7bar[2,2] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[0,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,2] * self.yu[0,mif2] * self.yubar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,2] * self.yu[0,mif2] * self.yubar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,2] * self.yu[0,mif2] * self.yubar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,2] * self.yu[0,mif2] * self.yubar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,2] * self.yu[0,mif2] * self.yubar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,2] * self.yu[0,mif2] * self.yubar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,2] * self.yu[0,mif2] * self.yubar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,2] * self.yu[0,mif2] * self.yubar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,2] * self.yu[0,mif2] * self.yubar[0,2] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,2] * self.yluPi7bar[0,0] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[0,2] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,2] * self.yluPi7bar[1,0] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[0,2] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,2] * self.yluPi7bar[2,0] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[0,2] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,2] * self.yluPi7bar[0,1] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[0,2] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,2] * self.yluPi7bar[1,1] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[0,2] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,2] * self.yluPi7bar[2,1] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,0] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,0] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,0] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,0] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,0] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,0] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,0] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,0] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,0] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[0,0] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[1,0] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[2,0] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,2] * self.yluPi7bar[0,2] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,2] * self.yluPi7bar[1,2] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,2] * self.yluPi7bar[2,2] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[0,0] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[1,0] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[2,0] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[0,0] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[1,0] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[2,0] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,0] * self.yu[1,mif2] * self.yubar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,0] * self.yu[1,mif2] * self.yubar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,0] * self.yu[1,mif2] * self.yubar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,0] * self.yu[1,mif2] * self.yubar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,0] * self.yu[1,mif2] * self.yubar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,0] * self.yu[1,mif2] * self.yubar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,0] * self.yu[1,mif2] * self.yubar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,0] * self.yu[1,mif2] * self.yubar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,0] * self.yu[1,mif2] * self.yubar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,1] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,1] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,1] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,1] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,1] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,1] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,1] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,1] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,1] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[0,1] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[1,1] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[2,1] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[0,1] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[1,1] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[2,1] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,0] * self.yluPi7bar[0,0] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,0] * self.yluPi7bar[1,0] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,0] * self.yluPi7bar[2,0] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[0,1] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[1,1] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[2,1] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,0] * self.yluPi7bar[0,1] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[1,0] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,0] * self.yluPi7bar[1,1] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[1,0] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,0] * self.yluPi7bar[2,1] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[1,0] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,0] * self.yluPi7bar[0,2] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[1,0] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,0] * self.yluPi7bar[1,2] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[1,0] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,0] * self.yluPi7bar[2,2] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[1,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,1] * self.yu[1,mif2] * self.yubar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,1] * self.yu[1,mif2] * self.yubar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,1] * self.yu[1,mif2] * self.yubar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,1] * self.yu[1,mif2] * self.yubar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,1] * self.yu[1,mif2] * self.yubar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,1] * self.yu[1,mif2] * self.yubar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,1] * self.yu[1,mif2] * self.yubar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,1] * self.yu[1,mif2] * self.yubar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,1] * self.yu[1,mif2] * self.yubar[1,1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,1] * self.yluPi7bar[0,0] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[1,1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,1] * self.yluPi7bar[1,0] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[1,1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,1] * self.yluPi7bar[2,0] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,1] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,1] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,1] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,1] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,1] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,1] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,1] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,1] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,1] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[0,1] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[1,1] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[2,1] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[0,1] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[1,1] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[2,1] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,1] * self.yluPi7bar[0,1] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,1] * self.yluPi7bar[1,1] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,1] * self.yluPi7bar[2,1] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[0,1] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[1,1] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[2,1] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,1] * self.yluPi7bar[0,2] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[1,1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,1] * self.yluPi7bar[1,2] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[1,1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,1] * self.yluPi7bar[2,2] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[1,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,2] * self.yu[1,mif2] * self.yubar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,2] * self.yu[1,mif2] * self.yubar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,2] * self.yu[1,mif2] * self.yubar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,2] * self.yu[1,mif2] * self.yubar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,2] * self.yu[1,mif2] * self.yubar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,2] * self.yu[1,mif2] * self.yubar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,2] * self.yu[1,mif2] * self.yubar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,2] * self.yu[1,mif2] * self.yubar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,2] * self.yu[1,mif2] * self.yubar[1,2] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,2] * self.yluPi7bar[0,0] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[1,2] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,2] * self.yluPi7bar[1,0] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[1,2] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,2] * self.yluPi7bar[2,0] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[1,2] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,2] * self.yluPi7bar[0,1] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[1,2] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,2] * self.yluPi7bar[1,1] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[1,2] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,2] * self.yluPi7bar[2,1] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,1] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,1] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,1] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,1] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,1] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,1] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,1] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,1] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,1] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[0,1] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[1,1] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[2,1] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[0,1] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[1,1] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[2,1] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,2] * self.yluPi7bar[0,2] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,2] * self.yluPi7bar[1,2] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,2] * self.yluPi7bar[2,2] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[0,1] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[1,1] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[2,1] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,0] * self.yu[2,mif2] * self.yubar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,0] * self.yu[2,mif2] * self.yubar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,0] * self.yu[2,mif2] * self.yubar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,0] * self.yu[2,mif2] * self.yubar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,0] * self.yu[2,mif2] * self.yubar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,0] * self.yu[2,mif2] * self.yubar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,0] * self.yu[2,mif2] * self.yubar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,0] * self.yu[2,mif2] * self.yubar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,0] * self.yu[2,mif2] * self.yubar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,2] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,2] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,2] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,2] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,2] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,2] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,2] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,2] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,2] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[0,2] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[1,2] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[2,2] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[0,2] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[1,2] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[2,2] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[0,2] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[1,2] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[2,2] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,0] * self.yluPi7bar[0,0] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,0] * self.yluPi7bar[1,0] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,0] * self.yluPi7bar[2,0] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,0] * self.yluPi7bar[0,1] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[2,0] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,0] * self.yluPi7bar[1,1] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[2,0] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,0] * self.yluPi7bar[2,1] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[2,0] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,0] * self.yluPi7bar[0,2] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[2,0] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,0] * self.yluPi7bar[1,2] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[2,0] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,0] * self.yluPi7bar[2,2] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[2,0] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,1] * self.yu[2,mif2] * self.yubar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,1] * self.yu[2,mif2] * self.yubar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,1] * self.yu[2,mif2] * self.yubar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,1] * self.yu[2,mif2] * self.yubar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,1] * self.yu[2,mif2] * self.yubar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,1] * self.yu[2,mif2] * self.yubar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,1] * self.yu[2,mif2] * self.yubar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,1] * self.yu[2,mif2] * self.yubar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,1] * self.yu[2,mif2] * self.yubar[2,1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,1] * self.yluPi7bar[0,0] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[2,1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,1] * self.yluPi7bar[1,0] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[2,1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,1] * self.yluPi7bar[2,0] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,2] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,2] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,2] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,2] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,2] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,2] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,2] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,2] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,2] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[0,2] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[1,2] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[2,2] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[0,2] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[1,2] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[2,2] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[0,2] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[1,2] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[2,2] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,1] * self.yluPi7bar[0,1] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,1] * self.yluPi7bar[1,1] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,1] * self.yluPi7bar[2,1] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,1] * self.yluPi7bar[0,2] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[2,1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,1] * self.yluPi7bar[1,2] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[2,1] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,1] * self.yluPi7bar[2,2] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[2,1] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,2] * self.yu[2,mif2] * self.yubar[2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,2] * self.yu[2,mif2] * self.yubar[2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,2] * self.yu[2,mif2] * self.yubar[2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,2] * self.yu[2,mif2] * self.yubar[2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,2] * self.yu[2,mif2] * self.yubar[2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,2] * self.yu[2,mif2] * self.yubar[2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,2] * self.yu[2,mif2] * self.yubar[2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,2] * self.yu[2,mif2] * self.yubar[2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,2] * self.yu[2,mif2] * self.yubar[2,2] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,2] * self.yluPi7bar[0,0] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[2,2] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,2] * self.yluPi7bar[1,0] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[2,2] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,2] * self.yluPi7bar[2,0] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[2,2] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,2] * self.yluPi7bar[0,1] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[2,2] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,2] * self.yluPi7bar[1,1] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[2,2] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,2] * self.yluPi7bar[2,1] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,2] * self.ylbar[0,0] * self.yluPi7[0,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,2] * self.ylbar[0,1] * self.yluPi7[0,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,2] * self.ylbar[0,2] * self.yluPi7[0,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,2] * self.ylbar[1,0] * self.yluPi7[1,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,2] * self.ylbar[1,1] * self.yluPi7[1,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,2] * self.ylbar[1,2] * self.yluPi7[1,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,2] * self.ylbar[2,0] * self.yluPi7[2,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,2] * self.ylbar[2,1] * self.yluPi7[2,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,2] * self.ylbar[2,2] * self.yluPi7[2,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[0,2] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[1,2] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[2,2] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[0,2] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[1,2] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[2,2] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[0,2] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[1,2] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/192 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[2,2] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,2] * self.yluPi7bar[0,2] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,2] * self.yluPi7bar[1,2] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/96 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,2] * self.yluPi7bar[2,2] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[2,2])

    def alphaOuu(self, mif1,mif2,mif3,mif4):
        return (-1/1920 * (self.g3)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.kronecker_delta(mif2,mif3) + -49/12960 * (self.g1)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 1/5760 * (self.g3)**(4) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 31/2592 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[0,mif2] * self.yluPi7bar[0,mif1] + -1/1728 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[0,mif2] * self.yluPi7bar[0,mif1] + 1/144 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[0,mif2] * self.yluPi7bar[0,mif1] + -1/144 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[0,mif2] * self.yluPi7bar[0,mif1] + 1/576 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yluPi7[0,mif4] * self.yluPi7bar[0,mif1] + 1/576 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yluPi7[0,mif2] * self.yluPi7bar[0,mif3] + 31/2592 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[0,mif4] * self.yluPi7bar[0,mif3] + -1/1728 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[0,mif4] * self.yluPi7bar[0,mif3] + 1/144 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[0,mif4] * self.yluPi7bar[0,mif3] + -1/144 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[0,mif4] * self.yluPi7bar[0,mif3] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,mif2] * self.yluPi7[0,mif4] * self.yluPi7bar[0,mif1] * self.yluPi7bar[0,mif3] + 31/2592 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[1,mif2] * self.yluPi7bar[1,mif1] + -1/1728 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[1,mif2] * self.yluPi7bar[1,mif1] + 1/144 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[1,mif2] * self.yluPi7bar[1,mif1] + -1/144 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[1,mif2] * self.yluPi7bar[1,mif1] + 1/576 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yluPi7[1,mif4] * self.yluPi7bar[1,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,mif2] * self.yluPi7[1,mif4] * self.yluPi7bar[0,mif3] * self.yluPi7bar[1,mif1] + 1/576 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yluPi7[1,mif2] * self.yluPi7bar[1,mif3] + 31/2592 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[1,mif4] * self.yluPi7bar[1,mif3] + -1/1728 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[1,mif4] * self.yluPi7bar[1,mif3] + 1/144 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[1,mif4] * self.yluPi7bar[1,mif3] + -1/144 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[1,mif4] * self.yluPi7bar[1,mif3] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,mif4] * self.yluPi7[1,mif2] * self.yluPi7bar[0,mif1] * self.yluPi7bar[1,mif3] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,mif2] * self.yluPi7[1,mif4] * self.yluPi7bar[1,mif1] * self.yluPi7bar[1,mif3] + 31/2592 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[2,mif2] * self.yluPi7bar[2,mif1] + -1/1728 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[2,mif2] * self.yluPi7bar[2,mif1] + 1/144 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yluPi7[2,mif2] * self.yluPi7bar[2,mif1] + -1/144 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[2,mif2] * self.yluPi7bar[2,mif1] + 1/576 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yluPi7[2,mif4] * self.yluPi7bar[2,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,mif2] * self.yluPi7[2,mif4] * self.yluPi7bar[0,mif3] * self.yluPi7bar[2,mif1] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,mif2] * self.yluPi7[2,mif4] * self.yluPi7bar[1,mif3] * self.yluPi7bar[2,mif1] + 1/576 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yluPi7[2,mif2] * self.yluPi7bar[2,mif3] + 31/2592 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[2,mif4] * self.yluPi7bar[2,mif3] + -1/1728 * (self.g3)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[2,mif4] * self.yluPi7bar[2,mif3] + 1/144 * (self.g1)**(2) * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yluPi7[2,mif4] * self.yluPi7bar[2,mif3] + -1/144 * (self.g1)**(2) * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yluPi7[2,mif4] * self.yluPi7bar[2,mif3] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[0,mif4] * self.yluPi7[2,mif2] * self.yluPi7bar[0,mif1] * self.yluPi7bar[2,mif3] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[1,mif4] * self.yluPi7[2,mif2] * self.yluPi7bar[1,mif1] * self.yluPi7bar[2,mif3] + -1/64 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yluPi7[2,mif2] * self.yluPi7[2,mif4] * self.yluPi7bar[2,mif1] * self.yluPi7bar[2,mif3])

    def alphaOuW(self, mif1,mif2):
        return (1/256 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,mif2] + 1/128 * self.g2 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,mif2] + -1/128 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.ylbar[0,0] * self.yluPi7[0,mif2] + 1/256 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,mif2] + 1/128 * self.g2 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,mif2] + -1/128 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.ylbar[0,1] * self.yluPi7[0,mif2] + 1/256 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,mif2] + 1/128 * self.g2 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,mif2] + -1/128 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.ylbar[0,2] * self.yluPi7[0,mif2] + 1/256 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,mif2] + 1/128 * self.g2 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,mif2] + -1/128 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.ylbar[1,0] * self.yluPi7[1,mif2] + 1/256 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,mif2] + 1/128 * self.g2 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,mif2] + -1/128 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.ylbar[1,1] * self.yluPi7[1,mif2] + 1/256 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,mif2] + 1/128 * self.g2 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,mif2] + -1/128 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.ylbar[1,2] * self.yluPi7[1,mif2] + 1/256 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,mif2] + 1/128 * self.g2 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,mif2] + -1/128 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[0,mif1] * self.ylbar[2,0] * self.yluPi7[2,mif2] + 1/256 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,mif2] + 1/128 * self.g2 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,mif2] + -1/128 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[1,mif1] * self.ylbar[2,1] * self.yluPi7[2,mif2] + 1/256 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,mif2] + 1/128 * self.g2 * self.invepsilonbar * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,mif2] + -1/128 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MPi7)**(2) * (self.mu)**(-2)) * self.yeqPi7bar[2,mif1] * self.ylbar[2,2] * self.yluPi7[2,mif2] + -1/768 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,0] * self.yeqPi7bar[0,mif1] * self.yu[0,mif2] + -1/768 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,0] * self.yeqPi7bar[1,mif1] * self.yu[0,mif2] + -1/768 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,0] * self.yeqPi7bar[2,mif1] * self.yu[0,mif2] + -1/768 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,1] * self.yeqPi7bar[0,mif1] * self.yu[1,mif2] + -1/768 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,1] * self.yeqPi7bar[1,mif1] * self.yu[1,mif2] + -1/768 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,1] * self.yeqPi7bar[2,mif1] * self.yu[1,mif2] + -1/768 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[0,2] * self.yeqPi7bar[0,mif1] * self.yu[2,mif2] + -1/768 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[1,2] * self.yeqPi7bar[1,mif1] * self.yu[2,mif2] + -1/768 * self.g2 * (self.MPi7)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yeqPi7[2,2] * self.yeqPi7bar[2,mif1] * self.yu[2,mif2])
