## Symbols used:
# ydbar
# yS2bar
# yd
# lambdaHatS2
# yl
# ylbar
# muH
# g1
# yS2
# invepsilonbar
# MS2
# mu
# lam
# yubar
# onelooporder
# yu

import sys
import os
import numpy as np

import lsme.numeric.matchingresult as matchingresult

class GranadaS2MatchingResult(matchingresult.GenericMatchingResult):
    def __init__(self, name='S2'):
        super().__init__(name)
        self.MS2 = 1
        self.yS2 = np.ones((3, 3))
        self.yS2bar = np.ones((3, 3))
        self.lambdaHatS2 = 1
        self.lambdaHatS2bar = 1
        self.nonvanishing = ['alphaOH', 'alphaOHB', 'alphaOHBox', 'alphaOHD', 'alphaOdd', 'alphaOeB', 'alphaOed', 'alphaOee', 'alphaOeH', 'alphaOeu', 'alphaOHd', 'alphaOHe', 'alphaOHl1', 'alphaOHl3', 'alphaOHq1', 'alphaOHu', 'alphaOld', 'alphaOle', 'alphaOll', 'alphaOlq1', 'alphaOlu', 'alphaOqd1', 'alphaOqe', 'alphaOqq1', 'alphaOqu1', 'alphaOud1', 'alphaOuu']

    def alphaO3G(self, ):
        return 0

    def alphaO3Gt(self, ):
        return 0

    def alphaO3W(self, ):
        return 0

    def alphaO3Wt(self, ):
        return 0

    def alphaOH(self, ):
        return 1/96 * (self.lambdaHatS2)**(3) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2)

    def alphaOHB(self, ):
        return -1/48 * (self.g1)**(2) * self.lambdaHatS2 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2)

    def alphaOHBox(self, ):
        return (-1/960 * (self.g1)**(4) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) + -1/192 * (self.lambdaHatS2)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2))

    def alphaOHBt(self, ):
        return 0

    def alphaOHD(self, ):
        return -1/240 * (self.g1)**(4) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2)

    def alphaOHG(self, ):
        return 0

    def alphaOHGt(self, ):
        return 0

    def alphaOHW(self, ):
        return 0

    def alphaOHWB(self, ):
        return 0

    def alphaOHWBt(self, ):
        return 0

    def alphaOHWt(self, ):
        return 0

    def alphaWeinberg(self, mif1,mif2):
        return 0

    def alphaOdB(self, mif1,mif2):
        return 0

    def alphaOdd(self, mif1,mif2,mif3,mif4):
        return -1/2160 * (self.g1)**(4) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4)

    def alphaOdG(self, mif1,mif2):
        return 0

    def alphaOdH(self, mif1,mif2):
        return 0

    def alphaOdW(self, mif1,mif2):
        return 0

    def alphaOeB(self, mif1,mif2):
        return (1/24 * self.g1 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.yS2[0,0] * self.yS2bar[0,mif2] + 1/24 * self.g1 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.yS2[0,1] * self.yS2bar[0,mif2] + 1/24 * self.g1 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.yS2[0,2] * self.yS2bar[0,mif2] + 1/24 * self.g1 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.yS2[1,0] * self.yS2bar[1,mif2] + 1/24 * self.g1 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.yS2[1,1] * self.yS2bar[1,mif2] + 1/24 * self.g1 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.yS2[1,2] * self.yS2bar[1,mif2] + 1/24 * self.g1 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.yS2[2,0] * self.yS2bar[2,mif2] + 1/24 * self.g1 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.yS2[2,1] * self.yS2bar[2,mif2] + 1/24 * self.g1 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.yS2[2,2] * self.yS2bar[2,mif2])

    def alphaOed(self, mif1,mif2,mif3,mif4):
        return (-1/360 * (self.g1)**(4) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 5/108 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yS2[0,mif1] * self.yS2bar[0,mif2] + 1/36 * (self.g1)**(2) * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yS2[0,mif1] * self.yS2bar[0,mif2] + -1/36 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,mif1] * self.yS2bar[0,mif2] + 5/108 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yS2[1,mif1] * self.yS2bar[1,mif2] + 1/36 * (self.g1)**(2) * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yS2[1,mif1] * self.yS2bar[1,mif2] + -1/36 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,mif1] * self.yS2bar[1,mif2] + 5/108 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yS2[2,mif1] * self.yS2bar[2,mif2] + 1/36 * (self.g1)**(2) * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yS2[2,mif1] * self.yS2bar[2,mif2] + -1/36 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[2,mif1] * self.yS2bar[2,mif2] + -1/72 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yS2[mif1,0] * self.yS2bar[mif2,0] + -1/72 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yS2[mif1,1] * self.yS2bar[mif2,1] + -1/72 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yS2[mif1,2] * self.yS2bar[mif2,2])

    def alphaOee(self, mif1,mif2,mif3,mif4):
        return (-1/240 * (self.g1)**(4) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 5/72 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yS2[0,mif1] * self.yS2bar[0,mif2] + 1/24 * (self.g1)**(2) * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yS2[0,mif1] * self.yS2bar[0,mif2] + -1/24 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,mif1] * self.yS2bar[0,mif2] + 5/72 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yS2[0,mif3] * self.yS2bar[0,mif4] + 1/24 * (self.g1)**(2) * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yS2[0,mif3] * self.yS2bar[0,mif4] + -1/24 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,mif3] * self.yS2bar[0,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif2] * self.yS2[mif3,mif1] * self.yS2bar[0,0] * self.yS2bar[0,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif2] * self.yS2[mif3,mif1] * self.yS2bar[0,0] * self.yS2bar[0,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,mif2] * self.yS2[mif3,mif1] * self.yS2bar[0,0] * self.yS2bar[0,mif4] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif1] * self.yS2[0,mif3] * self.yS2bar[0,mif2] * self.yS2bar[0,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,0] * self.yS2[mif1,mif3] * self.yS2bar[0,mif2] * self.yS2bar[0,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,0] * self.yS2[mif1,mif3] * self.yS2bar[0,mif2] * self.yS2bar[0,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,0] * self.yS2[mif1,mif3] * self.yS2bar[0,mif2] * self.yS2bar[0,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif2] * self.yS2[mif3,mif1] * self.yS2bar[0,mif4] * self.yS2bar[1,0] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif2] * self.yS2[mif3,mif1] * self.yS2bar[0,mif4] * self.yS2bar[1,0] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,mif2] * self.yS2[mif3,mif1] * self.yS2bar[0,mif4] * self.yS2bar[1,0] + 5/72 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yS2[1,mif1] * self.yS2bar[1,mif2] + 1/24 * (self.g1)**(2) * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yS2[1,mif1] * self.yS2bar[1,mif2] + -1/24 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,mif1] * self.yS2bar[1,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif3] * self.yS2[1,mif1] * self.yS2bar[0,mif4] * self.yS2bar[1,mif2] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,1] * self.yS2[mif1,mif3] * self.yS2bar[0,mif4] * self.yS2bar[1,mif2] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,1] * self.yS2[mif1,mif3] * self.yS2bar[0,mif4] * self.yS2bar[1,mif2] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,1] * self.yS2[mif1,mif3] * self.yS2bar[0,mif4] * self.yS2bar[1,mif2] + 5/72 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yS2[1,mif3] * self.yS2bar[1,mif4] + 1/24 * (self.g1)**(2) * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yS2[1,mif3] * self.yS2bar[1,mif4] + -1/24 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,mif3] * self.yS2bar[1,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif2] * self.yS2[mif3,mif1] * self.yS2bar[0,1] * self.yS2bar[1,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif2] * self.yS2[mif3,mif1] * self.yS2bar[0,1] * self.yS2bar[1,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,mif2] * self.yS2[mif3,mif1] * self.yS2bar[0,1] * self.yS2bar[1,mif4] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif1] * self.yS2[1,mif3] * self.yS2bar[0,mif2] * self.yS2bar[1,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,0] * self.yS2[mif1,mif3] * self.yS2bar[0,mif2] * self.yS2bar[1,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,0] * self.yS2[mif1,mif3] * self.yS2bar[0,mif2] * self.yS2bar[1,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,0] * self.yS2[mif1,mif3] * self.yS2bar[0,mif2] * self.yS2bar[1,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif2] * self.yS2[mif3,mif1] * self.yS2bar[1,1] * self.yS2bar[1,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif2] * self.yS2[mif3,mif1] * self.yS2bar[1,1] * self.yS2bar[1,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,mif2] * self.yS2[mif3,mif1] * self.yS2bar[1,1] * self.yS2bar[1,mif4] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif1] * self.yS2[1,mif3] * self.yS2bar[1,mif2] * self.yS2bar[1,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,1] * self.yS2[mif1,mif3] * self.yS2bar[1,mif2] * self.yS2bar[1,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,1] * self.yS2[mif1,mif3] * self.yS2bar[1,mif2] * self.yS2bar[1,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,1] * self.yS2[mif1,mif3] * self.yS2bar[1,mif2] * self.yS2bar[1,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,mif2] * self.yS2[mif3,mif1] * self.yS2bar[0,mif4] * self.yS2bar[2,0] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,mif2] * self.yS2[mif3,mif1] * self.yS2bar[0,mif4] * self.yS2bar[2,0] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[2,mif2] * self.yS2[mif3,mif1] * self.yS2bar[0,mif4] * self.yS2bar[2,0] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,mif2] * self.yS2[mif3,mif1] * self.yS2bar[1,mif4] * self.yS2bar[2,1] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,mif2] * self.yS2[mif3,mif1] * self.yS2bar[1,mif4] * self.yS2bar[2,1] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[2,mif2] * self.yS2[mif3,mif1] * self.yS2bar[1,mif4] * self.yS2bar[2,1] + 5/72 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yS2[2,mif1] * self.yS2bar[2,mif2] + 1/24 * (self.g1)**(2) * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yS2[2,mif1] * self.yS2bar[2,mif2] + -1/24 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[2,mif1] * self.yS2bar[2,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif3] * self.yS2[2,mif1] * self.yS2bar[0,mif4] * self.yS2bar[2,mif2] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,2] * self.yS2[mif1,mif3] * self.yS2bar[0,mif4] * self.yS2bar[2,mif2] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,2] * self.yS2[mif1,mif3] * self.yS2bar[0,mif4] * self.yS2bar[2,mif2] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,2] * self.yS2[mif1,mif3] * self.yS2bar[0,mif4] * self.yS2bar[2,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif3] * self.yS2[2,mif1] * self.yS2bar[1,mif4] * self.yS2bar[2,mif2] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,2] * self.yS2[mif1,mif3] * self.yS2bar[1,mif4] * self.yS2bar[2,mif2] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,2] * self.yS2[mif1,mif3] * self.yS2bar[1,mif4] * self.yS2bar[2,mif2] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,2] * self.yS2[mif1,mif3] * self.yS2bar[1,mif4] * self.yS2bar[2,mif2] + 5/72 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yS2[2,mif3] * self.yS2bar[2,mif4] + 1/24 * (self.g1)**(2) * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yS2[2,mif3] * self.yS2bar[2,mif4] + -1/24 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[2,mif3] * self.yS2bar[2,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif2] * self.yS2[mif3,mif1] * self.yS2bar[0,2] * self.yS2bar[2,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif2] * self.yS2[mif3,mif1] * self.yS2bar[0,2] * self.yS2bar[2,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,mif2] * self.yS2[mif3,mif1] * self.yS2bar[0,2] * self.yS2bar[2,mif4] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif1] * self.yS2[2,mif3] * self.yS2bar[0,mif2] * self.yS2bar[2,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,0] * self.yS2[mif1,mif3] * self.yS2bar[0,mif2] * self.yS2bar[2,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,0] * self.yS2[mif1,mif3] * self.yS2bar[0,mif2] * self.yS2bar[2,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[2,0] * self.yS2[mif1,mif3] * self.yS2bar[0,mif2] * self.yS2bar[2,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif2] * self.yS2[mif3,mif1] * self.yS2bar[1,2] * self.yS2bar[2,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif2] * self.yS2[mif3,mif1] * self.yS2bar[1,2] * self.yS2bar[2,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,mif2] * self.yS2[mif3,mif1] * self.yS2bar[1,2] * self.yS2bar[2,mif4] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif1] * self.yS2[2,mif3] * self.yS2bar[1,mif2] * self.yS2bar[2,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,1] * self.yS2[mif1,mif3] * self.yS2bar[1,mif2] * self.yS2bar[2,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,1] * self.yS2[mif1,mif3] * self.yS2bar[1,mif2] * self.yS2bar[2,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[2,1] * self.yS2[mif1,mif3] * self.yS2bar[1,mif2] * self.yS2bar[2,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,mif2] * self.yS2[mif3,mif1] * self.yS2bar[2,2] * self.yS2bar[2,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,mif2] * self.yS2[mif3,mif1] * self.yS2bar[2,2] * self.yS2bar[2,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[2,mif2] * self.yS2[mif3,mif1] * self.yS2bar[2,2] * self.yS2bar[2,mif4] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,mif1] * self.yS2[2,mif3] * self.yS2bar[2,mif2] * self.yS2bar[2,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,2] * self.yS2[mif1,mif3] * self.yS2bar[2,mif2] * self.yS2bar[2,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,2] * self.yS2[mif1,mif3] * self.yS2bar[2,mif2] * self.yS2bar[2,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[2,2] * self.yS2[mif1,mif3] * self.yS2bar[2,mif2] * self.yS2bar[2,mif4] + -1/24 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yS2[mif1,0] * self.yS2bar[mif2,0] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,0] * self.yS2[mif3,mif1] * self.yS2bar[0,mif4] * self.yS2bar[mif2,0] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,0] * self.yS2[mif3,mif1] * self.yS2bar[0,mif4] * self.yS2bar[mif2,0] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,0] * self.yS2[mif3,mif1] * self.yS2bar[0,mif4] * self.yS2bar[mif2,0] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,0] * self.yS2[mif3,mif1] * self.yS2bar[1,mif4] * self.yS2bar[mif2,0] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,0] * self.yS2[mif3,mif1] * self.yS2bar[1,mif4] * self.yS2bar[mif2,0] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,0] * self.yS2[mif3,mif1] * self.yS2bar[1,mif4] * self.yS2bar[mif2,0] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,0] * self.yS2[mif3,mif1] * self.yS2bar[2,mif4] * self.yS2bar[mif2,0] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,0] * self.yS2[mif3,mif1] * self.yS2bar[2,mif4] * self.yS2bar[mif2,0] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[2,0] * self.yS2[mif3,mif1] * self.yS2bar[2,mif4] * self.yS2bar[mif2,0] + -1/24 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yS2[mif1,1] * self.yS2bar[mif2,1] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,1] * self.yS2[mif3,mif1] * self.yS2bar[0,mif4] * self.yS2bar[mif2,1] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,1] * self.yS2[mif3,mif1] * self.yS2bar[0,mif4] * self.yS2bar[mif2,1] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,1] * self.yS2[mif3,mif1] * self.yS2bar[0,mif4] * self.yS2bar[mif2,1] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,1] * self.yS2[mif3,mif1] * self.yS2bar[1,mif4] * self.yS2bar[mif2,1] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,1] * self.yS2[mif3,mif1] * self.yS2bar[1,mif4] * self.yS2bar[mif2,1] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,1] * self.yS2[mif3,mif1] * self.yS2bar[1,mif4] * self.yS2bar[mif2,1] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,1] * self.yS2[mif3,mif1] * self.yS2bar[2,mif4] * self.yS2bar[mif2,1] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,1] * self.yS2[mif3,mif1] * self.yS2bar[2,mif4] * self.yS2bar[mif2,1] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[2,1] * self.yS2[mif3,mif1] * self.yS2bar[2,mif4] * self.yS2bar[mif2,1] + -1/24 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yS2[mif1,2] * self.yS2bar[mif2,2] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,2] * self.yS2[mif3,mif1] * self.yS2bar[0,mif4] * self.yS2bar[mif2,2] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,2] * self.yS2[mif3,mif1] * self.yS2bar[0,mif4] * self.yS2bar[mif2,2] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,2] * self.yS2[mif3,mif1] * self.yS2bar[0,mif4] * self.yS2bar[mif2,2] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,2] * self.yS2[mif3,mif1] * self.yS2bar[1,mif4] * self.yS2bar[mif2,2] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,2] * self.yS2[mif3,mif1] * self.yS2bar[1,mif4] * self.yS2bar[mif2,2] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,2] * self.yS2[mif3,mif1] * self.yS2bar[1,mif4] * self.yS2bar[mif2,2] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,2] * self.yS2[mif3,mif1] * self.yS2bar[2,mif4] * self.yS2bar[mif2,2] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,2] * self.yS2[mif3,mif1] * self.yS2bar[2,mif4] * self.yS2bar[mif2,2] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[2,2] * self.yS2[mif3,mif1] * self.yS2bar[2,mif4] * self.yS2bar[mif2,2] + 3/16 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[mif1,mif3] * self.yS2bar[mif2,mif4] + 1/4 * (self.MS2)**(-2) * self.yS2[mif3,mif1] * self.yS2bar[mif2,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif1] * self.yS2[0,mif3] * self.yS2bar[0,0] * self.yS2bar[mif2,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif1] * self.yS2[0,mif3] * self.yS2bar[0,0] * self.yS2bar[mif2,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,mif1] * self.yS2[0,mif3] * self.yS2bar[0,0] * self.yS2bar[mif2,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif3] * self.yS2[1,mif1] * self.yS2bar[0,1] * self.yS2bar[mif2,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif3] * self.yS2[1,mif1] * self.yS2bar[0,1] * self.yS2bar[mif2,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,mif3] * self.yS2[1,mif1] * self.yS2bar[0,1] * self.yS2bar[mif2,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif3] * self.yS2[2,mif1] * self.yS2bar[0,2] * self.yS2bar[mif2,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif3] * self.yS2[2,mif1] * self.yS2bar[0,2] * self.yS2bar[mif2,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,mif3] * self.yS2[2,mif1] * self.yS2bar[0,2] * self.yS2bar[mif2,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,0] * self.yS2[mif3,0] * self.yS2bar[0,mif1] * self.yS2bar[mif2,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,0] * self.yS2[mif3,0] * self.yS2bar[0,mif1] * self.yS2bar[mif2,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,0] * self.yS2[mif3,0] * self.yS2bar[0,mif1] * self.yS2bar[mif2,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,1] * self.yS2[mif3,1] * self.yS2bar[0,mif1] * self.yS2bar[mif2,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,1] * self.yS2[mif3,1] * self.yS2bar[0,mif1] * self.yS2bar[mif2,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,1] * self.yS2[mif3,1] * self.yS2bar[0,mif1] * self.yS2bar[mif2,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,2] * self.yS2[mif3,2] * self.yS2bar[0,mif1] * self.yS2bar[mif2,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,2] * self.yS2[mif3,2] * self.yS2bar[0,mif1] * self.yS2bar[mif2,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,2] * self.yS2[mif3,2] * self.yS2bar[0,mif1] * self.yS2bar[mif2,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif1] * self.yS2[1,mif3] * self.yS2bar[1,0] * self.yS2bar[mif2,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif1] * self.yS2[1,mif3] * self.yS2bar[1,0] * self.yS2bar[mif2,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,mif1] * self.yS2[1,mif3] * self.yS2bar[1,0] * self.yS2bar[mif2,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif1] * self.yS2[1,mif3] * self.yS2bar[1,1] * self.yS2bar[mif2,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif1] * self.yS2[1,mif3] * self.yS2bar[1,1] * self.yS2bar[mif2,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,mif1] * self.yS2[1,mif3] * self.yS2bar[1,1] * self.yS2bar[mif2,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif3] * self.yS2[2,mif1] * self.yS2bar[1,2] * self.yS2bar[mif2,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif3] * self.yS2[2,mif1] * self.yS2bar[1,2] * self.yS2bar[mif2,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,mif3] * self.yS2[2,mif1] * self.yS2bar[1,2] * self.yS2bar[mif2,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,0] * self.yS2[mif3,0] * self.yS2bar[1,mif1] * self.yS2bar[mif2,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,0] * self.yS2[mif3,0] * self.yS2bar[1,mif1] * self.yS2bar[mif2,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,0] * self.yS2[mif3,0] * self.yS2bar[1,mif1] * self.yS2bar[mif2,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,1] * self.yS2[mif3,1] * self.yS2bar[1,mif1] * self.yS2bar[mif2,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,1] * self.yS2[mif3,1] * self.yS2bar[1,mif1] * self.yS2bar[mif2,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,1] * self.yS2[mif3,1] * self.yS2bar[1,mif1] * self.yS2bar[mif2,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,2] * self.yS2[mif3,2] * self.yS2bar[1,mif1] * self.yS2bar[mif2,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,2] * self.yS2[mif3,2] * self.yS2bar[1,mif1] * self.yS2bar[mif2,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,2] * self.yS2[mif3,2] * self.yS2bar[1,mif1] * self.yS2bar[mif2,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif1] * self.yS2[2,mif3] * self.yS2bar[2,0] * self.yS2bar[mif2,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif1] * self.yS2[2,mif3] * self.yS2bar[2,0] * self.yS2bar[mif2,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,mif1] * self.yS2[2,mif3] * self.yS2bar[2,0] * self.yS2bar[mif2,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif1] * self.yS2[2,mif3] * self.yS2bar[2,1] * self.yS2bar[mif2,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif1] * self.yS2[2,mif3] * self.yS2bar[2,1] * self.yS2bar[mif2,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,mif1] * self.yS2[2,mif3] * self.yS2bar[2,1] * self.yS2bar[mif2,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,mif1] * self.yS2[2,mif3] * self.yS2bar[2,2] * self.yS2bar[mif2,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,mif1] * self.yS2[2,mif3] * self.yS2bar[2,2] * self.yS2bar[mif2,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[2,mif1] * self.yS2[2,mif3] * self.yS2bar[2,2] * self.yS2bar[mif2,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,0] * self.yS2[mif3,0] * self.yS2bar[2,mif1] * self.yS2bar[mif2,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,0] * self.yS2[mif3,0] * self.yS2bar[2,mif1] * self.yS2bar[mif2,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[2,0] * self.yS2[mif3,0] * self.yS2bar[2,mif1] * self.yS2bar[mif2,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,1] * self.yS2[mif3,1] * self.yS2bar[2,mif1] * self.yS2bar[mif2,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,1] * self.yS2[mif3,1] * self.yS2bar[2,mif1] * self.yS2bar[mif2,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[2,1] * self.yS2[mif3,1] * self.yS2bar[2,mif1] * self.yS2bar[mif2,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,2] * self.yS2[mif3,2] * self.yS2bar[2,mif1] * self.yS2bar[mif2,mif4] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,2] * self.yS2[mif3,2] * self.yS2bar[2,mif1] * self.yS2bar[mif2,mif4] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[2,2] * self.yS2[mif3,2] * self.yS2bar[2,mif1] * self.yS2bar[mif2,mif4] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif2] * self.yS2[mif1,mif3] * self.yS2bar[0,0] * self.yS2bar[mif4,0] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif2] * self.yS2[mif1,mif3] * self.yS2bar[0,0] * self.yS2bar[mif4,0] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,mif2] * self.yS2[mif1,mif3] * self.yS2bar[0,0] * self.yS2bar[mif4,0] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif2] * self.yS2[mif1,mif3] * self.yS2bar[1,0] * self.yS2bar[mif4,0] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif2] * self.yS2[mif1,mif3] * self.yS2bar[1,0] * self.yS2bar[mif4,0] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,mif2] * self.yS2[mif1,mif3] * self.yS2bar[1,0] * self.yS2bar[mif4,0] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,mif2] * self.yS2[mif1,mif3] * self.yS2bar[2,0] * self.yS2bar[mif4,0] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,mif2] * self.yS2[mif1,mif3] * self.yS2bar[2,0] * self.yS2bar[mif4,0] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[2,mif2] * self.yS2[mif1,mif3] * self.yS2bar[2,0] * self.yS2bar[mif4,0] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif2] * self.yS2[mif1,mif3] * self.yS2bar[0,1] * self.yS2bar[mif4,1] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif2] * self.yS2[mif1,mif3] * self.yS2bar[0,1] * self.yS2bar[mif4,1] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,mif2] * self.yS2[mif1,mif3] * self.yS2bar[0,1] * self.yS2bar[mif4,1] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif2] * self.yS2[mif1,mif3] * self.yS2bar[1,1] * self.yS2bar[mif4,1] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif2] * self.yS2[mif1,mif3] * self.yS2bar[1,1] * self.yS2bar[mif4,1] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,mif2] * self.yS2[mif1,mif3] * self.yS2bar[1,1] * self.yS2bar[mif4,1] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,mif2] * self.yS2[mif1,mif3] * self.yS2bar[2,1] * self.yS2bar[mif4,1] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,mif2] * self.yS2[mif1,mif3] * self.yS2bar[2,1] * self.yS2bar[mif4,1] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[2,mif2] * self.yS2[mif1,mif3] * self.yS2bar[2,1] * self.yS2bar[mif4,1] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif2] * self.yS2[mif1,mif3] * self.yS2bar[0,2] * self.yS2bar[mif4,2] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif2] * self.yS2[mif1,mif3] * self.yS2bar[0,2] * self.yS2bar[mif4,2] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,mif2] * self.yS2[mif1,mif3] * self.yS2bar[0,2] * self.yS2bar[mif4,2] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif2] * self.yS2[mif1,mif3] * self.yS2bar[1,2] * self.yS2bar[mif4,2] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif2] * self.yS2[mif1,mif3] * self.yS2bar[1,2] * self.yS2bar[mif4,2] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,mif2] * self.yS2[mif1,mif3] * self.yS2bar[1,2] * self.yS2bar[mif4,2] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,mif2] * self.yS2[mif1,mif3] * self.yS2bar[2,2] * self.yS2bar[mif4,2] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,mif2] * self.yS2[mif1,mif3] * self.yS2bar[2,2] * self.yS2bar[mif4,2] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[2,mif2] * self.yS2[mif1,mif3] * self.yS2bar[2,2] * self.yS2bar[mif4,2] + 1/4 * (self.MS2)**(-2) * self.yS2[mif1,mif3] * self.yS2bar[mif4,mif2] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif3] * self.yS2[mif1,0] * self.yS2bar[0,0] * self.yS2bar[mif4,mif2] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif3] * self.yS2[mif1,0] * self.yS2bar[0,0] * self.yS2bar[mif4,mif2] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,mif3] * self.yS2[mif1,0] * self.yS2bar[0,0] * self.yS2bar[mif4,mif2] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif3] * self.yS2[mif1,1] * self.yS2bar[0,1] * self.yS2bar[mif4,mif2] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif3] * self.yS2[mif1,1] * self.yS2bar[0,1] * self.yS2bar[mif4,mif2] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,mif3] * self.yS2[mif1,1] * self.yS2bar[0,1] * self.yS2bar[mif4,mif2] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif3] * self.yS2[mif1,2] * self.yS2bar[0,2] * self.yS2bar[mif4,mif2] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif3] * self.yS2[mif1,2] * self.yS2bar[0,2] * self.yS2bar[mif4,mif2] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,mif3] * self.yS2[mif1,2] * self.yS2bar[0,2] * self.yS2bar[mif4,mif2] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,0] * self.yS2[0,mif3] * self.yS2bar[0,mif1] * self.yS2bar[mif4,mif2] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,0] * self.yS2[0,mif3] * self.yS2bar[0,mif1] * self.yS2bar[mif4,mif2] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,0] * self.yS2[0,mif3] * self.yS2bar[0,mif1] * self.yS2bar[mif4,mif2] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,1] * self.yS2[1,mif3] * self.yS2bar[0,mif1] * self.yS2bar[mif4,mif2] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,1] * self.yS2[1,mif3] * self.yS2bar[0,mif1] * self.yS2bar[mif4,mif2] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,1] * self.yS2[1,mif3] * self.yS2bar[0,mif1] * self.yS2bar[mif4,mif2] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,2] * self.yS2[2,mif3] * self.yS2bar[0,mif1] * self.yS2bar[mif4,mif2] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,2] * self.yS2[2,mif3] * self.yS2bar[0,mif1] * self.yS2bar[mif4,mif2] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,2] * self.yS2[2,mif3] * self.yS2bar[0,mif1] * self.yS2bar[mif4,mif2] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif3] * self.yS2[mif1,0] * self.yS2bar[1,0] * self.yS2bar[mif4,mif2] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif3] * self.yS2[mif1,0] * self.yS2bar[1,0] * self.yS2bar[mif4,mif2] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,mif3] * self.yS2[mif1,0] * self.yS2bar[1,0] * self.yS2bar[mif4,mif2] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif3] * self.yS2[mif1,1] * self.yS2bar[1,1] * self.yS2bar[mif4,mif2] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif3] * self.yS2[mif1,1] * self.yS2bar[1,1] * self.yS2bar[mif4,mif2] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,mif3] * self.yS2[mif1,1] * self.yS2bar[1,1] * self.yS2bar[mif4,mif2] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif3] * self.yS2[mif1,2] * self.yS2bar[1,2] * self.yS2bar[mif4,mif2] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif3] * self.yS2[mif1,2] * self.yS2bar[1,2] * self.yS2bar[mif4,mif2] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,mif3] * self.yS2[mif1,2] * self.yS2bar[1,2] * self.yS2bar[mif4,mif2] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif3] * self.yS2[1,0] * self.yS2bar[1,mif1] * self.yS2bar[mif4,mif2] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif3] * self.yS2[1,0] * self.yS2bar[1,mif1] * self.yS2bar[mif4,mif2] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,mif3] * self.yS2[1,0] * self.yS2bar[1,mif1] * self.yS2bar[mif4,mif2] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,1] * self.yS2[1,mif3] * self.yS2bar[1,mif1] * self.yS2bar[mif4,mif2] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,1] * self.yS2[1,mif3] * self.yS2bar[1,mif1] * self.yS2bar[mif4,mif2] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,1] * self.yS2[1,mif3] * self.yS2bar[1,mif1] * self.yS2bar[mif4,mif2] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,2] * self.yS2[2,mif3] * self.yS2bar[1,mif1] * self.yS2bar[mif4,mif2] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,2] * self.yS2[2,mif3] * self.yS2bar[1,mif1] * self.yS2bar[mif4,mif2] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,2] * self.yS2[2,mif3] * self.yS2bar[1,mif1] * self.yS2bar[mif4,mif2] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,mif3] * self.yS2[mif1,0] * self.yS2bar[2,0] * self.yS2bar[mif4,mif2] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,mif3] * self.yS2[mif1,0] * self.yS2bar[2,0] * self.yS2bar[mif4,mif2] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[2,mif3] * self.yS2[mif1,0] * self.yS2bar[2,0] * self.yS2bar[mif4,mif2] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,mif3] * self.yS2[mif1,1] * self.yS2bar[2,1] * self.yS2bar[mif4,mif2] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,mif3] * self.yS2[mif1,1] * self.yS2bar[2,1] * self.yS2bar[mif4,mif2] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[2,mif3] * self.yS2[mif1,1] * self.yS2bar[2,1] * self.yS2bar[mif4,mif2] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,mif3] * self.yS2[mif1,2] * self.yS2bar[2,2] * self.yS2bar[mif4,mif2] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,mif3] * self.yS2[mif1,2] * self.yS2bar[2,2] * self.yS2bar[mif4,mif2] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[2,mif3] * self.yS2[mif1,2] * self.yS2bar[2,2] * self.yS2bar[mif4,mif2] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif3] * self.yS2[2,0] * self.yS2bar[2,mif1] * self.yS2bar[mif4,mif2] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif3] * self.yS2[2,0] * self.yS2bar[2,mif1] * self.yS2bar[mif4,mif2] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,mif3] * self.yS2[2,0] * self.yS2bar[2,mif1] * self.yS2bar[mif4,mif2] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif3] * self.yS2[2,1] * self.yS2bar[2,mif1] * self.yS2bar[mif4,mif2] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif3] * self.yS2[2,1] * self.yS2bar[2,mif1] * self.yS2bar[mif4,mif2] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,mif3] * self.yS2[2,1] * self.yS2bar[2,mif1] * self.yS2bar[mif4,mif2] + -1/128 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,2] * self.yS2[2,mif3] * self.yS2bar[2,mif1] * self.yS2bar[mif4,mif2] + -1/64 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,2] * self.yS2[2,mif3] * self.yS2bar[2,mif1] * self.yS2bar[mif4,mif2] + 1/64 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[2,2] * self.yS2[2,mif3] * self.yS2bar[2,mif1] * self.yS2bar[mif4,mif2])

    def alphaOeH(self, mif1,mif2):
        return (1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[0,0] * self.yS2[0,0] * self.yS2bar[0,0] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[1,0] * self.yS2[0,0] * self.yS2bar[0,0] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[2,0] * self.yS2[0,0] * self.yS2bar[0,0] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[0,0] * self.yS2[0,1] * self.yS2bar[0,0] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[1,0] * self.yS2[0,1] * self.yS2bar[0,0] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[2,0] * self.yS2[0,1] * self.yS2bar[0,0] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[0,0] * self.yS2[0,2] * self.yS2bar[0,0] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[1,0] * self.yS2[0,2] * self.yS2bar[0,0] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[2,0] * self.yS2[0,2] * self.yS2bar[0,0] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[0,1] * self.yS2[0,0] * self.yS2bar[0,1] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[1,1] * self.yS2[0,0] * self.yS2bar[0,1] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[2,1] * self.yS2[0,0] * self.yS2bar[0,1] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[0,1] * self.yS2[0,1] * self.yS2bar[0,1] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[1,1] * self.yS2[0,1] * self.yS2bar[0,1] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[2,1] * self.yS2[0,1] * self.yS2bar[0,1] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[0,1] * self.yS2[0,2] * self.yS2bar[0,1] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[1,1] * self.yS2[0,2] * self.yS2bar[0,1] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[2,1] * self.yS2[0,2] * self.yS2bar[0,1] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[0,2] * self.yS2[0,0] * self.yS2bar[0,2] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[1,2] * self.yS2[0,0] * self.yS2bar[0,2] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[2,2] * self.yS2[0,0] * self.yS2bar[0,2] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[0,2] * self.yS2[0,1] * self.yS2bar[0,2] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[1,2] * self.yS2[0,1] * self.yS2bar[0,2] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[2,2] * self.yS2[0,1] * self.yS2bar[0,2] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[0,2] * self.yS2[0,2] * self.yS2bar[0,2] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[1,2] * self.yS2[0,2] * self.yS2bar[0,2] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[2,2] * self.yS2[0,2] * self.yS2bar[0,2] + 1/16 * self.lambdaHatS2 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.yS2[0,0] * self.yS2bar[0,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.yl[mif1,0] * self.ylbar[0,0] * self.yS2[0,0] * self.yS2bar[0,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.yl[mif1,0] * self.ylbar[1,0] * self.yS2[0,0] * self.yS2bar[0,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.yl[mif1,0] * self.ylbar[2,0] * self.yS2[0,0] * self.yS2bar[0,mif2] + 1/16 * self.lambdaHatS2 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.yS2[0,1] * self.yS2bar[0,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.yl[mif1,1] * self.ylbar[0,0] * self.yS2[0,1] * self.yS2bar[0,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.yl[mif1,1] * self.ylbar[1,0] * self.yS2[0,1] * self.yS2bar[0,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.yl[mif1,1] * self.ylbar[2,0] * self.yS2[0,1] * self.yS2bar[0,mif2] + 1/16 * self.lambdaHatS2 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.yS2[0,2] * self.yS2bar[0,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.yl[mif1,2] * self.ylbar[0,0] * self.yS2[0,2] * self.yS2bar[0,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.yl[mif1,2] * self.ylbar[1,0] * self.yS2[0,2] * self.yS2bar[0,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.yl[mif1,2] * self.ylbar[2,0] * self.yS2[0,2] * self.yS2bar[0,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.yl[mif1,0] * self.ylbar[0,0] * self.yS2[1,0] * self.yS2bar[0,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.yl[mif1,0] * self.ylbar[1,0] * self.yS2[1,0] * self.yS2bar[0,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.yl[mif1,0] * self.ylbar[2,0] * self.yS2[1,0] * self.yS2bar[0,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.yl[mif1,1] * self.ylbar[0,0] * self.yS2[1,1] * self.yS2bar[0,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.yl[mif1,1] * self.ylbar[1,0] * self.yS2[1,1] * self.yS2bar[0,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.yl[mif1,1] * self.ylbar[2,0] * self.yS2[1,1] * self.yS2bar[0,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.yl[mif1,2] * self.ylbar[0,0] * self.yS2[1,2] * self.yS2bar[0,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.yl[mif1,2] * self.ylbar[1,0] * self.yS2[1,2] * self.yS2bar[0,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.yl[mif1,2] * self.ylbar[2,0] * self.yS2[1,2] * self.yS2bar[0,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.yl[mif1,0] * self.ylbar[0,0] * self.yS2[2,0] * self.yS2bar[0,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.yl[mif1,0] * self.ylbar[1,0] * self.yS2[2,0] * self.yS2bar[0,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.yl[mif1,0] * self.ylbar[2,0] * self.yS2[2,0] * self.yS2bar[0,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.yl[mif1,1] * self.ylbar[0,0] * self.yS2[2,1] * self.yS2bar[0,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.yl[mif1,1] * self.ylbar[1,0] * self.yS2[2,1] * self.yS2bar[0,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.yl[mif1,1] * self.ylbar[2,0] * self.yS2[2,1] * self.yS2bar[0,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.yl[mif1,2] * self.ylbar[0,0] * self.yS2[2,2] * self.yS2bar[0,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.yl[mif1,2] * self.ylbar[1,0] * self.yS2[2,2] * self.yS2bar[0,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.yl[mif1,2] * self.ylbar[2,0] * self.yS2[2,2] * self.yS2bar[0,mif2] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[0,0] * self.yS2[1,0] * self.yS2bar[1,0] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[1,0] * self.yS2[1,0] * self.yS2bar[1,0] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[2,0] * self.yS2[1,0] * self.yS2bar[1,0] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[0,0] * self.yS2[1,1] * self.yS2bar[1,0] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[1,0] * self.yS2[1,1] * self.yS2bar[1,0] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[2,0] * self.yS2[1,1] * self.yS2bar[1,0] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[0,0] * self.yS2[1,2] * self.yS2bar[1,0] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[1,0] * self.yS2[1,2] * self.yS2bar[1,0] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[2,0] * self.yS2[1,2] * self.yS2bar[1,0] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[0,1] * self.yS2[1,0] * self.yS2bar[1,1] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[1,1] * self.yS2[1,0] * self.yS2bar[1,1] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[2,1] * self.yS2[1,0] * self.yS2bar[1,1] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[0,1] * self.yS2[1,1] * self.yS2bar[1,1] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[1,1] * self.yS2[1,1] * self.yS2bar[1,1] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[2,1] * self.yS2[1,1] * self.yS2bar[1,1] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[0,1] * self.yS2[1,2] * self.yS2bar[1,1] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[1,1] * self.yS2[1,2] * self.yS2bar[1,1] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[2,1] * self.yS2[1,2] * self.yS2bar[1,1] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[0,2] * self.yS2[1,0] * self.yS2bar[1,2] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[1,2] * self.yS2[1,0] * self.yS2bar[1,2] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[2,2] * self.yS2[1,0] * self.yS2bar[1,2] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[0,2] * self.yS2[1,1] * self.yS2bar[1,2] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[1,2] * self.yS2[1,1] * self.yS2bar[1,2] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[2,2] * self.yS2[1,1] * self.yS2bar[1,2] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[0,2] * self.yS2[1,2] * self.yS2bar[1,2] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[1,2] * self.yS2[1,2] * self.yS2bar[1,2] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[2,2] * self.yS2[1,2] * self.yS2bar[1,2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.yl[mif1,0] * self.ylbar[0,1] * self.yS2[0,0] * self.yS2bar[1,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.yl[mif1,0] * self.ylbar[1,1] * self.yS2[0,0] * self.yS2bar[1,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.yl[mif1,0] * self.ylbar[2,1] * self.yS2[0,0] * self.yS2bar[1,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.yl[mif1,1] * self.ylbar[0,1] * self.yS2[0,1] * self.yS2bar[1,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.yl[mif1,1] * self.ylbar[1,1] * self.yS2[0,1] * self.yS2bar[1,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.yl[mif1,1] * self.ylbar[2,1] * self.yS2[0,1] * self.yS2bar[1,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.yl[mif1,2] * self.ylbar[0,1] * self.yS2[0,2] * self.yS2bar[1,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.yl[mif1,2] * self.ylbar[1,1] * self.yS2[0,2] * self.yS2bar[1,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.yl[mif1,2] * self.ylbar[2,1] * self.yS2[0,2] * self.yS2bar[1,mif2] + 1/16 * self.lambdaHatS2 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.yS2[1,0] * self.yS2bar[1,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.yl[mif1,0] * self.ylbar[0,1] * self.yS2[1,0] * self.yS2bar[1,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.yl[mif1,0] * self.ylbar[1,1] * self.yS2[1,0] * self.yS2bar[1,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.yl[mif1,0] * self.ylbar[2,1] * self.yS2[1,0] * self.yS2bar[1,mif2] + 1/16 * self.lambdaHatS2 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.yS2[1,1] * self.yS2bar[1,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.yl[mif1,1] * self.ylbar[0,1] * self.yS2[1,1] * self.yS2bar[1,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.yl[mif1,1] * self.ylbar[1,1] * self.yS2[1,1] * self.yS2bar[1,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.yl[mif1,1] * self.ylbar[2,1] * self.yS2[1,1] * self.yS2bar[1,mif2] + 1/16 * self.lambdaHatS2 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.yS2[1,2] * self.yS2bar[1,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.yl[mif1,2] * self.ylbar[0,1] * self.yS2[1,2] * self.yS2bar[1,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.yl[mif1,2] * self.ylbar[1,1] * self.yS2[1,2] * self.yS2bar[1,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.yl[mif1,2] * self.ylbar[2,1] * self.yS2[1,2] * self.yS2bar[1,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.yl[mif1,0] * self.ylbar[0,1] * self.yS2[2,0] * self.yS2bar[1,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.yl[mif1,0] * self.ylbar[1,1] * self.yS2[2,0] * self.yS2bar[1,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.yl[mif1,0] * self.ylbar[2,1] * self.yS2[2,0] * self.yS2bar[1,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.yl[mif1,1] * self.ylbar[0,1] * self.yS2[2,1] * self.yS2bar[1,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.yl[mif1,1] * self.ylbar[1,1] * self.yS2[2,1] * self.yS2bar[1,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.yl[mif1,1] * self.ylbar[2,1] * self.yS2[2,1] * self.yS2bar[1,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.yl[mif1,2] * self.ylbar[0,1] * self.yS2[2,2] * self.yS2bar[1,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.yl[mif1,2] * self.ylbar[1,1] * self.yS2[2,2] * self.yS2bar[1,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.yl[mif1,2] * self.ylbar[2,1] * self.yS2[2,2] * self.yS2bar[1,mif2] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[0,0] * self.yS2[2,0] * self.yS2bar[2,0] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[1,0] * self.yS2[2,0] * self.yS2bar[2,0] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[2,0] * self.yS2[2,0] * self.yS2bar[2,0] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[0,0] * self.yS2[2,1] * self.yS2bar[2,0] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[1,0] * self.yS2[2,1] * self.yS2bar[2,0] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[2,0] * self.yS2[2,1] * self.yS2bar[2,0] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[0,0] * self.yS2[2,2] * self.yS2bar[2,0] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[1,0] * self.yS2[2,2] * self.yS2bar[2,0] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[2,0] * self.yS2[2,2] * self.yS2bar[2,0] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[0,1] * self.yS2[2,0] * self.yS2bar[2,1] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[1,1] * self.yS2[2,0] * self.yS2bar[2,1] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[2,1] * self.yS2[2,0] * self.yS2bar[2,1] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[0,1] * self.yS2[2,1] * self.yS2bar[2,1] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[1,1] * self.yS2[2,1] * self.yS2bar[2,1] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[2,1] * self.yS2[2,1] * self.yS2bar[2,1] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[0,1] * self.yS2[2,2] * self.yS2bar[2,1] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[1,1] * self.yS2[2,2] * self.yS2bar[2,1] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[2,1] * self.yS2[2,2] * self.yS2bar[2,1] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[0,2] * self.yS2[2,0] * self.yS2bar[2,2] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[1,2] * self.yS2[2,0] * self.yS2bar[2,2] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[2,2] * self.yS2[2,0] * self.yS2bar[2,2] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[0,2] * self.yS2[2,1] * self.yS2bar[2,2] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[1,2] * self.yS2[2,1] * self.yS2bar[2,2] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[2,2] * self.yS2[2,1] * self.yS2bar[2,2] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[0,2] * self.yS2[2,2] * self.yS2bar[2,2] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[1,2] * self.yS2[2,2] * self.yS2bar[2,2] + 1/48 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[2,2] * self.yS2[2,2] * self.yS2bar[2,2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.yl[mif1,0] * self.ylbar[0,2] * self.yS2[0,0] * self.yS2bar[2,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.yl[mif1,0] * self.ylbar[1,2] * self.yS2[0,0] * self.yS2bar[2,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.yl[mif1,0] * self.ylbar[2,2] * self.yS2[0,0] * self.yS2bar[2,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.yl[mif1,1] * self.ylbar[0,2] * self.yS2[0,1] * self.yS2bar[2,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.yl[mif1,1] * self.ylbar[1,2] * self.yS2[0,1] * self.yS2bar[2,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.yl[mif1,1] * self.ylbar[2,2] * self.yS2[0,1] * self.yS2bar[2,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.yl[mif1,2] * self.ylbar[0,2] * self.yS2[0,2] * self.yS2bar[2,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.yl[mif1,2] * self.ylbar[1,2] * self.yS2[0,2] * self.yS2bar[2,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.yl[mif1,2] * self.ylbar[2,2] * self.yS2[0,2] * self.yS2bar[2,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.yl[mif1,0] * self.ylbar[0,2] * self.yS2[1,0] * self.yS2bar[2,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.yl[mif1,0] * self.ylbar[1,2] * self.yS2[1,0] * self.yS2bar[2,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.yl[mif1,0] * self.ylbar[2,2] * self.yS2[1,0] * self.yS2bar[2,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.yl[mif1,1] * self.ylbar[0,2] * self.yS2[1,1] * self.yS2bar[2,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.yl[mif1,1] * self.ylbar[1,2] * self.yS2[1,1] * self.yS2bar[2,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.yl[mif1,1] * self.ylbar[2,2] * self.yS2[1,1] * self.yS2bar[2,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.yl[mif1,2] * self.ylbar[0,2] * self.yS2[1,2] * self.yS2bar[2,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.yl[mif1,2] * self.ylbar[1,2] * self.yS2[1,2] * self.yS2bar[2,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.yl[mif1,2] * self.ylbar[2,2] * self.yS2[1,2] * self.yS2bar[2,mif2] + 1/16 * self.lambdaHatS2 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.yS2[2,0] * self.yS2bar[2,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.yl[mif1,0] * self.ylbar[0,2] * self.yS2[2,0] * self.yS2bar[2,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.yl[mif1,0] * self.ylbar[1,2] * self.yS2[2,0] * self.yS2bar[2,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.yl[mif1,0] * self.ylbar[2,2] * self.yS2[2,0] * self.yS2bar[2,mif2] + 1/16 * self.lambdaHatS2 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.yS2[2,1] * self.yS2bar[2,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.yl[mif1,1] * self.ylbar[0,2] * self.yS2[2,1] * self.yS2bar[2,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.yl[mif1,1] * self.ylbar[1,2] * self.yS2[2,1] * self.yS2bar[2,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.yl[mif1,1] * self.ylbar[2,2] * self.yS2[2,1] * self.yS2bar[2,mif2] + 1/16 * self.lambdaHatS2 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.yS2[2,2] * self.yS2bar[2,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.yl[mif1,2] * self.ylbar[0,2] * self.yS2[2,2] * self.yS2bar[2,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.yl[mif1,2] * self.ylbar[1,2] * self.yS2[2,2] * self.yS2bar[2,mif2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.yl[mif1,2] * self.ylbar[2,2] * self.yS2[2,2] * self.yS2bar[2,mif2])

    def alphaOeu(self, mif1,mif2,mif3,mif4):
        return (1/180 * (self.g1)**(4) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + -5/54 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yS2[0,mif1] * self.yS2bar[0,mif2] + -1/18 * (self.g1)**(2) * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yS2[0,mif1] * self.yS2bar[0,mif2] + 1/18 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,mif1] * self.yS2bar[0,mif2] + -5/54 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yS2[1,mif1] * self.yS2bar[1,mif2] + -1/18 * (self.g1)**(2) * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yS2[1,mif1] * self.yS2bar[1,mif2] + 1/18 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,mif1] * self.yS2bar[1,mif2] + -5/54 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yS2[2,mif1] * self.yS2bar[2,mif2] + -1/18 * (self.g1)**(2) * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yS2[2,mif1] * self.yS2bar[2,mif2] + 1/18 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[2,mif1] * self.yS2bar[2,mif2] + 1/36 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yS2[mif1,0] * self.yS2bar[mif2,0] + 1/36 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yS2[mif1,1] * self.yS2bar[mif2,1] + 1/36 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yS2[mif1,2] * self.yS2bar[mif2,2])

    def alphaOeW(self, mif1,mif2):
        return 0

    def alphaOHd(self, mif1,mif2):
        return 1/720 * (self.g1)**(4) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2)

    def alphaOHe(self, mif1,mif2):
        return (1/240 * (self.g1)**(4) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) + -5/72 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif1] * self.yS2bar[0,mif2] + -1/24 * (self.g1)**(2) * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[0,mif1] * self.yS2bar[0,mif2] + 1/24 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,mif1] * self.yS2bar[0,mif2] + 1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[0,0] * self.yS2[0,mif1] * self.yS2bar[0,mif2] + 1/8 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[0,0] * self.yS2[0,mif1] * self.yS2bar[0,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[0,0] * self.ylbar[0,0] * self.yS2[0,mif1] * self.yS2bar[0,mif2] + 1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[1,0] * self.yS2[0,mif1] * self.yS2bar[0,mif2] + 1/8 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[1,0] * self.yS2[0,mif1] * self.yS2bar[0,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[1,0] * self.ylbar[1,0] * self.yS2[0,mif1] * self.yS2bar[0,mif2] + 1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[2,0] * self.yS2[0,mif1] * self.yS2bar[0,mif2] + 1/8 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[2,0] * self.yS2[0,mif1] * self.yS2bar[0,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[2,0] * self.ylbar[2,0] * self.yS2[0,mif1] * self.yS2bar[0,mif2] + 1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[0,0] * self.yS2[1,mif1] * self.yS2bar[0,mif2] + 1/8 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[0,0] * self.yS2[1,mif1] * self.yS2bar[0,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[0,1] * self.ylbar[0,0] * self.yS2[1,mif1] * self.yS2bar[0,mif2] + 1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[1,0] * self.yS2[1,mif1] * self.yS2bar[0,mif2] + 1/8 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[1,0] * self.yS2[1,mif1] * self.yS2bar[0,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[1,1] * self.ylbar[1,0] * self.yS2[1,mif1] * self.yS2bar[0,mif2] + 1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[2,0] * self.yS2[1,mif1] * self.yS2bar[0,mif2] + 1/8 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[2,0] * self.yS2[1,mif1] * self.yS2bar[0,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[2,1] * self.ylbar[2,0] * self.yS2[1,mif1] * self.yS2bar[0,mif2] + 1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[0,0] * self.yS2[2,mif1] * self.yS2bar[0,mif2] + 1/8 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[0,0] * self.yS2[2,mif1] * self.yS2bar[0,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[0,2] * self.ylbar[0,0] * self.yS2[2,mif1] * self.yS2bar[0,mif2] + 1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[1,0] * self.yS2[2,mif1] * self.yS2bar[0,mif2] + 1/8 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[1,0] * self.yS2[2,mif1] * self.yS2bar[0,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[1,2] * self.ylbar[1,0] * self.yS2[2,mif1] * self.yS2bar[0,mif2] + 1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[2,0] * self.yS2[2,mif1] * self.yS2bar[0,mif2] + 1/8 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[2,0] * self.yS2[2,mif1] * self.yS2bar[0,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[2,2] * self.ylbar[2,0] * self.yS2[2,mif1] * self.yS2bar[0,mif2] + 1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[0,1] * self.yS2[0,mif1] * self.yS2bar[1,mif2] + 1/8 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[0,1] * self.yS2[0,mif1] * self.yS2bar[1,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[0,0] * self.ylbar[0,1] * self.yS2[0,mif1] * self.yS2bar[1,mif2] + 1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[1,1] * self.yS2[0,mif1] * self.yS2bar[1,mif2] + 1/8 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[1,1] * self.yS2[0,mif1] * self.yS2bar[1,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[1,0] * self.ylbar[1,1] * self.yS2[0,mif1] * self.yS2bar[1,mif2] + 1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[2,1] * self.yS2[0,mif1] * self.yS2bar[1,mif2] + 1/8 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[2,1] * self.yS2[0,mif1] * self.yS2bar[1,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[2,0] * self.ylbar[2,1] * self.yS2[0,mif1] * self.yS2bar[1,mif2] + -5/72 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif1] * self.yS2bar[1,mif2] + -1/24 * (self.g1)**(2) * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[1,mif1] * self.yS2bar[1,mif2] + 1/24 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,mif1] * self.yS2bar[1,mif2] + 1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[0,1] * self.yS2[1,mif1] * self.yS2bar[1,mif2] + 1/8 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[0,1] * self.yS2[1,mif1] * self.yS2bar[1,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[0,1] * self.ylbar[0,1] * self.yS2[1,mif1] * self.yS2bar[1,mif2] + 1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[1,1] * self.yS2[1,mif1] * self.yS2bar[1,mif2] + 1/8 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[1,1] * self.yS2[1,mif1] * self.yS2bar[1,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[1,1] * self.ylbar[1,1] * self.yS2[1,mif1] * self.yS2bar[1,mif2] + 1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[2,1] * self.yS2[1,mif1] * self.yS2bar[1,mif2] + 1/8 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[2,1] * self.yS2[1,mif1] * self.yS2bar[1,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[2,1] * self.ylbar[2,1] * self.yS2[1,mif1] * self.yS2bar[1,mif2] + 1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[0,1] * self.yS2[2,mif1] * self.yS2bar[1,mif2] + 1/8 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[0,1] * self.yS2[2,mif1] * self.yS2bar[1,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[0,2] * self.ylbar[0,1] * self.yS2[2,mif1] * self.yS2bar[1,mif2] + 1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[1,1] * self.yS2[2,mif1] * self.yS2bar[1,mif2] + 1/8 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[1,1] * self.yS2[2,mif1] * self.yS2bar[1,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[1,2] * self.ylbar[1,1] * self.yS2[2,mif1] * self.yS2bar[1,mif2] + 1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[2,1] * self.yS2[2,mif1] * self.yS2bar[1,mif2] + 1/8 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[2,1] * self.yS2[2,mif1] * self.yS2bar[1,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[2,2] * self.ylbar[2,1] * self.yS2[2,mif1] * self.yS2bar[1,mif2] + 1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[0,2] * self.yS2[0,mif1] * self.yS2bar[2,mif2] + 1/8 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[0,2] * self.yS2[0,mif1] * self.yS2bar[2,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[0,0] * self.ylbar[0,2] * self.yS2[0,mif1] * self.yS2bar[2,mif2] + 1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[1,2] * self.yS2[0,mif1] * self.yS2bar[2,mif2] + 1/8 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[1,2] * self.yS2[0,mif1] * self.yS2bar[2,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[1,0] * self.ylbar[1,2] * self.yS2[0,mif1] * self.yS2bar[2,mif2] + 1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[2,2] * self.yS2[0,mif1] * self.yS2bar[2,mif2] + 1/8 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[2,2] * self.yS2[0,mif1] * self.yS2bar[2,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[2,0] * self.ylbar[2,2] * self.yS2[0,mif1] * self.yS2bar[2,mif2] + 1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[0,2] * self.yS2[1,mif1] * self.yS2bar[2,mif2] + 1/8 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[0,2] * self.yS2[1,mif1] * self.yS2bar[2,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[0,1] * self.ylbar[0,2] * self.yS2[1,mif1] * self.yS2bar[2,mif2] + 1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[1,2] * self.yS2[1,mif1] * self.yS2bar[2,mif2] + 1/8 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[1,2] * self.yS2[1,mif1] * self.yS2bar[2,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[1,1] * self.ylbar[1,2] * self.yS2[1,mif1] * self.yS2bar[2,mif2] + 1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[2,2] * self.yS2[1,mif1] * self.yS2bar[2,mif2] + 1/8 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[2,2] * self.yS2[1,mif1] * self.yS2bar[2,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[2,1] * self.ylbar[2,2] * self.yS2[1,mif1] * self.yS2bar[2,mif2] + -5/72 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,mif1] * self.yS2bar[2,mif2] + -1/24 * (self.g1)**(2) * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[2,mif1] * self.yS2bar[2,mif2] + 1/24 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[2,mif1] * self.yS2bar[2,mif2] + 1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[0,2] * self.yS2[2,mif1] * self.yS2bar[2,mif2] + 1/8 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[0,2] * self.yS2[2,mif1] * self.yS2bar[2,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[0,2] * self.ylbar[0,2] * self.yS2[2,mif1] * self.yS2bar[2,mif2] + 1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[1,2] * self.yS2[2,mif1] * self.yS2bar[2,mif2] + 1/8 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[1,2] * self.yS2[2,mif1] * self.yS2bar[2,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[1,2] * self.ylbar[1,2] * self.yS2[2,mif1] * self.yS2bar[2,mif2] + 1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[2,2] * self.yS2[2,mif1] * self.yS2bar[2,mif2] + 1/8 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[2,2] * self.yS2[2,mif1] * self.yS2bar[2,mif2] + -1/8 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[2,2] * self.ylbar[2,2] * self.yS2[2,mif1] * self.yS2bar[2,mif2] + 1/48 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[mif1,0] * self.yS2bar[mif2,0] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[0,0] * self.yS2[mif1,0] * self.yS2bar[mif2,0] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[1,0] * self.yS2[mif1,0] * self.yS2bar[mif2,0] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[2,0] * self.yS2[mif1,0] * self.yS2bar[mif2,0] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[0,0] * self.yS2[mif1,1] * self.yS2bar[mif2,0] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[1,0] * self.yS2[mif1,1] * self.yS2bar[mif2,0] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[2,0] * self.yS2[mif1,1] * self.yS2bar[mif2,0] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[0,0] * self.yS2[mif1,2] * self.yS2bar[mif2,0] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[1,0] * self.yS2[mif1,2] * self.yS2bar[mif2,0] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[2,0] * self.yS2[mif1,2] * self.yS2bar[mif2,0] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[0,1] * self.yS2[mif1,0] * self.yS2bar[mif2,1] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[1,1] * self.yS2[mif1,0] * self.yS2bar[mif2,1] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[2,1] * self.yS2[mif1,0] * self.yS2bar[mif2,1] + 1/48 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[mif1,1] * self.yS2bar[mif2,1] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[0,1] * self.yS2[mif1,1] * self.yS2bar[mif2,1] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[1,1] * self.yS2[mif1,1] * self.yS2bar[mif2,1] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[2,1] * self.yS2[mif1,1] * self.yS2bar[mif2,1] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[0,1] * self.yS2[mif1,2] * self.yS2bar[mif2,1] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[1,1] * self.yS2[mif1,2] * self.yS2bar[mif2,1] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[2,1] * self.yS2[mif1,2] * self.yS2bar[mif2,1] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[0,2] * self.yS2[mif1,0] * self.yS2bar[mif2,2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[1,2] * self.yS2[mif1,0] * self.yS2bar[mif2,2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[2,2] * self.yS2[mif1,0] * self.yS2bar[mif2,2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[0,2] * self.yS2[mif1,1] * self.yS2bar[mif2,2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[1,2] * self.yS2[mif1,1] * self.yS2bar[mif2,2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[2,2] * self.yS2[mif1,1] * self.yS2bar[mif2,2] + 1/48 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yS2[mif1,2] * self.yS2bar[mif2,2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[0,2] * self.yS2[mif1,2] * self.yS2bar[mif2,2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[1,2] * self.yS2[mif1,2] * self.yS2bar[mif2,2] + -1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[2,2] * self.yS2[mif1,2] * self.yS2bar[mif2,2])

    def alphaOHl1(self, mif1,mif2):
        return (1/480 * (self.g1)**(4) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.ylbar[mif2,0] * self.yS2[0,0] * self.yS2bar[0,0] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.ylbar[mif2,0] * self.yS2[0,1] * self.yS2bar[0,0] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.ylbar[mif2,0] * self.yS2[0,2] * self.yS2bar[0,0] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.ylbar[mif2,1] * self.yS2[0,0] * self.yS2bar[0,1] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.ylbar[mif2,1] * self.yS2[0,1] * self.yS2bar[0,1] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.ylbar[mif2,1] * self.yS2[0,2] * self.yS2bar[0,1] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.ylbar[mif2,2] * self.yS2[0,0] * self.yS2bar[0,2] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.ylbar[mif2,2] * self.yS2[0,1] * self.yS2bar[0,2] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.ylbar[mif2,2] * self.yS2[0,2] * self.yS2bar[0,2] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.ylbar[mif2,0] * self.yS2[1,0] * self.yS2bar[1,0] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.ylbar[mif2,0] * self.yS2[1,1] * self.yS2bar[1,0] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.ylbar[mif2,0] * self.yS2[1,2] * self.yS2bar[1,0] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.ylbar[mif2,1] * self.yS2[1,0] * self.yS2bar[1,1] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.ylbar[mif2,1] * self.yS2[1,1] * self.yS2bar[1,1] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.ylbar[mif2,1] * self.yS2[1,2] * self.yS2bar[1,1] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.ylbar[mif2,2] * self.yS2[1,0] * self.yS2bar[1,2] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.ylbar[mif2,2] * self.yS2[1,1] * self.yS2bar[1,2] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.ylbar[mif2,2] * self.yS2[1,2] * self.yS2bar[1,2] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.ylbar[mif2,0] * self.yS2[2,0] * self.yS2bar[2,0] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.ylbar[mif2,0] * self.yS2[2,1] * self.yS2bar[2,0] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.ylbar[mif2,0] * self.yS2[2,2] * self.yS2bar[2,0] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.ylbar[mif2,1] * self.yS2[2,0] * self.yS2bar[2,1] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.ylbar[mif2,1] * self.yS2[2,1] * self.yS2bar[2,1] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.ylbar[mif2,1] * self.yS2[2,2] * self.yS2bar[2,1] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.ylbar[mif2,2] * self.yS2[2,0] * self.yS2bar[2,2] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.ylbar[mif2,2] * self.yS2[2,1] * self.yS2bar[2,2] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.ylbar[mif2,2] * self.yS2[2,2] * self.yS2bar[2,2])

    def alphaOHl3(self, mif1,mif2):
        return (-1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.ylbar[mif2,0] * self.yS2[0,0] * self.yS2bar[0,0] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.ylbar[mif2,0] * self.yS2[0,1] * self.yS2bar[0,0] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.ylbar[mif2,0] * self.yS2[0,2] * self.yS2bar[0,0] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.ylbar[mif2,1] * self.yS2[0,0] * self.yS2bar[0,1] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.ylbar[mif2,1] * self.yS2[0,1] * self.yS2bar[0,1] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.ylbar[mif2,1] * self.yS2[0,2] * self.yS2bar[0,1] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.ylbar[mif2,2] * self.yS2[0,0] * self.yS2bar[0,2] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.ylbar[mif2,2] * self.yS2[0,1] * self.yS2bar[0,2] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.ylbar[mif2,2] * self.yS2[0,2] * self.yS2bar[0,2] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.ylbar[mif2,0] * self.yS2[1,0] * self.yS2bar[1,0] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.ylbar[mif2,0] * self.yS2[1,1] * self.yS2bar[1,0] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.ylbar[mif2,0] * self.yS2[1,2] * self.yS2bar[1,0] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.ylbar[mif2,1] * self.yS2[1,0] * self.yS2bar[1,1] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.ylbar[mif2,1] * self.yS2[1,1] * self.yS2bar[1,1] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.ylbar[mif2,1] * self.yS2[1,2] * self.yS2bar[1,1] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.ylbar[mif2,2] * self.yS2[1,0] * self.yS2bar[1,2] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.ylbar[mif2,2] * self.yS2[1,1] * self.yS2bar[1,2] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.ylbar[mif2,2] * self.yS2[1,2] * self.yS2bar[1,2] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.ylbar[mif2,0] * self.yS2[2,0] * self.yS2bar[2,0] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.ylbar[mif2,0] * self.yS2[2,1] * self.yS2bar[2,0] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.ylbar[mif2,0] * self.yS2[2,2] * self.yS2bar[2,0] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.ylbar[mif2,1] * self.yS2[2,0] * self.yS2bar[2,1] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.ylbar[mif2,1] * self.yS2[2,1] * self.yS2bar[2,1] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.ylbar[mif2,1] * self.yS2[2,2] * self.yS2bar[2,1] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.ylbar[mif2,2] * self.yS2[2,0] * self.yS2bar[2,2] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.ylbar[mif2,2] * self.yS2[2,1] * self.yS2bar[2,2] + -1/96 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.ylbar[mif2,2] * self.yS2[2,2] * self.yS2bar[2,2])

    def alphaOHq1(self, mif1,mif2):
        return -1/1440 * (self.g1)**(4) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2)

    def alphaOHq3(self, mif1,mif2):
        return 0

    def alphaOHu(self, mif1,mif2):
        return -1/360 * (self.g1)**(4) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2)

    def alphaOHud(self, mif1,mif2):
        return 0

    def alphaOld(self, mif1,mif2,mif3,mif4):
        return -1/720 * (self.g1)**(4) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4)

    def alphaOle(self, mif1,mif2,mif3,mif4):
        return (-1/240 * (self.g1)**(4) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 5/72 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yS2[0,mif3] * self.yS2bar[0,mif4] + 1/24 * (self.g1)**(2) * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yS2[0,mif3] * self.yS2bar[0,mif4] + -1/24 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,mif3] * self.yS2bar[0,mif4] + -3/32 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.ylbar[mif2,0] * self.yS2[0,mif3] * self.yS2bar[0,mif4] + -1/16 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.ylbar[mif2,0] * self.yS2[0,mif3] * self.yS2bar[0,mif4] + 1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[mif1,0] * self.ylbar[mif2,0] * self.yS2[0,mif3] * self.yS2bar[0,mif4] + -3/32 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.ylbar[mif2,0] * self.yS2[1,mif3] * self.yS2bar[0,mif4] + -1/16 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.ylbar[mif2,0] * self.yS2[1,mif3] * self.yS2bar[0,mif4] + 1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[mif1,1] * self.ylbar[mif2,0] * self.yS2[1,mif3] * self.yS2bar[0,mif4] + -3/32 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.ylbar[mif2,0] * self.yS2[2,mif3] * self.yS2bar[0,mif4] + -1/16 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.ylbar[mif2,0] * self.yS2[2,mif3] * self.yS2bar[0,mif4] + 1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[mif1,2] * self.ylbar[mif2,0] * self.yS2[2,mif3] * self.yS2bar[0,mif4] + 3/32 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.ylbar[mif2,0] * self.yS2[mif3,0] * self.yS2bar[0,mif4] + 3/32 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.ylbar[mif2,0] * self.yS2[mif3,1] * self.yS2bar[0,mif4] + 3/32 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.ylbar[mif2,0] * self.yS2[mif3,2] * self.yS2bar[0,mif4] + -3/32 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.ylbar[mif2,1] * self.yS2[0,mif3] * self.yS2bar[1,mif4] + -1/16 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.ylbar[mif2,1] * self.yS2[0,mif3] * self.yS2bar[1,mif4] + 1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[mif1,0] * self.ylbar[mif2,1] * self.yS2[0,mif3] * self.yS2bar[1,mif4] + 5/72 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yS2[1,mif3] * self.yS2bar[1,mif4] + 1/24 * (self.g1)**(2) * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yS2[1,mif3] * self.yS2bar[1,mif4] + -1/24 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,mif3] * self.yS2bar[1,mif4] + -3/32 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.ylbar[mif2,1] * self.yS2[1,mif3] * self.yS2bar[1,mif4] + -1/16 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.ylbar[mif2,1] * self.yS2[1,mif3] * self.yS2bar[1,mif4] + 1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[mif1,1] * self.ylbar[mif2,1] * self.yS2[1,mif3] * self.yS2bar[1,mif4] + -3/32 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.ylbar[mif2,1] * self.yS2[2,mif3] * self.yS2bar[1,mif4] + -1/16 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.ylbar[mif2,1] * self.yS2[2,mif3] * self.yS2bar[1,mif4] + 1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[mif1,2] * self.ylbar[mif2,1] * self.yS2[2,mif3] * self.yS2bar[1,mif4] + 3/32 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.ylbar[mif2,1] * self.yS2[mif3,0] * self.yS2bar[1,mif4] + 3/32 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.ylbar[mif2,1] * self.yS2[mif3,1] * self.yS2bar[1,mif4] + 3/32 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.ylbar[mif2,1] * self.yS2[mif3,2] * self.yS2bar[1,mif4] + -3/32 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.ylbar[mif2,2] * self.yS2[0,mif3] * self.yS2bar[2,mif4] + -1/16 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.ylbar[mif2,2] * self.yS2[0,mif3] * self.yS2bar[2,mif4] + 1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[mif1,0] * self.ylbar[mif2,2] * self.yS2[0,mif3] * self.yS2bar[2,mif4] + -3/32 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.ylbar[mif2,2] * self.yS2[1,mif3] * self.yS2bar[2,mif4] + -1/16 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.ylbar[mif2,2] * self.yS2[1,mif3] * self.yS2bar[2,mif4] + 1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[mif1,1] * self.ylbar[mif2,2] * self.yS2[1,mif3] * self.yS2bar[2,mif4] + 5/72 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yS2[2,mif3] * self.yS2bar[2,mif4] + 1/24 * (self.g1)**(2) * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yS2[2,mif3] * self.yS2bar[2,mif4] + -1/24 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[2,mif3] * self.yS2bar[2,mif4] + -3/32 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.ylbar[mif2,2] * self.yS2[2,mif3] * self.yS2bar[2,mif4] + -1/16 * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.ylbar[mif2,2] * self.yS2[2,mif3] * self.yS2bar[2,mif4] + 1/16 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yl[mif1,2] * self.ylbar[mif2,2] * self.yS2[2,mif3] * self.yS2bar[2,mif4] + 3/32 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,0] * self.ylbar[mif2,2] * self.yS2[mif3,0] * self.yS2bar[2,mif4] + 3/32 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,1] * self.ylbar[mif2,2] * self.yS2[mif3,1] * self.yS2bar[2,mif4] + 3/32 * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,2] * self.ylbar[mif2,2] * self.yS2[mif3,2] * self.yS2bar[2,mif4] + -1/48 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yS2[mif3,0] * self.yS2bar[mif4,0] + -1/48 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yS2[mif3,1] * self.yS2bar[mif4,1] + -1/48 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yS2[mif3,2] * self.yS2bar[mif4,2])

    def alphaOledq(self, mif1,mif2,mif3,mif4):
        return 0

    def alphaOlequ1(self, mif1,mif2,mif3,mif4):
        return 0

    def alphaOlequ3(self, mif1,mif2,mif3,mif4):
        return 0

    def alphaOll(self, mif1,mif2,mif3,mif4):
        return -1/960 * (self.g1)**(4) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4)

    def alphaOlq1(self, mif1,mif2,mif3,mif4):
        return 1/1440 * (self.g1)**(4) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4)

    def alphaOlq3(self, mif1,mif2,mif3,mif4):
        return 0

    def alphaOlu(self, mif1,mif2,mif3,mif4):
        return 1/360 * (self.g1)**(4) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4)

    def alphaOqd1(self, mif1,mif2,mif3,mif4):
        return 1/2160 * (self.g1)**(4) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4)

    def alphaOqd8(self, mif1,mif2,mif3,mif4):
        return 0

    def alphaOqe(self, mif1,mif2,mif3,mif4):
        return (1/720 * (self.g1)**(4) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + -5/216 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yS2[0,mif3] * self.yS2bar[0,mif4] + -1/72 * (self.g1)**(2) * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yS2[0,mif3] * self.yS2bar[0,mif4] + 1/72 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[0,mif3] * self.yS2bar[0,mif4] + -5/216 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yS2[1,mif3] * self.yS2bar[1,mif4] + -1/72 * (self.g1)**(2) * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yS2[1,mif3] * self.yS2bar[1,mif4] + 1/72 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[1,mif3] * self.yS2bar[1,mif4] + -5/216 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yS2[2,mif3] * self.yS2bar[2,mif4] + -1/72 * (self.g1)**(2) * self.invepsilonbar * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yS2[2,mif3] * self.yS2bar[2,mif4] + 1/72 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.MS2)**(2) * (self.mu)**(-2)) * self.yS2[2,mif3] * self.yS2bar[2,mif4] + 1/144 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yS2[mif3,0] * self.yS2bar[mif4,0] + 1/144 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yS2[mif3,1] * self.yS2bar[mif4,1] + 1/144 * (self.g1)**(2) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yS2[mif3,2] * self.yS2bar[mif4,2])

    def alphaOqq1(self, mif1,mif2,mif3,mif4):
        return -1/8640 * (self.g1)**(4) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4)

    def alphaOqq3(self, mif1,mif2,mif3,mif4):
        return 0

    def alphaOqu1(self, mif1,mif2,mif3,mif4):
        return -1/1080 * (self.g1)**(4) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4)

    def alphaOqu8(self, mif1,mif2,mif3,mif4):
        return 0

    def alphaOquqd1(self, mif1,mif2,mif3,mif4):
        return 0

    def alphaOquqd8(self, mif1,mif2,mif3,mif4):
        return 0

    def alphaOuB(self, mif1,mif2):
        return 0

    def alphaOud1(self, mif1,mif2,mif3,mif4):
        return 1/540 * (self.g1)**(4) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4)

    def alphaOud8(self, mif1,mif2,mif3,mif4):
        return 0

    def alphaOuG(self, mif1,mif2):
        return 0

    def alphaOuH(self, mif1,mif2):
        return 0

    def alphaOuu(self, mif1,mif2,mif3,mif4):
        return -1/540 * (self.g1)**(4) * (self.MS2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4)

    def alphaOuW(self, mif1,mif2):
        return 0
