## Symbols used:
# ydbar
# yd
# yl
# ylbar
# Momega2
# yomega2bar
# muH
# g1
# yomega2
# epsilonbar
# invepsilonbar
# mu
# lam
# lambdaHatomega2
# yubar
# onelooporder
# g3
# yu

import sys
import os
import numpy as np

import lsme.numeric.matchingresult as matchingresult

class Granadaomega2MatchingResult(matchingresult.GenericMatchingResult):
    def __init__(self, name='omega2'):
        super().__init__(name)
        self.Momega2 = 1
        self.yomega2 = np.ones((3, 3))
        self.yomega2bar = np.ones((3, 3))
        self.lambdaHatomega2 = 1
        self.lambdaHatomega2bar = 1
        self.nonvanishing = ['alphaO3G', 'alphaOH', 'alphaOHB', 'alphaOHBox', 'alphaOHD', 'alphaOHG', 'alphaOdB', 'alphaOdd', 'alphaOdG', 'alphaOdH', 'alphaOed', 'alphaOee', 'alphaOeu', 'alphaOHd', 'alphaOHe', 'alphaOHl1', 'alphaOHq1', 'alphaOHq3', 'alphaOHu', 'alphaOld', 'alphaOle', 'alphaOll', 'alphaOlq1', 'alphaOlu', 'alphaOqd1', 'alphaOqd8', 'alphaOqe', 'alphaOqq1', 'alphaOqq3', 'alphaOqu1', 'alphaOqu8', 'alphaOud1', 'alphaOud8', 'alphaOuu']

    def alphaO3G(self, ):
        return 1/5760 * (self.g3)**(3) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2)

    def alphaO3Gt(self, ):
        return 0

    def alphaO3W(self, ):
        return 0

    def alphaO3Wt(self, ):
        return 0

    def alphaOH(self, ):
        return 1/32 * (self.lambdaHatomega2)**(3) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2)

    def alphaOHB(self, ):
        return -1/144 * (self.g1)**(2) * self.lambdaHatomega2 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2)

    def alphaOHBox(self, ):
        return (-1/2880 * (self.g1)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) + -1/64 * (self.lambdaHatomega2)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2))

    def alphaOHBt(self, ):
        return 0

    def alphaOHD(self, ):
        return -1/720 * (self.g1)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2)

    def alphaOHG(self, ):
        return -1/384 * (self.g3)**(2) * self.lambdaHatomega2 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2)

    def alphaOHGt(self, ):
        return 0

    def alphaOHW(self, ):
        return 0

    def alphaOHWB(self, ):
        return 0

    def alphaOHWBt(self, ):
        return 0

    def alphaOHWt(self, ):
        return 0

    def alphaWeinberg(self, mif1,mif2):
        return 0

    def alphaOdB(self, mif1,mif2):
        return (1/36 * self.g1 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.yomega2[0,0] * self.yomega2bar[0,mif2] + 1/36 * self.g1 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.yomega2[0,1] * self.yomega2bar[0,mif2] + 1/36 * self.g1 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.yomega2[0,2] * self.yomega2bar[0,mif2] + 1/36 * self.g1 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.yomega2[1,0] * self.yomega2bar[1,mif2] + 1/36 * self.g1 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.yomega2[1,1] * self.yomega2bar[1,mif2] + 1/36 * self.g1 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.yomega2[1,2] * self.yomega2bar[1,mif2] + 1/36 * self.g1 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.yomega2[2,0] * self.yomega2bar[2,mif2] + 1/36 * self.g1 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.yomega2[2,1] * self.yomega2bar[2,mif2] + 1/36 * self.g1 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.yomega2[2,2] * self.yomega2bar[2,mif2])

    def alphaOdd(self, mif1,mif2,mif3,mif4):
        return (-1/3840 * (self.g3)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.kronecker_delta(mif2,mif3) + -1/6480 * (self.g1)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 1/11520 * (self.g3)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 5/324 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yomega2[0,mif1] * self.yomega2bar[0,mif2] + 7/864 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yomega2[0,mif1] * self.yomega2bar[0,mif2] + 1/108 * (self.g1)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yomega2[0,mif1] * self.yomega2bar[0,mif2] + 1/144 * (self.g3)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yomega2[0,mif1] * self.yomega2bar[0,mif2] + -1/108 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,mif1] * self.yomega2bar[0,mif2] + -1/144 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,mif1] * self.yomega2bar[0,mif2] + -7/288 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yomega2[0,mif3] * self.yomega2bar[0,mif2] + -1/48 * (self.g3)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yomega2[0,mif3] * self.yomega2bar[0,mif2] + 1/48 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,mif3] * self.yomega2bar[0,mif2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif4] * self.yomega2[mif1,mif3] * self.yomega2bar[0,0] * self.yomega2bar[0,mif2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif4] * self.yomega2[mif1,mif3] * self.yomega2bar[0,0] * self.yomega2bar[0,mif2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,mif4] * self.yomega2[mif1,mif3] * self.yomega2bar[0,0] * self.yomega2bar[0,mif2] + -7/288 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yomega2[0,mif1] * self.yomega2bar[0,mif4] + -1/48 * (self.g3)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yomega2[0,mif1] * self.yomega2bar[0,mif4] + 1/48 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,mif1] * self.yomega2bar[0,mif4] + 5/324 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + 7/864 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + 1/108 * (self.g1)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + 1/144 * (self.g3)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + -1/108 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + -1/144 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif1] * self.yomega2[0,mif3] * self.yomega2bar[0,mif2] * self.yomega2bar[0,mif4] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,0] * self.yomega2[mif3,mif1] * self.yomega2bar[0,mif2] * self.yomega2bar[0,mif4] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,0] * self.yomega2[mif3,mif1] * self.yomega2bar[0,mif2] * self.yomega2bar[0,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,0] * self.yomega2[mif3,mif1] * self.yomega2bar[0,mif2] * self.yomega2bar[0,mif4] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif4] * self.yomega2[mif1,mif3] * self.yomega2bar[0,mif2] * self.yomega2bar[1,0] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif4] * self.yomega2[mif1,mif3] * self.yomega2bar[0,mif2] * self.yomega2bar[1,0] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,mif4] * self.yomega2[mif1,mif3] * self.yomega2bar[0,mif2] * self.yomega2bar[1,0] + 5/324 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yomega2[1,mif1] * self.yomega2bar[1,mif2] + 7/864 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yomega2[1,mif1] * self.yomega2bar[1,mif2] + 1/108 * (self.g1)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yomega2[1,mif1] * self.yomega2bar[1,mif2] + 1/144 * (self.g3)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yomega2[1,mif1] * self.yomega2bar[1,mif2] + -1/108 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,mif1] * self.yomega2bar[1,mif2] + -1/144 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,mif1] * self.yomega2bar[1,mif2] + -7/288 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yomega2[1,mif3] * self.yomega2bar[1,mif2] + -1/48 * (self.g3)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yomega2[1,mif3] * self.yomega2bar[1,mif2] + 1/48 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,mif3] * self.yomega2bar[1,mif2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif4] * self.yomega2[mif1,mif3] * self.yomega2bar[0,1] * self.yomega2bar[1,mif2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif4] * self.yomega2[mif1,mif3] * self.yomega2bar[0,1] * self.yomega2bar[1,mif2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,mif4] * self.yomega2[mif1,mif3] * self.yomega2bar[0,1] * self.yomega2bar[1,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif3] * self.yomega2[1,mif1] * self.yomega2bar[0,mif4] * self.yomega2bar[1,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif1] * self.yomega2[1,mif3] * self.yomega2bar[0,mif4] * self.yomega2bar[1,mif2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,0] * self.yomega2[mif3,mif1] * self.yomega2bar[0,mif4] * self.yomega2bar[1,mif2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,0] * self.yomega2[mif3,mif1] * self.yomega2bar[0,mif4] * self.yomega2bar[1,mif2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,0] * self.yomega2[mif3,mif1] * self.yomega2bar[0,mif4] * self.yomega2bar[1,mif2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif4] * self.yomega2[mif1,mif3] * self.yomega2bar[1,1] * self.yomega2bar[1,mif2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif4] * self.yomega2[mif1,mif3] * self.yomega2bar[1,1] * self.yomega2bar[1,mif2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,mif4] * self.yomega2[mif1,mif3] * self.yomega2bar[1,1] * self.yomega2bar[1,mif2] + -7/288 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yomega2[1,mif1] * self.yomega2bar[1,mif4] + -1/48 * (self.g3)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yomega2[1,mif1] * self.yomega2bar[1,mif4] + 1/48 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,mif1] * self.yomega2bar[1,mif4] + 5/324 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + 7/864 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + 1/108 * (self.g1)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + 1/144 * (self.g3)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + -1/108 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + -1/144 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif3] * self.yomega2[1,mif1] * self.yomega2bar[0,mif2] * self.yomega2bar[1,mif4] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif1] * self.yomega2[1,mif3] * self.yomega2bar[0,mif2] * self.yomega2bar[1,mif4] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,1] * self.yomega2[mif3,mif1] * self.yomega2bar[0,mif2] * self.yomega2bar[1,mif4] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,1] * self.yomega2[mif3,mif1] * self.yomega2bar[0,mif2] * self.yomega2bar[1,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,1] * self.yomega2[mif3,mif1] * self.yomega2bar[0,mif2] * self.yomega2bar[1,mif4] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif1] * self.yomega2[1,mif3] * self.yomega2bar[1,mif2] * self.yomega2bar[1,mif4] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,1] * self.yomega2[mif3,mif1] * self.yomega2bar[1,mif2] * self.yomega2bar[1,mif4] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,1] * self.yomega2[mif3,mif1] * self.yomega2bar[1,mif2] * self.yomega2bar[1,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,1] * self.yomega2[mif3,mif1] * self.yomega2bar[1,mif2] * self.yomega2bar[1,mif4] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,mif4] * self.yomega2[mif1,mif3] * self.yomega2bar[0,mif2] * self.yomega2bar[2,0] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,mif4] * self.yomega2[mif1,mif3] * self.yomega2bar[0,mif2] * self.yomega2bar[2,0] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,mif4] * self.yomega2[mif1,mif3] * self.yomega2bar[0,mif2] * self.yomega2bar[2,0] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,mif4] * self.yomega2[mif1,mif3] * self.yomega2bar[1,mif2] * self.yomega2bar[2,1] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,mif4] * self.yomega2[mif1,mif3] * self.yomega2bar[1,mif2] * self.yomega2bar[2,1] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,mif4] * self.yomega2[mif1,mif3] * self.yomega2bar[1,mif2] * self.yomega2bar[2,1] + 5/324 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yomega2[2,mif1] * self.yomega2bar[2,mif2] + 7/864 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yomega2[2,mif1] * self.yomega2bar[2,mif2] + 1/108 * (self.g1)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yomega2[2,mif1] * self.yomega2bar[2,mif2] + 1/144 * (self.g3)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yomega2[2,mif1] * self.yomega2bar[2,mif2] + -1/108 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,mif1] * self.yomega2bar[2,mif2] + -1/144 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,mif1] * self.yomega2bar[2,mif2] + -7/288 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yomega2[2,mif3] * self.yomega2bar[2,mif2] + -1/48 * (self.g3)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yomega2[2,mif3] * self.yomega2bar[2,mif2] + 1/48 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,mif3] * self.yomega2bar[2,mif2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif4] * self.yomega2[mif1,mif3] * self.yomega2bar[0,2] * self.yomega2bar[2,mif2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif4] * self.yomega2[mif1,mif3] * self.yomega2bar[0,2] * self.yomega2bar[2,mif2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,mif4] * self.yomega2[mif1,mif3] * self.yomega2bar[0,2] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif3] * self.yomega2[2,mif1] * self.yomega2bar[0,mif4] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif1] * self.yomega2[2,mif3] * self.yomega2bar[0,mif4] * self.yomega2bar[2,mif2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,0] * self.yomega2[mif3,mif1] * self.yomega2bar[0,mif4] * self.yomega2bar[2,mif2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,0] * self.yomega2[mif3,mif1] * self.yomega2bar[0,mif4] * self.yomega2bar[2,mif2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,0] * self.yomega2[mif3,mif1] * self.yomega2bar[0,mif4] * self.yomega2bar[2,mif2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif4] * self.yomega2[mif1,mif3] * self.yomega2bar[1,2] * self.yomega2bar[2,mif2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif4] * self.yomega2[mif1,mif3] * self.yomega2bar[1,2] * self.yomega2bar[2,mif2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,mif4] * self.yomega2[mif1,mif3] * self.yomega2bar[1,2] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif3] * self.yomega2[2,mif1] * self.yomega2bar[1,mif4] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif1] * self.yomega2[2,mif3] * self.yomega2bar[1,mif4] * self.yomega2bar[2,mif2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,1] * self.yomega2[mif3,mif1] * self.yomega2bar[1,mif4] * self.yomega2bar[2,mif2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,1] * self.yomega2[mif3,mif1] * self.yomega2bar[1,mif4] * self.yomega2bar[2,mif2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,1] * self.yomega2[mif3,mif1] * self.yomega2bar[1,mif4] * self.yomega2bar[2,mif2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,mif4] * self.yomega2[mif1,mif3] * self.yomega2bar[2,2] * self.yomega2bar[2,mif2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,mif4] * self.yomega2[mif1,mif3] * self.yomega2bar[2,2] * self.yomega2bar[2,mif2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,mif4] * self.yomega2[mif1,mif3] * self.yomega2bar[2,2] * self.yomega2bar[2,mif2] + -7/288 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yomega2[2,mif1] * self.yomega2bar[2,mif4] + -1/48 * (self.g3)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yomega2[2,mif1] * self.yomega2bar[2,mif4] + 1/48 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,mif1] * self.yomega2bar[2,mif4] + 5/324 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[2,mif3] * self.yomega2bar[2,mif4] + 7/864 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[2,mif3] * self.yomega2bar[2,mif4] + 1/108 * (self.g1)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[2,mif3] * self.yomega2bar[2,mif4] + 1/144 * (self.g3)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[2,mif3] * self.yomega2bar[2,mif4] + -1/108 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,mif3] * self.yomega2bar[2,mif4] + -1/144 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,mif3] * self.yomega2bar[2,mif4] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif3] * self.yomega2[2,mif1] * self.yomega2bar[0,mif2] * self.yomega2bar[2,mif4] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif1] * self.yomega2[2,mif3] * self.yomega2bar[0,mif2] * self.yomega2bar[2,mif4] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,2] * self.yomega2[mif3,mif1] * self.yomega2bar[0,mif2] * self.yomega2bar[2,mif4] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,2] * self.yomega2[mif3,mif1] * self.yomega2bar[0,mif2] * self.yomega2bar[2,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,2] * self.yomega2[mif3,mif1] * self.yomega2bar[0,mif2] * self.yomega2bar[2,mif4] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif3] * self.yomega2[2,mif1] * self.yomega2bar[1,mif2] * self.yomega2bar[2,mif4] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif1] * self.yomega2[2,mif3] * self.yomega2bar[1,mif2] * self.yomega2bar[2,mif4] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,2] * self.yomega2[mif3,mif1] * self.yomega2bar[1,mif2] * self.yomega2bar[2,mif4] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,2] * self.yomega2[mif3,mif1] * self.yomega2bar[1,mif2] * self.yomega2bar[2,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,2] * self.yomega2[mif3,mif1] * self.yomega2bar[1,mif2] * self.yomega2bar[2,mif4] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,mif1] * self.yomega2[2,mif3] * self.yomega2bar[2,mif2] * self.yomega2bar[2,mif4] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,2] * self.yomega2[mif3,mif1] * self.yomega2bar[2,mif2] * self.yomega2bar[2,mif4] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,2] * self.yomega2[mif3,mif1] * self.yomega2bar[2,mif2] * self.yomega2bar[2,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,2] * self.yomega2[mif3,mif1] * self.yomega2bar[2,mif2] * self.yomega2bar[2,mif4] + 1/24 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yomega2[mif3,0] * self.yomega2bar[mif2,0] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif4] * self.yomega2[mif3,mif1] * self.yomega2bar[0,0] * self.yomega2bar[mif2,0] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif4] * self.yomega2[mif3,mif1] * self.yomega2bar[0,0] * self.yomega2bar[mif2,0] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,mif4] * self.yomega2[mif3,mif1] * self.yomega2bar[0,0] * self.yomega2bar[mif2,0] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif4] * self.yomega2[mif3,mif1] * self.yomega2bar[1,0] * self.yomega2bar[mif2,0] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif4] * self.yomega2[mif3,mif1] * self.yomega2bar[1,0] * self.yomega2bar[mif2,0] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,mif4] * self.yomega2[mif3,mif1] * self.yomega2bar[1,0] * self.yomega2bar[mif2,0] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,mif4] * self.yomega2[mif3,mif1] * self.yomega2bar[2,0] * self.yomega2bar[mif2,0] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,mif4] * self.yomega2[mif3,mif1] * self.yomega2bar[2,0] * self.yomega2bar[mif2,0] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,mif4] * self.yomega2[mif3,mif1] * self.yomega2bar[2,0] * self.yomega2bar[mif2,0] + 1/24 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yomega2[mif3,1] * self.yomega2bar[mif2,1] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif4] * self.yomega2[mif3,mif1] * self.yomega2bar[0,1] * self.yomega2bar[mif2,1] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif4] * self.yomega2[mif3,mif1] * self.yomega2bar[0,1] * self.yomega2bar[mif2,1] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,mif4] * self.yomega2[mif3,mif1] * self.yomega2bar[0,1] * self.yomega2bar[mif2,1] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif4] * self.yomega2[mif3,mif1] * self.yomega2bar[1,1] * self.yomega2bar[mif2,1] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif4] * self.yomega2[mif3,mif1] * self.yomega2bar[1,1] * self.yomega2bar[mif2,1] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,mif4] * self.yomega2[mif3,mif1] * self.yomega2bar[1,1] * self.yomega2bar[mif2,1] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,mif4] * self.yomega2[mif3,mif1] * self.yomega2bar[2,1] * self.yomega2bar[mif2,1] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,mif4] * self.yomega2[mif3,mif1] * self.yomega2bar[2,1] * self.yomega2bar[mif2,1] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,mif4] * self.yomega2[mif3,mif1] * self.yomega2bar[2,1] * self.yomega2bar[mif2,1] + 1/24 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yomega2[mif3,2] * self.yomega2bar[mif2,2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif4] * self.yomega2[mif3,mif1] * self.yomega2bar[0,2] * self.yomega2bar[mif2,2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif4] * self.yomega2[mif3,mif1] * self.yomega2bar[0,2] * self.yomega2bar[mif2,2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,mif4] * self.yomega2[mif3,mif1] * self.yomega2bar[0,2] * self.yomega2bar[mif2,2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif4] * self.yomega2[mif3,mif1] * self.yomega2bar[1,2] * self.yomega2bar[mif2,2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif4] * self.yomega2[mif3,mif1] * self.yomega2bar[1,2] * self.yomega2bar[mif2,2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,mif4] * self.yomega2[mif3,mif1] * self.yomega2bar[1,2] * self.yomega2bar[mif2,2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,mif4] * self.yomega2[mif3,mif1] * self.yomega2bar[2,2] * self.yomega2bar[mif2,2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,mif4] * self.yomega2[mif3,mif1] * self.yomega2bar[2,2] * self.yomega2bar[mif2,2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,mif4] * self.yomega2[mif3,mif1] * self.yomega2bar[2,2] * self.yomega2bar[mif2,2] + -3/16 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[mif1,mif3] * self.yomega2bar[mif2,mif4] + -1/2 * (self.Momega2)**(-2) * self.yomega2[mif3,mif1] * self.yomega2bar[mif2,mif4] + -1/32 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[mif3,mif1] * self.yomega2bar[mif2,mif4] + -3/32 * self.epsilonbar * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[mif3,mif1] * self.yomega2bar[mif2,mif4] + -1/16 * self.epsilonbar * (self.g3)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[mif3,mif1] * self.yomega2bar[mif2,mif4] + 1/16 * self.epsilonbar * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[mif3,mif1] * self.yomega2bar[mif2,mif4] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif1] * self.yomega2[mif3,0] * self.yomega2bar[0,0] * self.yomega2bar[mif2,mif4] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif1] * self.yomega2[mif3,0] * self.yomega2bar[0,0] * self.yomega2bar[mif2,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,mif1] * self.yomega2[mif3,0] * self.yomega2bar[0,0] * self.yomega2bar[mif2,mif4] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif1] * self.yomega2[mif3,1] * self.yomega2bar[0,1] * self.yomega2bar[mif2,mif4] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif1] * self.yomega2[mif3,1] * self.yomega2bar[0,1] * self.yomega2bar[mif2,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,mif1] * self.yomega2[mif3,1] * self.yomega2bar[0,1] * self.yomega2bar[mif2,mif4] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif1] * self.yomega2[mif3,2] * self.yomega2bar[0,2] * self.yomega2bar[mif2,mif4] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif1] * self.yomega2[mif3,2] * self.yomega2bar[0,2] * self.yomega2bar[mif2,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,mif1] * self.yomega2[mif3,2] * self.yomega2bar[0,2] * self.yomega2bar[mif2,mif4] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,0] * self.yomega2[0,mif1] * self.yomega2bar[0,mif3] * self.yomega2bar[mif2,mif4] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,0] * self.yomega2[0,mif1] * self.yomega2bar[0,mif3] * self.yomega2bar[mif2,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,0] * self.yomega2[0,mif1] * self.yomega2bar[0,mif3] * self.yomega2bar[mif2,mif4] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,1] * self.yomega2[1,mif1] * self.yomega2bar[0,mif3] * self.yomega2bar[mif2,mif4] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,1] * self.yomega2[1,mif1] * self.yomega2bar[0,mif3] * self.yomega2bar[mif2,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,1] * self.yomega2[1,mif1] * self.yomega2bar[0,mif3] * self.yomega2bar[mif2,mif4] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,2] * self.yomega2[2,mif1] * self.yomega2bar[0,mif3] * self.yomega2bar[mif2,mif4] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,2] * self.yomega2[2,mif1] * self.yomega2bar[0,mif3] * self.yomega2bar[mif2,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,2] * self.yomega2[2,mif1] * self.yomega2bar[0,mif3] * self.yomega2bar[mif2,mif4] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif1] * self.yomega2[mif3,0] * self.yomega2bar[1,0] * self.yomega2bar[mif2,mif4] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif1] * self.yomega2[mif3,0] * self.yomega2bar[1,0] * self.yomega2bar[mif2,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,mif1] * self.yomega2[mif3,0] * self.yomega2bar[1,0] * self.yomega2bar[mif2,mif4] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif1] * self.yomega2[mif3,1] * self.yomega2bar[1,1] * self.yomega2bar[mif2,mif4] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif1] * self.yomega2[mif3,1] * self.yomega2bar[1,1] * self.yomega2bar[mif2,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,mif1] * self.yomega2[mif3,1] * self.yomega2bar[1,1] * self.yomega2bar[mif2,mif4] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif1] * self.yomega2[mif3,2] * self.yomega2bar[1,2] * self.yomega2bar[mif2,mif4] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif1] * self.yomega2[mif3,2] * self.yomega2bar[1,2] * self.yomega2bar[mif2,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,mif1] * self.yomega2[mif3,2] * self.yomega2bar[1,2] * self.yomega2bar[mif2,mif4] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif1] * self.yomega2[1,0] * self.yomega2bar[1,mif3] * self.yomega2bar[mif2,mif4] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif1] * self.yomega2[1,0] * self.yomega2bar[1,mif3] * self.yomega2bar[mif2,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,mif1] * self.yomega2[1,0] * self.yomega2bar[1,mif3] * self.yomega2bar[mif2,mif4] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,1] * self.yomega2[1,mif1] * self.yomega2bar[1,mif3] * self.yomega2bar[mif2,mif4] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,1] * self.yomega2[1,mif1] * self.yomega2bar[1,mif3] * self.yomega2bar[mif2,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,1] * self.yomega2[1,mif1] * self.yomega2bar[1,mif3] * self.yomega2bar[mif2,mif4] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,2] * self.yomega2[2,mif1] * self.yomega2bar[1,mif3] * self.yomega2bar[mif2,mif4] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,2] * self.yomega2[2,mif1] * self.yomega2bar[1,mif3] * self.yomega2bar[mif2,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,2] * self.yomega2[2,mif1] * self.yomega2bar[1,mif3] * self.yomega2bar[mif2,mif4] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,mif1] * self.yomega2[mif3,0] * self.yomega2bar[2,0] * self.yomega2bar[mif2,mif4] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,mif1] * self.yomega2[mif3,0] * self.yomega2bar[2,0] * self.yomega2bar[mif2,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,mif1] * self.yomega2[mif3,0] * self.yomega2bar[2,0] * self.yomega2bar[mif2,mif4] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,mif1] * self.yomega2[mif3,1] * self.yomega2bar[2,1] * self.yomega2bar[mif2,mif4] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,mif1] * self.yomega2[mif3,1] * self.yomega2bar[2,1] * self.yomega2bar[mif2,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,mif1] * self.yomega2[mif3,1] * self.yomega2bar[2,1] * self.yomega2bar[mif2,mif4] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,mif1] * self.yomega2[mif3,2] * self.yomega2bar[2,2] * self.yomega2bar[mif2,mif4] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,mif1] * self.yomega2[mif3,2] * self.yomega2bar[2,2] * self.yomega2bar[mif2,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,mif1] * self.yomega2[mif3,2] * self.yomega2bar[2,2] * self.yomega2bar[mif2,mif4] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif1] * self.yomega2[2,0] * self.yomega2bar[2,mif3] * self.yomega2bar[mif2,mif4] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif1] * self.yomega2[2,0] * self.yomega2bar[2,mif3] * self.yomega2bar[mif2,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,mif1] * self.yomega2[2,0] * self.yomega2bar[2,mif3] * self.yomega2bar[mif2,mif4] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif1] * self.yomega2[2,1] * self.yomega2bar[2,mif3] * self.yomega2bar[mif2,mif4] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif1] * self.yomega2[2,1] * self.yomega2bar[2,mif3] * self.yomega2bar[mif2,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,mif1] * self.yomega2[2,1] * self.yomega2bar[2,mif3] * self.yomega2bar[mif2,mif4] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,2] * self.yomega2[2,mif1] * self.yomega2bar[2,mif3] * self.yomega2bar[mif2,mif4] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,2] * self.yomega2[2,mif1] * self.yomega2bar[2,mif3] * self.yomega2bar[mif2,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,2] * self.yomega2[2,mif1] * self.yomega2bar[2,mif3] * self.yomega2bar[mif2,mif4] + 1/108 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[mif3,0] * self.yomega2bar[mif4,0] + -1/72 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[mif3,0] * self.yomega2bar[mif4,0] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,0] * self.yomega2[mif1,mif3] * self.yomega2bar[0,mif2] * self.yomega2bar[mif4,0] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,0] * self.yomega2[mif1,mif3] * self.yomega2bar[0,mif2] * self.yomega2bar[mif4,0] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,0] * self.yomega2[mif1,mif3] * self.yomega2bar[0,mif2] * self.yomega2bar[mif4,0] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,0] * self.yomega2[mif1,mif3] * self.yomega2bar[1,mif2] * self.yomega2bar[mif4,0] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,0] * self.yomega2[mif1,mif3] * self.yomega2bar[1,mif2] * self.yomega2bar[mif4,0] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,0] * self.yomega2[mif1,mif3] * self.yomega2bar[1,mif2] * self.yomega2bar[mif4,0] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,0] * self.yomega2[mif1,mif3] * self.yomega2bar[2,mif2] * self.yomega2bar[mif4,0] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,0] * self.yomega2[mif1,mif3] * self.yomega2bar[2,mif2] * self.yomega2bar[mif4,0] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,0] * self.yomega2[mif1,mif3] * self.yomega2bar[2,mif2] * self.yomega2bar[mif4,0] + 1/108 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[mif3,1] * self.yomega2bar[mif4,1] + -1/72 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[mif3,1] * self.yomega2bar[mif4,1] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,1] * self.yomega2[mif1,mif3] * self.yomega2bar[0,mif2] * self.yomega2bar[mif4,1] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,1] * self.yomega2[mif1,mif3] * self.yomega2bar[0,mif2] * self.yomega2bar[mif4,1] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,1] * self.yomega2[mif1,mif3] * self.yomega2bar[0,mif2] * self.yomega2bar[mif4,1] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,1] * self.yomega2[mif1,mif3] * self.yomega2bar[1,mif2] * self.yomega2bar[mif4,1] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,1] * self.yomega2[mif1,mif3] * self.yomega2bar[1,mif2] * self.yomega2bar[mif4,1] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,1] * self.yomega2[mif1,mif3] * self.yomega2bar[1,mif2] * self.yomega2bar[mif4,1] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,1] * self.yomega2[mif1,mif3] * self.yomega2bar[2,mif2] * self.yomega2bar[mif4,1] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,1] * self.yomega2[mif1,mif3] * self.yomega2bar[2,mif2] * self.yomega2bar[mif4,1] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,1] * self.yomega2[mif1,mif3] * self.yomega2bar[2,mif2] * self.yomega2bar[mif4,1] + 1/108 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[mif3,2] * self.yomega2bar[mif4,2] + -1/72 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[mif3,2] * self.yomega2bar[mif4,2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,2] * self.yomega2[mif1,mif3] * self.yomega2bar[0,mif2] * self.yomega2bar[mif4,2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,2] * self.yomega2[mif1,mif3] * self.yomega2bar[0,mif2] * self.yomega2bar[mif4,2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,2] * self.yomega2[mif1,mif3] * self.yomega2bar[0,mif2] * self.yomega2bar[mif4,2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,2] * self.yomega2[mif1,mif3] * self.yomega2bar[1,mif2] * self.yomega2bar[mif4,2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,2] * self.yomega2[mif1,mif3] * self.yomega2bar[1,mif2] * self.yomega2bar[mif4,2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,2] * self.yomega2[mif1,mif3] * self.yomega2bar[1,mif2] * self.yomega2bar[mif4,2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,2] * self.yomega2[mif1,mif3] * self.yomega2bar[2,mif2] * self.yomega2bar[mif4,2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,2] * self.yomega2[mif1,mif3] * self.yomega2bar[2,mif2] * self.yomega2bar[mif4,2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,2] * self.yomega2[mif1,mif3] * self.yomega2bar[2,mif2] * self.yomega2bar[mif4,2] + -1/2 * (self.Momega2)**(-2) * self.yomega2[mif1,mif3] * self.yomega2bar[mif4,mif2] + -1/24 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[mif1,mif3] * self.yomega2bar[mif4,mif2] + 1/32 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[mif1,mif3] * self.yomega2bar[mif4,mif2] + -3/32 * self.epsilonbar * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[mif1,mif3] * self.yomega2bar[mif4,mif2] + -1/16 * self.epsilonbar * (self.g3)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[mif1,mif3] * self.yomega2bar[mif4,mif2] + 1/16 * self.epsilonbar * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[mif1,mif3] * self.yomega2bar[mif4,mif2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif1] * self.yomega2[0,mif3] * self.yomega2bar[0,0] * self.yomega2bar[mif4,mif2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif1] * self.yomega2[0,mif3] * self.yomega2bar[0,0] * self.yomega2bar[mif4,mif2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,mif1] * self.yomega2[0,mif3] * self.yomega2bar[0,0] * self.yomega2bar[mif4,mif2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif1] * self.yomega2[1,mif3] * self.yomega2bar[0,1] * self.yomega2bar[mif4,mif2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif1] * self.yomega2[1,mif3] * self.yomega2bar[0,1] * self.yomega2bar[mif4,mif2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,mif1] * self.yomega2[1,mif3] * self.yomega2bar[0,1] * self.yomega2bar[mif4,mif2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif1] * self.yomega2[2,mif3] * self.yomega2bar[0,2] * self.yomega2bar[mif4,mif2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif1] * self.yomega2[2,mif3] * self.yomega2bar[0,2] * self.yomega2bar[mif4,mif2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,mif1] * self.yomega2[2,mif3] * self.yomega2bar[0,2] * self.yomega2bar[mif4,mif2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,0] * self.yomega2[mif1,0] * self.yomega2bar[0,mif3] * self.yomega2bar[mif4,mif2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,0] * self.yomega2[mif1,0] * self.yomega2bar[0,mif3] * self.yomega2bar[mif4,mif2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,0] * self.yomega2[mif1,0] * self.yomega2bar[0,mif3] * self.yomega2bar[mif4,mif2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,1] * self.yomega2[mif1,1] * self.yomega2bar[0,mif3] * self.yomega2bar[mif4,mif2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,1] * self.yomega2[mif1,1] * self.yomega2bar[0,mif3] * self.yomega2bar[mif4,mif2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,1] * self.yomega2[mif1,1] * self.yomega2bar[0,mif3] * self.yomega2bar[mif4,mif2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,2] * self.yomega2[mif1,2] * self.yomega2bar[0,mif3] * self.yomega2bar[mif4,mif2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,2] * self.yomega2[mif1,2] * self.yomega2bar[0,mif3] * self.yomega2bar[mif4,mif2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,2] * self.yomega2[mif1,2] * self.yomega2bar[0,mif3] * self.yomega2bar[mif4,mif2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif3] * self.yomega2[1,mif1] * self.yomega2bar[1,0] * self.yomega2bar[mif4,mif2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif3] * self.yomega2[1,mif1] * self.yomega2bar[1,0] * self.yomega2bar[mif4,mif2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,mif3] * self.yomega2[1,mif1] * self.yomega2bar[1,0] * self.yomega2bar[mif4,mif2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif1] * self.yomega2[1,mif3] * self.yomega2bar[1,1] * self.yomega2bar[mif4,mif2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif1] * self.yomega2[1,mif3] * self.yomega2bar[1,1] * self.yomega2bar[mif4,mif2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,mif1] * self.yomega2[1,mif3] * self.yomega2bar[1,1] * self.yomega2bar[mif4,mif2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif1] * self.yomega2[2,mif3] * self.yomega2bar[1,2] * self.yomega2bar[mif4,mif2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif1] * self.yomega2[2,mif3] * self.yomega2bar[1,2] * self.yomega2bar[mif4,mif2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,mif1] * self.yomega2[2,mif3] * self.yomega2bar[1,2] * self.yomega2bar[mif4,mif2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,0] * self.yomega2[mif1,0] * self.yomega2bar[1,mif3] * self.yomega2bar[mif4,mif2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,0] * self.yomega2[mif1,0] * self.yomega2bar[1,mif3] * self.yomega2bar[mif4,mif2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,0] * self.yomega2[mif1,0] * self.yomega2bar[1,mif3] * self.yomega2bar[mif4,mif2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,1] * self.yomega2[mif1,1] * self.yomega2bar[1,mif3] * self.yomega2bar[mif4,mif2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,1] * self.yomega2[mif1,1] * self.yomega2bar[1,mif3] * self.yomega2bar[mif4,mif2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,1] * self.yomega2[mif1,1] * self.yomega2bar[1,mif3] * self.yomega2bar[mif4,mif2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,2] * self.yomega2[mif1,2] * self.yomega2bar[1,mif3] * self.yomega2bar[mif4,mif2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,2] * self.yomega2[mif1,2] * self.yomega2bar[1,mif3] * self.yomega2bar[mif4,mif2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,2] * self.yomega2[mif1,2] * self.yomega2bar[1,mif3] * self.yomega2bar[mif4,mif2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif3] * self.yomega2[2,mif1] * self.yomega2bar[2,0] * self.yomega2bar[mif4,mif2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif3] * self.yomega2[2,mif1] * self.yomega2bar[2,0] * self.yomega2bar[mif4,mif2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,mif3] * self.yomega2[2,mif1] * self.yomega2bar[2,0] * self.yomega2bar[mif4,mif2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif3] * self.yomega2[2,mif1] * self.yomega2bar[2,1] * self.yomega2bar[mif4,mif2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif3] * self.yomega2[2,mif1] * self.yomega2bar[2,1] * self.yomega2bar[mif4,mif2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,mif3] * self.yomega2[2,mif1] * self.yomega2bar[2,1] * self.yomega2bar[mif4,mif2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,mif1] * self.yomega2[2,mif3] * self.yomega2bar[2,2] * self.yomega2bar[mif4,mif2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,mif1] * self.yomega2[2,mif3] * self.yomega2bar[2,2] * self.yomega2bar[mif4,mif2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,mif1] * self.yomega2[2,mif3] * self.yomega2bar[2,2] * self.yomega2bar[mif4,mif2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,0] * self.yomega2[mif1,0] * self.yomega2bar[2,mif3] * self.yomega2bar[mif4,mif2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,0] * self.yomega2[mif1,0] * self.yomega2bar[2,mif3] * self.yomega2bar[mif4,mif2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,0] * self.yomega2[mif1,0] * self.yomega2bar[2,mif3] * self.yomega2bar[mif4,mif2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,1] * self.yomega2[mif1,1] * self.yomega2bar[2,mif3] * self.yomega2bar[mif4,mif2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,1] * self.yomega2[mif1,1] * self.yomega2bar[2,mif3] * self.yomega2bar[mif4,mif2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,1] * self.yomega2[mif1,1] * self.yomega2bar[2,mif3] * self.yomega2bar[mif4,mif2] + 1/32 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,2] * self.yomega2[mif1,2] * self.yomega2bar[2,mif3] * self.yomega2bar[mif4,mif2] + 1/16 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,2] * self.yomega2[mif1,2] * self.yomega2bar[2,mif3] * self.yomega2bar[mif4,mif2] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,2] * self.yomega2[mif1,2] * self.yomega2bar[2,mif3] * self.yomega2bar[mif4,mif2])

    def alphaOdG(self, mif1,mif2):
        return (1/96 * self.g3 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.yomega2[0,0] * self.yomega2bar[0,mif2] + 1/96 * self.g3 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.yomega2[0,1] * self.yomega2bar[0,mif2] + 1/96 * self.g3 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.yomega2[0,2] * self.yomega2bar[0,mif2] + 1/96 * self.g3 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.yomega2[1,0] * self.yomega2bar[1,mif2] + 1/96 * self.g3 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.yomega2[1,1] * self.yomega2bar[1,mif2] + 1/96 * self.g3 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.yomega2[1,2] * self.yomega2bar[1,mif2] + 1/96 * self.g3 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.yomega2[2,0] * self.yomega2bar[2,mif2] + 1/96 * self.g3 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.yomega2[2,1] * self.yomega2bar[2,mif2] + 1/96 * self.g3 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.yomega2[2,2] * self.yomega2bar[2,mif2])

    def alphaOdH(self, mif1,mif2):
        return (1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yomega2[0,0] * self.yomega2bar[0,0] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yomega2[0,0] * self.yomega2bar[0,0] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yomega2[0,0] * self.yomega2bar[0,0] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[0,0] * self.yomega2[0,1] * self.yomega2bar[0,0] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[1,0] * self.yomega2[0,1] * self.yomega2bar[0,0] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[2,0] * self.yomega2[0,1] * self.yomega2bar[0,0] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[0,0] * self.yomega2[0,2] * self.yomega2bar[0,0] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[1,0] * self.yomega2[0,2] * self.yomega2bar[0,0] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[2,0] * self.yomega2[0,2] * self.yomega2bar[0,0] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[0,1] * self.yomega2[0,0] * self.yomega2bar[0,1] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[1,1] * self.yomega2[0,0] * self.yomega2bar[0,1] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[2,1] * self.yomega2[0,0] * self.yomega2bar[0,1] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yomega2[0,1] * self.yomega2bar[0,1] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yomega2[0,1] * self.yomega2bar[0,1] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yomega2[0,1] * self.yomega2bar[0,1] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[0,1] * self.yomega2[0,2] * self.yomega2bar[0,1] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[1,1] * self.yomega2[0,2] * self.yomega2bar[0,1] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[2,1] * self.yomega2[0,2] * self.yomega2bar[0,1] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[0,2] * self.yomega2[0,0] * self.yomega2bar[0,2] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[1,2] * self.yomega2[0,0] * self.yomega2bar[0,2] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[2,2] * self.yomega2[0,0] * self.yomega2bar[0,2] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[0,2] * self.yomega2[0,1] * self.yomega2bar[0,2] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[1,2] * self.yomega2[0,1] * self.yomega2bar[0,2] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[2,2] * self.yomega2[0,1] * self.yomega2bar[0,2] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yomega2[0,2] * self.yomega2bar[0,2] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yomega2[0,2] * self.yomega2bar[0,2] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yomega2[0,2] * self.yomega2bar[0,2] + 1/8 * self.lambdaHatomega2 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.yomega2[0,0] * self.yomega2bar[0,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.yd[mif1,0] * self.ydbar[0,0] * self.yomega2[0,0] * self.yomega2bar[0,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.yd[mif1,0] * self.ydbar[1,0] * self.yomega2[0,0] * self.yomega2bar[0,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.yd[mif1,0] * self.ydbar[2,0] * self.yomega2[0,0] * self.yomega2bar[0,mif2] + 1/8 * self.lambdaHatomega2 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.yomega2[0,1] * self.yomega2bar[0,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.yd[mif1,1] * self.ydbar[0,0] * self.yomega2[0,1] * self.yomega2bar[0,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.yd[mif1,1] * self.ydbar[1,0] * self.yomega2[0,1] * self.yomega2bar[0,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.yd[mif1,1] * self.ydbar[2,0] * self.yomega2[0,1] * self.yomega2bar[0,mif2] + 1/8 * self.lambdaHatomega2 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.yomega2[0,2] * self.yomega2bar[0,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.yd[mif1,2] * self.ydbar[0,0] * self.yomega2[0,2] * self.yomega2bar[0,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.yd[mif1,2] * self.ydbar[1,0] * self.yomega2[0,2] * self.yomega2bar[0,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.yd[mif1,2] * self.ydbar[2,0] * self.yomega2[0,2] * self.yomega2bar[0,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.yd[mif1,0] * self.ydbar[0,0] * self.yomega2[1,0] * self.yomega2bar[0,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.yd[mif1,0] * self.ydbar[1,0] * self.yomega2[1,0] * self.yomega2bar[0,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.yd[mif1,0] * self.ydbar[2,0] * self.yomega2[1,0] * self.yomega2bar[0,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.yd[mif1,1] * self.ydbar[0,0] * self.yomega2[1,1] * self.yomega2bar[0,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.yd[mif1,1] * self.ydbar[1,0] * self.yomega2[1,1] * self.yomega2bar[0,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.yd[mif1,1] * self.ydbar[2,0] * self.yomega2[1,1] * self.yomega2bar[0,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.yd[mif1,2] * self.ydbar[0,0] * self.yomega2[1,2] * self.yomega2bar[0,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.yd[mif1,2] * self.ydbar[1,0] * self.yomega2[1,2] * self.yomega2bar[0,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.yd[mif1,2] * self.ydbar[2,0] * self.yomega2[1,2] * self.yomega2bar[0,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yomega2[2,0] * self.yomega2bar[0,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yomega2[2,0] * self.yomega2bar[0,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yomega2[2,0] * self.yomega2bar[0,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.yd[mif1,1] * self.ydbar[0,0] * self.yomega2[2,1] * self.yomega2bar[0,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.yd[mif1,1] * self.ydbar[1,0] * self.yomega2[2,1] * self.yomega2bar[0,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.yd[mif1,1] * self.ydbar[2,0] * self.yomega2[2,1] * self.yomega2bar[0,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.yd[mif1,2] * self.ydbar[0,0] * self.yomega2[2,2] * self.yomega2bar[0,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.yd[mif1,2] * self.ydbar[1,0] * self.yomega2[2,2] * self.yomega2bar[0,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.yd[mif1,2] * self.ydbar[2,0] * self.yomega2[2,2] * self.yomega2bar[0,mif2] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yomega2[1,0] * self.yomega2bar[1,0] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yomega2[1,0] * self.yomega2bar[1,0] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yomega2[1,0] * self.yomega2bar[1,0] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[0,0] * self.yomega2[1,1] * self.yomega2bar[1,0] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[1,0] * self.yomega2[1,1] * self.yomega2bar[1,0] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[2,0] * self.yomega2[1,1] * self.yomega2bar[1,0] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[0,0] * self.yomega2[1,2] * self.yomega2bar[1,0] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[1,0] * self.yomega2[1,2] * self.yomega2bar[1,0] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[2,0] * self.yomega2[1,2] * self.yomega2bar[1,0] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[0,1] * self.yomega2[1,0] * self.yomega2bar[1,1] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[1,1] * self.yomega2[1,0] * self.yomega2bar[1,1] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[2,1] * self.yomega2[1,0] * self.yomega2bar[1,1] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yomega2[1,1] * self.yomega2bar[1,1] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yomega2[1,1] * self.yomega2bar[1,1] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yomega2[1,1] * self.yomega2bar[1,1] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[0,1] * self.yomega2[1,2] * self.yomega2bar[1,1] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[1,1] * self.yomega2[1,2] * self.yomega2bar[1,1] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[2,1] * self.yomega2[1,2] * self.yomega2bar[1,1] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[0,2] * self.yomega2[1,0] * self.yomega2bar[1,2] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[1,2] * self.yomega2[1,0] * self.yomega2bar[1,2] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[2,2] * self.yomega2[1,0] * self.yomega2bar[1,2] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[0,2] * self.yomega2[1,1] * self.yomega2bar[1,2] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[1,2] * self.yomega2[1,1] * self.yomega2bar[1,2] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[2,2] * self.yomega2[1,1] * self.yomega2bar[1,2] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yomega2[1,2] * self.yomega2bar[1,2] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yomega2[1,2] * self.yomega2bar[1,2] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yomega2[1,2] * self.yomega2bar[1,2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.yd[mif1,0] * self.ydbar[0,1] * self.yomega2[0,0] * self.yomega2bar[1,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.yd[mif1,0] * self.ydbar[1,1] * self.yomega2[0,0] * self.yomega2bar[1,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.yd[mif1,0] * self.ydbar[2,1] * self.yomega2[0,0] * self.yomega2bar[1,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.yd[mif1,1] * self.ydbar[0,1] * self.yomega2[0,1] * self.yomega2bar[1,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.yd[mif1,1] * self.ydbar[1,1] * self.yomega2[0,1] * self.yomega2bar[1,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.yd[mif1,1] * self.ydbar[2,1] * self.yomega2[0,1] * self.yomega2bar[1,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.yd[mif1,2] * self.ydbar[0,1] * self.yomega2[0,2] * self.yomega2bar[1,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.yd[mif1,2] * self.ydbar[1,1] * self.yomega2[0,2] * self.yomega2bar[1,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.yd[mif1,2] * self.ydbar[2,1] * self.yomega2[0,2] * self.yomega2bar[1,mif2] + 1/8 * self.lambdaHatomega2 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.yomega2[1,0] * self.yomega2bar[1,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.yd[mif1,0] * self.ydbar[0,1] * self.yomega2[1,0] * self.yomega2bar[1,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.yd[mif1,0] * self.ydbar[1,1] * self.yomega2[1,0] * self.yomega2bar[1,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.yd[mif1,0] * self.ydbar[2,1] * self.yomega2[1,0] * self.yomega2bar[1,mif2] + 1/8 * self.lambdaHatomega2 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.yomega2[1,1] * self.yomega2bar[1,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.yd[mif1,1] * self.ydbar[0,1] * self.yomega2[1,1] * self.yomega2bar[1,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.yd[mif1,1] * self.ydbar[1,1] * self.yomega2[1,1] * self.yomega2bar[1,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.yd[mif1,1] * self.ydbar[2,1] * self.yomega2[1,1] * self.yomega2bar[1,mif2] + 1/8 * self.lambdaHatomega2 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.yomega2[1,2] * self.yomega2bar[1,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.yd[mif1,2] * self.ydbar[0,1] * self.yomega2[1,2] * self.yomega2bar[1,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.yd[mif1,2] * self.ydbar[1,1] * self.yomega2[1,2] * self.yomega2bar[1,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.yd[mif1,2] * self.ydbar[2,1] * self.yomega2[1,2] * self.yomega2bar[1,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.yd[mif1,0] * self.ydbar[0,1] * self.yomega2[2,0] * self.yomega2bar[1,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.yd[mif1,0] * self.ydbar[1,1] * self.yomega2[2,0] * self.yomega2bar[1,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.yd[mif1,0] * self.ydbar[2,1] * self.yomega2[2,0] * self.yomega2bar[1,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yomega2[2,1] * self.yomega2bar[1,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yomega2[2,1] * self.yomega2bar[1,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yomega2[2,1] * self.yomega2bar[1,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.yd[mif1,2] * self.ydbar[0,1] * self.yomega2[2,2] * self.yomega2bar[1,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.yd[mif1,2] * self.ydbar[1,1] * self.yomega2[2,2] * self.yomega2bar[1,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.yd[mif1,2] * self.ydbar[2,1] * self.yomega2[2,2] * self.yomega2bar[1,mif2] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yomega2[2,0] * self.yomega2bar[2,0] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yomega2[2,0] * self.yomega2bar[2,0] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yomega2[2,0] * self.yomega2bar[2,0] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[0,0] * self.yomega2[2,1] * self.yomega2bar[2,0] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[1,0] * self.yomega2[2,1] * self.yomega2bar[2,0] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[2,0] * self.yomega2[2,1] * self.yomega2bar[2,0] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[0,0] * self.yomega2[2,2] * self.yomega2bar[2,0] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[1,0] * self.yomega2[2,2] * self.yomega2bar[2,0] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[2,0] * self.yomega2[2,2] * self.yomega2bar[2,0] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[0,1] * self.yomega2[2,0] * self.yomega2bar[2,1] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[1,1] * self.yomega2[2,0] * self.yomega2bar[2,1] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[2,1] * self.yomega2[2,0] * self.yomega2bar[2,1] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yomega2[2,1] * self.yomega2bar[2,1] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yomega2[2,1] * self.yomega2bar[2,1] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yomega2[2,1] * self.yomega2bar[2,1] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[0,1] * self.yomega2[2,2] * self.yomega2bar[2,1] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[1,1] * self.yomega2[2,2] * self.yomega2bar[2,1] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[2,1] * self.yomega2[2,2] * self.yomega2bar[2,1] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[0,2] * self.yomega2[2,0] * self.yomega2bar[2,2] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[1,2] * self.yomega2[2,0] * self.yomega2bar[2,2] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[2,2] * self.yomega2[2,0] * self.yomega2bar[2,2] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[0,2] * self.yomega2[2,1] * self.yomega2bar[2,2] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[1,2] * self.yomega2[2,1] * self.yomega2bar[2,2] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[2,2] * self.yomega2[2,1] * self.yomega2bar[2,2] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yomega2[2,2] * self.yomega2bar[2,2] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yomega2[2,2] * self.yomega2bar[2,2] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yomega2[2,2] * self.yomega2bar[2,2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.yd[mif1,0] * self.ydbar[0,2] * self.yomega2[0,0] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.yd[mif1,0] * self.ydbar[1,2] * self.yomega2[0,0] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.yd[mif1,0] * self.ydbar[2,2] * self.yomega2[0,0] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.yd[mif1,1] * self.ydbar[0,2] * self.yomega2[0,1] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.yd[mif1,1] * self.ydbar[1,2] * self.yomega2[0,1] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.yd[mif1,1] * self.ydbar[2,2] * self.yomega2[0,1] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.yd[mif1,2] * self.ydbar[0,2] * self.yomega2[0,2] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.yd[mif1,2] * self.ydbar[1,2] * self.yomega2[0,2] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.yd[mif1,2] * self.ydbar[2,2] * self.yomega2[0,2] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.yd[mif1,0] * self.ydbar[0,2] * self.yomega2[1,0] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.yd[mif1,0] * self.ydbar[1,2] * self.yomega2[1,0] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.yd[mif1,0] * self.ydbar[2,2] * self.yomega2[1,0] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.yd[mif1,1] * self.ydbar[0,2] * self.yomega2[1,1] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.yd[mif1,1] * self.ydbar[1,2] * self.yomega2[1,1] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.yd[mif1,1] * self.ydbar[2,2] * self.yomega2[1,1] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.yd[mif1,2] * self.ydbar[0,2] * self.yomega2[1,2] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.yd[mif1,2] * self.ydbar[1,2] * self.yomega2[1,2] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.yd[mif1,2] * self.ydbar[2,2] * self.yomega2[1,2] * self.yomega2bar[2,mif2] + 1/8 * self.lambdaHatomega2 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.yomega2[2,0] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.yd[mif1,0] * self.ydbar[0,2] * self.yomega2[2,0] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.yd[mif1,0] * self.ydbar[1,2] * self.yomega2[2,0] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.yd[mif1,0] * self.ydbar[2,2] * self.yomega2[2,0] * self.yomega2bar[2,mif2] + 1/8 * self.lambdaHatomega2 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.yomega2[2,1] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.yd[mif1,1] * self.ydbar[0,2] * self.yomega2[2,1] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.yd[mif1,1] * self.ydbar[1,2] * self.yomega2[2,1] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.yd[mif1,1] * self.ydbar[2,2] * self.yomega2[2,1] * self.yomega2bar[2,mif2] + 1/8 * self.lambdaHatomega2 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.yomega2[2,2] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yomega2[2,2] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yomega2[2,2] * self.yomega2bar[2,mif2] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yomega2[2,2] * self.yomega2bar[2,mif2])

    def alphaOdW(self, mif1,mif2):
        return 0

    def alphaOeB(self, mif1,mif2):
        return 0

    def alphaOed(self, mif1,mif2,mif3,mif4):
        return (-1/1080 * (self.g1)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 5/54 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + 1/18 * (self.g1)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + -1/18 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + 5/54 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + 1/18 * (self.g1)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + -1/18 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + 5/54 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[2,mif3] * self.yomega2bar[2,mif4] + 1/18 * (self.g1)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[2,mif3] * self.yomega2bar[2,mif4] + -1/18 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,mif3] * self.yomega2bar[2,mif4] + 1/36 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[mif3,0] * self.yomega2bar[mif4,0] + 1/36 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[mif3,1] * self.yomega2bar[mif4,1] + 1/36 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[mif3,2] * self.yomega2bar[mif4,2])

    def alphaOee(self, mif1,mif2,mif3,mif4):
        return -1/720 * (self.g1)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4)

    def alphaOeH(self, mif1,mif2):
        return 0

    def alphaOeu(self, mif1,mif2,mif3,mif4):
        return 1/540 * (self.g1)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4)

    def alphaOeW(self, mif1,mif2):
        return 0

    def alphaOHd(self, mif1,mif2):
        return (1/2160 * (self.g1)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) + -5/108 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif1] * self.yomega2bar[0,mif2] + -1/36 * (self.g1)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[0,mif1] * self.yomega2bar[0,mif2] + 1/36 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,mif1] * self.yomega2bar[0,mif2] + 1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,0] * self.yomega2[0,mif1] * self.yomega2bar[0,mif2] + 1/4 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,0] * self.yomega2[0,mif1] * self.yomega2bar[0,mif2] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[0,0] * self.ydbar[0,0] * self.yomega2[0,mif1] * self.yomega2bar[0,mif2] + 1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,0] * self.yomega2[0,mif1] * self.yomega2bar[0,mif2] + 1/4 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,0] * self.yomega2[0,mif1] * self.yomega2bar[0,mif2] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[1,0] * self.ydbar[1,0] * self.yomega2[0,mif1] * self.yomega2bar[0,mif2] + 1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,0] * self.yomega2[0,mif1] * self.yomega2bar[0,mif2] + 1/4 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,0] * self.yomega2[0,mif1] * self.yomega2bar[0,mif2] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[2,0] * self.ydbar[2,0] * self.yomega2[0,mif1] * self.yomega2bar[0,mif2] + 1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,0] * self.yomega2[1,mif1] * self.yomega2bar[0,mif2] + 1/4 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,0] * self.yomega2[1,mif1] * self.yomega2bar[0,mif2] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[0,1] * self.ydbar[0,0] * self.yomega2[1,mif1] * self.yomega2bar[0,mif2] + 1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,0] * self.yomega2[1,mif1] * self.yomega2bar[0,mif2] + 1/4 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,0] * self.yomega2[1,mif1] * self.yomega2bar[0,mif2] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[1,1] * self.ydbar[1,0] * self.yomega2[1,mif1] * self.yomega2bar[0,mif2] + 1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,0] * self.yomega2[1,mif1] * self.yomega2bar[0,mif2] + 1/4 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,0] * self.yomega2[1,mif1] * self.yomega2bar[0,mif2] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[2,1] * self.ydbar[2,0] * self.yomega2[1,mif1] * self.yomega2bar[0,mif2] + 1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,0] * self.yomega2[2,mif1] * self.yomega2bar[0,mif2] + 1/4 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,0] * self.yomega2[2,mif1] * self.yomega2bar[0,mif2] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[0,2] * self.ydbar[0,0] * self.yomega2[2,mif1] * self.yomega2bar[0,mif2] + 1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,0] * self.yomega2[2,mif1] * self.yomega2bar[0,mif2] + 1/4 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,0] * self.yomega2[2,mif1] * self.yomega2bar[0,mif2] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[1,2] * self.ydbar[1,0] * self.yomega2[2,mif1] * self.yomega2bar[0,mif2] + 1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,0] * self.yomega2[2,mif1] * self.yomega2bar[0,mif2] + 1/4 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,0] * self.yomega2[2,mif1] * self.yomega2bar[0,mif2] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[2,2] * self.ydbar[2,0] * self.yomega2[2,mif1] * self.yomega2bar[0,mif2] + 1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,1] * self.yomega2[0,mif1] * self.yomega2bar[1,mif2] + 1/4 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,1] * self.yomega2[0,mif1] * self.yomega2bar[1,mif2] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[0,0] * self.ydbar[0,1] * self.yomega2[0,mif1] * self.yomega2bar[1,mif2] + 1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,1] * self.yomega2[0,mif1] * self.yomega2bar[1,mif2] + 1/4 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,1] * self.yomega2[0,mif1] * self.yomega2bar[1,mif2] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[1,0] * self.ydbar[1,1] * self.yomega2[0,mif1] * self.yomega2bar[1,mif2] + 1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,1] * self.yomega2[0,mif1] * self.yomega2bar[1,mif2] + 1/4 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,1] * self.yomega2[0,mif1] * self.yomega2bar[1,mif2] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[2,0] * self.ydbar[2,1] * self.yomega2[0,mif1] * self.yomega2bar[1,mif2] + -5/108 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif1] * self.yomega2bar[1,mif2] + -1/36 * (self.g1)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[1,mif1] * self.yomega2bar[1,mif2] + 1/36 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,mif1] * self.yomega2bar[1,mif2] + 1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,1] * self.yomega2[1,mif1] * self.yomega2bar[1,mif2] + 1/4 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,1] * self.yomega2[1,mif1] * self.yomega2bar[1,mif2] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[0,1] * self.ydbar[0,1] * self.yomega2[1,mif1] * self.yomega2bar[1,mif2] + 1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,1] * self.yomega2[1,mif1] * self.yomega2bar[1,mif2] + 1/4 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,1] * self.yomega2[1,mif1] * self.yomega2bar[1,mif2] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[1,1] * self.ydbar[1,1] * self.yomega2[1,mif1] * self.yomega2bar[1,mif2] + 1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,1] * self.yomega2[1,mif1] * self.yomega2bar[1,mif2] + 1/4 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,1] * self.yomega2[1,mif1] * self.yomega2bar[1,mif2] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[2,1] * self.ydbar[2,1] * self.yomega2[1,mif1] * self.yomega2bar[1,mif2] + 1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,1] * self.yomega2[2,mif1] * self.yomega2bar[1,mif2] + 1/4 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,1] * self.yomega2[2,mif1] * self.yomega2bar[1,mif2] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[0,2] * self.ydbar[0,1] * self.yomega2[2,mif1] * self.yomega2bar[1,mif2] + 1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,1] * self.yomega2[2,mif1] * self.yomega2bar[1,mif2] + 1/4 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,1] * self.yomega2[2,mif1] * self.yomega2bar[1,mif2] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[1,2] * self.ydbar[1,1] * self.yomega2[2,mif1] * self.yomega2bar[1,mif2] + 1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,1] * self.yomega2[2,mif1] * self.yomega2bar[1,mif2] + 1/4 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,1] * self.yomega2[2,mif1] * self.yomega2bar[1,mif2] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[2,2] * self.ydbar[2,1] * self.yomega2[2,mif1] * self.yomega2bar[1,mif2] + 1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,2] * self.yomega2[0,mif1] * self.yomega2bar[2,mif2] + 1/4 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,2] * self.yomega2[0,mif1] * self.yomega2bar[2,mif2] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[0,0] * self.ydbar[0,2] * self.yomega2[0,mif1] * self.yomega2bar[2,mif2] + 1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,2] * self.yomega2[0,mif1] * self.yomega2bar[2,mif2] + 1/4 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,2] * self.yomega2[0,mif1] * self.yomega2bar[2,mif2] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[1,0] * self.ydbar[1,2] * self.yomega2[0,mif1] * self.yomega2bar[2,mif2] + 1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,2] * self.yomega2[0,mif1] * self.yomega2bar[2,mif2] + 1/4 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,2] * self.yomega2[0,mif1] * self.yomega2bar[2,mif2] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[2,0] * self.ydbar[2,2] * self.yomega2[0,mif1] * self.yomega2bar[2,mif2] + 1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,2] * self.yomega2[1,mif1] * self.yomega2bar[2,mif2] + 1/4 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,2] * self.yomega2[1,mif1] * self.yomega2bar[2,mif2] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[0,1] * self.ydbar[0,2] * self.yomega2[1,mif1] * self.yomega2bar[2,mif2] + 1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,2] * self.yomega2[1,mif1] * self.yomega2bar[2,mif2] + 1/4 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,2] * self.yomega2[1,mif1] * self.yomega2bar[2,mif2] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[1,1] * self.ydbar[1,2] * self.yomega2[1,mif1] * self.yomega2bar[2,mif2] + 1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,2] * self.yomega2[1,mif1] * self.yomega2bar[2,mif2] + 1/4 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,2] * self.yomega2[1,mif1] * self.yomega2bar[2,mif2] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[2,1] * self.ydbar[2,2] * self.yomega2[1,mif1] * self.yomega2bar[2,mif2] + -5/108 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,mif1] * self.yomega2bar[2,mif2] + -1/36 * (self.g1)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[2,mif1] * self.yomega2bar[2,mif2] + 1/36 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,mif1] * self.yomega2bar[2,mif2] + 1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,2] * self.yomega2[2,mif1] * self.yomega2bar[2,mif2] + 1/4 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,2] * self.yomega2[2,mif1] * self.yomega2bar[2,mif2] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[0,2] * self.ydbar[0,2] * self.yomega2[2,mif1] * self.yomega2bar[2,mif2] + 1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,2] * self.yomega2[2,mif1] * self.yomega2bar[2,mif2] + 1/4 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,2] * self.yomega2[2,mif1] * self.yomega2bar[2,mif2] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[1,2] * self.ydbar[1,2] * self.yomega2[2,mif1] * self.yomega2bar[2,mif2] + 1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,2] * self.yomega2[2,mif1] * self.yomega2bar[2,mif2] + 1/4 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,2] * self.yomega2[2,mif1] * self.yomega2bar[2,mif2] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[2,2] * self.ydbar[2,2] * self.yomega2[2,mif1] * self.yomega2bar[2,mif2] + -1/72 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[mif1,0] * self.yomega2bar[mif2,0] + 1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,0] * self.yomega2[mif1,0] * self.yomega2bar[mif2,0] + 1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,0] * self.yomega2[mif1,0] * self.yomega2bar[mif2,0] + 1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,0] * self.yomega2[mif1,0] * self.yomega2bar[mif2,0] + 1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,0] * self.yomega2[mif1,1] * self.yomega2bar[mif2,0] + 1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,0] * self.yomega2[mif1,1] * self.yomega2bar[mif2,0] + 1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,0] * self.yomega2[mif1,1] * self.yomega2bar[mif2,0] + 1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,0] * self.yomega2[mif1,2] * self.yomega2bar[mif2,0] + 1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,0] * self.yomega2[mif1,2] * self.yomega2bar[mif2,0] + 1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,0] * self.yomega2[mif1,2] * self.yomega2bar[mif2,0] + 1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,1] * self.yomega2[mif1,0] * self.yomega2bar[mif2,1] + 1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,1] * self.yomega2[mif1,0] * self.yomega2bar[mif2,1] + 1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,1] * self.yomega2[mif1,0] * self.yomega2bar[mif2,1] + -1/72 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[mif1,1] * self.yomega2bar[mif2,1] + 1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,1] * self.yomega2[mif1,1] * self.yomega2bar[mif2,1] + 1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,1] * self.yomega2[mif1,1] * self.yomega2bar[mif2,1] + 1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,1] * self.yomega2[mif1,1] * self.yomega2bar[mif2,1] + 1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,1] * self.yomega2[mif1,2] * self.yomega2bar[mif2,1] + 1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,1] * self.yomega2[mif1,2] * self.yomega2bar[mif2,1] + 1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,1] * self.yomega2[mif1,2] * self.yomega2bar[mif2,1] + 1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,2] * self.yomega2[mif1,0] * self.yomega2bar[mif2,2] + 1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,2] * self.yomega2[mif1,0] * self.yomega2bar[mif2,2] + 1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,2] * self.yomega2[mif1,0] * self.yomega2bar[mif2,2] + 1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,2] * self.yomega2[mif1,1] * self.yomega2bar[mif2,2] + 1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,2] * self.yomega2[mif1,1] * self.yomega2bar[mif2,2] + 1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,2] * self.yomega2[mif1,1] * self.yomega2bar[mif2,2] + -1/72 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yomega2[mif1,2] * self.yomega2bar[mif2,2] + 1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,2] * self.yomega2[mif1,2] * self.yomega2bar[mif2,2] + 1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,2] * self.yomega2[mif1,2] * self.yomega2bar[mif2,2] + 1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,2] * self.yomega2[mif1,2] * self.yomega2bar[mif2,2])

    def alphaOHe(self, mif1,mif2):
        return 1/720 * (self.g1)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2)

    def alphaOHl1(self, mif1,mif2):
        return 1/1440 * (self.g1)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2)

    def alphaOHl3(self, mif1,mif2):
        return 0

    def alphaOHq1(self, mif1,mif2):
        return (-1/4320 * (self.g1)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,0] * self.yomega2[0,0] * self.yomega2bar[0,0] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,0] * self.yomega2[0,1] * self.yomega2bar[0,0] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,0] * self.yomega2[0,2] * self.yomega2bar[0,0] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,1] * self.yomega2[0,0] * self.yomega2bar[0,1] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,1] * self.yomega2[0,1] * self.yomega2bar[0,1] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,1] * self.yomega2[0,2] * self.yomega2bar[0,1] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,2] * self.yomega2[0,0] * self.yomega2bar[0,2] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,2] * self.yomega2[0,1] * self.yomega2bar[0,2] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,2] * self.yomega2[0,2] * self.yomega2bar[0,2] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,0] * self.yomega2[1,0] * self.yomega2bar[1,0] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,0] * self.yomega2[1,1] * self.yomega2bar[1,0] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,0] * self.yomega2[1,2] * self.yomega2bar[1,0] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,1] * self.yomega2[1,0] * self.yomega2bar[1,1] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,1] * self.yomega2[1,1] * self.yomega2bar[1,1] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,1] * self.yomega2[1,2] * self.yomega2bar[1,1] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,2] * self.yomega2[1,0] * self.yomega2bar[1,2] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,2] * self.yomega2[1,1] * self.yomega2bar[1,2] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,2] * self.yomega2[1,2] * self.yomega2bar[1,2] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,0] * self.yomega2[2,0] * self.yomega2bar[2,0] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,0] * self.yomega2[2,1] * self.yomega2bar[2,0] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,0] * self.yomega2[2,2] * self.yomega2bar[2,0] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,1] * self.yomega2[2,0] * self.yomega2bar[2,1] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,1] * self.yomega2[2,1] * self.yomega2bar[2,1] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,1] * self.yomega2[2,2] * self.yomega2bar[2,1] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,2] * self.yomega2[2,0] * self.yomega2bar[2,2] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,2] * self.yomega2[2,1] * self.yomega2bar[2,2] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,2] * self.yomega2[2,2] * self.yomega2bar[2,2])

    def alphaOHq3(self, mif1,mif2):
        return (-1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,0] * self.yomega2[0,0] * self.yomega2bar[0,0] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,0] * self.yomega2[0,1] * self.yomega2bar[0,0] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,0] * self.yomega2[0,2] * self.yomega2bar[0,0] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,1] * self.yomega2[0,0] * self.yomega2bar[0,1] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,1] * self.yomega2[0,1] * self.yomega2bar[0,1] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,1] * self.yomega2[0,2] * self.yomega2bar[0,1] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,2] * self.yomega2[0,0] * self.yomega2bar[0,2] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,2] * self.yomega2[0,1] * self.yomega2bar[0,2] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,2] * self.yomega2[0,2] * self.yomega2bar[0,2] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,0] * self.yomega2[1,0] * self.yomega2bar[1,0] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,0] * self.yomega2[1,1] * self.yomega2bar[1,0] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,0] * self.yomega2[1,2] * self.yomega2bar[1,0] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,1] * self.yomega2[1,0] * self.yomega2bar[1,1] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,1] * self.yomega2[1,1] * self.yomega2bar[1,1] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,1] * self.yomega2[1,2] * self.yomega2bar[1,1] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,2] * self.yomega2[1,0] * self.yomega2bar[1,2] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,2] * self.yomega2[1,1] * self.yomega2bar[1,2] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,2] * self.yomega2[1,2] * self.yomega2bar[1,2] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,0] * self.yomega2[2,0] * self.yomega2bar[2,0] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,0] * self.yomega2[2,1] * self.yomega2bar[2,0] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,0] * self.yomega2[2,2] * self.yomega2bar[2,0] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,1] * self.yomega2[2,0] * self.yomega2bar[2,1] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,1] * self.yomega2[2,1] * self.yomega2bar[2,1] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,1] * self.yomega2[2,2] * self.yomega2bar[2,1] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,2] * self.yomega2[2,0] * self.yomega2bar[2,2] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,2] * self.yomega2[2,1] * self.yomega2bar[2,2] + -1/48 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,2] * self.yomega2[2,2] * self.yomega2bar[2,2])

    def alphaOHu(self, mif1,mif2):
        return -1/1080 * (self.g1)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2)

    def alphaOHud(self, mif1,mif2):
        return 0

    def alphaOld(self, mif1,mif2,mif3,mif4):
        return (-1/2160 * (self.g1)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 5/108 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + 1/36 * (self.g1)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + -1/36 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + 5/108 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + 1/36 * (self.g1)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + -1/36 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + 5/108 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[2,mif3] * self.yomega2bar[2,mif4] + 1/36 * (self.g1)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[2,mif3] * self.yomega2bar[2,mif4] + -1/36 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,mif3] * self.yomega2bar[2,mif4] + 1/72 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[mif3,0] * self.yomega2bar[mif4,0] + 1/72 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[mif3,1] * self.yomega2bar[mif4,1] + 1/72 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[mif3,2] * self.yomega2bar[mif4,2])

    def alphaOle(self, mif1,mif2,mif3,mif4):
        return -1/720 * (self.g1)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4)

    def alphaOledq(self, mif1,mif2,mif3,mif4):
        return 0

    def alphaOlequ1(self, mif1,mif2,mif3,mif4):
        return 0

    def alphaOlequ3(self, mif1,mif2,mif3,mif4):
        return 0

    def alphaOll(self, mif1,mif2,mif3,mif4):
        return -1/2880 * (self.g1)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4)

    def alphaOlq1(self, mif1,mif2,mif3,mif4):
        return 1/4320 * (self.g1)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4)

    def alphaOlq3(self, mif1,mif2,mif3,mif4):
        return 0

    def alphaOlu(self, mif1,mif2,mif3,mif4):
        return 1/1080 * (self.g1)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4)

    def alphaOqd1(self, mif1,mif2,mif3,mif4):
        return (1/6480 * (self.g1)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + -5/324 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + -1/108 * (self.g1)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + 1/108 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,0] * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + -1/24 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,0] * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[mif1,0] * self.ydbar[mif2,0] * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,0] * self.yomega2[1,mif3] * self.yomega2bar[0,mif4] + -1/24 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,0] * self.yomega2[1,mif3] * self.yomega2bar[0,mif4] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[mif1,1] * self.ydbar[mif2,0] * self.yomega2[1,mif3] * self.yomega2bar[0,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,0] * self.yomega2[2,mif3] * self.yomega2bar[0,mif4] + -1/24 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,0] * self.yomega2[2,mif3] * self.yomega2bar[0,mif4] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[mif1,2] * self.ydbar[mif2,0] * self.yomega2[2,mif3] * self.yomega2bar[0,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,0] * self.yomega2[mif3,0] * self.yomega2bar[0,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,0] * self.yomega2[mif3,1] * self.yomega2bar[0,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,0] * self.yomega2[mif3,2] * self.yomega2bar[0,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,1] * self.yomega2[0,mif3] * self.yomega2bar[1,mif4] + -1/24 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,1] * self.yomega2[0,mif3] * self.yomega2bar[1,mif4] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[mif1,0] * self.ydbar[mif2,1] * self.yomega2[0,mif3] * self.yomega2bar[1,mif4] + -5/324 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + -1/108 * (self.g1)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + 1/108 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,1] * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + -1/24 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,1] * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[mif1,1] * self.ydbar[mif2,1] * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,1] * self.yomega2[2,mif3] * self.yomega2bar[1,mif4] + -1/24 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,1] * self.yomega2[2,mif3] * self.yomega2bar[1,mif4] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[mif1,2] * self.ydbar[mif2,1] * self.yomega2[2,mif3] * self.yomega2bar[1,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,1] * self.yomega2[mif3,0] * self.yomega2bar[1,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,1] * self.yomega2[mif3,1] * self.yomega2bar[1,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,1] * self.yomega2[mif3,2] * self.yomega2bar[1,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,2] * self.yomega2[0,mif3] * self.yomega2bar[2,mif4] + -1/24 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,2] * self.yomega2[0,mif3] * self.yomega2bar[2,mif4] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[mif1,0] * self.ydbar[mif2,2] * self.yomega2[0,mif3] * self.yomega2bar[2,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,2] * self.yomega2[1,mif3] * self.yomega2bar[2,mif4] + -1/24 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,2] * self.yomega2[1,mif3] * self.yomega2bar[2,mif4] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[mif1,1] * self.ydbar[mif2,2] * self.yomega2[1,mif3] * self.yomega2bar[2,mif4] + -5/324 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[2,mif3] * self.yomega2bar[2,mif4] + -1/108 * (self.g1)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[2,mif3] * self.yomega2bar[2,mif4] + 1/108 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,mif3] * self.yomega2bar[2,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,2] * self.yomega2[2,mif3] * self.yomega2bar[2,mif4] + -1/24 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,2] * self.yomega2[2,mif3] * self.yomega2bar[2,mif4] + 1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[mif1,2] * self.ydbar[mif2,2] * self.yomega2[2,mif3] * self.yomega2bar[2,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,2] * self.yomega2[mif3,0] * self.yomega2bar[2,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,2] * self.yomega2[mif3,1] * self.yomega2bar[2,mif4] + -1/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,2] * self.yomega2[mif3,2] * self.yomega2bar[2,mif4] + -1/216 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[mif3,0] * self.yomega2bar[mif4,0] + -1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,0] * self.yomega2[mif3,0] * self.yomega2bar[mif4,0] + -1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,0] * self.yomega2[mif3,1] * self.yomega2bar[mif4,0] + -1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,0] * self.yomega2[mif3,2] * self.yomega2bar[mif4,0] + -1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,1] * self.yomega2[mif3,0] * self.yomega2bar[mif4,1] + -1/216 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[mif3,1] * self.yomega2bar[mif4,1] + -1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,1] * self.yomega2[mif3,1] * self.yomega2bar[mif4,1] + -1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,1] * self.yomega2[mif3,2] * self.yomega2bar[mif4,1] + -1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,2] * self.yomega2[mif3,0] * self.yomega2bar[mif4,2] + -1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,2] * self.yomega2[mif3,1] * self.yomega2bar[mif4,2] + -1/216 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[mif3,2] * self.yomega2bar[mif4,2] + -1/24 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,2] * self.yomega2[mif3,2] * self.yomega2bar[mif4,2])

    def alphaOqd8(self, mif1,mif2,mif3,mif4):
        return (-1/960 * (self.g3)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + -7/72 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + -1/12 * (self.g3)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + 1/12 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + 3/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,0] * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + 1/8 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,0] * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[mif1,0] * self.ydbar[mif2,0] * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + 3/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,0] * self.yomega2[1,mif3] * self.yomega2bar[0,mif4] + 1/8 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,0] * self.yomega2[1,mif3] * self.yomega2bar[0,mif4] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[mif1,1] * self.ydbar[mif2,0] * self.yomega2[1,mif3] * self.yomega2bar[0,mif4] + 3/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,0] * self.yomega2[2,mif3] * self.yomega2bar[0,mif4] + 1/8 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,0] * self.yomega2[2,mif3] * self.yomega2bar[0,mif4] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[mif1,2] * self.ydbar[mif2,0] * self.yomega2[2,mif3] * self.yomega2bar[0,mif4] + 3/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,1] * self.yomega2[0,mif3] * self.yomega2bar[1,mif4] + 1/8 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,1] * self.yomega2[0,mif3] * self.yomega2bar[1,mif4] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[mif1,0] * self.ydbar[mif2,1] * self.yomega2[0,mif3] * self.yomega2bar[1,mif4] + -7/72 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + -1/12 * (self.g3)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + 1/12 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + 3/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,1] * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + 1/8 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,1] * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[mif1,1] * self.ydbar[mif2,1] * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + 3/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,1] * self.yomega2[2,mif3] * self.yomega2bar[1,mif4] + 1/8 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,1] * self.yomega2[2,mif3] * self.yomega2bar[1,mif4] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[mif1,2] * self.ydbar[mif2,1] * self.yomega2[2,mif3] * self.yomega2bar[1,mif4] + 3/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,2] * self.yomega2[0,mif3] * self.yomega2bar[2,mif4] + 1/8 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,2] * self.yomega2[0,mif3] * self.yomega2bar[2,mif4] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[mif1,0] * self.ydbar[mif2,2] * self.yomega2[0,mif3] * self.yomega2bar[2,mif4] + 3/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,2] * self.yomega2[1,mif3] * self.yomega2bar[2,mif4] + 1/8 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,2] * self.yomega2[1,mif3] * self.yomega2bar[2,mif4] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[mif1,1] * self.ydbar[mif2,2] * self.yomega2[1,mif3] * self.yomega2bar[2,mif4] + -7/72 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[2,mif3] * self.yomega2bar[2,mif4] + -1/12 * (self.g3)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[2,mif3] * self.yomega2bar[2,mif4] + 1/12 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,mif3] * self.yomega2bar[2,mif4] + 3/16 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,2] * self.yomega2[2,mif3] * self.yomega2bar[2,mif4] + 1/8 * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,2] * self.yomega2[2,mif3] * self.yomega2bar[2,mif4] + -1/8 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yd[mif1,2] * self.ydbar[mif2,2] * self.yomega2[2,mif3] * self.yomega2bar[2,mif4] + 1/12 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[mif3,0] * self.yomega2bar[mif4,0] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,0] * self.yomega2[mif3,0] * self.yomega2bar[mif4,0] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,0] * self.yomega2[mif3,1] * self.yomega2bar[mif4,0] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,0] * self.yomega2[mif3,2] * self.yomega2bar[mif4,0] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,1] * self.yomega2[mif3,0] * self.yomega2bar[mif4,1] + 1/12 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[mif3,1] * self.yomega2bar[mif4,1] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,1] * self.yomega2[mif3,1] * self.yomega2bar[mif4,1] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,1] * self.yomega2[mif3,2] * self.yomega2bar[mif4,1] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,0] * self.ydbar[mif2,2] * self.yomega2[mif3,0] * self.yomega2bar[mif4,2] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,1] * self.ydbar[mif2,2] * self.yomega2[mif3,1] * self.yomega2bar[mif4,2] + 1/12 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[mif3,2] * self.yomega2bar[mif4,2] + -1/4 * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,2] * self.ydbar[mif2,2] * self.yomega2[mif3,2] * self.yomega2bar[mif4,2])

    def alphaOqe(self, mif1,mif2,mif3,mif4):
        return 1/2160 * (self.g1)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4)

    def alphaOqq1(self, mif1,mif2,mif3,mif4):
        return (-1/7680 * (self.g3)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.kronecker_delta(mif2,mif3) + -1/25920 * (self.g1)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 1/11520 * (self.g3)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4))

    def alphaOqq3(self, mif1,mif2,mif3,mif4):
        return -1/7680 * (self.g3)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.kronecker_delta(mif2,mif3)

    def alphaOqu1(self, mif1,mif2,mif3,mif4):
        return -1/3240 * (self.g1)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4)

    def alphaOqu8(self, mif1,mif2,mif3,mif4):
        return -1/960 * (self.g3)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4)

    def alphaOquqd1(self, mif1,mif2,mif3,mif4):
        return 0

    def alphaOquqd8(self, mif1,mif2,mif3,mif4):
        return 0

    def alphaOuB(self, mif1,mif2):
        return 0

    def alphaOud1(self, mif1,mif2,mif3,mif4):
        return (1/1620 * (self.g1)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + -13/162 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + -1/27 * (self.g1)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + 1/27 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + -13/162 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + -1/27 * (self.g1)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + 1/27 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + -13/162 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[2,mif3] * self.yomega2bar[2,mif4] + -1/27 * (self.g1)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[2,mif3] * self.yomega2bar[2,mif4] + 1/27 * (self.g1)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,mif3] * self.yomega2bar[2,mif4])

    def alphaOud8(self, mif1,mif2,mif3,mif4):
        return (-1/960 * (self.g3)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + -1/72 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + -1/12 * (self.g3)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + 1/12 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[0,mif3] * self.yomega2bar[0,mif4] + -1/72 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + -1/12 * (self.g3)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + 1/12 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[1,mif3] * self.yomega2bar[1,mif4] + -1/72 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[2,mif3] * self.yomega2bar[2,mif4] + -1/12 * (self.g3)**(2) * self.invepsilonbar * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yomega2[2,mif3] * self.yomega2bar[2,mif4] + 1/12 * (self.g3)**(2) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Momega2)**(2) * (self.mu)**(-2)) * self.yomega2[2,mif3] * self.yomega2bar[2,mif4])

    def alphaOuG(self, mif1,mif2):
        return 0

    def alphaOuH(self, mif1,mif2):
        return 0

    def alphaOuu(self, mif1,mif2,mif3,mif4):
        return (-1/3840 * (self.g3)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.kronecker_delta(mif2,mif3) + -1/1620 * (self.g1)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 1/11520 * (self.g3)**(4) * (self.Momega2)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4))

    def alphaOuW(self, mif1,mif2):
        return 0
