## Symbols used:
# ydbar
# yd
# yqqzeta
# yl
# ylbar
# yqqzetabar
# muH
# g1
# g2
# epsilonbar
# invepsilonbar
# Mzeta
# mu
# lam
# yubar
# yqlzetabar
# yqlzeta
# onelooporder
# g3
# lambdaHatPrimezeta
# yu
# lambdaHatzeta

import sys
import os
import numpy as np

import lsme.numeric.matchingresult as matchingresult

class GranadazetaMatchingResult(matchingresult.GenericMatchingResult):
    def __init__(self, name='zeta'):
        super().__init__(name)
        self.Mzeta = 1
        self.yqlzeta = np.ones((3, 3))
        self.yqlzetabar = np.ones((3, 3))
        self.yqqzeta = np.ones((3, 3))
        self.yqqzetabar = np.ones((3, 3))
        self.lambdaHatzeta = 1
        self.lambdaHatzetabar = 1
        self.lambdaHatPrimezeta = 1
        self.lambdaHatPrimezetabar = 1
        self.nonvanishing = ['alphaO3G', 'alphaO3W', 'alphaOH', 'alphaOHB', 'alphaOHBox', 'alphaOHD', 'alphaOHG', 'alphaOHW', 'alphaOHWB', 'alphaOdB', 'alphaOdd', 'alphaOdG', 'alphaOdH', 'alphaOdW', 'alphaOed', 'alphaOee', 'alphaOeH', 'alphaOeu', 'alphaOeW', 'alphaOHd', 'alphaOHe', 'alphaOHl1', 'alphaOHl3', 'alphaOHq1', 'alphaOHq3', 'alphaOHu', 'alphaOHud', 'alphaOld', 'alphaOle', 'alphaOledq', 'alphaOll', 'alphaOlq1', 'alphaOlq3', 'alphaOlu', 'alphaOqd1', 'alphaOqd8', 'alphaOqe', 'alphaOqq1', 'alphaOqq3', 'alphaOqu1', 'alphaOqu8', 'alphaOquqd1', 'alphaOquqd8', 'alphaOuB', 'alphaOud1', 'alphaOud8', 'alphaOuG', 'alphaOuH', 'alphaOuu', 'alphaOuW']

    def alphaO3G(self, ):
        return 1/1920 * (self.g3)**(3) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2)

    def alphaO3Gt(self, ):
        return 0

    def alphaO3W(self, ):
        return 1/480 * (self.g2)**(3) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2)

    def alphaO3Wt(self, ):
        return 0

    def alphaOH(self, ):
        return (-1/80 * (self.g2)**(4) * self.lam * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) + 1/8 * self.lam * (self.lambdaHatPrimezeta)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) + 3/32 * (self.lambdaHatPrimezeta)**(2) * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) + 3/32 * (self.lambdaHatzeta)**(3) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2))

    def alphaOHB(self, ):
        return -1/192 * (self.g1)**(2) * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2)

    def alphaOHBox(self, ):
        return (-1/3840 * (self.g1)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) + -3/640 * (self.g2)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) + 1/64 * (self.lambdaHatPrimezeta)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) + -3/64 * (self.lambdaHatzeta)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2))

    def alphaOHBt(self, ):
        return 0

    def alphaOHD(self, ):
        return (-1/960 * (self.g1)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) + -1/16 * (self.lambdaHatPrimezeta)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2))

    def alphaOHG(self, ):
        return -1/128 * (self.g3)**(2) * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2)

    def alphaOHGt(self, ):
        return 0

    def alphaOHW(self, ):
        return -1/32 * (self.g2)**(2) * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2)

    def alphaOHWB(self, ):
        return -1/48 * (2)**(-1/2) * self.g1 * self.g2 * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2)

    def alphaOHWBt(self, ):
        return 0

    def alphaOHWt(self, ):
        return 0

    def alphaWeinberg(self, mif1,mif2):
        return 0

    def alphaOdB(self, mif1,mif2):
        return (1/96 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] + 1/96 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] + 1/96 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] + 1/96 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] + 1/96 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] + 1/96 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] + 1/96 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] + 1/96 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] + 1/96 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] + -1/24 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,0] + -1/24 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,1] + -1/24 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,2] + -1/24 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,0] + -1/24 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,1] + -1/24 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,2] + -1/24 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,0] + -1/24 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,1] + -1/24 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,2])

    def alphaOdd(self, mif1,mif2,mif3,mif4):
        return (-1/1280 * (self.g3)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.kronecker_delta(mif2,mif3) + -1/8640 * (self.g1)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 1/3840 * (self.g3)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4))

    def alphaOdG(self, mif1,mif2):
        return (-1/128 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] + -1/128 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] + -1/128 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] + -1/128 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] + -1/128 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] + -1/128 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] + -1/128 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] + -1/128 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] + -1/128 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] + 1/32 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,0] + 1/32 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,1] + 1/32 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,2] + 1/32 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,0] + 1/32 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,1] + 1/32 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,2] + 1/32 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,0] + 1/32 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,1] + 1/32 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,2])

    def alphaOdH(self, mif1,mif2):
        return (-1/320 * (self.g2)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,mif2] + 1/32 * (self.lambdaHatPrimezeta)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[mif1,mif2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yqlzeta[0,0] * self.yqlzetabar[0,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yqlzeta[0,0] * self.yqlzetabar[0,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yqlzeta[0,0] * self.yqlzetabar[0,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yqlzeta[1,0] * self.yqlzetabar[0,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yqlzeta[1,0] * self.yqlzetabar[0,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yqlzeta[1,0] * self.yqlzetabar[0,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yqlzeta[2,0] * self.yqlzetabar[0,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yqlzeta[2,0] * self.yqlzetabar[0,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yqlzeta[2,0] * self.yqlzetabar[0,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yqlzeta[0,1] * self.yqlzetabar[0,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yqlzeta[0,1] * self.yqlzetabar[0,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yqlzeta[0,1] * self.yqlzetabar[0,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yqlzeta[1,1] * self.yqlzetabar[0,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yqlzeta[1,1] * self.yqlzetabar[0,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yqlzeta[1,1] * self.yqlzetabar[0,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yqlzeta[2,1] * self.yqlzetabar[0,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yqlzeta[2,1] * self.yqlzetabar[0,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yqlzeta[2,1] * self.yqlzetabar[0,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yqlzeta[0,2] * self.yqlzetabar[0,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yqlzeta[0,2] * self.yqlzetabar[0,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yqlzeta[0,2] * self.yqlzetabar[0,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yqlzeta[1,2] * self.yqlzetabar[0,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yqlzeta[1,2] * self.yqlzetabar[0,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yqlzeta[1,2] * self.yqlzetabar[0,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yqlzeta[2,2] * self.yqlzetabar[0,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yqlzeta[2,2] * self.yqlzetabar[0,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yqlzeta[2,2] * self.yqlzetabar[0,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yqlzeta[0,0] * self.yqlzetabar[1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yqlzeta[0,0] * self.yqlzetabar[1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yqlzeta[0,0] * self.yqlzetabar[1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yqlzeta[1,0] * self.yqlzetabar[1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yqlzeta[1,0] * self.yqlzetabar[1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yqlzeta[1,0] * self.yqlzetabar[1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yqlzeta[2,0] * self.yqlzetabar[1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yqlzeta[2,0] * self.yqlzetabar[1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yqlzeta[2,0] * self.yqlzetabar[1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yqlzeta[0,1] * self.yqlzetabar[1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yqlzeta[0,1] * self.yqlzetabar[1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yqlzeta[0,1] * self.yqlzetabar[1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yqlzeta[1,1] * self.yqlzetabar[1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yqlzeta[1,1] * self.yqlzetabar[1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yqlzeta[1,1] * self.yqlzetabar[1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yqlzeta[2,1] * self.yqlzetabar[1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yqlzeta[2,1] * self.yqlzetabar[1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yqlzeta[2,1] * self.yqlzetabar[1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yqlzeta[0,2] * self.yqlzetabar[1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yqlzeta[0,2] * self.yqlzetabar[1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yqlzeta[0,2] * self.yqlzetabar[1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yqlzeta[1,2] * self.yqlzetabar[1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yqlzeta[1,2] * self.yqlzetabar[1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yqlzeta[1,2] * self.yqlzetabar[1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yqlzeta[2,2] * self.yqlzetabar[1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yqlzeta[2,2] * self.yqlzetabar[1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yqlzeta[2,2] * self.yqlzetabar[1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yqlzeta[0,0] * self.yqlzetabar[2,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yqlzeta[0,0] * self.yqlzetabar[2,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yqlzeta[0,0] * self.yqlzetabar[2,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yqlzeta[1,0] * self.yqlzetabar[2,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yqlzeta[1,0] * self.yqlzetabar[2,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yqlzeta[1,0] * self.yqlzetabar[2,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yqlzeta[2,0] * self.yqlzetabar[2,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yqlzeta[2,0] * self.yqlzetabar[2,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yqlzeta[2,0] * self.yqlzetabar[2,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yqlzeta[0,1] * self.yqlzetabar[2,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yqlzeta[0,1] * self.yqlzetabar[2,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yqlzeta[0,1] * self.yqlzetabar[2,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yqlzeta[1,1] * self.yqlzetabar[2,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yqlzeta[1,1] * self.yqlzetabar[2,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yqlzeta[1,1] * self.yqlzetabar[2,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yqlzeta[2,1] * self.yqlzetabar[2,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yqlzeta[2,1] * self.yqlzetabar[2,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yqlzeta[2,1] * self.yqlzetabar[2,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yqlzeta[0,2] * self.yqlzetabar[2,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yqlzeta[0,2] * self.yqlzetabar[2,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yqlzeta[0,2] * self.yqlzetabar[2,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yqlzeta[1,2] * self.yqlzetabar[2,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yqlzeta[1,2] * self.yqlzetabar[2,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yqlzeta[1,2] * self.yqlzetabar[2,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yqlzeta[2,2] * self.yqlzetabar[2,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yqlzeta[2,2] * self.yqlzetabar[2,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yqlzeta[2,2] * self.yqlzetabar[2,2] + -1/32 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] + 3/64 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yl[0,0] * self.ylbar[0,0] * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yl[0,1] * self.ylbar[0,1] * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yl[0,2] * self.ylbar[0,2] * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yl[1,0] * self.ylbar[0,0] * self.yqlzeta[0,1] * self.yqlzetabar[mif1,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yl[1,1] * self.ylbar[0,1] * self.yqlzeta[0,1] * self.yqlzetabar[mif1,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yl[1,2] * self.ylbar[0,2] * self.yqlzeta[0,1] * self.yqlzetabar[mif1,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yl[2,0] * self.ylbar[0,0] * self.yqlzeta[0,2] * self.yqlzetabar[mif1,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yl[2,1] * self.ylbar[0,1] * self.yqlzeta[0,2] * self.yqlzetabar[mif1,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yl[2,2] * self.ylbar[0,2] * self.yqlzeta[0,2] * self.yqlzetabar[mif1,0] + -1/32 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] + 3/64 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yl[0,0] * self.ylbar[0,0] * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yl[0,1] * self.ylbar[0,1] * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yl[0,2] * self.ylbar[0,2] * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yl[1,0] * self.ylbar[0,0] * self.yqlzeta[1,1] * self.yqlzetabar[mif1,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yl[1,1] * self.ylbar[0,1] * self.yqlzeta[1,1] * self.yqlzetabar[mif1,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yl[1,2] * self.ylbar[0,2] * self.yqlzeta[1,1] * self.yqlzetabar[mif1,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yl[2,0] * self.ylbar[0,0] * self.yqlzeta[1,2] * self.yqlzetabar[mif1,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yl[2,1] * self.ylbar[0,1] * self.yqlzeta[1,2] * self.yqlzetabar[mif1,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yl[2,2] * self.ylbar[0,2] * self.yqlzeta[1,2] * self.yqlzetabar[mif1,0] + -1/32 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] + 3/64 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yl[0,0] * self.ylbar[0,0] * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yl[0,1] * self.ylbar[0,1] * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yl[0,2] * self.ylbar[0,2] * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yl[1,0] * self.ylbar[0,0] * self.yqlzeta[2,1] * self.yqlzetabar[mif1,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yl[1,1] * self.ylbar[0,1] * self.yqlzeta[2,1] * self.yqlzetabar[mif1,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yl[1,2] * self.ylbar[0,2] * self.yqlzeta[2,1] * self.yqlzetabar[mif1,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yl[2,0] * self.ylbar[0,0] * self.yqlzeta[2,2] * self.yqlzetabar[mif1,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yl[2,1] * self.ylbar[0,1] * self.yqlzeta[2,2] * self.yqlzetabar[mif1,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yl[2,2] * self.ylbar[0,2] * self.yqlzeta[2,2] * self.yqlzetabar[mif1,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yl[0,0] * self.ylbar[1,0] * self.yqlzeta[0,0] * self.yqlzetabar[mif1,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yl[0,1] * self.ylbar[1,1] * self.yqlzeta[0,0] * self.yqlzetabar[mif1,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yl[0,2] * self.ylbar[1,2] * self.yqlzeta[0,0] * self.yqlzetabar[mif1,1] + -1/32 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] + 3/64 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yl[1,0] * self.ylbar[1,0] * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yl[1,1] * self.ylbar[1,1] * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yl[1,2] * self.ylbar[1,2] * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yl[2,0] * self.ylbar[1,0] * self.yqlzeta[0,2] * self.yqlzetabar[mif1,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yl[2,1] * self.ylbar[1,1] * self.yqlzeta[0,2] * self.yqlzetabar[mif1,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yl[2,2] * self.ylbar[1,2] * self.yqlzeta[0,2] * self.yqlzetabar[mif1,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yl[0,0] * self.ylbar[1,0] * self.yqlzeta[1,0] * self.yqlzetabar[mif1,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yl[0,1] * self.ylbar[1,1] * self.yqlzeta[1,0] * self.yqlzetabar[mif1,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yl[0,2] * self.ylbar[1,2] * self.yqlzeta[1,0] * self.yqlzetabar[mif1,1] + -1/32 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] + 3/64 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yl[1,0] * self.ylbar[1,0] * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yl[1,1] * self.ylbar[1,1] * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yl[1,2] * self.ylbar[1,2] * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yl[2,0] * self.ylbar[1,0] * self.yqlzeta[1,2] * self.yqlzetabar[mif1,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yl[2,1] * self.ylbar[1,1] * self.yqlzeta[1,2] * self.yqlzetabar[mif1,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yl[2,2] * self.ylbar[1,2] * self.yqlzeta[1,2] * self.yqlzetabar[mif1,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yl[0,0] * self.ylbar[1,0] * self.yqlzeta[2,0] * self.yqlzetabar[mif1,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yl[0,1] * self.ylbar[1,1] * self.yqlzeta[2,0] * self.yqlzetabar[mif1,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yl[0,2] * self.ylbar[1,2] * self.yqlzeta[2,0] * self.yqlzetabar[mif1,1] + -1/32 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] + 3/64 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yl[1,0] * self.ylbar[1,0] * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yl[1,1] * self.ylbar[1,1] * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yl[1,2] * self.ylbar[1,2] * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yl[2,0] * self.ylbar[1,0] * self.yqlzeta[2,2] * self.yqlzetabar[mif1,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yl[2,1] * self.ylbar[1,1] * self.yqlzeta[2,2] * self.yqlzetabar[mif1,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yl[2,2] * self.ylbar[1,2] * self.yqlzeta[2,2] * self.yqlzetabar[mif1,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yl[0,0] * self.ylbar[2,0] * self.yqlzeta[0,0] * self.yqlzetabar[mif1,2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yl[0,1] * self.ylbar[2,1] * self.yqlzeta[0,0] * self.yqlzetabar[mif1,2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yl[0,2] * self.ylbar[2,2] * self.yqlzeta[0,0] * self.yqlzetabar[mif1,2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yl[1,0] * self.ylbar[2,0] * self.yqlzeta[0,1] * self.yqlzetabar[mif1,2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yl[1,1] * self.ylbar[2,1] * self.yqlzeta[0,1] * self.yqlzetabar[mif1,2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yl[1,2] * self.ylbar[2,2] * self.yqlzeta[0,1] * self.yqlzetabar[mif1,2] + -1/32 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] + 3/64 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yl[2,0] * self.ylbar[2,0] * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yl[2,1] * self.ylbar[2,1] * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yl[2,2] * self.ylbar[2,2] * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yl[0,0] * self.ylbar[2,0] * self.yqlzeta[1,0] * self.yqlzetabar[mif1,2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yl[0,1] * self.ylbar[2,1] * self.yqlzeta[1,0] * self.yqlzetabar[mif1,2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yl[0,2] * self.ylbar[2,2] * self.yqlzeta[1,0] * self.yqlzetabar[mif1,2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yl[1,0] * self.ylbar[2,0] * self.yqlzeta[1,1] * self.yqlzetabar[mif1,2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yl[1,1] * self.ylbar[2,1] * self.yqlzeta[1,1] * self.yqlzetabar[mif1,2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yl[1,2] * self.ylbar[2,2] * self.yqlzeta[1,1] * self.yqlzetabar[mif1,2] + -1/32 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] + 3/64 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yl[2,0] * self.ylbar[2,0] * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yl[2,1] * self.ylbar[2,1] * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yl[2,2] * self.ylbar[2,2] * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yl[0,0] * self.ylbar[2,0] * self.yqlzeta[2,0] * self.yqlzetabar[mif1,2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yl[0,1] * self.ylbar[2,1] * self.yqlzeta[2,0] * self.yqlzetabar[mif1,2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yl[0,2] * self.ylbar[2,2] * self.yqlzeta[2,0] * self.yqlzetabar[mif1,2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yl[1,0] * self.ylbar[2,0] * self.yqlzeta[2,1] * self.yqlzetabar[mif1,2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yl[1,1] * self.ylbar[2,1] * self.yqlzeta[2,1] * self.yqlzetabar[mif1,2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yl[1,2] * self.ylbar[2,2] * self.yqlzeta[2,1] * self.yqlzetabar[mif1,2] + -1/32 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] + 3/64 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yl[2,0] * self.ylbar[2,0] * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yl[2,1] * self.ylbar[2,1] * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yl[2,2] * self.ylbar[2,2] * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yqqzeta[0,0] * self.yqqzetabar[0,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yqqzeta[0,0] * self.yqqzetabar[0,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yqqzeta[0,0] * self.yqqzetabar[0,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yqqzeta[0,1] * self.yqqzetabar[0,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yqqzeta[0,1] * self.yqqzetabar[0,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yqqzeta[0,1] * self.yqqzetabar[0,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yqqzeta[0,2] * self.yqqzetabar[0,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yqqzeta[0,2] * self.yqqzetabar[0,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yqqzeta[0,2] * self.yqqzetabar[0,0] + 1/4 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,0] + 3/8 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.yd[0,mif2] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.yd[0,mif2] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.yd[0,mif2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.yd[0,mif2] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.yd[0,mif2] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.yd[0,mif2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.yd[0,mif2] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.yd[0,mif2] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.yd[0,mif2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yqqzeta[0,0] * self.yqqzetabar[0,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yqqzeta[0,0] * self.yqqzetabar[0,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yqqzeta[0,0] * self.yqqzetabar[0,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yqqzeta[0,1] * self.yqqzetabar[0,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yqqzeta[0,1] * self.yqqzetabar[0,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yqqzeta[0,1] * self.yqqzetabar[0,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yqqzeta[0,2] * self.yqqzetabar[0,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yqqzeta[0,2] * self.yqqzetabar[0,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yqqzeta[0,2] * self.yqqzetabar[0,1] + 1/4 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,1] + 3/8 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.yd[1,mif2] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.yd[1,mif2] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.yd[1,mif2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.yd[1,mif2] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.yd[1,mif2] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.yd[1,mif2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.yd[1,mif2] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.yd[1,mif2] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.yd[1,mif2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yqqzeta[0,0] * self.yqqzetabar[0,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yqqzeta[0,0] * self.yqqzetabar[0,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yqqzeta[0,0] * self.yqqzetabar[0,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yqqzeta[0,1] * self.yqqzetabar[0,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yqqzeta[0,1] * self.yqqzetabar[0,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yqqzeta[0,1] * self.yqqzetabar[0,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yqqzeta[0,2] * self.yqqzetabar[0,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yqqzeta[0,2] * self.yqqzetabar[0,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yqqzeta[0,2] * self.yqqzetabar[0,2] + 1/4 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,2] + 3/8 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.yd[2,mif2] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.yd[2,mif2] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.yd[2,mif2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.yd[2,mif2] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.yd[2,mif2] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.yd[2,mif2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.yd[2,mif2] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.yd[2,mif2] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.yd[2,mif2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[1,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[1,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[1,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yqqzeta[1,0] * self.yqqzetabar[1,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yqqzeta[1,0] * self.yqqzetabar[1,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yqqzeta[1,0] * self.yqqzetabar[1,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yqqzeta[1,1] * self.yqqzetabar[1,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yqqzeta[1,1] * self.yqqzetabar[1,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yqqzeta[1,1] * self.yqqzetabar[1,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yqqzeta[1,2] * self.yqqzetabar[1,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yqqzeta[1,2] * self.yqqzetabar[1,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yqqzeta[1,2] * self.yqqzetabar[1,0] + 1/4 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,0] + 3/8 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[1,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[1,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[1,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[1,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[1,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[1,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.yd[1,mif2] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.yd[1,mif2] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.yd[1,mif2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yqqzeta[1,0] * self.yqqzetabar[1,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yqqzeta[1,0] * self.yqqzetabar[1,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yqqzeta[1,0] * self.yqqzetabar[1,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yqqzeta[1,1] * self.yqqzetabar[1,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yqqzeta[1,1] * self.yqqzetabar[1,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yqqzeta[1,1] * self.yqqzetabar[1,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yqqzeta[1,2] * self.yqqzetabar[1,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yqqzeta[1,2] * self.yqqzetabar[1,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yqqzeta[1,2] * self.yqqzetabar[1,1] + 1/4 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,1] + 3/8 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.yd[1,mif2] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.yd[1,mif2] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.yd[1,mif2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.yd[1,mif2] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.yd[1,mif2] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.yd[1,mif2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.yd[2,mif2] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.yd[2,mif2] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.yd[2,mif2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yqqzeta[1,0] * self.yqqzetabar[1,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yqqzeta[1,0] * self.yqqzetabar[1,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yqqzeta[1,0] * self.yqqzetabar[1,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yqqzeta[1,1] * self.yqqzetabar[1,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yqqzeta[1,1] * self.yqqzetabar[1,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yqqzeta[1,1] * self.yqqzetabar[1,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yqqzeta[1,2] * self.yqqzetabar[1,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yqqzeta[1,2] * self.yqqzetabar[1,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yqqzeta[1,2] * self.yqqzetabar[1,2] + 1/4 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,2] + 3/8 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.yd[2,mif2] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.yd[2,mif2] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.yd[2,mif2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.yd[2,mif2] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.yd[2,mif2] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.yd[2,mif2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[2,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[2,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[2,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[2,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[2,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[2,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yqqzeta[2,0] * self.yqqzetabar[2,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yqqzeta[2,0] * self.yqqzetabar[2,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yqqzeta[2,0] * self.yqqzetabar[2,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yqqzeta[2,1] * self.yqqzetabar[2,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yqqzeta[2,1] * self.yqqzetabar[2,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yqqzeta[2,1] * self.yqqzetabar[2,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yqqzeta[2,2] * self.yqqzetabar[2,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yqqzeta[2,2] * self.yqqzetabar[2,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yqqzeta[2,2] * self.yqqzetabar[2,0] + 1/4 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,0] + 3/8 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[2,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[2,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yd[2,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[2,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[2,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[2,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[2,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[2,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[2,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yqqzeta[2,0] * self.yqqzetabar[2,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yqqzeta[2,0] * self.yqqzetabar[2,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yqqzeta[2,0] * self.yqqzetabar[2,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yqqzeta[2,1] * self.yqqzetabar[2,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yqqzeta[2,1] * self.yqqzetabar[2,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yqqzeta[2,1] * self.yqqzetabar[2,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yqqzeta[2,2] * self.yqqzetabar[2,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yqqzeta[2,2] * self.yqqzetabar[2,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yqqzeta[2,2] * self.yqqzetabar[2,1] + 1/4 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,1] + 3/8 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[2,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[2,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yd[2,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.yd[2,mif2] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.yd[2,mif2] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.yd[2,mif2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.yd[2,mif2] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.yd[2,mif2] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.yd[2,mif2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[0,0] * self.yqqzeta[2,0] * self.yqqzetabar[2,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[0,1] * self.yqqzeta[2,0] * self.yqqzetabar[2,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[0,2] * self.yqqzeta[2,0] * self.yqqzetabar[2,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[1,0] * self.yqqzeta[2,1] * self.yqqzetabar[2,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[1,1] * self.yqqzeta[2,1] * self.yqqzetabar[2,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[1,2] * self.yqqzeta[2,1] * self.yqqzetabar[2,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,0] * self.ydbar[2,0] * self.yqqzeta[2,2] * self.yqqzetabar[2,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,1] * self.ydbar[2,1] * self.yqqzeta[2,2] * self.yqqzetabar[2,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yd[mif1,2] * self.ydbar[2,2] * self.yqqzeta[2,2] * self.yqqzetabar[2,2] + 1/4 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,2] + 3/8 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.yd[2,mif2] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.yd[2,mif2] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.yd[2,mif2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,0] * self.yu[0,0] * self.yubar[0,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,1] * self.yu[0,0] * self.yubar[0,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,2] * self.yu[0,0] * self.yubar[0,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,0] * self.yu[1,0] * self.yubar[0,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,1] * self.yu[1,0] * self.yubar[0,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,2] * self.yu[1,0] * self.yubar[0,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,0] * self.yu[2,0] * self.yubar[0,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,1] * self.yu[2,0] * self.yubar[0,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,2] * self.yu[2,0] * self.yubar[0,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,0] * self.yu[0,1] * self.yubar[0,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,1] * self.yu[0,1] * self.yubar[0,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,2] * self.yu[0,1] * self.yubar[0,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,0] * self.yu[1,1] * self.yubar[0,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,1] * self.yu[1,1] * self.yubar[0,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,2] * self.yu[1,1] * self.yubar[0,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,0] * self.yu[2,1] * self.yubar[0,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,1] * self.yu[2,1] * self.yubar[0,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,2] * self.yu[2,1] * self.yubar[0,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,0] * self.yu[0,2] * self.yubar[0,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,1] * self.yu[0,2] * self.yubar[0,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,2] * self.yu[0,2] * self.yubar[0,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,0] * self.yu[1,2] * self.yubar[0,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,1] * self.yu[1,2] * self.yubar[0,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,2] * self.yu[1,2] * self.yubar[0,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,0] * self.yu[2,2] * self.yubar[0,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,1] * self.yu[2,2] * self.yubar[0,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,2] * self.yu[2,2] * self.yubar[0,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,0] * self.yu[0,0] * self.yubar[1,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,1] * self.yu[0,0] * self.yubar[1,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,2] * self.yu[0,0] * self.yubar[1,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,0] * self.yu[1,0] * self.yubar[1,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,1] * self.yu[1,0] * self.yubar[1,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,2] * self.yu[1,0] * self.yubar[1,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,0] * self.yu[2,0] * self.yubar[1,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,1] * self.yu[2,0] * self.yubar[1,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,2] * self.yu[2,0] * self.yubar[1,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,0] * self.yu[0,1] * self.yubar[1,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,1] * self.yu[0,1] * self.yubar[1,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,2] * self.yu[0,1] * self.yubar[1,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,0] * self.yu[1,1] * self.yubar[1,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,1] * self.yu[1,1] * self.yubar[1,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,2] * self.yu[1,1] * self.yubar[1,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,0] * self.yu[2,1] * self.yubar[1,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,1] * self.yu[2,1] * self.yubar[1,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,2] * self.yu[2,1] * self.yubar[1,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,0] * self.yu[0,2] * self.yubar[1,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,1] * self.yu[0,2] * self.yubar[1,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,2] * self.yu[0,2] * self.yubar[1,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,0] * self.yu[1,2] * self.yubar[1,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,1] * self.yu[1,2] * self.yubar[1,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,2] * self.yu[1,2] * self.yubar[1,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,0] * self.yu[2,2] * self.yubar[1,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,1] * self.yu[2,2] * self.yubar[1,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,2] * self.yu[2,2] * self.yubar[1,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,0] * self.yu[0,0] * self.yubar[2,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,1] * self.yu[0,0] * self.yubar[2,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,2] * self.yu[0,0] * self.yubar[2,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,0] * self.yu[1,0] * self.yubar[2,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,1] * self.yu[1,0] * self.yubar[2,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,2] * self.yu[1,0] * self.yubar[2,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,0] * self.yu[2,0] * self.yubar[2,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,1] * self.yu[2,0] * self.yubar[2,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,2] * self.yu[2,0] * self.yubar[2,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,0] * self.yu[0,1] * self.yubar[2,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,1] * self.yu[0,1] * self.yubar[2,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,2] * self.yu[0,1] * self.yubar[2,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,0] * self.yu[1,1] * self.yubar[2,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,1] * self.yu[1,1] * self.yubar[2,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,2] * self.yu[1,1] * self.yubar[2,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,0] * self.yu[2,1] * self.yubar[2,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,1] * self.yu[2,1] * self.yubar[2,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,2] * self.yu[2,1] * self.yubar[2,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,0] * self.yu[0,2] * self.yubar[2,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,1] * self.yu[0,2] * self.yubar[2,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,2] * self.yu[0,2] * self.yubar[2,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,0] * self.yu[1,2] * self.yubar[2,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,1] * self.yu[1,2] * self.yubar[2,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,2] * self.yu[1,2] * self.yubar[2,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,0] * self.yu[2,2] * self.yubar[2,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,1] * self.yu[2,2] * self.yubar[2,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,2] * self.yu[2,2] * self.yubar[2,2])

    def alphaOdW(self, mif1,mif2):
        return (-1/128 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] + -1/128 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] + -1/128 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] + -1/128 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] + -1/128 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] + -1/128 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] + -1/128 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] + -1/128 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] + -1/128 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] + -1/16 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,0] + -1/16 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,1] + -1/16 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,2] + -1/16 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,0] + -1/16 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,1] + -1/16 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,2] + -1/16 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,0] + -1/16 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,1] + -1/16 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,2])

    def alphaOeB(self, mif1,mif2):
        return 0

    def alphaOed(self, mif1,mif2,mif3,mif4):
        return -1/1440 * (self.g1)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4)

    def alphaOee(self, mif1,mif2,mif3,mif4):
        return -1/960 * (self.g1)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4)

    def alphaOeH(self, mif1,mif2):
        return (-1/320 * (self.g2)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,mif2] + 1/32 * (self.lambdaHatPrimezeta)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[mif1,mif2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[0,0] * self.yqlzeta[0,0] * self.yqlzetabar[0,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[0,1] * self.yqlzeta[0,0] * self.yqlzetabar[0,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[0,2] * self.yqlzeta[0,0] * self.yqlzetabar[0,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[0,0] * self.yqlzeta[0,1] * self.yqlzetabar[0,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[0,1] * self.yqlzeta[0,1] * self.yqlzetabar[0,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[0,2] * self.yqlzeta[0,1] * self.yqlzetabar[0,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[0,0] * self.yqlzeta[0,2] * self.yqlzetabar[0,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[0,1] * self.yqlzeta[0,2] * self.yqlzetabar[0,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[0,2] * self.yqlzeta[0,2] * self.yqlzetabar[0,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[1,0] * self.yqlzeta[0,0] * self.yqlzetabar[0,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[1,1] * self.yqlzeta[0,0] * self.yqlzetabar[0,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[1,2] * self.yqlzeta[0,0] * self.yqlzetabar[0,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[1,0] * self.yqlzeta[0,1] * self.yqlzetabar[0,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[1,1] * self.yqlzeta[0,1] * self.yqlzetabar[0,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[1,2] * self.yqlzeta[0,1] * self.yqlzetabar[0,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[1,0] * self.yqlzeta[0,2] * self.yqlzetabar[0,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[1,1] * self.yqlzeta[0,2] * self.yqlzetabar[0,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[1,2] * self.yqlzeta[0,2] * self.yqlzetabar[0,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[2,0] * self.yqlzeta[0,0] * self.yqlzetabar[0,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[2,1] * self.yqlzeta[0,0] * self.yqlzetabar[0,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[2,2] * self.yqlzeta[0,0] * self.yqlzetabar[0,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[2,0] * self.yqlzeta[0,1] * self.yqlzetabar[0,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[2,1] * self.yqlzeta[0,1] * self.yqlzetabar[0,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[2,2] * self.yqlzeta[0,1] * self.yqlzetabar[0,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[2,0] * self.yqlzeta[0,2] * self.yqlzetabar[0,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[2,1] * self.yqlzeta[0,2] * self.yqlzetabar[0,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[2,2] * self.yqlzeta[0,2] * self.yqlzetabar[0,2] + -3/32 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[0,0] * self.yqlzetabar[0,mif1] + 9/64 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[0,0] * self.yqlzetabar[0,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,0] * self.yl[0,mif2] * self.yqlzeta[0,0] * self.yqlzetabar[0,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,1] * self.yl[0,mif2] * self.yqlzeta[0,0] * self.yqlzetabar[0,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,2] * self.yl[0,mif2] * self.yqlzeta[0,0] * self.yqlzetabar[0,mif1] + -3/32 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[0,1] * self.yqlzetabar[0,mif1] + 9/64 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[0,1] * self.yqlzetabar[0,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,0] * self.yl[1,mif2] * self.yqlzeta[0,1] * self.yqlzetabar[0,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,1] * self.yl[1,mif2] * self.yqlzeta[0,1] * self.yqlzetabar[0,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,2] * self.yl[1,mif2] * self.yqlzeta[0,1] * self.yqlzetabar[0,mif1] + -3/32 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[0,2] * self.yqlzetabar[0,mif1] + 9/64 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[0,2] * self.yqlzetabar[0,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,0] * self.yl[2,mif2] * self.yqlzeta[0,2] * self.yqlzetabar[0,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,1] * self.yl[2,mif2] * self.yqlzeta[0,2] * self.yqlzetabar[0,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,2] * self.yl[2,mif2] * self.yqlzeta[0,2] * self.yqlzetabar[0,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[0,0] * self.yl[0,mif2] * self.yqlzeta[1,0] * self.yqlzetabar[0,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[0,1] * self.yl[0,mif2] * self.yqlzeta[1,0] * self.yqlzetabar[0,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[0,2] * self.yl[0,mif2] * self.yqlzeta[1,0] * self.yqlzetabar[0,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[0,0] * self.yl[1,mif2] * self.yqlzeta[1,1] * self.yqlzetabar[0,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[0,1] * self.yl[1,mif2] * self.yqlzeta[1,1] * self.yqlzetabar[0,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[0,2] * self.yl[1,mif2] * self.yqlzeta[1,1] * self.yqlzetabar[0,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[0,0] * self.yl[2,mif2] * self.yqlzeta[1,2] * self.yqlzetabar[0,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[0,1] * self.yl[2,mif2] * self.yqlzeta[1,2] * self.yqlzetabar[0,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[0,2] * self.yl[2,mif2] * self.yqlzeta[1,2] * self.yqlzetabar[0,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[0,0] * self.yl[0,mif2] * self.yqlzeta[2,0] * self.yqlzetabar[0,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[0,1] * self.yl[0,mif2] * self.yqlzeta[2,0] * self.yqlzetabar[0,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[0,2] * self.yl[0,mif2] * self.yqlzeta[2,0] * self.yqlzetabar[0,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[0,0] * self.yl[1,mif2] * self.yqlzeta[2,1] * self.yqlzetabar[0,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[0,1] * self.yl[1,mif2] * self.yqlzeta[2,1] * self.yqlzetabar[0,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[0,2] * self.yl[1,mif2] * self.yqlzeta[2,1] * self.yqlzetabar[0,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[0,0] * self.yl[2,mif2] * self.yqlzeta[2,2] * self.yqlzetabar[0,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[0,1] * self.yl[2,mif2] * self.yqlzeta[2,2] * self.yqlzetabar[0,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[0,2] * self.yl[2,mif2] * self.yqlzeta[2,2] * self.yqlzetabar[0,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[0,0] * self.yqlzeta[1,0] * self.yqlzetabar[1,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[0,1] * self.yqlzeta[1,0] * self.yqlzetabar[1,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[0,2] * self.yqlzeta[1,0] * self.yqlzetabar[1,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[0,0] * self.yqlzeta[1,1] * self.yqlzetabar[1,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[0,1] * self.yqlzeta[1,1] * self.yqlzetabar[1,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[0,2] * self.yqlzeta[1,1] * self.yqlzetabar[1,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[0,0] * self.yqlzeta[1,2] * self.yqlzetabar[1,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[0,1] * self.yqlzeta[1,2] * self.yqlzetabar[1,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[0,2] * self.yqlzeta[1,2] * self.yqlzetabar[1,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[1,0] * self.yqlzeta[1,0] * self.yqlzetabar[1,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[1,1] * self.yqlzeta[1,0] * self.yqlzetabar[1,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[1,2] * self.yqlzeta[1,0] * self.yqlzetabar[1,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[1,0] * self.yqlzeta[1,1] * self.yqlzetabar[1,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[1,1] * self.yqlzeta[1,1] * self.yqlzetabar[1,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[1,2] * self.yqlzeta[1,1] * self.yqlzetabar[1,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[1,0] * self.yqlzeta[1,2] * self.yqlzetabar[1,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[1,1] * self.yqlzeta[1,2] * self.yqlzetabar[1,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[1,2] * self.yqlzeta[1,2] * self.yqlzetabar[1,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[2,0] * self.yqlzeta[1,0] * self.yqlzetabar[1,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[2,1] * self.yqlzeta[1,0] * self.yqlzetabar[1,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[2,2] * self.yqlzeta[1,0] * self.yqlzetabar[1,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[2,0] * self.yqlzeta[1,1] * self.yqlzetabar[1,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[2,1] * self.yqlzeta[1,1] * self.yqlzetabar[1,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[2,2] * self.yqlzeta[1,1] * self.yqlzetabar[1,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[2,0] * self.yqlzeta[1,2] * self.yqlzetabar[1,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[2,1] * self.yqlzeta[1,2] * self.yqlzetabar[1,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[2,2] * self.yqlzeta[1,2] * self.yqlzetabar[1,2] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[1,0] * self.yl[0,mif2] * self.yqlzeta[0,0] * self.yqlzetabar[1,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[1,1] * self.yl[0,mif2] * self.yqlzeta[0,0] * self.yqlzetabar[1,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[1,2] * self.yl[0,mif2] * self.yqlzeta[0,0] * self.yqlzetabar[1,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[1,0] * self.yl[1,mif2] * self.yqlzeta[0,1] * self.yqlzetabar[1,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[1,1] * self.yl[1,mif2] * self.yqlzeta[0,1] * self.yqlzetabar[1,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[1,2] * self.yl[1,mif2] * self.yqlzeta[0,1] * self.yqlzetabar[1,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[1,0] * self.yl[2,mif2] * self.yqlzeta[0,2] * self.yqlzetabar[1,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[1,1] * self.yl[2,mif2] * self.yqlzeta[0,2] * self.yqlzetabar[1,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[1,2] * self.yl[2,mif2] * self.yqlzeta[0,2] * self.yqlzetabar[1,mif1] + -3/32 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[1,0] * self.yqlzetabar[1,mif1] + 9/64 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[1,0] * self.yqlzetabar[1,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,0] * self.yl[0,mif2] * self.yqlzeta[1,0] * self.yqlzetabar[1,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,1] * self.yl[0,mif2] * self.yqlzeta[1,0] * self.yqlzetabar[1,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,2] * self.yl[0,mif2] * self.yqlzeta[1,0] * self.yqlzetabar[1,mif1] + -3/32 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[1,1] * self.yqlzetabar[1,mif1] + 9/64 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[1,1] * self.yqlzetabar[1,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,0] * self.yl[1,mif2] * self.yqlzeta[1,1] * self.yqlzetabar[1,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,1] * self.yl[1,mif2] * self.yqlzeta[1,1] * self.yqlzetabar[1,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,2] * self.yl[1,mif2] * self.yqlzeta[1,1] * self.yqlzetabar[1,mif1] + -3/32 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[1,2] * self.yqlzetabar[1,mif1] + 9/64 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[1,2] * self.yqlzetabar[1,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,0] * self.yl[2,mif2] * self.yqlzeta[1,2] * self.yqlzetabar[1,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,1] * self.yl[2,mif2] * self.yqlzeta[1,2] * self.yqlzetabar[1,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,2] * self.yl[2,mif2] * self.yqlzeta[1,2] * self.yqlzetabar[1,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[1,0] * self.yl[0,mif2] * self.yqlzeta[2,0] * self.yqlzetabar[1,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[1,1] * self.yl[0,mif2] * self.yqlzeta[2,0] * self.yqlzetabar[1,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[1,2] * self.yl[0,mif2] * self.yqlzeta[2,0] * self.yqlzetabar[1,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[1,0] * self.yl[1,mif2] * self.yqlzeta[2,1] * self.yqlzetabar[1,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[1,1] * self.yl[1,mif2] * self.yqlzeta[2,1] * self.yqlzetabar[1,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[1,2] * self.yl[1,mif2] * self.yqlzeta[2,1] * self.yqlzetabar[1,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[1,0] * self.yl[2,mif2] * self.yqlzeta[2,2] * self.yqlzetabar[1,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[1,1] * self.yl[2,mif2] * self.yqlzeta[2,2] * self.yqlzetabar[1,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[1,2] * self.yl[2,mif2] * self.yqlzeta[2,2] * self.yqlzetabar[1,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[0,0] * self.yqlzeta[2,0] * self.yqlzetabar[2,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[0,1] * self.yqlzeta[2,0] * self.yqlzetabar[2,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[0,2] * self.yqlzeta[2,0] * self.yqlzetabar[2,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[0,0] * self.yqlzeta[2,1] * self.yqlzetabar[2,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[0,1] * self.yqlzeta[2,1] * self.yqlzetabar[2,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[0,2] * self.yqlzeta[2,1] * self.yqlzetabar[2,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[0,0] * self.yqlzeta[2,2] * self.yqlzetabar[2,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[0,1] * self.yqlzeta[2,2] * self.yqlzetabar[2,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[0,2] * self.yqlzeta[2,2] * self.yqlzetabar[2,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[1,0] * self.yqlzeta[2,0] * self.yqlzetabar[2,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[1,1] * self.yqlzeta[2,0] * self.yqlzetabar[2,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[1,2] * self.yqlzeta[2,0] * self.yqlzetabar[2,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[1,0] * self.yqlzeta[2,1] * self.yqlzetabar[2,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[1,1] * self.yqlzeta[2,1] * self.yqlzetabar[2,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[1,2] * self.yqlzeta[2,1] * self.yqlzetabar[2,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[1,0] * self.yqlzeta[2,2] * self.yqlzetabar[2,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[1,1] * self.yqlzeta[2,2] * self.yqlzetabar[2,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[1,2] * self.yqlzeta[2,2] * self.yqlzetabar[2,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,0] * self.ylbar[2,0] * self.yqlzeta[2,0] * self.yqlzetabar[2,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,1] * self.ylbar[2,1] * self.yqlzeta[2,0] * self.yqlzetabar[2,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yl[mif1,2] * self.ylbar[2,2] * self.yqlzeta[2,0] * self.yqlzetabar[2,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,0] * self.ylbar[2,0] * self.yqlzeta[2,1] * self.yqlzetabar[2,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,1] * self.ylbar[2,1] * self.yqlzeta[2,1] * self.yqlzetabar[2,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yl[mif1,2] * self.ylbar[2,2] * self.yqlzeta[2,1] * self.yqlzetabar[2,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,0] * self.ylbar[2,0] * self.yqlzeta[2,2] * self.yqlzetabar[2,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,1] * self.ylbar[2,1] * self.yqlzeta[2,2] * self.yqlzetabar[2,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yl[mif1,2] * self.ylbar[2,2] * self.yqlzeta[2,2] * self.yqlzetabar[2,2] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[2,0] * self.yl[0,mif2] * self.yqlzeta[0,0] * self.yqlzetabar[2,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[2,1] * self.yl[0,mif2] * self.yqlzeta[0,0] * self.yqlzetabar[2,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[2,2] * self.yl[0,mif2] * self.yqlzeta[0,0] * self.yqlzetabar[2,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[2,0] * self.yl[1,mif2] * self.yqlzeta[0,1] * self.yqlzetabar[2,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[2,1] * self.yl[1,mif2] * self.yqlzeta[0,1] * self.yqlzetabar[2,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[2,2] * self.yl[1,mif2] * self.yqlzeta[0,1] * self.yqlzetabar[2,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[2,0] * self.yl[2,mif2] * self.yqlzeta[0,2] * self.yqlzetabar[2,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[2,1] * self.yl[2,mif2] * self.yqlzeta[0,2] * self.yqlzetabar[2,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[2,2] * self.yl[2,mif2] * self.yqlzeta[0,2] * self.yqlzetabar[2,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[2,0] * self.yl[0,mif2] * self.yqlzeta[1,0] * self.yqlzetabar[2,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[2,1] * self.yl[0,mif2] * self.yqlzeta[1,0] * self.yqlzetabar[2,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[2,2] * self.yl[0,mif2] * self.yqlzeta[1,0] * self.yqlzetabar[2,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[2,0] * self.yl[1,mif2] * self.yqlzeta[1,1] * self.yqlzetabar[2,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[2,1] * self.yl[1,mif2] * self.yqlzeta[1,1] * self.yqlzetabar[2,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[2,2] * self.yl[1,mif2] * self.yqlzeta[1,1] * self.yqlzetabar[2,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[2,0] * self.yl[2,mif2] * self.yqlzeta[1,2] * self.yqlzetabar[2,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[2,1] * self.yl[2,mif2] * self.yqlzeta[1,2] * self.yqlzetabar[2,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[2,2] * self.yl[2,mif2] * self.yqlzeta[1,2] * self.yqlzetabar[2,mif1] + -3/32 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[2,0] * self.yqlzetabar[2,mif1] + 9/64 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[2,0] * self.yqlzetabar[2,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,0] * self.yl[0,mif2] * self.yqlzeta[2,0] * self.yqlzetabar[2,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,1] * self.yl[0,mif2] * self.yqlzeta[2,0] * self.yqlzetabar[2,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,2] * self.yl[0,mif2] * self.yqlzeta[2,0] * self.yqlzetabar[2,mif1] + -3/32 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[2,1] * self.yqlzetabar[2,mif1] + 9/64 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[2,1] * self.yqlzetabar[2,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,0] * self.yl[1,mif2] * self.yqlzeta[2,1] * self.yqlzetabar[2,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,1] * self.yl[1,mif2] * self.yqlzeta[2,1] * self.yqlzetabar[2,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,2] * self.yl[1,mif2] * self.yqlzeta[2,1] * self.yqlzetabar[2,mif1] + -3/32 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[2,2] * self.yqlzetabar[2,mif1] + 9/64 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[2,2] * self.yqlzetabar[2,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,0] * self.yl[2,mif2] * self.yqlzeta[2,2] * self.yqlzetabar[2,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,1] * self.yl[2,mif2] * self.yqlzeta[2,2] * self.yqlzetabar[2,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,2] * self.yl[2,mif2] * self.yqlzeta[2,2] * self.yqlzetabar[2,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[0,0] * self.yqlzetabar[0,mif1] * self.yu[0,0] * self.yubar[0,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[0,1] * self.yqlzetabar[0,mif1] * self.yu[0,0] * self.yubar[0,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[0,2] * self.yqlzetabar[0,mif1] * self.yu[0,0] * self.yubar[0,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[1,0] * self.yqlzetabar[0,mif1] * self.yu[1,0] * self.yubar[0,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[1,1] * self.yqlzetabar[0,mif1] * self.yu[1,0] * self.yubar[0,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[1,2] * self.yqlzetabar[0,mif1] * self.yu[1,0] * self.yubar[0,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[2,0] * self.yqlzetabar[0,mif1] * self.yu[2,0] * self.yubar[0,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[2,1] * self.yqlzetabar[0,mif1] * self.yu[2,0] * self.yubar[0,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[2,2] * self.yqlzetabar[0,mif1] * self.yu[2,0] * self.yubar[0,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[0,0] * self.yqlzetabar[0,mif1] * self.yu[0,1] * self.yubar[0,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[0,1] * self.yqlzetabar[0,mif1] * self.yu[0,1] * self.yubar[0,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[0,2] * self.yqlzetabar[0,mif1] * self.yu[0,1] * self.yubar[0,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[1,0] * self.yqlzetabar[0,mif1] * self.yu[1,1] * self.yubar[0,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[1,1] * self.yqlzetabar[0,mif1] * self.yu[1,1] * self.yubar[0,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[1,2] * self.yqlzetabar[0,mif1] * self.yu[1,1] * self.yubar[0,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[2,0] * self.yqlzetabar[0,mif1] * self.yu[2,1] * self.yubar[0,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[2,1] * self.yqlzetabar[0,mif1] * self.yu[2,1] * self.yubar[0,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[2,2] * self.yqlzetabar[0,mif1] * self.yu[2,1] * self.yubar[0,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[0,0] * self.yqlzetabar[0,mif1] * self.yu[0,2] * self.yubar[0,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[0,1] * self.yqlzetabar[0,mif1] * self.yu[0,2] * self.yubar[0,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[0,2] * self.yqlzetabar[0,mif1] * self.yu[0,2] * self.yubar[0,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[1,0] * self.yqlzetabar[0,mif1] * self.yu[1,2] * self.yubar[0,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[1,1] * self.yqlzetabar[0,mif1] * self.yu[1,2] * self.yubar[0,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[1,2] * self.yqlzetabar[0,mif1] * self.yu[1,2] * self.yubar[0,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[2,0] * self.yqlzetabar[0,mif1] * self.yu[2,2] * self.yubar[0,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[2,1] * self.yqlzetabar[0,mif1] * self.yu[2,2] * self.yubar[0,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[2,2] * self.yqlzetabar[0,mif1] * self.yu[2,2] * self.yubar[0,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[0,0] * self.yqlzetabar[1,mif1] * self.yu[0,0] * self.yubar[1,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[0,1] * self.yqlzetabar[1,mif1] * self.yu[0,0] * self.yubar[1,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[0,2] * self.yqlzetabar[1,mif1] * self.yu[0,0] * self.yubar[1,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[1,0] * self.yqlzetabar[1,mif1] * self.yu[1,0] * self.yubar[1,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[1,1] * self.yqlzetabar[1,mif1] * self.yu[1,0] * self.yubar[1,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[1,2] * self.yqlzetabar[1,mif1] * self.yu[1,0] * self.yubar[1,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[2,0] * self.yqlzetabar[1,mif1] * self.yu[2,0] * self.yubar[1,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[2,1] * self.yqlzetabar[1,mif1] * self.yu[2,0] * self.yubar[1,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[2,2] * self.yqlzetabar[1,mif1] * self.yu[2,0] * self.yubar[1,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[0,0] * self.yqlzetabar[1,mif1] * self.yu[0,1] * self.yubar[1,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[0,1] * self.yqlzetabar[1,mif1] * self.yu[0,1] * self.yubar[1,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[0,2] * self.yqlzetabar[1,mif1] * self.yu[0,1] * self.yubar[1,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[1,0] * self.yqlzetabar[1,mif1] * self.yu[1,1] * self.yubar[1,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[1,1] * self.yqlzetabar[1,mif1] * self.yu[1,1] * self.yubar[1,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[1,2] * self.yqlzetabar[1,mif1] * self.yu[1,1] * self.yubar[1,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[2,0] * self.yqlzetabar[1,mif1] * self.yu[2,1] * self.yubar[1,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[2,1] * self.yqlzetabar[1,mif1] * self.yu[2,1] * self.yubar[1,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[2,2] * self.yqlzetabar[1,mif1] * self.yu[2,1] * self.yubar[1,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[0,0] * self.yqlzetabar[1,mif1] * self.yu[0,2] * self.yubar[1,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[0,1] * self.yqlzetabar[1,mif1] * self.yu[0,2] * self.yubar[1,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[0,2] * self.yqlzetabar[1,mif1] * self.yu[0,2] * self.yubar[1,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[1,0] * self.yqlzetabar[1,mif1] * self.yu[1,2] * self.yubar[1,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[1,1] * self.yqlzetabar[1,mif1] * self.yu[1,2] * self.yubar[1,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[1,2] * self.yqlzetabar[1,mif1] * self.yu[1,2] * self.yubar[1,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[2,0] * self.yqlzetabar[1,mif1] * self.yu[2,2] * self.yubar[1,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[2,1] * self.yqlzetabar[1,mif1] * self.yu[2,2] * self.yubar[1,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[2,2] * self.yqlzetabar[1,mif1] * self.yu[2,2] * self.yubar[1,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[0,0] * self.yqlzetabar[2,mif1] * self.yu[0,0] * self.yubar[2,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[0,1] * self.yqlzetabar[2,mif1] * self.yu[0,0] * self.yubar[2,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[0,2] * self.yqlzetabar[2,mif1] * self.yu[0,0] * self.yubar[2,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[1,0] * self.yqlzetabar[2,mif1] * self.yu[1,0] * self.yubar[2,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[1,1] * self.yqlzetabar[2,mif1] * self.yu[1,0] * self.yubar[2,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[1,2] * self.yqlzetabar[2,mif1] * self.yu[1,0] * self.yubar[2,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[2,0] * self.yqlzetabar[2,mif1] * self.yu[2,0] * self.yubar[2,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[2,1] * self.yqlzetabar[2,mif1] * self.yu[2,0] * self.yubar[2,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[2,2] * self.yqlzetabar[2,mif1] * self.yu[2,0] * self.yubar[2,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[0,0] * self.yqlzetabar[2,mif1] * self.yu[0,1] * self.yubar[2,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[0,1] * self.yqlzetabar[2,mif1] * self.yu[0,1] * self.yubar[2,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[0,2] * self.yqlzetabar[2,mif1] * self.yu[0,1] * self.yubar[2,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[1,0] * self.yqlzetabar[2,mif1] * self.yu[1,1] * self.yubar[2,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[1,1] * self.yqlzetabar[2,mif1] * self.yu[1,1] * self.yubar[2,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[1,2] * self.yqlzetabar[2,mif1] * self.yu[1,1] * self.yubar[2,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[2,0] * self.yqlzetabar[2,mif1] * self.yu[2,1] * self.yubar[2,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[2,1] * self.yqlzetabar[2,mif1] * self.yu[2,1] * self.yubar[2,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[2,2] * self.yqlzetabar[2,mif1] * self.yu[2,1] * self.yubar[2,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[0,0] * self.yqlzetabar[2,mif1] * self.yu[0,2] * self.yubar[2,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[0,1] * self.yqlzetabar[2,mif1] * self.yu[0,2] * self.yubar[2,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[0,2] * self.yqlzetabar[2,mif1] * self.yu[0,2] * self.yubar[2,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[1,0] * self.yqlzetabar[2,mif1] * self.yu[1,2] * self.yubar[2,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[1,1] * self.yqlzetabar[2,mif1] * self.yu[1,2] * self.yubar[2,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[1,2] * self.yqlzetabar[2,mif1] * self.yu[1,2] * self.yubar[2,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[2,0] * self.yqlzetabar[2,mif1] * self.yu[2,2] * self.yubar[2,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[2,1] * self.yqlzetabar[2,mif1] * self.yu[2,2] * self.yubar[2,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[2,2] * self.yqlzetabar[2,mif1] * self.yu[2,2] * self.yubar[2,2])

    def alphaOeu(self, mif1,mif2,mif3,mif4):
        return 1/720 * (self.g1)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4)

    def alphaOeW(self, mif1,mif2):
        return (-3/128 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[0,0] * self.yqlzetabar[0,mif1] + -3/128 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[0,1] * self.yqlzetabar[0,mif1] + -3/128 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[0,2] * self.yqlzetabar[0,mif1] + -3/128 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[1,0] * self.yqlzetabar[1,mif1] + -3/128 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[1,1] * self.yqlzetabar[1,mif1] + -3/128 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[1,2] * self.yqlzetabar[1,mif1] + -3/128 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.yqlzeta[2,0] * self.yqlzetabar[2,mif1] + -3/128 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.yqlzeta[2,1] * self.yqlzetabar[2,mif1] + -3/128 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.yqlzeta[2,2] * self.yqlzetabar[2,mif1])

    def alphaOHd(self, mif1,mif2):
        return (1/2880 * (self.g1)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.ydbar[0,mif1] * self.yqlzeta[0,0] * self.yqlzetabar[0,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.ydbar[0,mif1] * self.yqlzeta[1,0] * self.yqlzetabar[0,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.ydbar[0,mif1] * self.yqlzeta[2,0] * self.yqlzetabar[0,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.ydbar[0,mif1] * self.yqlzeta[0,1] * self.yqlzetabar[0,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.ydbar[0,mif1] * self.yqlzeta[1,1] * self.yqlzetabar[0,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.ydbar[0,mif1] * self.yqlzeta[2,1] * self.yqlzetabar[0,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.ydbar[0,mif1] * self.yqlzeta[0,2] * self.yqlzetabar[0,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.ydbar[0,mif1] * self.yqlzeta[1,2] * self.yqlzetabar[0,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.ydbar[0,mif1] * self.yqlzeta[2,2] * self.yqlzetabar[0,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.ydbar[1,mif1] * self.yqlzeta[0,0] * self.yqlzetabar[1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.ydbar[1,mif1] * self.yqlzeta[1,0] * self.yqlzetabar[1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.ydbar[1,mif1] * self.yqlzeta[2,0] * self.yqlzetabar[1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.ydbar[1,mif1] * self.yqlzeta[0,1] * self.yqlzetabar[1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.ydbar[1,mif1] * self.yqlzeta[1,1] * self.yqlzetabar[1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.ydbar[1,mif1] * self.yqlzeta[2,1] * self.yqlzetabar[1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.ydbar[1,mif1] * self.yqlzeta[0,2] * self.yqlzetabar[1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.ydbar[1,mif1] * self.yqlzeta[1,2] * self.yqlzetabar[1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.ydbar[1,mif1] * self.yqlzeta[2,2] * self.yqlzetabar[1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.ydbar[2,mif1] * self.yqlzeta[0,0] * self.yqlzetabar[2,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.ydbar[2,mif1] * self.yqlzeta[1,0] * self.yqlzetabar[2,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.ydbar[2,mif1] * self.yqlzeta[2,0] * self.yqlzetabar[2,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.ydbar[2,mif1] * self.yqlzeta[0,1] * self.yqlzetabar[2,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.ydbar[2,mif1] * self.yqlzeta[1,1] * self.yqlzetabar[2,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.ydbar[2,mif1] * self.yqlzeta[2,1] * self.yqlzetabar[2,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.ydbar[2,mif1] * self.yqlzeta[0,2] * self.yqlzetabar[2,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.ydbar[2,mif1] * self.yqlzeta[1,2] * self.yqlzetabar[2,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.ydbar[2,mif1] * self.yqlzeta[2,2] * self.yqlzetabar[2,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.ydbar[0,mif1] * self.yqqzeta[0,0] * self.yqqzetabar[0,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.ydbar[1,mif1] * self.yqqzeta[0,1] * self.yqqzetabar[0,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.ydbar[2,mif1] * self.yqqzeta[0,2] * self.yqqzetabar[0,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.ydbar[0,mif1] * self.yqqzeta[0,0] * self.yqqzetabar[0,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.ydbar[1,mif1] * self.yqqzeta[0,1] * self.yqqzetabar[0,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.ydbar[2,mif1] * self.yqqzeta[0,2] * self.yqqzetabar[0,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.ydbar[0,mif1] * self.yqqzeta[0,0] * self.yqqzetabar[0,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.ydbar[1,mif1] * self.yqqzeta[0,1] * self.yqqzetabar[0,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.ydbar[2,mif1] * self.yqqzeta[0,2] * self.yqqzetabar[0,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.ydbar[0,mif1] * self.yqqzeta[1,0] * self.yqqzetabar[1,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.ydbar[1,mif1] * self.yqqzeta[1,1] * self.yqqzetabar[1,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.ydbar[2,mif1] * self.yqqzeta[1,2] * self.yqqzetabar[1,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.ydbar[0,mif1] * self.yqqzeta[1,0] * self.yqqzetabar[1,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.ydbar[1,mif1] * self.yqqzeta[1,1] * self.yqqzetabar[1,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.ydbar[2,mif1] * self.yqqzeta[1,2] * self.yqqzetabar[1,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.ydbar[0,mif1] * self.yqqzeta[1,0] * self.yqqzetabar[1,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.ydbar[1,mif1] * self.yqqzeta[1,1] * self.yqqzetabar[1,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.ydbar[2,mif1] * self.yqqzeta[1,2] * self.yqqzetabar[1,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.ydbar[0,mif1] * self.yqqzeta[2,0] * self.yqqzetabar[2,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.ydbar[1,mif1] * self.yqqzeta[2,1] * self.yqqzetabar[2,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.ydbar[2,mif1] * self.yqqzeta[2,2] * self.yqqzetabar[2,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.ydbar[0,mif1] * self.yqqzeta[2,0] * self.yqqzetabar[2,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.ydbar[1,mif1] * self.yqqzeta[2,1] * self.yqqzetabar[2,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.ydbar[2,mif1] * self.yqqzeta[2,2] * self.yqqzetabar[2,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.ydbar[0,mif1] * self.yqqzeta[2,0] * self.yqqzetabar[2,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.ydbar[1,mif1] * self.yqqzeta[2,1] * self.yqqzetabar[2,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.ydbar[2,mif1] * self.yqqzeta[2,2] * self.yqqzetabar[2,2])

    def alphaOHe(self, mif1,mif2):
        return (1/960 * (self.g1)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.ylbar[0,mif1] * self.yqlzeta[0,0] * self.yqlzetabar[0,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.ylbar[0,mif1] * self.yqlzeta[0,1] * self.yqlzetabar[0,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.ylbar[0,mif1] * self.yqlzeta[0,2] * self.yqlzetabar[0,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.ylbar[1,mif1] * self.yqlzeta[0,0] * self.yqlzetabar[0,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.ylbar[1,mif1] * self.yqlzeta[0,1] * self.yqlzetabar[0,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.ylbar[1,mif1] * self.yqlzeta[0,2] * self.yqlzetabar[0,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.ylbar[2,mif1] * self.yqlzeta[0,0] * self.yqlzetabar[0,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.ylbar[2,mif1] * self.yqlzeta[0,1] * self.yqlzetabar[0,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.ylbar[2,mif1] * self.yqlzeta[0,2] * self.yqlzetabar[0,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.ylbar[0,mif1] * self.yqlzeta[1,0] * self.yqlzetabar[1,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.ylbar[0,mif1] * self.yqlzeta[1,1] * self.yqlzetabar[1,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.ylbar[0,mif1] * self.yqlzeta[1,2] * self.yqlzetabar[1,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.ylbar[1,mif1] * self.yqlzeta[1,0] * self.yqlzetabar[1,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.ylbar[1,mif1] * self.yqlzeta[1,1] * self.yqlzetabar[1,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.ylbar[1,mif1] * self.yqlzeta[1,2] * self.yqlzetabar[1,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.ylbar[2,mif1] * self.yqlzeta[1,0] * self.yqlzetabar[1,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.ylbar[2,mif1] * self.yqlzeta[1,1] * self.yqlzetabar[1,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.ylbar[2,mif1] * self.yqlzeta[1,2] * self.yqlzetabar[1,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.ylbar[0,mif1] * self.yqlzeta[2,0] * self.yqlzetabar[2,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.ylbar[0,mif1] * self.yqlzeta[2,1] * self.yqlzetabar[2,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.ylbar[0,mif1] * self.yqlzeta[2,2] * self.yqlzetabar[2,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.ylbar[1,mif1] * self.yqlzeta[2,0] * self.yqlzetabar[2,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.ylbar[1,mif1] * self.yqlzeta[2,1] * self.yqlzetabar[2,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.ylbar[1,mif1] * self.yqlzeta[2,2] * self.yqlzetabar[2,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif2] * self.ylbar[2,mif1] * self.yqlzeta[2,0] * self.yqlzetabar[2,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif2] * self.ylbar[2,mif1] * self.yqlzeta[2,1] * self.yqlzetabar[2,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif2] * self.ylbar[2,mif1] * self.yqlzeta[2,2] * self.yqlzetabar[2,2])

    def alphaOHl1(self, mif1,mif2):
        return (1/1920 * (self.g1)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) + 1/64 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + 1/64 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + -1/64 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,0] * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,0] * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,0] * self.ydbar[0,0] * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,1] * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,1] * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,1] * self.ydbar[0,1] * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,2] * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,2] * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,2] * self.ydbar[0,2] * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[0,0] * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[0,0] * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,0] * self.ydbar[0,0] * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[0,1] * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[0,1] * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,1] * self.ydbar[0,1] * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[0,2] * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[0,2] * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,2] * self.ydbar[0,2] * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[0,0] * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[0,0] * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,0] * self.ydbar[0,0] * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[0,1] * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[0,1] * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,1] * self.ydbar[0,1] * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[0,2] * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[0,2] * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,2] * self.ydbar[0,2] * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[1,0] * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[1,0] * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,0] * self.ydbar[1,0] * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[1,1] * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[1,1] * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,1] * self.ydbar[1,1] * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[1,2] * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[1,2] * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,2] * self.ydbar[1,2] * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] + 1/64 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + 1/64 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + -1/64 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,0] * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,0] * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,0] * self.ydbar[1,0] * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,1] * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,1] * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,1] * self.ydbar[1,1] * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,2] * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,2] * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,2] * self.ydbar[1,2] * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[1,0] * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[1,0] * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,0] * self.ydbar[1,0] * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[1,1] * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[1,1] * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,1] * self.ydbar[1,1] * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[1,2] * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[1,2] * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,2] * self.ydbar[1,2] * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[2,0] * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[2,0] * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,0] * self.ydbar[2,0] * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[2,1] * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[2,1] * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,1] * self.ydbar[2,1] * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[2,2] * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[2,2] * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,2] * self.ydbar[2,2] * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[2,0] * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[2,0] * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,0] * self.ydbar[2,0] * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[2,1] * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[2,1] * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,1] * self.ydbar[2,1] * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[2,2] * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[2,2] * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,2] * self.ydbar[2,2] * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] + 1/64 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + 1/64 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + -1/64 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,0] * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,0] * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,0] * self.ydbar[2,0] * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,1] * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,1] * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,1] * self.ydbar[2,1] * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,2] * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,2] * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,2] * self.ydbar[2,2] * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] * self.yu[0,0] * self.yubar[0,0] + 9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] * self.yu[0,0] * self.yubar[0,0] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] * self.yu[0,0] * self.yubar[0,0] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] * self.yu[1,0] * self.yubar[0,0] + 9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] * self.yu[1,0] * self.yubar[0,0] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] * self.yu[1,0] * self.yubar[0,0] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] * self.yu[2,0] * self.yubar[0,0] + 9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] * self.yu[2,0] * self.yubar[0,0] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] * self.yu[2,0] * self.yubar[0,0] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] * self.yu[0,1] * self.yubar[0,1] + 9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] * self.yu[0,1] * self.yubar[0,1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] * self.yu[0,1] * self.yubar[0,1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] * self.yu[1,1] * self.yubar[0,1] + 9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] * self.yu[1,1] * self.yubar[0,1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] * self.yu[1,1] * self.yubar[0,1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] * self.yu[2,1] * self.yubar[0,1] + 9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] * self.yu[2,1] * self.yubar[0,1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] * self.yu[2,1] * self.yubar[0,1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] * self.yu[0,2] * self.yubar[0,2] + 9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] * self.yu[0,2] * self.yubar[0,2] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] * self.yu[0,2] * self.yubar[0,2] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] * self.yu[1,2] * self.yubar[0,2] + 9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] * self.yu[1,2] * self.yubar[0,2] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] * self.yu[1,2] * self.yubar[0,2] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] * self.yu[2,2] * self.yubar[0,2] + 9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] * self.yu[2,2] * self.yubar[0,2] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] * self.yu[2,2] * self.yubar[0,2] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] * self.yu[0,0] * self.yubar[1,0] + 9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] * self.yu[0,0] * self.yubar[1,0] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] * self.yu[0,0] * self.yubar[1,0] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] * self.yu[1,0] * self.yubar[1,0] + 9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] * self.yu[1,0] * self.yubar[1,0] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] * self.yu[1,0] * self.yubar[1,0] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] * self.yu[2,0] * self.yubar[1,0] + 9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] * self.yu[2,0] * self.yubar[1,0] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] * self.yu[2,0] * self.yubar[1,0] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] * self.yu[0,1] * self.yubar[1,1] + 9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] * self.yu[0,1] * self.yubar[1,1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] * self.yu[0,1] * self.yubar[1,1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] * self.yu[1,1] * self.yubar[1,1] + 9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] * self.yu[1,1] * self.yubar[1,1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] * self.yu[1,1] * self.yubar[1,1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] * self.yu[2,1] * self.yubar[1,1] + 9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] * self.yu[2,1] * self.yubar[1,1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] * self.yu[2,1] * self.yubar[1,1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] * self.yu[0,2] * self.yubar[1,2] + 9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] * self.yu[0,2] * self.yubar[1,2] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] * self.yu[0,2] * self.yubar[1,2] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] * self.yu[1,2] * self.yubar[1,2] + 9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] * self.yu[1,2] * self.yubar[1,2] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] * self.yu[1,2] * self.yubar[1,2] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] * self.yu[2,2] * self.yubar[1,2] + 9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] * self.yu[2,2] * self.yubar[1,2] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] * self.yu[2,2] * self.yubar[1,2] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] * self.yu[0,0] * self.yubar[2,0] + 9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] * self.yu[0,0] * self.yubar[2,0] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] * self.yu[0,0] * self.yubar[2,0] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] * self.yu[1,0] * self.yubar[2,0] + 9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] * self.yu[1,0] * self.yubar[2,0] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] * self.yu[1,0] * self.yubar[2,0] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] * self.yu[2,0] * self.yubar[2,0] + 9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] * self.yu[2,0] * self.yubar[2,0] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] * self.yu[2,0] * self.yubar[2,0] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] * self.yu[0,1] * self.yubar[2,1] + 9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] * self.yu[0,1] * self.yubar[2,1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] * self.yu[0,1] * self.yubar[2,1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] * self.yu[1,1] * self.yubar[2,1] + 9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] * self.yu[1,1] * self.yubar[2,1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] * self.yu[1,1] * self.yubar[2,1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] * self.yu[2,1] * self.yubar[2,1] + 9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] * self.yu[2,1] * self.yubar[2,1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] * self.yu[2,1] * self.yubar[2,1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] * self.yu[0,2] * self.yubar[2,2] + 9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] * self.yu[0,2] * self.yubar[2,2] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] * self.yu[0,2] * self.yubar[2,2] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] * self.yu[1,2] * self.yubar[2,2] + 9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] * self.yu[1,2] * self.yubar[2,2] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] * self.yu[1,2] * self.yubar[2,2] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] * self.yu[2,2] * self.yubar[2,2] + 9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] * self.yu[2,2] * self.yubar[2,2] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] * self.yu[2,2] * self.yubar[2,2])

    def alphaOHl3(self, mif1,mif2):
        return (-1/320 * (self.g2)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) + 1/32 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + 1/64 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + -1/64 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,0] * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,0] * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,0] * self.ydbar[0,0] * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,1] * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,1] * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,1] * self.ydbar[0,1] * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,2] * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,2] * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,2] * self.ydbar[0,2] * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[0,0] * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[0,0] * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,0] * self.ydbar[0,0] * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[0,1] * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[0,1] * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,1] * self.ydbar[0,1] * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[0,2] * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[0,2] * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,2] * self.ydbar[0,2] * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[0,0] * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[0,0] * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,0] * self.ydbar[0,0] * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[0,1] * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[0,1] * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,1] * self.ydbar[0,1] * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[0,2] * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[0,2] * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,2] * self.ydbar[0,2] * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[1,0] * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[1,0] * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,0] * self.ydbar[1,0] * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[1,1] * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[1,1] * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,1] * self.ydbar[1,1] * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[1,2] * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[1,2] * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,2] * self.ydbar[1,2] * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] + 1/32 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + 1/64 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + -1/64 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,0] * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,0] * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,0] * self.ydbar[1,0] * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,1] * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,1] * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,1] * self.ydbar[1,1] * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,2] * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,2] * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,2] * self.ydbar[1,2] * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[1,0] * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[1,0] * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,0] * self.ydbar[1,0] * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[1,1] * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[1,1] * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,1] * self.ydbar[1,1] * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[1,2] * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[1,2] * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,2] * self.ydbar[1,2] * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[2,0] * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[2,0] * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,0] * self.ydbar[2,0] * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[2,1] * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[2,1] * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,1] * self.ydbar[2,1] * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[2,2] * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[2,2] * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,2] * self.ydbar[2,2] * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[2,0] * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[2,0] * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,0] * self.ydbar[2,0] * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[2,1] * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[2,1] * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,1] * self.ydbar[2,1] * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[2,2] * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[2,2] * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,2] * self.ydbar[2,2] * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] + 1/32 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + 1/64 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + -1/64 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,0] * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,0] * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,0] * self.ydbar[2,0] * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,1] * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,1] * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,1] * self.ydbar[2,1] * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,2] * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,2] * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,2] * self.ydbar[2,2] * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] * self.yu[0,0] * self.yubar[0,0] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] * self.yu[0,0] * self.yubar[0,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] * self.yu[0,0] * self.yubar[0,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] * self.yu[1,0] * self.yubar[0,0] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] * self.yu[1,0] * self.yubar[0,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] * self.yu[1,0] * self.yubar[0,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] * self.yu[2,0] * self.yubar[0,0] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] * self.yu[2,0] * self.yubar[0,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] * self.yu[2,0] * self.yubar[0,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] * self.yu[0,1] * self.yubar[0,1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] * self.yu[0,1] * self.yubar[0,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] * self.yu[0,1] * self.yubar[0,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] * self.yu[1,1] * self.yubar[0,1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] * self.yu[1,1] * self.yubar[0,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] * self.yu[1,1] * self.yubar[0,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] * self.yu[2,1] * self.yubar[0,1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] * self.yu[2,1] * self.yubar[0,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] * self.yu[2,1] * self.yubar[0,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] * self.yu[0,2] * self.yubar[0,2] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] * self.yu[0,2] * self.yubar[0,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] * self.yu[0,2] * self.yubar[0,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] * self.yu[1,2] * self.yubar[0,2] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] * self.yu[1,2] * self.yubar[0,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] * self.yu[1,2] * self.yubar[0,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] * self.yu[2,2] * self.yubar[0,2] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] * self.yu[2,2] * self.yubar[0,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] * self.yu[2,2] * self.yubar[0,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] * self.yu[0,0] * self.yubar[1,0] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] * self.yu[0,0] * self.yubar[1,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] * self.yu[0,0] * self.yubar[1,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] * self.yu[1,0] * self.yubar[1,0] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] * self.yu[1,0] * self.yubar[1,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] * self.yu[1,0] * self.yubar[1,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] * self.yu[2,0] * self.yubar[1,0] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] * self.yu[2,0] * self.yubar[1,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] * self.yu[2,0] * self.yubar[1,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] * self.yu[0,1] * self.yubar[1,1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] * self.yu[0,1] * self.yubar[1,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] * self.yu[0,1] * self.yubar[1,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] * self.yu[1,1] * self.yubar[1,1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] * self.yu[1,1] * self.yubar[1,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] * self.yu[1,1] * self.yubar[1,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] * self.yu[2,1] * self.yubar[1,1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] * self.yu[2,1] * self.yubar[1,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] * self.yu[2,1] * self.yubar[1,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] * self.yu[0,2] * self.yubar[1,2] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] * self.yu[0,2] * self.yubar[1,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] * self.yu[0,2] * self.yubar[1,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] * self.yu[1,2] * self.yubar[1,2] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] * self.yu[1,2] * self.yubar[1,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] * self.yu[1,2] * self.yubar[1,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] * self.yu[2,2] * self.yubar[1,2] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] * self.yu[2,2] * self.yubar[1,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] * self.yu[2,2] * self.yubar[1,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] * self.yu[0,0] * self.yubar[2,0] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] * self.yu[0,0] * self.yubar[2,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] * self.yu[0,0] * self.yubar[2,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] * self.yu[1,0] * self.yubar[2,0] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] * self.yu[1,0] * self.yubar[2,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] * self.yu[1,0] * self.yubar[2,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] * self.yu[2,0] * self.yubar[2,0] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] * self.yu[2,0] * self.yubar[2,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] * self.yu[2,0] * self.yubar[2,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] * self.yu[0,1] * self.yubar[2,1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] * self.yu[0,1] * self.yubar[2,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] * self.yu[0,1] * self.yubar[2,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] * self.yu[1,1] * self.yubar[2,1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] * self.yu[1,1] * self.yubar[2,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] * self.yu[1,1] * self.yubar[2,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] * self.yu[2,1] * self.yubar[2,1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] * self.yu[2,1] * self.yubar[2,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] * self.yu[2,1] * self.yubar[2,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] * self.yu[0,2] * self.yubar[2,2] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] * self.yu[0,2] * self.yubar[2,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] * self.yu[0,2] * self.yubar[2,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] * self.yu[1,2] * self.yubar[2,2] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] * self.yu[1,2] * self.yubar[2,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] * self.yu[1,2] * self.yubar[2,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] * self.yu[2,2] * self.yubar[2,2] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] * self.yu[2,2] * self.yubar[2,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] * self.yu[2,2] * self.yubar[2,2])

    def alphaOHq1(self, mif1,mif2):
        return (-1/5760 * (self.g1)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) + -13/576 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + -1/64 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + 1/64 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[0,0] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[0,0] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[0,0] * self.ylbar[0,0] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[0,1] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[0,1] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[0,1] * self.ylbar[0,1] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[0,2] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[0,2] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[0,2] * self.ylbar[0,2] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[0,0] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,0] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[0,0] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[1,0] * self.ylbar[0,0] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[0,1] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,0] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[0,1] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[1,1] * self.ylbar[0,1] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[0,2] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,0] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[0,2] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[1,2] * self.ylbar[0,2] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[0,0] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,0] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[0,0] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[2,0] * self.ylbar[0,0] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[0,1] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,0] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[0,1] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[2,1] * self.ylbar[0,1] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[0,2] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,0] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[0,2] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[2,2] * self.ylbar[0,2] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[1,0] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[1,0] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[0,0] * self.ylbar[1,0] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[1,1] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[1,1] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[0,1] * self.ylbar[1,1] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[1,2] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[1,2] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[0,2] * self.ylbar[1,2] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,1] + -13/576 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + -1/64 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + 1/64 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[1,0] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[1,0] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[1,0] * self.ylbar[1,0] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[1,1] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[1,1] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[1,1] * self.ylbar[1,1] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[1,2] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[1,2] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[1,2] * self.ylbar[1,2] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[1,0] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[1,0] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[2,0] * self.ylbar[1,0] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[1,1] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[1,1] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[2,1] * self.ylbar[1,1] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[1,2] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[1,2] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[2,2] * self.ylbar[1,2] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[2,0] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,2] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[2,0] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[0,0] * self.ylbar[2,0] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[2,1] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,2] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[2,1] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[0,1] * self.ylbar[2,1] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[2,2] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,2] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[2,2] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[0,2] * self.ylbar[2,2] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[2,0] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,2] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[2,0] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[1,0] * self.ylbar[2,0] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[2,1] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,2] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[2,1] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[1,1] * self.ylbar[2,1] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[2,2] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,2] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[2,2] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[1,2] * self.ylbar[2,2] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,2] + -13/576 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + -1/64 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + 1/64 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[2,0] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[2,0] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[2,0] * self.ylbar[2,0] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[2,1] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[2,1] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[2,1] * self.ylbar[2,1] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[2,2] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[2,2] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[2,2] * self.ylbar[2,2] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + 5/72 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + 1/24 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -1/24 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] + -3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] + -3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] + -3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] + -3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] + -3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] + -3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] + -3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] + -3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] + -3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] + 5/72 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + 1/24 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -1/24 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] + -3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] + -3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] + -3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] + -3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] + -3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] + -3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] + -3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] + -3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] + -3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] + 5/72 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + 1/24 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -1/24 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -1/144 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,0] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,0] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,0] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,1] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,0] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,2] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,0] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[1,0] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,0] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[1,1] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,0] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[1,2] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,0] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[2,0] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,0] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[2,1] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,0] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[2,2] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,0] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[0,0] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,1] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[0,1] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,1] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[0,2] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,1] + -1/144 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,1] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,0] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,1] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,1] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,1] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,2] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,1] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[2,0] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,1] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[2,1] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,1] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[2,2] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,1] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[0,0] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,2] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[0,1] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,2] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[0,2] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,2] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[1,0] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,2] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[1,1] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,2] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[1,2] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,2] + -1/144 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,2] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,0] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,2] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,1] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,2] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,2] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,0] * self.yubar[0,0] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,0] * self.yubar[0,0] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,0] * self.yubar[0,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,0] * self.yu[0,0] * self.yubar[0,0] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,0] * self.yubar[0,0] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,0] * self.yubar[0,0] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,0] * self.yubar[0,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,1] * self.yu[1,0] * self.yubar[0,0] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,0] * self.yubar[0,0] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,0] * self.yubar[0,0] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,0] * self.yubar[0,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,2] * self.yu[2,0] * self.yubar[0,0] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,1] * self.yubar[0,1] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,1] * self.yubar[0,1] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,1] * self.yubar[0,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,0] * self.yu[0,1] * self.yubar[0,1] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,1] * self.yubar[0,1] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,1] * self.yubar[0,1] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,1] * self.yubar[0,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,1] * self.yu[1,1] * self.yubar[0,1] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,1] * self.yubar[0,1] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,1] * self.yubar[0,1] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,1] * self.yubar[0,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,2] * self.yu[2,1] * self.yubar[0,1] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,2] * self.yubar[0,2] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,2] * self.yubar[0,2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,2] * self.yubar[0,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,0] * self.yu[0,2] * self.yubar[0,2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,2] * self.yubar[0,2] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,2] * self.yubar[0,2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,2] * self.yubar[0,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,1] * self.yu[1,2] * self.yubar[0,2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,2] * self.yubar[0,2] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,2] * self.yubar[0,2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,2] * self.yubar[0,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,2] * self.yu[2,2] * self.yubar[0,2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,0] * self.yubar[1,0] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,0] * self.yubar[1,0] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,0] * self.yubar[1,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,0] * self.yu[0,0] * self.yubar[1,0] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,0] * self.yubar[1,0] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,0] * self.yubar[1,0] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,0] * self.yubar[1,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,1] * self.yu[1,0] * self.yubar[1,0] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,0] * self.yubar[1,0] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,0] * self.yubar[1,0] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,0] * self.yubar[1,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,2] * self.yu[2,0] * self.yubar[1,0] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,1] * self.yubar[1,1] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,1] * self.yubar[1,1] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,1] * self.yubar[1,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,0] * self.yu[0,1] * self.yubar[1,1] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,1] * self.yubar[1,1] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,1] * self.yubar[1,1] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,1] * self.yubar[1,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,1] * self.yu[1,1] * self.yubar[1,1] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,1] * self.yubar[1,1] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,1] * self.yubar[1,1] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,1] * self.yubar[1,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,2] * self.yu[2,1] * self.yubar[1,1] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,2] * self.yubar[1,2] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,2] * self.yubar[1,2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,2] * self.yubar[1,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,0] * self.yu[0,2] * self.yubar[1,2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,2] * self.yubar[1,2] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,2] * self.yubar[1,2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,2] * self.yubar[1,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,1] * self.yu[1,2] * self.yubar[1,2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,2] * self.yubar[1,2] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,2] * self.yubar[1,2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,2] * self.yubar[1,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,2] * self.yu[2,2] * self.yubar[1,2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,0] * self.yubar[2,0] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,0] * self.yubar[2,0] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,0] * self.yubar[2,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,0] * self.yu[0,0] * self.yubar[2,0] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,0] * self.yubar[2,0] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,0] * self.yubar[2,0] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,0] * self.yubar[2,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,1] * self.yu[1,0] * self.yubar[2,0] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,0] * self.yubar[2,0] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,0] * self.yubar[2,0] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,0] * self.yubar[2,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,2] * self.yu[2,0] * self.yubar[2,0] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,1] * self.yubar[2,1] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,1] * self.yubar[2,1] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,1] * self.yubar[2,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,0] * self.yu[0,1] * self.yubar[2,1] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,1] * self.yubar[2,1] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,1] * self.yubar[2,1] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,1] * self.yubar[2,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,1] * self.yu[1,1] * self.yubar[2,1] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,1] * self.yubar[2,1] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,1] * self.yubar[2,1] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,1] * self.yubar[2,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,2] * self.yu[2,1] * self.yubar[2,1] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,2] * self.yubar[2,2] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,2] * self.yubar[2,2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,2] * self.yubar[2,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,0] * self.yu[0,2] * self.yubar[2,2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,2] * self.yubar[2,2] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,2] * self.yubar[2,2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,2] * self.yubar[2,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,1] * self.yu[1,2] * self.yubar[2,2] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,2] * self.yubar[2,2] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,2] * self.yubar[2,2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,2] * self.yubar[2,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,2] * self.yu[2,2] * self.yubar[2,2])

    def alphaOHq3(self, mif1,mif2):
        return (-1/320 * (self.g2)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) + 1/96 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + 1/192 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + -1/192 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[0,0] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + -1/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[0,0] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[0,0] * self.ylbar[0,0] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[0,1] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + -1/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[0,1] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[0,1] * self.ylbar[0,1] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[0,2] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + -1/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[0,2] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[0,2] * self.ylbar[0,2] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[0,0] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,0] + -1/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[0,0] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[1,0] * self.ylbar[0,0] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,0] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[0,1] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,0] + -1/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[0,1] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[1,1] * self.ylbar[0,1] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,0] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[0,2] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,0] + -1/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[0,2] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[1,2] * self.ylbar[0,2] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,0] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[0,0] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,0] + -1/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[0,0] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[2,0] * self.ylbar[0,0] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,0] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[0,1] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,0] + -1/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[0,1] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[2,1] * self.ylbar[0,1] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,0] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[0,2] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,0] + -1/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[0,2] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[2,2] * self.ylbar[0,2] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,0] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[1,0] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,1] + -1/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[1,0] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[0,0] * self.ylbar[1,0] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[1,1] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,1] + -1/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[1,1] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[0,1] * self.ylbar[1,1] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[1,2] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,1] + -1/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[1,2] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[0,2] * self.ylbar[1,2] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,1] + 1/96 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + 1/192 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + -1/192 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[1,0] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + -1/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[1,0] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[1,0] * self.ylbar[1,0] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[1,1] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + -1/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[1,1] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[1,1] * self.ylbar[1,1] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[1,2] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + -1/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[1,2] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[1,2] * self.ylbar[1,2] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[1,0] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,1] + -1/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[1,0] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[2,0] * self.ylbar[1,0] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[1,1] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,1] + -1/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[1,1] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[2,1] * self.ylbar[1,1] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[1,2] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,1] + -1/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[1,2] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[2,2] * self.ylbar[1,2] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[2,0] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,2] + -1/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[2,0] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[0,0] * self.ylbar[2,0] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[2,1] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,2] + -1/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[2,1] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[0,1] * self.ylbar[2,1] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[2,2] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,2] + -1/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[2,2] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[0,2] * self.ylbar[2,2] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[2,0] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,2] + -1/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[2,0] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[1,0] * self.ylbar[2,0] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[2,1] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,2] + -1/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[2,1] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[1,1] * self.ylbar[2,1] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[2,2] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,2] + -1/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[2,2] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[1,2] * self.ylbar[2,2] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,2] + 1/96 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + 1/192 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + -1/192 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[2,0] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + -1/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[2,0] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[2,0] * self.ylbar[2,0] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[2,1] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + -1/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[2,1] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[2,1] * self.ylbar[2,1] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[2,2] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + -1/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[2,2] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[2,2] * self.ylbar[2,2] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + 1/12 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + 1/24 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -1/24 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] + 1/12 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + 1/24 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -1/24 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] + 1/12 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + 1/24 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -1/24 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + 1/48 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,0] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,1] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,2] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[1,0] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[1,1] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[1,2] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[2,0] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[2,1] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[2,2] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[0,0] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[0,1] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[0,2] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,1] + 1/48 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,0] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,1] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,2] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[2,0] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[2,1] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[2,2] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[0,0] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[0,1] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[0,2] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[1,0] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[1,1] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[1,2] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,2] + 1/48 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,0] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,1] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,2] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,0] * self.yubar[0,0] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,0] * self.yubar[0,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,0] * self.yubar[0,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,0] * self.yu[0,0] * self.yubar[0,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,0] * self.yubar[0,0] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,0] * self.yubar[0,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,0] * self.yubar[0,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,1] * self.yu[1,0] * self.yubar[0,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,0] * self.yubar[0,0] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,0] * self.yubar[0,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,0] * self.yubar[0,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,2] * self.yu[2,0] * self.yubar[0,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,1] * self.yubar[0,1] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,1] * self.yubar[0,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,1] * self.yubar[0,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,0] * self.yu[0,1] * self.yubar[0,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,1] * self.yubar[0,1] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,1] * self.yubar[0,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,1] * self.yubar[0,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,1] * self.yu[1,1] * self.yubar[0,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,1] * self.yubar[0,1] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,1] * self.yubar[0,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,1] * self.yubar[0,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,2] * self.yu[2,1] * self.yubar[0,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,2] * self.yubar[0,2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,2] * self.yubar[0,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,2] * self.yubar[0,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,0] * self.yu[0,2] * self.yubar[0,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,2] * self.yubar[0,2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,2] * self.yubar[0,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,2] * self.yubar[0,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,1] * self.yu[1,2] * self.yubar[0,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,2] * self.yubar[0,2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,2] * self.yubar[0,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,2] * self.yubar[0,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,2] * self.yu[2,2] * self.yubar[0,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,0] * self.yubar[1,0] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,0] * self.yubar[1,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,0] * self.yubar[1,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,0] * self.yu[0,0] * self.yubar[1,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,0] * self.yubar[1,0] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,0] * self.yubar[1,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,0] * self.yubar[1,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,1] * self.yu[1,0] * self.yubar[1,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,0] * self.yubar[1,0] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,0] * self.yubar[1,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,0] * self.yubar[1,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,2] * self.yu[2,0] * self.yubar[1,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,1] * self.yubar[1,1] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,1] * self.yubar[1,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,1] * self.yubar[1,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,0] * self.yu[0,1] * self.yubar[1,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,1] * self.yubar[1,1] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,1] * self.yubar[1,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,1] * self.yubar[1,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,1] * self.yu[1,1] * self.yubar[1,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,1] * self.yubar[1,1] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,1] * self.yubar[1,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,1] * self.yubar[1,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,2] * self.yu[2,1] * self.yubar[1,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,2] * self.yubar[1,2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,2] * self.yubar[1,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,2] * self.yubar[1,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,0] * self.yu[0,2] * self.yubar[1,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,2] * self.yubar[1,2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,2] * self.yubar[1,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,2] * self.yubar[1,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,1] * self.yu[1,2] * self.yubar[1,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,2] * self.yubar[1,2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,2] * self.yubar[1,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,2] * self.yubar[1,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,2] * self.yu[2,2] * self.yubar[1,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,0] * self.yubar[2,0] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,0] * self.yubar[2,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,0] * self.yubar[2,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,0] * self.yu[0,0] * self.yubar[2,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,0] * self.yubar[2,0] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,0] * self.yubar[2,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,0] * self.yubar[2,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,1] * self.yu[1,0] * self.yubar[2,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,0] * self.yubar[2,0] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,0] * self.yubar[2,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,0] * self.yubar[2,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,2] * self.yu[2,0] * self.yubar[2,0] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,1] * self.yubar[2,1] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,1] * self.yubar[2,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,1] * self.yubar[2,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,0] * self.yu[0,1] * self.yubar[2,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,1] * self.yubar[2,1] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,1] * self.yubar[2,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,1] * self.yubar[2,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,1] * self.yu[1,1] * self.yubar[2,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,1] * self.yubar[2,1] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,1] * self.yubar[2,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,1] * self.yubar[2,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,2] * self.yu[2,1] * self.yubar[2,1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,2] * self.yubar[2,2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,2] * self.yubar[2,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,2] * self.yubar[2,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,0] * self.yu[0,2] * self.yubar[2,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,2] * self.yubar[2,2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,2] * self.yubar[2,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,2] * self.yubar[2,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,1] * self.yu[1,2] * self.yubar[2,2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,2] * self.yubar[2,2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,2] * self.yubar[2,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,2] * self.yubar[2,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,2] * self.yu[2,2] * self.yubar[2,2])

    def alphaOHu(self, mif1,mif2):
        return (-1/1440 * (self.g1)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[0,0] * self.yu[0,mif2] * self.yubar[0,mif1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[0,1] * self.yu[0,mif2] * self.yubar[0,mif1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[0,2] * self.yu[0,mif2] * self.yubar[0,mif1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzetabar[0,0] * self.yu[0,mif2] * self.yubar[0,mif1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzetabar[1,0] * self.yu[0,mif2] * self.yubar[0,mif1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzetabar[2,0] * self.yu[0,mif2] * self.yubar[0,mif1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[0,0] * self.yu[1,mif2] * self.yubar[0,mif1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[0,1] * self.yu[1,mif2] * self.yubar[0,mif1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[0,2] * self.yu[1,mif2] * self.yubar[0,mif1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzetabar[0,1] * self.yu[1,mif2] * self.yubar[0,mif1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzetabar[1,1] * self.yu[1,mif2] * self.yubar[0,mif1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzetabar[2,1] * self.yu[1,mif2] * self.yubar[0,mif1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[0,0] * self.yu[2,mif2] * self.yubar[0,mif1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[0,1] * self.yu[2,mif2] * self.yubar[0,mif1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[0,2] * self.yu[2,mif2] * self.yubar[0,mif1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzetabar[0,2] * self.yu[2,mif2] * self.yubar[0,mif1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzetabar[1,2] * self.yu[2,mif2] * self.yubar[0,mif1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzetabar[2,2] * self.yu[2,mif2] * self.yubar[0,mif1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[1,0] * self.yu[0,mif2] * self.yubar[1,mif1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[1,1] * self.yu[0,mif2] * self.yubar[1,mif1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[1,2] * self.yu[0,mif2] * self.yubar[1,mif1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzetabar[0,0] * self.yu[0,mif2] * self.yubar[1,mif1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzetabar[1,0] * self.yu[0,mif2] * self.yubar[1,mif1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzetabar[2,0] * self.yu[0,mif2] * self.yubar[1,mif1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[1,0] * self.yu[1,mif2] * self.yubar[1,mif1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[1,1] * self.yu[1,mif2] * self.yubar[1,mif1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[1,2] * self.yu[1,mif2] * self.yubar[1,mif1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzetabar[0,1] * self.yu[1,mif2] * self.yubar[1,mif1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzetabar[1,1] * self.yu[1,mif2] * self.yubar[1,mif1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzetabar[2,1] * self.yu[1,mif2] * self.yubar[1,mif1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[1,0] * self.yu[2,mif2] * self.yubar[1,mif1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[1,1] * self.yu[2,mif2] * self.yubar[1,mif1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[1,2] * self.yu[2,mif2] * self.yubar[1,mif1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzetabar[0,2] * self.yu[2,mif2] * self.yubar[1,mif1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzetabar[1,2] * self.yu[2,mif2] * self.yubar[1,mif1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzetabar[2,2] * self.yu[2,mif2] * self.yubar[1,mif1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[2,0] * self.yu[0,mif2] * self.yubar[2,mif1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[2,1] * self.yu[0,mif2] * self.yubar[2,mif1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[2,2] * self.yu[0,mif2] * self.yubar[2,mif1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzetabar[0,0] * self.yu[0,mif2] * self.yubar[2,mif1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzetabar[1,0] * self.yu[0,mif2] * self.yubar[2,mif1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzetabar[2,0] * self.yu[0,mif2] * self.yubar[2,mif1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[2,0] * self.yu[1,mif2] * self.yubar[2,mif1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[2,1] * self.yu[1,mif2] * self.yubar[2,mif1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[2,2] * self.yu[1,mif2] * self.yubar[2,mif1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzetabar[0,1] * self.yu[1,mif2] * self.yubar[2,mif1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzetabar[1,1] * self.yu[1,mif2] * self.yubar[2,mif1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzetabar[2,1] * self.yu[1,mif2] * self.yubar[2,mif1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[2,0] * self.yu[2,mif2] * self.yubar[2,mif1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[2,1] * self.yu[2,mif2] * self.yubar[2,mif1] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[2,2] * self.yu[2,mif2] * self.yubar[2,mif1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzetabar[0,2] * self.yu[2,mif2] * self.yubar[2,mif1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzetabar[1,2] * self.yu[2,mif2] * self.yubar[2,mif1] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzetabar[2,2] * self.yu[2,mif2] * self.yubar[2,mif1])

    def alphaOHud(self, mif1,mif2):
        return (1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqlzeta[0,0] * self.yqlzetabar[0,0] * self.yubar[0,mif1] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqlzeta[1,0] * self.yqlzetabar[0,0] * self.yubar[0,mif1] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqlzeta[2,0] * self.yqlzetabar[0,0] * self.yubar[0,mif1] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqlzeta[0,1] * self.yqlzetabar[0,1] * self.yubar[0,mif1] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqlzeta[1,1] * self.yqlzetabar[0,1] * self.yubar[0,mif1] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqlzeta[2,1] * self.yqlzetabar[0,1] * self.yubar[0,mif1] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqlzeta[0,2] * self.yqlzetabar[0,2] * self.yubar[0,mif1] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqlzeta[1,2] * self.yqlzetabar[0,2] * self.yubar[0,mif1] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqlzeta[2,2] * self.yqlzetabar[0,2] * self.yubar[0,mif1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[0,0] * self.yqqzetabar[0,0] * self.yubar[0,mif1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[0,0] * self.yqqzetabar[0,1] * self.yubar[0,mif1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[0,0] * self.yqqzetabar[0,2] * self.yubar[0,mif1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[1,0] * self.yqqzetabar[1,0] * self.yubar[0,mif1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[1,0] * self.yqqzetabar[1,1] * self.yubar[0,mif1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[1,0] * self.yqqzetabar[1,2] * self.yubar[0,mif1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[2,0] * self.yqqzetabar[2,0] * self.yubar[0,mif1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[2,0] * self.yqqzetabar[2,1] * self.yubar[0,mif1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[2,0] * self.yqqzetabar[2,2] * self.yubar[0,mif1] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqlzeta[0,0] * self.yqlzetabar[1,0] * self.yubar[1,mif1] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqlzeta[1,0] * self.yqlzetabar[1,0] * self.yubar[1,mif1] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqlzeta[2,0] * self.yqlzetabar[1,0] * self.yubar[1,mif1] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqlzeta[0,1] * self.yqlzetabar[1,1] * self.yubar[1,mif1] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqlzeta[1,1] * self.yqlzetabar[1,1] * self.yubar[1,mif1] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqlzeta[2,1] * self.yqlzetabar[1,1] * self.yubar[1,mif1] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqlzeta[0,2] * self.yqlzetabar[1,2] * self.yubar[1,mif1] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqlzeta[1,2] * self.yqlzetabar[1,2] * self.yubar[1,mif1] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqlzeta[2,2] * self.yqlzetabar[1,2] * self.yubar[1,mif1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[0,1] * self.yqqzetabar[0,0] * self.yubar[1,mif1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[0,1] * self.yqqzetabar[0,1] * self.yubar[1,mif1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[0,1] * self.yqqzetabar[0,2] * self.yubar[1,mif1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[1,1] * self.yqqzetabar[1,0] * self.yubar[1,mif1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[1,1] * self.yqqzetabar[1,1] * self.yubar[1,mif1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[1,1] * self.yqqzetabar[1,2] * self.yubar[1,mif1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[2,1] * self.yqqzetabar[2,0] * self.yubar[1,mif1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[2,1] * self.yqqzetabar[2,1] * self.yubar[1,mif1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[2,1] * self.yqqzetabar[2,2] * self.yubar[1,mif1] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqlzeta[0,0] * self.yqlzetabar[2,0] * self.yubar[2,mif1] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqlzeta[1,0] * self.yqlzetabar[2,0] * self.yubar[2,mif1] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqlzeta[2,0] * self.yqlzetabar[2,0] * self.yubar[2,mif1] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqlzeta[0,1] * self.yqlzetabar[2,1] * self.yubar[2,mif1] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqlzeta[1,1] * self.yqlzetabar[2,1] * self.yubar[2,mif1] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqlzeta[2,1] * self.yqlzetabar[2,1] * self.yubar[2,mif1] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqlzeta[0,2] * self.yqlzetabar[2,2] * self.yubar[2,mif1] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqlzeta[1,2] * self.yqlzetabar[2,2] * self.yubar[2,mif1] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqlzeta[2,2] * self.yqlzetabar[2,2] * self.yubar[2,mif1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[0,2] * self.yqqzetabar[0,0] * self.yubar[2,mif1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[0,2] * self.yqqzetabar[0,1] * self.yubar[2,mif1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[0,2] * self.yqqzetabar[0,2] * self.yubar[2,mif1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[1,2] * self.yqqzetabar[1,0] * self.yubar[2,mif1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[1,2] * self.yqqzetabar[1,1] * self.yubar[2,mif1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[1,2] * self.yqqzetabar[1,2] * self.yubar[2,mif1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif2] * self.yqqzeta[2,2] * self.yqqzetabar[2,0] * self.yubar[2,mif1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif2] * self.yqqzeta[2,2] * self.yqqzetabar[2,1] * self.yubar[2,mif1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif2] * self.yqqzeta[2,2] * self.yqqzetabar[2,2] * self.yubar[2,mif1])

    def alphaOld(self, mif1,mif2,mif3,mif4):
        return (-1/2880 * (self.g1)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + -1/96 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + -1/96 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + 1/96 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[0,mif3] * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[0,mif3] * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,mif4] * self.ydbar[0,mif3] * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[0,mif3] * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[0,mif3] * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,mif4] * self.ydbar[0,mif3] * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[0,mif3] * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[0,mif3] * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,mif4] * self.ydbar[0,mif3] * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[1,mif3] * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[1,mif3] * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,mif4] * self.ydbar[1,mif3] * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] + -1/96 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + -1/96 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + 1/96 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[1,mif3] * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[1,mif3] * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,mif4] * self.ydbar[1,mif3] * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[1,mif3] * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[1,mif3] * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,mif4] * self.ydbar[1,mif3] * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[2,mif3] * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[2,mif3] * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,mif4] * self.ydbar[2,mif3] * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[2,mif3] * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[2,mif3] * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,mif4] * self.ydbar[2,mif3] * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] + -1/96 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + -1/96 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + 1/96 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[2,mif3] * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[2,mif3] * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,mif4] * self.ydbar[2,mif3] * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1])

    def alphaOle(self, mif1,mif2,mif3,mif4):
        return (-1/960 * (self.g1)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + -1/32 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + -1/32 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + 1/32 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + -1/32 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + -1/32 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + 1/32 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + -1/32 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + -1/32 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + 1/32 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1])

    def alphaOledq(self, mif1,mif2,mif3,mif4):
        return (-21/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[0,mif3] * self.yl[0,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[0,mif1] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[0,mif3] * self.yl[0,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[0,mif1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.ydbar[0,mif3] * self.yl[0,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[0,mif1] + -21/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[0,mif3] * self.yl[1,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[0,mif1] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[0,mif3] * self.yl[1,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[0,mif1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.ydbar[0,mif3] * self.yl[1,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[0,mif1] + -21/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[0,mif3] * self.yl[2,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[0,mif1] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[0,mif3] * self.yl[2,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[0,mif1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.ydbar[0,mif3] * self.yl[2,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[0,mif1] + -21/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[1,mif3] * self.yl[0,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[1,mif1] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[1,mif3] * self.yl[0,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[1,mif1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.ydbar[1,mif3] * self.yl[0,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[1,mif1] + -21/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[1,mif3] * self.yl[1,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[1,mif1] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[1,mif3] * self.yl[1,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[1,mif1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.ydbar[1,mif3] * self.yl[1,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[1,mif1] + -21/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[1,mif3] * self.yl[2,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[1,mif1] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[1,mif3] * self.yl[2,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[1,mif1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.ydbar[1,mif3] * self.yl[2,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[1,mif1] + -21/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[2,mif3] * self.yl[0,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[2,mif1] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[2,mif3] * self.yl[0,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[2,mif1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.ydbar[2,mif3] * self.yl[0,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[2,mif1] + -21/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[2,mif3] * self.yl[1,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[2,mif1] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[2,mif3] * self.yl[1,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[2,mif1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.ydbar[2,mif3] * self.yl[1,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[2,mif1] + -21/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[2,mif3] * self.yl[2,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[2,mif1] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.ydbar[2,mif3] * self.yl[2,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[2,mif1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.ydbar[2,mif3] * self.yl[2,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[2,mif1])

    def alphaOlequ1(self, mif1,mif2,mif3,mif4):
        return 0

    def alphaOlequ3(self, mif1,mif2,mif3,mif4):
        return 0

    def alphaOll(self, mif1,mif2,mif3,mif4):
        return (-1/320 * (self.g2)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.kronecker_delta(mif2,mif3) + -1/3840 * (self.g1)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 1/640 * (self.g2)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + -1/128 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + -1/64 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + -1/128 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + -1/128 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + 1/128 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + 1/128 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + 1/32 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yqlzeta[0,mif4] * self.yqlzetabar[0,mif1] + 1/64 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yqlzeta[0,mif4] * self.yqlzetabar[0,mif1] + -1/64 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif4] * self.yqlzetabar[0,mif1] + 1/32 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif3] + 1/64 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif3] + -1/64 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif3] + -1/128 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[0,mif4] * self.yqlzetabar[0,mif3] + -1/64 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[0,mif4] * self.yqlzetabar[0,mif3] + -1/128 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[0,mif4] * self.yqlzetabar[0,mif3] + -1/128 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[0,mif4] * self.yqlzetabar[0,mif3] + 1/128 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif4] * self.yqlzetabar[0,mif3] + 1/128 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif4] * self.yqlzetabar[0,mif3] + -15/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzeta[0,mif4] * self.yqlzetabar[0,mif1] * self.yqlzetabar[0,mif3] + -1/128 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + -1/64 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + -1/128 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + -1/128 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + 1/128 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + 1/128 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + 1/32 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yqlzeta[1,mif4] * self.yqlzetabar[1,mif1] + 1/64 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yqlzeta[1,mif4] * self.yqlzetabar[1,mif1] + -1/64 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif4] * self.yqlzetabar[1,mif1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif4] * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif3] * self.yqlzetabar[1,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzeta[1,mif4] * self.yqlzetabar[0,mif3] * self.yqlzetabar[1,mif1] + 1/32 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif3] + 1/64 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif3] + -1/64 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif3] + -1/128 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[1,mif4] * self.yqlzetabar[1,mif3] + -1/64 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[1,mif4] * self.yqlzetabar[1,mif3] + -1/128 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[1,mif4] * self.yqlzetabar[1,mif3] + -1/128 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[1,mif4] * self.yqlzetabar[1,mif3] + 1/128 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif4] * self.yqlzetabar[1,mif3] + 1/128 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif4] * self.yqlzetabar[1,mif3] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif4] * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] * self.yqlzetabar[1,mif3] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzeta[1,mif4] * self.yqlzetabar[0,mif1] * self.yqlzetabar[1,mif3] + -15/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzeta[1,mif4] * self.yqlzetabar[1,mif1] * self.yqlzetabar[1,mif3] + -1/128 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + -1/64 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + -1/128 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + -1/128 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + 1/128 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + 1/128 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + 1/32 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yqlzeta[2,mif4] * self.yqlzetabar[2,mif1] + 1/64 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yqlzeta[2,mif4] * self.yqlzetabar[2,mif1] + -1/64 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif4] * self.yqlzetabar[2,mif1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif4] * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif3] * self.yqlzetabar[2,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzeta[2,mif4] * self.yqlzetabar[0,mif3] * self.yqlzetabar[2,mif1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif4] * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif3] * self.yqlzetabar[2,mif1] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzeta[2,mif4] * self.yqlzetabar[1,mif3] * self.yqlzetabar[2,mif1] + 1/32 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif3] + 1/64 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif3] + -1/64 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif3] + -1/128 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[2,mif4] * self.yqlzetabar[2,mif3] + -1/64 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[2,mif4] * self.yqlzetabar[2,mif3] + -1/128 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[2,mif4] * self.yqlzetabar[2,mif3] + -1/128 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[2,mif4] * self.yqlzetabar[2,mif3] + 1/128 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif4] * self.yqlzetabar[2,mif3] + 1/128 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif4] * self.yqlzetabar[2,mif3] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif4] * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] * self.yqlzetabar[2,mif3] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzeta[2,mif4] * self.yqlzetabar[0,mif1] * self.yqlzetabar[2,mif3] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif4] * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] * self.yqlzetabar[2,mif3] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzeta[2,mif4] * self.yqlzetabar[1,mif1] * self.yqlzetabar[2,mif3] + -15/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzeta[2,mif4] * self.yqlzetabar[2,mif1] * self.yqlzetabar[2,mif3])

    def alphaOlq1(self, mif1,mif2,mif3,mif4):
        return (1/5760 * (self.g1)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 1/192 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + 1/192 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + -1/192 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + 1/192 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + 1/192 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + -1/192 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + 1/192 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + 1/192 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + -1/192 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + 13/576 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[mif4,0] * self.yqlzetabar[mif3,0] + 1/64 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[mif4,0] * self.yqlzetabar[mif3,0] + -1/64 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,0] * self.yqlzetabar[mif3,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[0,mif1] * self.yqlzetabar[mif3,0] + -9/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqlzetabar[mif3,0] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqlzetabar[mif3,0] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,0] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqlzetabar[mif3,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[1,mif1] * self.yqlzetabar[mif3,0] + -9/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqlzetabar[mif3,0] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqlzetabar[mif3,0] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,0] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqlzetabar[mif3,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[2,mif1] * self.yqlzetabar[mif3,0] + -9/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqlzetabar[mif3,0] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqlzetabar[mif3,0] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,0] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqlzetabar[mif3,0] + 13/576 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[mif4,1] * self.yqlzetabar[mif3,1] + 1/64 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[mif4,1] * self.yqlzetabar[mif3,1] + -1/64 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,1] * self.yqlzetabar[mif3,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[0,mif1] * self.yqlzetabar[mif3,1] + -9/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqlzetabar[mif3,1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqlzetabar[mif3,1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,1] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqlzetabar[mif3,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[1,mif1] * self.yqlzetabar[mif3,1] + -9/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqlzetabar[mif3,1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqlzetabar[mif3,1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,1] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqlzetabar[mif3,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[2,mif1] * self.yqlzetabar[mif3,1] + -9/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqlzetabar[mif3,1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqlzetabar[mif3,1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,1] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqlzetabar[mif3,1] + 13/576 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[mif4,2] * self.yqlzetabar[mif3,2] + 1/64 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[mif4,2] * self.yqlzetabar[mif3,2] + -1/64 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,2] * self.yqlzetabar[mif3,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[0,mif1] * self.yqlzetabar[mif3,2] + -9/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqlzetabar[mif3,2] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqlzetabar[mif3,2] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,2] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqlzetabar[mif3,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[1,mif1] * self.yqlzetabar[mif3,2] + -9/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqlzetabar[mif3,2] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqlzetabar[mif3,2] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,2] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqlzetabar[mif3,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[2,mif1] * self.yqlzetabar[mif3,2] + -9/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqlzetabar[mif3,2] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqlzetabar[mif3,2] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,2] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqlzetabar[mif3,2] + 3/4 * (self.Mzeta)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[mif3,mif1] + 5/192 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[mif3,mif1] + 1/32 * self.epsilonbar * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[mif3,mif1] + 39/128 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[mif3,mif1] + 9/128 * self.epsilonbar * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[mif3,mif1] + 7/32 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[mif3,mif1] + 3/32 * self.epsilonbar * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[mif3,mif1] + 1/48 * self.epsilonbar * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[mif3,mif1] + 3/64 * self.epsilonbar * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[mif3,mif1] + 1/16 * self.epsilonbar * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[mif3,mif1] + -1/48 * self.epsilonbar * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[mif3,mif1] + -3/64 * self.epsilonbar * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[mif3,mif1] + -1/16 * self.epsilonbar * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[mif3,mif1] + -9/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[0,0] * self.yqlzetabar[mif3,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[0,0] * self.yqlzetabar[mif3,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[0,0] * self.yqlzetabar[mif3,mif1] + -9/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[0,1] * self.yqlzetabar[mif3,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[0,1] * self.yqlzetabar[mif3,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[0,1] * self.yqlzetabar[mif3,mif1] + -9/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[0,2] * self.yqlzetabar[mif3,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[0,2] * self.yqlzetabar[mif3,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[0,2] * self.yqlzetabar[mif3,mif1] + -9/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[1,0] * self.yqlzetabar[mif3,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[1,0] * self.yqlzetabar[mif3,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[1,0] * self.yqlzetabar[mif3,mif1] + -9/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[1,1] * self.yqlzetabar[mif3,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[1,1] * self.yqlzetabar[mif3,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[1,1] * self.yqlzetabar[mif3,mif1] + -9/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[1,2] * self.yqlzetabar[mif3,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[1,2] * self.yqlzetabar[mif3,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[1,2] * self.yqlzetabar[mif3,mif1] + -9/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[2,0] * self.yqlzetabar[mif3,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[2,0] * self.yqlzetabar[mif3,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[2,0] * self.yqlzetabar[mif3,mif1] + -9/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[2,1] * self.yqlzetabar[mif3,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[2,1] * self.yqlzetabar[mif3,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[2,1] * self.yqlzetabar[mif3,mif1] + -9/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[2,2] * self.yqlzetabar[mif3,mif1] + -9/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[2,2] * self.yqlzetabar[mif3,mif1] + 9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[2,2] * self.yqlzetabar[mif3,mif1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,0] + -9/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,0] + 9/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,0] + -21/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,1] + -15/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,1] + 15/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,1] + 3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[0,1] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[0,1] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[0,1] + -21/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,2] + -15/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,2] + 15/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,2] + 3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[0,2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[0,2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[0,2] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,0] * self.yqqzetabar[0,mif4] + -9/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,0] * self.yqqzetabar[0,mif4] + 9/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,0] * self.yqqzetabar[0,mif4] + -21/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,1] * self.yqqzetabar[0,mif4] + -15/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,1] * self.yqqzetabar[0,mif4] + 15/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,1] * self.yqqzetabar[0,mif4] + -21/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,2] * self.yqqzetabar[0,mif4] + -15/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,2] * self.yqqzetabar[0,mif4] + 15/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,2] * self.yqqzetabar[0,mif4] + -5/72 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif4] + -1/24 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif4] + 1/24 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif4] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif4] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif4] + 3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,0] * self.yqqzetabar[0,mif4] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,0] * self.yqqzetabar[0,mif4] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,0] * self.yqqzetabar[0,mif4] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[0,mif4] + 3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,0] * self.yqqzetabar[0,mif4] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,0] * self.yqqzetabar[0,mif4] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,0] * self.yqqzetabar[0,mif4] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[0,mif4] + 3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[1,0] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[1,0] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[1,0] + -21/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,0] + -15/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,0] + 15/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,0] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,1] + -9/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,1] + 9/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,1] + -21/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,2] + -15/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,2] + 15/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,2] + 3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[1,2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[1,2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[1,2] + 3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,1] * self.yqqzetabar[1,mif4] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,1] * self.yqqzetabar[1,mif4] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,1] * self.yqqzetabar[1,mif4] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[1,mif4] + -21/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,0] * self.yqqzetabar[1,mif4] + -15/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,0] * self.yqqzetabar[1,mif4] + 15/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,0] * self.yqqzetabar[1,mif4] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,1] * self.yqqzetabar[1,mif4] + -9/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,1] * self.yqqzetabar[1,mif4] + 9/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,1] * self.yqqzetabar[1,mif4] + -21/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,2] * self.yqqzetabar[1,mif4] + -15/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,2] * self.yqqzetabar[1,mif4] + 15/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,2] * self.yqqzetabar[1,mif4] + -5/72 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif4] + -1/24 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif4] + 1/24 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif4] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif4] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif4] + 3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,1] * self.yqqzetabar[1,mif4] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,1] * self.yqqzetabar[1,mif4] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,1] * self.yqqzetabar[1,mif4] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[1,mif4] + 3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[2,0] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[2,0] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[2,0] + -21/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,0] + -15/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,0] + 15/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,0] + 3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[2,1] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[2,1] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[2,1] + -21/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,1] + -15/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,1] + 15/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,1] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,2] + -9/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,2] + 9/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,2] + 3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,2] * self.yqqzetabar[2,mif4] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,2] * self.yqqzetabar[2,mif4] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,2] * self.yqqzetabar[2,mif4] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[2,mif4] + 3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,2] * self.yqqzetabar[2,mif4] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,2] * self.yqqzetabar[2,mif4] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,2] * self.yqqzetabar[2,mif4] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[2,mif4] + -21/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,0] * self.yqqzetabar[2,mif4] + -15/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,0] * self.yqqzetabar[2,mif4] + 15/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,0] * self.yqqzetabar[2,mif4] + -21/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,1] * self.yqqzetabar[2,mif4] + -15/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,1] * self.yqqzetabar[2,mif4] + 15/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,1] * self.yqqzetabar[2,mif4] + -9/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,2] * self.yqqzetabar[2,mif4] + -9/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,2] * self.yqqzetabar[2,mif4] + 9/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,2] * self.yqqzetabar[2,mif4] + -5/72 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif4] + -1/24 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif4] + 1/24 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif4] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif4] + 3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif4] + 1/144 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,0] + 1/144 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,1] + 1/144 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,2])

    def alphaOlq3(self, mif1,mif2,mif3,mif4):
        return (-1/320 * (self.g2)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 1/32 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + 1/64 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + -1/64 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + 1/32 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + 1/64 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + -1/64 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + 1/32 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + 1/64 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + -1/64 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + 1/96 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[mif4,0] * self.yqlzetabar[mif3,0] + 1/192 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[mif4,0] * self.yqlzetabar[mif3,0] + -1/192 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,0] * self.yqlzetabar[mif3,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[0,mif1] * self.yqlzetabar[mif3,0] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqlzetabar[mif3,0] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqlzetabar[mif3,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,0] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqlzetabar[mif3,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[1,mif1] * self.yqlzetabar[mif3,0] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqlzetabar[mif3,0] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqlzetabar[mif3,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,0] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqlzetabar[mif3,0] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[2,mif1] * self.yqlzetabar[mif3,0] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqlzetabar[mif3,0] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqlzetabar[mif3,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,0] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqlzetabar[mif3,0] + 1/96 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[mif4,1] * self.yqlzetabar[mif3,1] + 1/192 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[mif4,1] * self.yqlzetabar[mif3,1] + -1/192 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,1] * self.yqlzetabar[mif3,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[0,mif1] * self.yqlzetabar[mif3,1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqlzetabar[mif3,1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqlzetabar[mif3,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,1] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqlzetabar[mif3,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[1,mif1] * self.yqlzetabar[mif3,1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqlzetabar[mif3,1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqlzetabar[mif3,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,1] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqlzetabar[mif3,1] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[2,mif1] * self.yqlzetabar[mif3,1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqlzetabar[mif3,1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqlzetabar[mif3,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,1] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqlzetabar[mif3,1] + 1/96 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[mif4,2] * self.yqlzetabar[mif3,2] + 1/192 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[mif4,2] * self.yqlzetabar[mif3,2] + -1/192 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,2] * self.yqlzetabar[mif3,2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[0,mif1] * self.yqlzetabar[mif3,2] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqlzetabar[mif3,2] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqlzetabar[mif3,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,2] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqlzetabar[mif3,2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[1,mif1] * self.yqlzetabar[mif3,2] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqlzetabar[mif3,2] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqlzetabar[mif3,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,2] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqlzetabar[mif3,2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[2,mif1] * self.yqlzetabar[mif3,2] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqlzetabar[mif3,2] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqlzetabar[mif3,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,2] * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqlzetabar[mif3,2] + 1/4 * (self.Mzeta)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[mif3,mif1] + 5/576 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[mif3,mif1] + 1/96 * self.epsilonbar * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[mif3,mif1] + -3/128 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[mif3,mif1] + -9/128 * self.epsilonbar * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[mif3,mif1] + 7/96 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[mif3,mif1] + 1/32 * self.epsilonbar * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[mif3,mif1] + 1/144 * self.epsilonbar * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[mif3,mif1] + -3/64 * self.epsilonbar * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[mif3,mif1] + 1/48 * self.epsilonbar * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[mif3,mif1] + -1/144 * self.epsilonbar * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[mif3,mif1] + 3/64 * self.epsilonbar * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[mif3,mif1] + -1/48 * self.epsilonbar * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[mif3,mif1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[0,0] * self.yqlzetabar[mif3,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[0,0] * self.yqlzetabar[mif3,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[0,0] * self.yqlzetabar[mif3,mif1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[0,1] * self.yqlzetabar[mif3,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[0,1] * self.yqlzetabar[mif3,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[0,1] * self.yqlzetabar[mif3,mif1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[0,2] * self.yqlzetabar[mif3,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[0,2] * self.yqlzetabar[mif3,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[0,2] * self.yqlzetabar[mif3,mif1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[1,0] * self.yqlzetabar[mif3,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[1,0] * self.yqlzetabar[mif3,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[1,0] * self.yqlzetabar[mif3,mif1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[1,1] * self.yqlzetabar[mif3,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[1,1] * self.yqlzetabar[mif3,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[1,1] * self.yqlzetabar[mif3,mif1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[1,2] * self.yqlzetabar[mif3,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[1,2] * self.yqlzetabar[mif3,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[1,2] * self.yqlzetabar[mif3,mif1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[2,0] * self.yqlzetabar[mif3,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[2,0] * self.yqlzetabar[mif3,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzeta[mif4,0] * self.yqlzetabar[2,0] * self.yqlzetabar[mif3,mif1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[2,1] * self.yqlzetabar[mif3,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[2,1] * self.yqlzetabar[mif3,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzeta[mif4,1] * self.yqlzetabar[2,1] * self.yqlzetabar[mif3,mif1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[2,2] * self.yqlzetabar[mif3,mif1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[2,2] * self.yqlzetabar[mif3,mif1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzeta[mif4,2] * self.yqlzetabar[2,2] * self.yqlzetabar[mif3,mif1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,0] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,0] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,0] + -7/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,1] + -5/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,1] + 5/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,1] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[0,1] + 1/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[0,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[0,1] + -7/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,2] + -5/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,2] + 5/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,2] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[0,2] + 1/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[0,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[0,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,0] * self.yqqzetabar[0,mif4] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,0] * self.yqqzetabar[0,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,0] * self.yqqzetabar[0,mif4] + -7/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,1] * self.yqqzetabar[0,mif4] + -5/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,1] * self.yqqzetabar[0,mif4] + 5/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,1] * self.yqqzetabar[0,mif4] + -7/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,2] * self.yqqzetabar[0,mif4] + -5/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,2] * self.yqqzetabar[0,mif4] + 5/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,2] * self.yqqzetabar[0,mif4] + 1/12 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif4] + 1/24 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif4] + -1/24 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif4] + -5/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif4] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif4] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif4] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,0] * self.yqqzetabar[0,mif4] + 1/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,0] * self.yqqzetabar[0,mif4] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,0] * self.yqqzetabar[0,mif4] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[0,mif4] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,0] * self.yqqzetabar[0,mif4] + 1/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,0] * self.yqqzetabar[0,mif4] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,0] * self.yqqzetabar[0,mif4] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[0,mif4] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[1,0] + 1/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[1,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[1,0] + -7/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,0] + -5/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,0] + 5/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,1] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,1] + -7/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,2] + -5/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,2] + 5/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,2] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[1,2] + 1/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[1,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[1,2] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,1] * self.yqqzetabar[1,mif4] + 1/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,1] * self.yqqzetabar[1,mif4] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,1] * self.yqqzetabar[1,mif4] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[1,mif4] + -7/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,0] * self.yqqzetabar[1,mif4] + -5/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,0] * self.yqqzetabar[1,mif4] + 5/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,0] * self.yqqzetabar[1,mif4] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,1] * self.yqqzetabar[1,mif4] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,1] * self.yqqzetabar[1,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,1] * self.yqqzetabar[1,mif4] + -7/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,2] * self.yqqzetabar[1,mif4] + -5/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,2] * self.yqqzetabar[1,mif4] + 5/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,2] * self.yqqzetabar[1,mif4] + 1/12 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif4] + 1/24 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif4] + -1/24 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif4] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif4] + -5/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif4] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif4] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,1] * self.yqqzetabar[1,mif4] + 1/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,1] * self.yqqzetabar[1,mif4] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,1] * self.yqqzetabar[1,mif4] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[1,mif4] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[2,0] + 1/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[2,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[2,0] + -7/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,0] + -5/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,0] + 5/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,0] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[2,1] + 1/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[2,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[2,1] + -7/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,1] + -5/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,1] + 5/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,2] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,2] * self.yqqzetabar[2,mif4] + 1/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,2] * self.yqqzetabar[2,mif4] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[0,2] * self.yqqzetabar[2,mif4] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[2,mif4] + 1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,2] * self.yqqzetabar[2,mif4] + 1/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,2] * self.yqqzetabar[2,mif4] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[1,2] * self.yqqzetabar[2,mif4] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[2,mif4] + -7/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,0] * self.yqqzetabar[2,mif4] + -5/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,0] * self.yqqzetabar[2,mif4] + 5/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,0] * self.yqqzetabar[2,mif4] + -7/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,1] * self.yqqzetabar[2,mif4] + -5/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,1] * self.yqqzetabar[2,mif4] + 5/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,1] * self.yqqzetabar[2,mif4] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,2] * self.yqqzetabar[2,mif4] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,2] * self.yqqzetabar[2,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[mif3,mif1] * self.yqqzeta[2,2] * self.yqqzetabar[2,mif4] + 1/12 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif4] + 1/24 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif4] + -1/24 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif4] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif4] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif4] + -5/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif4] + 1/48 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,0] + 1/48 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,1] + 1/48 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,2])

    def alphaOlu(self, mif1,mif2,mif3,mif4):
        return (1/1440 * (self.g1)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 1/48 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + 1/48 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + -1/48 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] + 1/48 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + 1/48 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + -1/48 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] + 1/48 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + 1/48 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + -1/48 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] * self.yu[0,mif4] * self.yubar[0,mif3] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] * self.yu[0,mif4] * self.yubar[0,mif3] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[0,mif1] * self.yu[0,mif4] * self.yubar[0,mif3] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] * self.yu[1,mif4] * self.yubar[0,mif3] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] * self.yu[1,mif4] * self.yubar[0,mif3] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[0,mif1] * self.yu[1,mif4] * self.yubar[0,mif3] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] * self.yu[2,mif4] * self.yubar[0,mif3] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] * self.yu[2,mif4] * self.yubar[0,mif3] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[0,mif1] * self.yu[2,mif4] * self.yubar[0,mif3] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] * self.yu[0,mif4] * self.yubar[1,mif3] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] * self.yu[0,mif4] * self.yubar[1,mif3] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[1,mif1] * self.yu[0,mif4] * self.yubar[1,mif3] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] * self.yu[1,mif4] * self.yubar[1,mif3] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] * self.yu[1,mif4] * self.yubar[1,mif3] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[1,mif1] * self.yu[1,mif4] * self.yubar[1,mif3] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] * self.yu[2,mif4] * self.yubar[1,mif3] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] * self.yu[2,mif4] * self.yubar[1,mif3] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[1,mif1] * self.yu[2,mif4] * self.yubar[1,mif3] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] * self.yu[0,mif4] * self.yubar[2,mif3] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] * self.yu[0,mif4] * self.yubar[2,mif3] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,mif2] * self.yqlzetabar[2,mif1] * self.yu[0,mif4] * self.yubar[2,mif3] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] * self.yu[1,mif4] * self.yubar[2,mif3] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] * self.yu[1,mif4] * self.yubar[2,mif3] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,mif2] * self.yqlzetabar[2,mif1] * self.yu[1,mif4] * self.yubar[2,mif3] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] * self.yu[2,mif4] * self.yubar[2,mif3] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] * self.yu[2,mif4] * self.yubar[2,mif3] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,mif2] * self.yqlzetabar[2,mif1] * self.yu[2,mif4] * self.yubar[2,mif3])

    def alphaOqd1(self, mif1,mif2,mif3,mif4):
        return (1/8640 * (self.g1)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 13/864 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + 1/96 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + -1/96 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + 13/864 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + 1/96 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + -1/96 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + 13/864 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + 1/96 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + -1/96 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + -5/108 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -1/36 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + 1/36 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[0,mif3] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[0,mif3] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,mif4] * self.ydbar[0,mif3] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[1,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[1,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,mif4] * self.ydbar[1,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[2,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[2,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,mif4] * self.ydbar[2,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[0,mif3] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[0,mif3] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,mif4] * self.ydbar[0,mif3] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] + -5/108 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -1/36 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + 1/36 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[1,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[1,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,mif4] * self.ydbar[1,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[2,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[2,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,mif4] * self.ydbar[2,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[0,mif3] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[0,mif3] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,mif4] * self.ydbar[0,mif3] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[1,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[1,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,mif4] * self.ydbar[1,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] + -5/108 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -1/36 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + 1/36 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[2,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[2,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,mif4] * self.ydbar[2,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[0,mif3] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif2,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[1,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif2,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[2,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif2,0] + 1/216 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,0] + 1/24 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[0,mif3] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,0] + 1/24 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[1,mif3] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,0] + 1/24 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[2,mif3] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,0] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[0,mif3] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif2,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[1,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif2,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[2,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif2,1] + 1/24 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[0,mif3] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,1] + 1/216 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,1] + 1/24 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[1,mif3] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,1] + 1/24 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[2,mif3] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,1] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[0,mif3] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif2,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[1,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif2,2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[2,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif2,2] + 1/24 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[0,mif3] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,2] + 1/24 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[1,mif3] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,2] + 1/216 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,2] + 1/24 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[2,mif3] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,2])

    def alphaOqd8(self, mif1,mif2,mif3,mif4):
        return (-1/320 * (self.g3)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 1/96 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + 1/96 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + 1/96 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + -7/24 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -1/4 * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + 1/4 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + 9/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[0,mif3] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[0,mif3] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,mif4] * self.ydbar[0,mif3] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + 9/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[1,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[1,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,mif4] * self.ydbar[1,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] + 9/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[2,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[2,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[0,mif4] * self.ydbar[2,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] + 9/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[0,mif3] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[0,mif3] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,mif4] * self.ydbar[0,mif3] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] + -7/24 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -1/4 * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + 1/4 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + 9/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[1,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[1,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,mif4] * self.ydbar[1,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + 9/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[2,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[2,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[1,mif4] * self.ydbar[2,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] + 9/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[0,mif3] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[0,mif3] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,mif4] * self.ydbar[0,mif3] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] + 9/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[1,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[1,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,mif4] * self.ydbar[1,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] + -7/24 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -1/4 * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + 1/4 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + 9/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[2,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[2,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yd[2,mif4] * self.ydbar[2,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -1/12 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,0] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[0,mif3] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,0] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[1,mif3] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,0] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.ydbar[2,mif3] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,0] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[0,mif3] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,1] + -1/12 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[1,mif3] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.ydbar[2,mif3] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,1] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[0,mif3] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,2] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[1,mif3] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,2] + -1/12 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,2] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.ydbar[2,mif3] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,2])

    def alphaOqe(self, mif1,mif2,mif3,mif4):
        return (1/2880 * (self.g1)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 13/288 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + 1/32 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + -1/32 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif4] * self.ylbar[0,mif3] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif4] * self.ylbar[0,mif3] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[0,mif4] * self.ylbar[0,mif3] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif4] * self.ylbar[0,mif3] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,0] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif4] * self.ylbar[0,mif3] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[1,mif4] * self.ylbar[0,mif3] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,0] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif4] * self.ylbar[0,mif3] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,0] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif4] * self.ylbar[0,mif3] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,0] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[2,mif4] * self.ylbar[0,mif3] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,0] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif4] * self.ylbar[1,mif3] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif4] * self.ylbar[1,mif3] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[0,mif4] * self.ylbar[1,mif3] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,1] + 13/288 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + 1/32 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + -1/32 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif4] * self.ylbar[1,mif3] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif4] * self.ylbar[1,mif3] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[1,mif4] * self.ylbar[1,mif3] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif4] * self.ylbar[1,mif3] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,1] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif4] * self.ylbar[1,mif3] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,1] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[2,mif4] * self.ylbar[1,mif3] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif4] * self.ylbar[2,mif3] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,2] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,mif4] * self.ylbar[2,mif3] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[0,mif4] * self.ylbar[2,mif3] * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,2] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif4] * self.ylbar[2,mif3] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,2] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,mif4] * self.ylbar[2,mif3] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[1,mif4] * self.ylbar[2,mif3] * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,2] + 13/288 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + 1/32 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + -1/32 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif4] * self.ylbar[2,mif3] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + -3/64 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,mif4] * self.ylbar[2,mif3] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yl[2,mif4] * self.ylbar[2,mif3] * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + -5/36 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -1/12 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + 1/12 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -5/36 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -1/12 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + 1/12 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -5/36 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -1/12 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + 1/12 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + 1/72 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,0] + 1/72 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,1] + 1/72 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,2])

    def alphaOqq1(self, mif1,mif2,mif3,mif4):
        return (-1/2560 * (self.g3)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.kronecker_delta(mif2,mif3) + -1/34560 * (self.g1)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 1/3840 * (self.g3)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + -13/3456 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + -1/1152 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + -1/384 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + 1/384 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + 1/768 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yqlzeta[mif4,0] * self.yqlzetabar[mif1,0] + -13/3456 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + -1/1152 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + -1/384 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + 1/384 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + 1/768 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yqlzeta[mif4,1] * self.yqlzetabar[mif1,1] + -13/3456 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + -1/1152 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + -1/384 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + 1/384 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + 1/768 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yqlzeta[mif4,2] * self.yqlzetabar[mif1,2] + 1/768 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif3,0] + -13/3456 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[mif4,0] * self.yqlzetabar[mif3,0] + -1/1152 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[mif4,0] * self.yqlzetabar[mif3,0] + -1/384 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[mif4,0] * self.yqlzetabar[mif3,0] + 1/384 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,0] * self.yqlzetabar[mif3,0] + -9/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzeta[mif4,0] * self.yqlzetabar[mif1,0] * self.yqlzetabar[mif3,0] + -9/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzeta[mif4,1] * self.yqlzetabar[mif1,1] * self.yqlzetabar[mif3,0] + -9/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzeta[mif4,2] * self.yqlzetabar[mif1,2] * self.yqlzetabar[mif3,0] + 1/768 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif3,1] + -13/3456 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[mif4,1] * self.yqlzetabar[mif3,1] + -1/1152 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[mif4,1] * self.yqlzetabar[mif3,1] + -1/384 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[mif4,1] * self.yqlzetabar[mif3,1] + 1/384 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,1] * self.yqlzetabar[mif3,1] + -9/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzeta[mif4,0] * self.yqlzetabar[mif1,0] * self.yqlzetabar[mif3,1] + -9/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzeta[mif4,1] * self.yqlzetabar[mif1,1] * self.yqlzetabar[mif3,1] + -9/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzeta[mif4,2] * self.yqlzetabar[mif1,2] * self.yqlzetabar[mif3,1] + 1/768 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif3,2] + -13/3456 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[mif4,2] * self.yqlzetabar[mif3,2] + -1/1152 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[mif4,2] * self.yqlzetabar[mif3,2] + -1/384 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[mif4,2] * self.yqlzetabar[mif3,2] + 1/384 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,2] * self.yqlzetabar[mif3,2] + -9/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzeta[mif4,0] * self.yqlzetabar[mif1,0] * self.yqlzetabar[mif3,2] + -9/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzeta[mif4,1] * self.yqlzetabar[mif1,1] * self.yqlzetabar[mif3,2] + -9/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzeta[mif4,2] * self.yqlzetabar[mif1,2] * self.yqlzetabar[mif3,2] + 5/432 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + 7/288 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + 1/144 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + 1/48 * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -1/144 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -1/48 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -7/192 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif2] + -1/32 * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif2] + 1/32 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif2] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] + -35/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + -19/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + -35/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + -19/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + -35/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + -19/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,0] * self.yqqzetabar[0,mif2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,0] * self.yqqzetabar[0,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,0] * self.yqqzetabar[0,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,0] * self.yqqzetabar[0,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,0] * self.yqqzetabar[0,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,0] * self.yqqzetabar[0,mif2] + -7/192 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif4] + -1/32 * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif4] + 1/32 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif4] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif4] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif4] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif4] + 5/432 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif4] + 7/288 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif4] + 1/144 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif4] + 1/48 * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif4] + -1/144 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif4] + -1/48 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif4] + -1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif4] + -1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif4] + -1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif4] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] + 11/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] + -11/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] + 11/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] + -11/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] + 11/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] + -11/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] + -15/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif2] * self.yqqzetabar[0,mif4] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[0,mif4] + 3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[0,mif4] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[0,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] * self.yqqzetabar[1,0] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] * self.yqqzetabar[1,0] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] * self.yqqzetabar[1,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[1,0] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[1,0] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[1,0] + 5/432 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + 7/288 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + 1/144 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + 1/48 * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -1/144 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -1/48 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -7/192 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif2] + -1/32 * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif2] + 1/32 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif2] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] + -35/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + -19/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + -35/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + -19/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + -35/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + -19/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,1] * self.yqqzetabar[1,mif2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,1] * self.yqqzetabar[1,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,1] * self.yqqzetabar[1,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,1] * self.yqqzetabar[1,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,1] * self.yqqzetabar[1,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,1] * self.yqqzetabar[1,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif4] * self.yqqzetabar[1,mif2] + -9/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[0,mif4] * self.yqqzetabar[1,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] * self.yqqzetabar[1,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] * self.yqqzetabar[1,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] * self.yqqzetabar[1,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] * self.yqqzetabar[1,mif2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] * self.yqqzetabar[1,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] * self.yqqzetabar[1,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,1] * self.yqqzetabar[1,mif2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,1] * self.yqqzetabar[1,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,1] * self.yqqzetabar[1,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,1] * self.yqqzetabar[1,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,1] * self.yqqzetabar[1,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,1] * self.yqqzetabar[1,mif2] + -7/192 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif4] + -1/32 * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif4] + 1/32 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif4] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif4] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif4] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif4] + 5/432 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif4] + 7/288 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif4] + 1/144 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif4] + 1/48 * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif4] + -1/144 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif4] + -1/48 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif4] + -1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif4] + -1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif4] + -1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif4] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif4] + 11/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif4] + -11/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif4] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif4] + 11/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif4] + -11/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif4] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif4] + 11/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif4] + -11/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif4] + -9/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[1,mif4] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[0,mif2] * self.yqqzetabar[1,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[1,mif4] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[1,mif4] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[1,mif4] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[1,mif4] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[1,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[1,mif4] + -15/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif2] * self.yqqzetabar[1,mif4] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[1,mif4] + 3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[1,mif4] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[1,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] * self.yqqzetabar[2,0] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] * self.yqqzetabar[2,0] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] * self.yqqzetabar[2,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[2,0] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[2,0] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[2,0] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] * self.yqqzetabar[2,1] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] * self.yqqzetabar[2,1] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] * self.yqqzetabar[2,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[2,1] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[2,1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[2,1] + 5/432 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + 7/288 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + 1/144 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + 1/48 * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -1/144 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -1/48 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -7/192 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif2] + -1/32 * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif2] + 1/32 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif2] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif2] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif2] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif2] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif2] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif2] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif2] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif2] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif2] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif2] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif2] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif2] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif2] + -35/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + -19/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + -35/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + -19/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + -35/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + -19/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,2] * self.yqqzetabar[2,mif2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,2] * self.yqqzetabar[2,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,2] * self.yqqzetabar[2,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,2] * self.yqqzetabar[2,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,2] * self.yqqzetabar[2,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,2] * self.yqqzetabar[2,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif4] * self.yqqzetabar[2,mif2] + -9/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[0,mif4] * self.yqqzetabar[2,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] * self.yqqzetabar[2,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] * self.yqqzetabar[2,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] * self.yqqzetabar[2,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] * self.yqqzetabar[2,mif2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] * self.yqqzetabar[2,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] * self.yqqzetabar[2,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,2] * self.yqqzetabar[2,mif2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,2] * self.yqqzetabar[2,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,2] * self.yqqzetabar[2,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,2] * self.yqqzetabar[2,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,2] * self.yqqzetabar[2,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,2] * self.yqqzetabar[2,mif2] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif4] * self.yqqzetabar[2,mif2] + -9/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[1,mif4] * self.yqqzetabar[2,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif4] * self.yqqzetabar[2,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif4] * self.yqqzetabar[2,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif4] * self.yqqzetabar[2,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif4] * self.yqqzetabar[2,mif2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif4] * self.yqqzetabar[2,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif4] * self.yqqzetabar[2,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,2] * self.yqqzetabar[2,mif2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,2] * self.yqqzetabar[2,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,2] * self.yqqzetabar[2,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,2] * self.yqqzetabar[2,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,2] * self.yqqzetabar[2,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,2] * self.yqqzetabar[2,mif2] + -7/192 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif4] + -1/32 * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif4] + 1/32 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif4] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif4] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif4] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif4] + 5/432 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif4] + 7/288 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif4] + 1/144 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif4] + 1/48 * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif4] + -1/144 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif4] + -1/48 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif4] + -1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif4] + -1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif4] + -1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif4] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif4] + 11/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif4] + -11/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif4] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif4] + 11/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif4] + -11/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif4] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif4] + 11/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif4] + -11/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif4] + -9/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[2,mif4] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[0,mif2] * self.yqqzetabar[2,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[2,mif4] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[2,mif4] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[2,mif4] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[2,mif4] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[2,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[2,mif4] + -9/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[2,mif4] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[1,mif2] * self.yqqzetabar[2,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[2,mif4] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[2,mif4] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[2,mif4] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[2,mif4] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[2,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[2,mif4] + -15/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif2] * self.yqqzetabar[2,mif4] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] * self.yqqzetabar[2,mif4] + 3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] * self.yqqzetabar[2,mif4] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] * self.yqqzetabar[2,mif4] + -1/48 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqqzeta[mif3,0] * self.yqqzetabar[mif2,0] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,0] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,0] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,0] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,0] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,0] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,0] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,0] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,0] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,0] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,0] * self.yqqzetabar[mif2,0] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,0] * self.yqqzetabar[mif2,0] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,0] * self.yqqzetabar[mif2,0] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,0] * self.yqqzetabar[mif2,0] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,0] * self.yqqzetabar[mif2,0] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,0] * self.yqqzetabar[mif2,0] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,0] * self.yqqzetabar[mif2,0] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,0] * self.yqqzetabar[mif2,0] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,0] * self.yqqzetabar[mif2,0] + -1/48 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqqzeta[mif3,1] * self.yqqzetabar[mif2,1] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,1] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,1] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,1] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,1] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,1] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,1] * self.yqqzetabar[mif2,1] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,1] * self.yqqzetabar[mif2,1] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,1] * self.yqqzetabar[mif2,1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,1] * self.yqqzetabar[mif2,1] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,1] * self.yqqzetabar[mif2,1] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,1] * self.yqqzetabar[mif2,1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,1] * self.yqqzetabar[mif2,1] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,1] * self.yqqzetabar[mif2,1] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,1] * self.yqqzetabar[mif2,1] + -1/48 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqqzeta[mif3,2] * self.yqqzetabar[mif2,2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,2] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,2] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,2] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,2] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,2] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,2] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,2] * self.yqqzetabar[mif2,2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,2] * self.yqqzetabar[mif2,2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,2] * self.yqqzetabar[mif2,2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,2] * self.yqqzetabar[mif2,2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,2] * self.yqqzetabar[mif2,2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,2] * self.yqqzetabar[mif2,2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,2] * self.yqqzetabar[mif2,2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,2] * self.yqqzetabar[mif2,2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,2] * self.yqqzetabar[mif2,2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,0] * self.yqlzetabar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif2,mif4] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,0] * self.yqlzetabar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif2,mif4] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,0] * self.yqlzetabar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif2,mif4] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,1] * self.yqlzetabar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif2,mif4] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,1] * self.yqlzetabar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif2,mif4] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,1] * self.yqlzetabar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif2,mif4] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,2] * self.yqlzetabar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif2,mif4] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,2] * self.yqlzetabar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif2,mif4] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,2] * self.yqlzetabar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif2,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif2,mif4] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif2,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif2,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif2,mif4] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif2,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif2,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif2,mif4] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif2,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif2,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[0,mif3] * self.yqqzetabar[mif2,mif4] + -1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[0,mif3] * self.yqqzetabar[mif2,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[0,mif3] * self.yqqzetabar[mif2,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[0,mif3] * self.yqqzetabar[mif2,mif4] + -1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[0,mif3] * self.yqqzetabar[mif2,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[0,mif3] * self.yqqzetabar[mif2,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[0,mif3] * self.yqqzetabar[mif2,mif4] + -1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[0,mif3] * self.yqqzetabar[mif2,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[0,mif3] * self.yqqzetabar[mif2,mif4] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,0] * self.yqlzetabar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif2,mif4] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,0] * self.yqlzetabar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif2,mif4] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,0] * self.yqlzetabar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif2,mif4] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,1] * self.yqlzetabar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif2,mif4] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,1] * self.yqlzetabar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif2,mif4] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,1] * self.yqlzetabar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif2,mif4] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,2] * self.yqlzetabar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif2,mif4] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,2] * self.yqlzetabar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif2,mif4] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,2] * self.yqlzetabar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif2,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif2,mif4] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif2,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif2,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif2,mif4] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif2,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif2,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif2,mif4] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif2,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif2,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[1,mif3] * self.yqqzetabar[mif2,mif4] + -1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[1,mif3] * self.yqqzetabar[mif2,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[1,mif3] * self.yqqzetabar[mif2,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[1,mif3] * self.yqqzetabar[mif2,mif4] + -1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[1,mif3] * self.yqqzetabar[mif2,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[1,mif3] * self.yqqzetabar[mif2,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[1,mif3] * self.yqqzetabar[mif2,mif4] + -1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[1,mif3] * self.yqqzetabar[mif2,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[1,mif3] * self.yqqzetabar[mif2,mif4] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,0] * self.yqlzetabar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif2,mif4] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,0] * self.yqlzetabar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif2,mif4] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,0] * self.yqlzetabar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif2,mif4] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,1] * self.yqlzetabar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif2,mif4] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,1] * self.yqlzetabar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif2,mif4] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,1] * self.yqlzetabar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif2,mif4] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,2] * self.yqlzetabar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif2,mif4] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,2] * self.yqlzetabar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif2,mif4] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,2] * self.yqlzetabar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif2,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif2,mif4] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif2,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif2,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif2,mif4] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif2,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif2,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif2,mif4] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif2,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif2,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[2,mif3] * self.yqqzetabar[mif2,mif4] + -1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[2,mif3] * self.yqqzetabar[mif2,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[2,mif3] * self.yqqzetabar[mif2,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[2,mif3] * self.yqqzetabar[mif2,mif4] + -1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[2,mif3] * self.yqqzetabar[mif2,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[2,mif3] * self.yqqzetabar[mif2,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[2,mif3] * self.yqqzetabar[mif2,mif4] + -1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[2,mif3] * self.yqqzetabar[mif2,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[2,mif3] * self.yqqzetabar[mif2,mif4] + 3/16 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif2,mif4] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif2,mif4] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif2,mif4] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif2,mif4] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif2,mif4] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif2,mif4] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif2,mif4] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif2,mif4] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif2,mif4] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif2,mif4] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif2,mif4] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif2,mif4] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif2,mif4] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif2,mif4] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif2,mif4] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif2,mif4] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif2,mif4] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif2,mif4] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif2,mif4] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif2,mif4] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif2,mif4] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif2,mif4] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif2,mif4] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif2,mif4] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif2,mif4] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif2,mif4] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif2,mif4] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif2,mif4] + -1/2 * (self.Mzeta)**(-2) * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,mif4] + -3/64 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,mif4] + -9/64 * self.epsilonbar * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,mif4] + -1/32 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,mif4] + -3/32 * self.epsilonbar * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,mif4] + -3/32 * self.epsilonbar * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,mif4] + -1/16 * self.epsilonbar * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,mif4] + 3/32 * self.epsilonbar * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,mif4] + 1/16 * self.epsilonbar * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[mif3,0] * self.yqqzetabar[0,0] * self.yqqzetabar[mif2,mif4] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[mif3,0] * self.yqqzetabar[0,0] * self.yqqzetabar[mif2,mif4] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzeta[mif3,0] * self.yqqzetabar[0,0] * self.yqqzetabar[mif2,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[mif3,1] * self.yqqzetabar[0,1] * self.yqqzetabar[mif2,mif4] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[mif3,1] * self.yqqzetabar[0,1] * self.yqqzetabar[mif2,mif4] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzeta[mif3,1] * self.yqqzetabar[0,1] * self.yqqzetabar[mif2,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[mif3,2] * self.yqqzetabar[0,2] * self.yqqzetabar[mif2,mif4] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[mif3,2] * self.yqqzetabar[0,2] * self.yqqzetabar[mif2,mif4] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzeta[mif3,2] * self.yqqzetabar[0,2] * self.yqqzetabar[mif2,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif2,mif4] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif2,mif4] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif2,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif2,mif4] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif2,mif4] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif2,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif2,mif4] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif2,mif4] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif2,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[mif3,0] * self.yqqzetabar[1,0] * self.yqqzetabar[mif2,mif4] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[mif3,0] * self.yqqzetabar[1,0] * self.yqqzetabar[mif2,mif4] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzeta[mif3,0] * self.yqqzetabar[1,0] * self.yqqzetabar[mif2,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[mif3,1] * self.yqqzetabar[1,1] * self.yqqzetabar[mif2,mif4] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[mif3,1] * self.yqqzetabar[1,1] * self.yqqzetabar[mif2,mif4] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzeta[mif3,1] * self.yqqzetabar[1,1] * self.yqqzetabar[mif2,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[mif3,2] * self.yqqzetabar[1,2] * self.yqqzetabar[mif2,mif4] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[mif3,2] * self.yqqzetabar[1,2] * self.yqqzetabar[mif2,mif4] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzeta[mif3,2] * self.yqqzetabar[1,2] * self.yqqzetabar[mif2,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[1,0] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif2,mif4] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[1,0] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif2,mif4] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzeta[1,0] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif2,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif2,mif4] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif2,mif4] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif2,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif2,mif4] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif2,mif4] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif2,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzeta[mif3,0] * self.yqqzetabar[2,0] * self.yqqzetabar[mif2,mif4] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzeta[mif3,0] * self.yqqzetabar[2,0] * self.yqqzetabar[mif2,mif4] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzeta[mif3,0] * self.yqqzetabar[2,0] * self.yqqzetabar[mif2,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzeta[mif3,1] * self.yqqzetabar[2,1] * self.yqqzetabar[mif2,mif4] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzeta[mif3,1] * self.yqqzetabar[2,1] * self.yqqzetabar[mif2,mif4] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzeta[mif3,1] * self.yqqzetabar[2,1] * self.yqqzetabar[mif2,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzeta[mif3,2] * self.yqqzetabar[2,2] * self.yqqzetabar[mif2,mif4] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzeta[mif3,2] * self.yqqzetabar[2,2] * self.yqqzetabar[mif2,mif4] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzeta[mif3,2] * self.yqqzetabar[2,2] * self.yqqzetabar[mif2,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[2,0] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif2,mif4] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[2,0] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif2,mif4] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzeta[2,0] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif2,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[2,1] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif2,mif4] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[2,1] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif2,mif4] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzeta[2,1] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif2,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif2,mif4] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif2,mif4] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif2,mif4] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,0] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,0] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,0] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,0] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,0] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,0] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,0] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,0] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,0] + -1/432 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,0] + 1/72 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,0] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,0] * self.yqlzetabar[mif2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,1] * self.yqlzetabar[mif2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,2] * self.yqlzetabar[mif2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,0] * self.yqqzetabar[mif4,0] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,0] * self.yqqzetabar[mif4,0] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,0] * self.yqqzetabar[mif4,0] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] * self.yqqzetabar[mif4,0] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] * self.yqqzetabar[mif4,0] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] * self.yqqzetabar[mif4,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[mif4,0] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[mif4,0] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[mif4,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,0] * self.yqqzetabar[mif4,0] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,0] * self.yqqzetabar[mif4,0] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,0] * self.yqqzetabar[mif4,0] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] * self.yqqzetabar[mif4,0] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] * self.yqqzetabar[mif4,0] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] * self.yqqzetabar[mif4,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[mif4,0] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[mif4,0] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[mif4,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,0] * self.yqqzetabar[mif4,0] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,0] * self.yqqzetabar[mif4,0] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,0] * self.yqqzetabar[mif4,0] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif2] * self.yqqzetabar[mif4,0] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif2] * self.yqqzetabar[mif4,0] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif2] * self.yqqzetabar[mif4,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] * self.yqqzetabar[mif4,0] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] * self.yqqzetabar[mif4,0] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] * self.yqqzetabar[mif4,0] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,1] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,1] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,1] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,1] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,1] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,1] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,1] + -1/432 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,1] + 1/72 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,1] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,0] * self.yqlzetabar[mif2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,1] * self.yqlzetabar[mif2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,2] * self.yqlzetabar[mif2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,1] * self.yqqzetabar[mif4,1] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,1] * self.yqqzetabar[mif4,1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,1] * self.yqqzetabar[mif4,1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] * self.yqqzetabar[mif4,1] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] * self.yqqzetabar[mif4,1] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] * self.yqqzetabar[mif4,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[mif4,1] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[mif4,1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[mif4,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,1] * self.yqqzetabar[mif4,1] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,1] * self.yqqzetabar[mif4,1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,1] * self.yqqzetabar[mif4,1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] * self.yqqzetabar[mif4,1] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] * self.yqqzetabar[mif4,1] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] * self.yqqzetabar[mif4,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[mif4,1] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[mif4,1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[mif4,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,1] * self.yqqzetabar[mif4,1] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,1] * self.yqqzetabar[mif4,1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,1] * self.yqqzetabar[mif4,1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif2] * self.yqqzetabar[mif4,1] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif2] * self.yqqzetabar[mif4,1] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif2] * self.yqqzetabar[mif4,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] * self.yqqzetabar[mif4,1] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] * self.yqqzetabar[mif4,1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] * self.yqqzetabar[mif4,1] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,2] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,2] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,2] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,2] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,2] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,2] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,2] + -1/432 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,2] + 1/72 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,0] * self.yqlzetabar[mif2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,1] * self.yqlzetabar[mif2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,2] * self.yqlzetabar[mif2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,2] * self.yqqzetabar[mif4,2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,2] * self.yqqzetabar[mif4,2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,2] * self.yqqzetabar[mif4,2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] * self.yqqzetabar[mif4,2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] * self.yqqzetabar[mif4,2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,mif2] * self.yqqzetabar[mif4,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[mif4,2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[mif4,2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[mif4,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,2] * self.yqqzetabar[mif4,2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,2] * self.yqqzetabar[mif4,2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,2] * self.yqqzetabar[mif4,2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] * self.yqqzetabar[mif4,2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] * self.yqqzetabar[mif4,2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,mif2] * self.yqqzetabar[mif4,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[mif4,2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[mif4,2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[mif4,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,2] * self.yqqzetabar[mif4,2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,2] * self.yqqzetabar[mif4,2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,2] * self.yqqzetabar[mif4,2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif2] * self.yqqzetabar[mif4,2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif2] * self.yqqzetabar[mif4,2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,2] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,mif2] * self.yqqzetabar[mif4,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] * self.yqqzetabar[mif4,2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] * self.yqqzetabar[mif4,2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] * self.yqqzetabar[mif4,2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,0] * self.yqlzetabar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,0] * self.yqlzetabar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,0] * self.yqlzetabar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,1] * self.yqlzetabar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,1] * self.yqlzetabar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,1] * self.yqlzetabar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,2] * self.yqlzetabar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,2] * self.yqlzetabar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,2] * self.yqlzetabar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + -35/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + -19/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + -35/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + -19/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + -35/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + -19/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[0,mif3] * self.yqqzetabar[mif4,mif2] + 11/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[0,mif3] * self.yqqzetabar[mif4,mif2] + -11/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[0,mif3] * self.yqqzetabar[mif4,mif2] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[0,mif3] * self.yqqzetabar[mif4,mif2] + 11/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[0,mif3] * self.yqqzetabar[mif4,mif2] + -11/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[0,mif3] * self.yqqzetabar[mif4,mif2] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[0,mif3] * self.yqqzetabar[mif4,mif2] + 11/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[0,mif3] * self.yqqzetabar[mif4,mif2] + -11/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[0,mif3] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,0] * self.yqlzetabar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,0] * self.yqlzetabar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,0] * self.yqlzetabar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,1] * self.yqlzetabar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,1] * self.yqlzetabar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,1] * self.yqlzetabar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,2] * self.yqlzetabar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,2] * self.yqlzetabar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,2] * self.yqlzetabar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + -35/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + -19/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + -35/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + -19/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + -35/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + -19/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[1,mif3] * self.yqqzetabar[mif4,mif2] + 11/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[1,mif3] * self.yqqzetabar[mif4,mif2] + -11/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[1,mif3] * self.yqqzetabar[mif4,mif2] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[1,mif3] * self.yqqzetabar[mif4,mif2] + 11/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[1,mif3] * self.yqqzetabar[mif4,mif2] + -11/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[1,mif3] * self.yqqzetabar[mif4,mif2] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[1,mif3] * self.yqqzetabar[mif4,mif2] + 11/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[1,mif3] * self.yqqzetabar[mif4,mif2] + -11/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[1,mif3] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,0] * self.yqlzetabar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,0] * self.yqlzetabar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,0] * self.yqlzetabar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,1] * self.yqlzetabar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,1] * self.yqlzetabar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,1] * self.yqlzetabar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,2] * self.yqlzetabar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,2] * self.yqlzetabar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,2] * self.yqlzetabar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + -35/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + -19/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + -35/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + -19/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + -35/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + -19/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[2,mif3] * self.yqqzetabar[mif4,mif2] + 11/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[2,mif3] * self.yqqzetabar[mif4,mif2] + -11/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[2,mif3] * self.yqqzetabar[mif4,mif2] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[2,mif3] * self.yqqzetabar[mif4,mif2] + 11/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[2,mif3] * self.yqqzetabar[mif4,mif2] + -11/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[2,mif3] * self.yqqzetabar[mif4,mif2] + 19/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[2,mif3] * self.yqqzetabar[mif4,mif2] + 11/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[2,mif3] * self.yqqzetabar[mif4,mif2] + -11/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[2,mif3] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif4,mif2] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif4,mif2] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif4,mif2] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif4,mif2] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif4,mif2] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif4,mif2] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif1,0] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif4,mif2] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif4,mif2] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif4,mif2] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif4,mif2] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif4,mif2] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif4,mif2] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif1,1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif4,mif2] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif4,mif2] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif4,mif2] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif4,mif2] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif4,mif2] + 3/128 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif4,mif2] + -3/128 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif1,2] * self.yqqzetabar[mif4,mif2] + -1/2 * (self.Mzeta)**(-2) * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,mif2] + -1/192 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,mif2] + -9/64 * self.epsilonbar * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,mif2] + -3/32 * self.epsilonbar * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,mif2] + -3/32 * self.epsilonbar * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,mif2] + -1/16 * self.epsilonbar * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * self.epsilonbar * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,mif2] + 1/16 * self.epsilonbar * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif1,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif1,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif1,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif1,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif1,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif1,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif1,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif1,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif1,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + 1/2 * (self.Mzeta)**(-2) * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,mif2] + 3/64 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,mif2] + 9/64 * self.epsilonbar * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,mif2] + -1/8 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.epsilonbar * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,mif2] + 3/32 * self.epsilonbar * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,mif2] + -1/16 * self.epsilonbar * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.epsilonbar * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,mif2] + 1/16 * self.epsilonbar * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,mif2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,0] * self.yqqzetabar[mif4,mif2] + 3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,0] * self.yqqzetabar[mif4,mif2] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,0] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[mif3,0] * self.yqqzetabar[0,0] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[mif3,0] * self.yqqzetabar[0,0] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzeta[mif3,0] * self.yqqzetabar[0,0] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[0,1] * self.yqqzetabar[mif4,mif2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[0,1] * self.yqqzetabar[mif4,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[0,1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[mif3,1] * self.yqqzetabar[0,1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[mif3,1] * self.yqqzetabar[0,1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzeta[mif3,1] * self.yqqzetabar[0,1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,2] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,2] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,2] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[0,2] * self.yqqzetabar[mif4,mif2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[0,2] * self.yqqzetabar[mif4,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[0,2] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[mif3,2] * self.yqqzetabar[0,2] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[mif3,2] * self.yqqzetabar[0,2] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzeta[mif3,2] * self.yqqzetabar[0,2] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[0,mif1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[0,mif1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[0,mif1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[0,mif1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[0,mif1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[0,mif1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[0,mif1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[0,mif1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[0,mif1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzeta[mif1,0] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif4,mif2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzeta[mif1,0] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif4,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,0] * self.yqqzeta[mif1,0] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzeta[mif1,1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif4,mif2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzeta[mif1,1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif4,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,1] * self.yqqzeta[mif1,1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzeta[mif1,2] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif4,mif2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzeta[mif1,2] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif4,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,2] * self.yqqzeta[mif1,2] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,0] * self.yqqzetabar[mif4,mif2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,0] * self.yqqzetabar[mif4,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,0] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,0] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,0] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,0] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[mif3,0] * self.yqqzetabar[1,0] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[mif3,0] * self.yqqzetabar[1,0] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzeta[mif3,0] * self.yqqzetabar[1,0] * self.yqqzetabar[mif4,mif2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,1] * self.yqqzetabar[mif4,mif2] + 3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,1] * self.yqqzetabar[mif4,mif2] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[mif3,1] * self.yqqzetabar[1,1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[mif3,1] * self.yqqzetabar[1,1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzeta[mif3,1] * self.yqqzetabar[1,1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,2] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,2] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,2] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[1,2] * self.yqqzetabar[mif4,mif2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[1,2] * self.yqqzetabar[mif4,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[1,2] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[mif3,2] * self.yqqzetabar[1,2] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[mif3,2] * self.yqqzetabar[1,2] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzeta[mif3,2] * self.yqqzetabar[1,2] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[1,mif1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[1,mif1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[1,mif1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[1,mif1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[1,mif1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[1,mif1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[1,mif1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[1,mif1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[1,mif1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[1,0] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[1,0] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzeta[1,0] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzeta[mif1,0] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif4,mif2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzeta[mif1,0] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif4,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,0] * self.yqqzeta[mif1,0] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzeta[mif1,1] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif4,mif2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzeta[mif1,1] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif4,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,1] * self.yqqzeta[mif1,1] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzeta[mif1,2] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif4,mif2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzeta[mif1,2] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif4,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,2] * self.yqqzeta[mif1,2] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,0] * self.yqqzetabar[mif4,mif2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,0] * self.yqqzetabar[mif4,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,0] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,0] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,0] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,0] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzeta[mif3,0] * self.yqqzetabar[2,0] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzeta[mif3,0] * self.yqqzetabar[2,0] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzeta[mif3,0] * self.yqqzetabar[2,0] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,1] * self.yqqzetabar[mif4,mif2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,1] * self.yqqzetabar[mif4,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzeta[mif3,1] * self.yqqzetabar[2,1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzeta[mif3,1] * self.yqqzetabar[2,1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzeta[mif3,1] * self.yqqzetabar[2,1] * self.yqqzetabar[mif4,mif2] + 3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,2] * self.yqqzetabar[mif4,mif2] + 3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,2] * self.yqqzetabar[mif4,mif2] + -3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,2] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzeta[mif3,2] * self.yqqzetabar[2,2] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzeta[mif3,2] * self.yqqzetabar[2,2] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzeta[mif3,2] * self.yqqzetabar[2,2] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[2,mif1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[2,mif1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[2,mif1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[2,mif1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[2,mif1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[2,mif1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[2,mif1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[2,mif1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[2,mif1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[2,0] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[2,0] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzeta[2,0] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[2,1] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[2,1] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzeta[2,1] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzeta[mif1,0] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif4,mif2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzeta[mif1,0] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif4,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,0] * self.yqqzeta[mif1,0] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzeta[mif1,1] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif4,mif2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzeta[mif1,1] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif4,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,1] * self.yqqzeta[mif1,1] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzeta[mif1,2] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif4,mif2] + 3/16 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzeta[mif1,2] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif4,mif2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,2] * self.yqqzeta[mif1,2] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif4,mif2])

    def alphaOqq3(self, mif1,mif2,mif3,mif4):
        return (-1/2560 * (self.g3)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.kronecker_delta(mif2,mif3) + -1/640 * (self.g2)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 1/192 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + 1/384 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + -1/384 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + 1/768 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yqlzeta[mif4,0] * self.yqlzetabar[mif1,0] + 1/192 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + 1/384 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + -1/384 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + 1/768 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yqlzeta[mif4,1] * self.yqlzetabar[mif1,1] + 1/192 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + 1/384 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + -1/384 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + 1/768 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yqlzeta[mif4,2] * self.yqlzetabar[mif1,2] + 1/768 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif3,0] + 1/192 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[mif4,0] * self.yqlzetabar[mif3,0] + 1/384 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[mif4,0] * self.yqlzetabar[mif3,0] + -1/384 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,0] * self.yqlzetabar[mif3,0] + -1/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzeta[mif4,0] * self.yqlzetabar[mif1,0] * self.yqlzetabar[mif3,0] + -1/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzeta[mif4,1] * self.yqlzetabar[mif1,1] * self.yqlzetabar[mif3,0] + -1/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzeta[mif4,2] * self.yqlzetabar[mif1,2] * self.yqlzetabar[mif3,0] + 1/768 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif3,1] + 1/192 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[mif4,1] * self.yqlzetabar[mif3,1] + 1/384 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[mif4,1] * self.yqlzetabar[mif3,1] + -1/384 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,1] * self.yqlzetabar[mif3,1] + -1/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzeta[mif4,0] * self.yqlzetabar[mif1,0] * self.yqlzetabar[mif3,1] + -1/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzeta[mif4,1] * self.yqlzetabar[mif1,1] * self.yqlzetabar[mif3,1] + -1/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzeta[mif4,2] * self.yqlzetabar[mif1,2] * self.yqlzetabar[mif3,1] + 1/768 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif3,2] + 1/192 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[mif4,2] * self.yqlzetabar[mif3,2] + 1/384 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqlzeta[mif4,2] * self.yqlzetabar[mif3,2] + -1/384 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,2] * self.yqlzetabar[mif3,2] + -1/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzeta[mif4,0] * self.yqlzetabar[mif1,0] * self.yqlzetabar[mif3,2] + -1/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzeta[mif4,1] * self.yqlzetabar[mif1,1] * self.yqlzetabar[mif3,2] + -1/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzeta[mif4,2] * self.yqlzetabar[mif1,2] * self.yqlzetabar[mif3,2] + 1/24 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + 1/48 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -1/48 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -7/192 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif2] + -1/32 * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif2] + 1/32 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif2] + -5/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif2] + -5/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif2] + -5/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif2] + -19/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + -11/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + 11/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + -19/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + -11/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + 11/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + -19/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + -11/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + 11/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,0] * self.yqqzetabar[0,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,0] * self.yqqzetabar[0,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,0] * self.yqqzetabar[0,mif2] + -7/192 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif4] + -1/32 * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif4] + 1/32 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif4] + -5/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif4] + -5/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif4] + -5/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif4] + 1/24 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif4] + 1/48 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif4] + -1/48 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif4] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif4] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif4] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] + -5/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,mif2] * self.yqqzetabar[0,mif4] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[0,mif4] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[0,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[0,mif4] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[1,0] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[1,0] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[1,0] + 1/24 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + 1/48 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -1/48 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -7/192 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif2] + -1/32 * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif2] + 1/32 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif2] + -5/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif2] + -5/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif2] + -5/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif2] + -19/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + -11/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + 11/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + -19/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + -11/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + 11/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + -19/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + -11/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + 11/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,1] * self.yqqzetabar[1,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,1] * self.yqqzetabar[1,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,1] * self.yqqzetabar[1,mif2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif4] * self.yqqzetabar[1,mif2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[0,mif4] * self.yqqzetabar[1,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] * self.yqqzetabar[1,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] * self.yqqzetabar[1,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] * self.yqqzetabar[1,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,1] * self.yqqzetabar[1,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,1] * self.yqqzetabar[1,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,1] * self.yqqzetabar[1,mif2] + -7/192 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif4] + -1/32 * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif4] + 1/32 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif4] + -5/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif4] + -5/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif4] + -5/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif4] + 1/24 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif4] + 1/48 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif4] + -1/48 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif4] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif4] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif4] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif4] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif4] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif4] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif4] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[1,mif4] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[0,mif2] * self.yqqzetabar[1,mif4] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[1,mif4] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[1,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[1,mif4] + -5/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,mif2] * self.yqqzetabar[1,mif4] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[1,mif4] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[1,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[1,mif4] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[2,0] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[2,0] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[2,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[2,1] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[2,1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[2,1] + 1/24 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + 1/48 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -1/48 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -7/192 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif2] + -1/32 * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif2] + 1/32 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif2] + -5/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif2] + -5/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif2] + -5/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif2] + -19/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + -11/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + 11/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + -19/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + -11/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + 11/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + -19/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + -11/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif4,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + 11/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif4,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,0] * self.yqlzetabar[mif4,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,1] * self.yqlzetabar[mif4,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,2] * self.yqlzetabar[mif4,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,2] * self.yqqzetabar[2,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,2] * self.yqqzetabar[2,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,2] * self.yqqzetabar[2,mif2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif4] * self.yqqzetabar[2,mif2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[0,mif4] * self.yqqzetabar[2,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] * self.yqqzetabar[2,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] * self.yqqzetabar[2,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif4] * self.yqqzetabar[2,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,2] * self.yqqzetabar[2,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,2] * self.yqqzetabar[2,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,2] * self.yqqzetabar[2,mif2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif4] * self.yqqzetabar[2,mif2] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[1,mif4] * self.yqqzetabar[2,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif4] * self.yqqzetabar[2,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif4] * self.yqqzetabar[2,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif4] * self.yqqzetabar[2,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,2] * self.yqqzetabar[2,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,2] * self.yqqzetabar[2,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif4] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,2] * self.yqqzetabar[2,mif2] + -7/192 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif4] + -1/32 * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif4] + 1/32 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif2,mif3) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif4] + -5/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif4] + -5/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif4] + -5/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif4] + 1/24 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif4] + 1/48 * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif4] + -1/48 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif4] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif4] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif4] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif4] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif4] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif4] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif4] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif4] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif4] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[2,mif4] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[0,mif2] * self.yqqzetabar[2,mif4] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[2,mif4] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[2,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[2,mif4] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[2,mif4] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[1,mif2] * self.yqqzetabar[2,mif4] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[2,mif4] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[2,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[2,mif4] + -5/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,mif2] * self.yqqzetabar[2,mif4] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] * self.yqqzetabar[2,mif4] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] * self.yqqzetabar[2,mif4] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] * self.yqqzetabar[2,mif4] + -1/48 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqqzeta[mif3,0] * self.yqqzetabar[mif2,0] + -1/48 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqqzeta[mif3,1] * self.yqqzetabar[mif2,1] + -1/48 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.yqqzeta[mif3,2] * self.yqqzetabar[mif2,2] + -3/32 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif2,mif4] + 1/48 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,0] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,0] * self.yqlzetabar[mif2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,1] * self.yqlzetabar[mif2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,2] * self.yqlzetabar[mif2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,0] * self.yqqzetabar[mif4,0] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,0] * self.yqqzetabar[mif4,0] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,0] * self.yqqzetabar[mif4,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[mif4,0] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[mif4,0] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[mif4,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,0] * self.yqqzetabar[mif4,0] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,0] * self.yqqzetabar[mif4,0] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,0] * self.yqqzetabar[mif4,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[mif4,0] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[mif4,0] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[mif4,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,0] * self.yqqzetabar[mif4,0] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,0] * self.yqqzetabar[mif4,0] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,0] * self.yqqzetabar[mif4,0] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] * self.yqqzetabar[mif4,0] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] * self.yqqzetabar[mif4,0] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] * self.yqqzetabar[mif4,0] + 1/48 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,1] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,0] * self.yqlzetabar[mif2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,1] * self.yqlzetabar[mif2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,2] * self.yqlzetabar[mif2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,1] * self.yqqzetabar[mif4,1] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,1] * self.yqqzetabar[mif4,1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,1] * self.yqqzetabar[mif4,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[mif4,1] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[mif4,1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[mif4,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,1] * self.yqqzetabar[mif4,1] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,1] * self.yqqzetabar[mif4,1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,1] * self.yqqzetabar[mif4,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[mif4,1] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[mif4,1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[mif4,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,1] * self.yqqzetabar[mif4,1] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,1] * self.yqqzetabar[mif4,1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,1] * self.yqqzetabar[mif4,1] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] * self.yqqzetabar[mif4,1] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] * self.yqqzetabar[mif4,1] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] * self.yqqzetabar[mif4,1] + 1/48 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif2,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,0] * self.yqlzetabar[mif2,0] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,1] * self.yqlzetabar[mif2,1] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,2] * self.yqlzetabar[mif2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,2] * self.yqqzetabar[mif4,2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,2] * self.yqqzetabar[mif4,2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,2] * self.yqqzetabar[mif4,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[mif4,2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[mif4,2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[0,mif2] * self.yqqzetabar[mif4,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,2] * self.yqqzetabar[mif4,2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,2] * self.yqqzetabar[mif4,2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,2] * self.yqqzetabar[mif4,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[mif4,2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[mif4,2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[1,mif2] * self.yqqzetabar[mif4,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,2] * self.yqqzetabar[mif4,2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,2] * self.yqqzetabar[mif4,2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,2] * self.yqqzetabar[mif4,2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] * self.yqqzetabar[mif4,2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] * self.yqqzetabar[mif4,2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,2] * self.yqqzeta[mif3,mif1] * self.yqqzetabar[2,mif2] * self.yqqzetabar[mif4,2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,0] * self.yqlzetabar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,0] * self.yqlzetabar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,0] * self.yqlzetabar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,1] * self.yqlzetabar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,1] * self.yqlzetabar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,1] * self.yqlzetabar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,2] * self.yqlzetabar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,2] * self.yqlzetabar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,2] * self.yqlzetabar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + -19/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + -11/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + 11/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + -19/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + -11/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + 11/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + -19/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + -11/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + 11/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[mif4,mif2] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[0,mif3] * self.yqqzetabar[mif4,mif2] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[0,mif3] * self.yqqzetabar[mif4,mif2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[0,mif3] * self.yqqzetabar[mif4,mif2] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[0,mif3] * self.yqqzetabar[mif4,mif2] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[0,mif3] * self.yqqzetabar[mif4,mif2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[0,mif3] * self.yqqzetabar[mif4,mif2] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[0,mif3] * self.yqqzetabar[mif4,mif2] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[0,mif3] * self.yqqzetabar[mif4,mif2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[0,mif3] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,0] * self.yqlzetabar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,0] * self.yqlzetabar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,0] * self.yqlzetabar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,1] * self.yqlzetabar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,1] * self.yqlzetabar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,1] * self.yqlzetabar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,2] * self.yqlzetabar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,2] * self.yqlzetabar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,2] * self.yqlzetabar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + -19/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + -11/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + 11/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + -19/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + -11/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + 11/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + -19/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + -11/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + 11/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[mif4,mif2] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[1,mif3] * self.yqqzetabar[mif4,mif2] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[1,mif3] * self.yqqzetabar[mif4,mif2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[1,mif3] * self.yqqzetabar[mif4,mif2] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[1,mif3] * self.yqqzetabar[mif4,mif2] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[1,mif3] * self.yqqzetabar[mif4,mif2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[1,mif3] * self.yqqzetabar[mif4,mif2] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[1,mif3] * self.yqqzetabar[mif4,mif2] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[1,mif3] * self.yqqzetabar[mif4,mif2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[1,mif3] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,0] * self.yqlzetabar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,0] * self.yqlzetabar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,0] * self.yqlzetabar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,1] * self.yqlzetabar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,1] * self.yqlzetabar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,1] * self.yqlzetabar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,2] * self.yqlzetabar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif3,2] * self.yqlzetabar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif3,2] * self.yqlzetabar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + -19/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + -11/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + 11/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,0] * self.yqlzetabar[mif3,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + -19/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + -11/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + 11/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,1] * self.yqlzetabar[mif3,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + -19/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + -11/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + 11/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,2] * self.yqlzetabar[mif3,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[mif4,mif2] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[2,mif3] * self.yqqzetabar[mif4,mif2] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[2,mif3] * self.yqqzetabar[mif4,mif2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[2,mif3] * self.yqqzetabar[mif4,mif2] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[2,mif3] * self.yqqzetabar[mif4,mif2] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[2,mif3] * self.yqqzetabar[mif4,mif2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[2,mif3] * self.yqqzetabar[mif4,mif2] + 1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[2,mif3] * self.yqqzetabar[mif4,mif2] + 1/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[2,mif3] * self.yqqzetabar[mif4,mif2] + -1/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[2,mif3] * self.yqqzetabar[mif4,mif2] + 1/192 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,mif2] + -1/32 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,mif3] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif1,0] * self.yqlzetabar[0,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif1,1] * self.yqlzetabar[0,1] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif1,2] * self.yqlzetabar[0,2] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[mif3,0] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif1,0] * self.yqlzetabar[1,0] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif1,1] * self.yqlzetabar[1,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif1,2] * self.yqlzetabar[1,2] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[mif3,1] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif1,0] * self.yqlzetabar[2,0] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif1,1] * self.yqlzetabar[2,1] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[mif1,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif1,2] * self.yqlzetabar[2,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + -3/512 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + -3/256 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + 3/256 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[mif4,mif2] + 1/2 * (self.Mzeta)**(-2) * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,mif2] + 3/64 * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,mif2] + 9/64 * self.epsilonbar * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,mif2] + -1/8 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.epsilonbar * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,mif2] + 3/32 * self.epsilonbar * (self.g2)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,mif2] + -1/16 * self.epsilonbar * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.epsilonbar * (self.g2)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,mif2] + 1/16 * self.epsilonbar * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[mif3,mif1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,0] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,0] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzeta[0,mif3] * self.yqqzetabar[0,0] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[mif3,0] * self.yqqzetabar[0,0] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[mif3,0] * self.yqqzetabar[0,0] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzeta[mif3,0] * self.yqqzetabar[0,0] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif3] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[mif3,1] * self.yqqzetabar[0,1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[mif3,1] * self.yqqzetabar[0,1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzeta[mif3,1] * self.yqqzetabar[0,1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,2] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,2] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,2] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[mif3,2] * self.yqqzetabar[0,2] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[mif3,2] * self.yqqzetabar[0,2] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzeta[mif3,2] * self.yqqzetabar[0,2] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[0,mif1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[0,mif1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[0,mif1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[0,mif1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[0,mif1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[0,mif1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[0,mif1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[0,mif1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[0,mif1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif3] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,0] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,0] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,0] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[mif3,0] * self.yqqzetabar[1,0] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[mif3,0] * self.yqqzetabar[1,0] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzeta[mif3,0] * self.yqqzetabar[1,0] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzeta[1,mif3] * self.yqqzetabar[1,1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[mif3,1] * self.yqqzetabar[1,1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[mif3,1] * self.yqqzetabar[1,1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzeta[mif3,1] * self.yqqzetabar[1,1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,2] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,2] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif3] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,2] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[mif3,2] * self.yqqzetabar[1,2] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[mif3,2] * self.yqqzetabar[1,2] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzeta[mif3,2] * self.yqqzetabar[1,2] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[1,mif1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[1,mif1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[1,mif1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[1,mif1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[1,mif1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[1,mif1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[1,mif1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[1,mif1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[1,mif1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[1,0] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[1,0] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzeta[1,0] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif3] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,0] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,0] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,0] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzeta[mif3,0] * self.yqqzetabar[2,0] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzeta[mif3,0] * self.yqqzetabar[2,0] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzeta[mif3,0] * self.yqqzetabar[2,0] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzeta[mif3,1] * self.yqqzetabar[2,1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzeta[mif3,1] * self.yqqzetabar[2,1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzeta[mif3,1] * self.yqqzetabar[2,1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,2] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,2] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzeta[2,mif3] * self.yqqzetabar[2,2] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzeta[mif3,2] * self.yqqzetabar[2,2] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzeta[mif3,2] * self.yqqzetabar[2,2] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzeta[mif3,2] * self.yqqzetabar[2,2] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[2,mif1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[2,mif1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,0] * self.yqqzeta[mif3,0] * self.yqqzetabar[2,mif1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[2,mif1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[2,mif1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,1] * self.yqqzeta[mif3,1] * self.yqqzetabar[2,mif1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[2,mif1] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[2,mif1] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,2] * self.yqqzeta[mif3,2] * self.yqqzetabar[2,mif1] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[2,0] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzeta[2,0] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzeta[2,0] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[2,1] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzeta[2,1] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzeta[2,1] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif4,mif2] + -3/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif4,mif2] + -3/32 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif4,mif2] + 3/32 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif3] * self.yqqzetabar[mif4,mif2])

    def alphaOqu1(self, mif1,mif2,mif3,mif4):
        return (-1/4320 * (self.g1)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + -13/432 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + -1/48 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + 1/48 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + -13/432 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + -1/48 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + 1/48 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + -13/432 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + -1/48 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + 1/48 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + 5/54 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + 1/18 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -1/18 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + 5/54 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + 1/18 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -1/18 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + 5/54 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + 1/18 * (self.g1)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -1/18 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -1/108 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,0] + -1/108 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,1] + -1/108 * (self.g1)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,2] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,mif4] * self.yubar[0,mif3] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,mif4] * self.yubar[0,mif3] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,mif4] * self.yubar[0,mif3] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[mif2,0] * self.yu[0,mif4] * self.yubar[0,mif3] + 1/24 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,0] * self.yu[0,mif4] * self.yubar[0,mif3] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,mif4] * self.yubar[0,mif3] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,mif4] * self.yubar[0,mif3] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,mif4] * self.yubar[0,mif3] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[mif2,1] * self.yu[1,mif4] * self.yubar[0,mif3] + 1/24 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,1] * self.yu[1,mif4] * self.yubar[0,mif3] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,mif4] * self.yubar[0,mif3] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,mif4] * self.yubar[0,mif3] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,mif4] * self.yubar[0,mif3] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[mif2,2] * self.yu[2,mif4] * self.yubar[0,mif3] + 1/24 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,2] * self.yu[2,mif4] * self.yubar[0,mif3] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,mif4] * self.yubar[1,mif3] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,mif4] * self.yubar[1,mif3] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,mif4] * self.yubar[1,mif3] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[mif2,0] * self.yu[0,mif4] * self.yubar[1,mif3] + 1/24 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,0] * self.yu[0,mif4] * self.yubar[1,mif3] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,mif4] * self.yubar[1,mif3] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,mif4] * self.yubar[1,mif3] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,mif4] * self.yubar[1,mif3] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[mif2,1] * self.yu[1,mif4] * self.yubar[1,mif3] + 1/24 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,1] * self.yu[1,mif4] * self.yubar[1,mif3] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,mif4] * self.yubar[1,mif3] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,mif4] * self.yubar[1,mif3] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,mif4] * self.yubar[1,mif3] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[mif2,2] * self.yu[2,mif4] * self.yubar[1,mif3] + 1/24 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,2] * self.yu[2,mif4] * self.yubar[1,mif3] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,mif4] * self.yubar[2,mif3] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,mif4] * self.yubar[2,mif3] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,mif4] * self.yubar[2,mif3] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[mif2,0] * self.yu[0,mif4] * self.yubar[2,mif3] + 1/24 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,0] * self.yu[0,mif4] * self.yubar[2,mif3] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,mif4] * self.yubar[2,mif3] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,mif4] * self.yubar[2,mif3] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,mif4] * self.yubar[2,mif3] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[mif2,1] * self.yu[1,mif4] * self.yubar[2,mif3] + 1/24 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,1] * self.yu[1,mif4] * self.yubar[2,mif3] + -3/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,mif4] * self.yubar[2,mif3] + -1/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,mif4] * self.yubar[2,mif3] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,mif4] * self.yubar[2,mif3] + -1/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[mif2,2] * self.yu[2,mif4] * self.yubar[2,mif3] + 1/24 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,2] * self.yu[2,mif4] * self.yubar[2,mif3])

    def alphaOqu8(self, mif1,mif2,mif3,mif4):
        return (-1/320 * (self.g3)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 1/96 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,0] * self.yqlzetabar[mif1,0] + 1/96 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,1] * self.yqlzetabar[mif1,1] + 1/96 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqlzeta[mif2,2] * self.yqlzetabar[mif1,2] + -7/24 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -1/4 * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + 1/4 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] + -7/24 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -1/4 * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + 1/4 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] + -7/24 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -1/4 * (self.g3)**(2) * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + 1/4 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] + -1/12 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,0] + -1/12 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,1] + -1/12 * (self.g3)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif3,mif4) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,2] + 9/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,mif4] * self.yubar[0,mif3] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,mif4] * self.yubar[0,mif3] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,mif4] * self.yubar[0,mif3] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,0] * self.yu[0,mif4] * self.yubar[0,mif3] + 9/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,mif4] * self.yubar[0,mif3] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,mif4] * self.yubar[0,mif3] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,mif4] * self.yubar[0,mif3] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,1] * self.yu[1,mif4] * self.yubar[0,mif3] + 9/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,mif4] * self.yubar[0,mif3] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,mif4] * self.yubar[0,mif3] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,mif4] * self.yubar[0,mif3] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,0] * self.yqqzetabar[mif2,2] * self.yu[2,mif4] * self.yubar[0,mif3] + 9/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,mif4] * self.yubar[1,mif3] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,mif4] * self.yubar[1,mif3] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,mif4] * self.yubar[1,mif3] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,0] * self.yu[0,mif4] * self.yubar[1,mif3] + 9/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,mif4] * self.yubar[1,mif3] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,mif4] * self.yubar[1,mif3] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,mif4] * self.yubar[1,mif3] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,1] * self.yu[1,mif4] * self.yubar[1,mif3] + 9/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,mif4] * self.yubar[1,mif3] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,mif4] * self.yubar[1,mif3] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,mif4] * self.yubar[1,mif3] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,1] * self.yqqzetabar[mif2,2] * self.yu[2,mif4] * self.yubar[1,mif3] + 9/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,mif4] * self.yubar[2,mif3] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,mif4] * self.yubar[2,mif3] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,mif2] * self.yu[0,mif4] * self.yubar[2,mif3] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,0] * self.yu[0,mif4] * self.yubar[2,mif3] + 9/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,mif4] * self.yubar[2,mif3] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,mif4] * self.yubar[2,mif3] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,mif2] * self.yu[1,mif4] * self.yubar[2,mif3] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,1] * self.yu[1,mif4] * self.yubar[2,mif3] + 9/16 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,mif4] * self.yubar[2,mif3] + 3/8 * self.invepsilonbar * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,mif4] * self.yubar[2,mif3] + -3/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * np.log((self.Mzeta)**(2) * (self.mu)**(-2)) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,mif2] * self.yu[2,mif4] * self.yubar[2,mif3] + 1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[mif1,2] * self.yqqzetabar[mif2,2] * self.yu[2,mif4] * self.yubar[2,mif3])

    def alphaOquqd1(self, mif1,mif2,mif3,mif4):
        return (1/24 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,0] * self.yu[0,mif2] + -1/12 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,1] * self.yu[0,mif2] + -1/12 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,2] * self.yu[0,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,0] * self.yu[0,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,0] * self.yu[0,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,1] * self.yu[1,mif2] + -1/12 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,0] * self.yu[1,mif2] + 1/24 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,1] * self.yu[1,mif2] + -1/12 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,2] * self.yu[1,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,1] * self.yu[1,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,2] * self.yu[2,mif2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,2] * self.yu[2,mif2] + -1/12 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,0] * self.yu[2,mif2] + -1/12 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,1] * self.yu[2,mif2] + 1/24 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,2] * self.yu[2,mif2])

    def alphaOquqd8(self, mif1,mif2,mif3,mif4):
        return (-1/2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,0] * self.yu[0,mif2] + -1/2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,1] * self.yu[0,mif2] + -1/2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[0,2] * self.yu[0,mif2] + -1/2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,0] * self.yu[1,mif2] + -1/2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,1] * self.yu[1,mif2] + -1/2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[1,2] * self.yu[1,mif2] + -1/2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,0] * self.yu[2,mif2] + -1/2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,1] * self.yu[2,mif2] + -1/2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,mif4] * self.yqqzeta[mif1,mif3] * self.yqqzetabar[2,2] * self.yu[2,mif2])

    def alphaOuB(self, mif1,mif2):
        return (1/96 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] * self.yu[0,mif2] + 1/96 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] * self.yu[0,mif2] + 1/96 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] * self.yu[0,mif2] + -1/24 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,0] * self.yu[0,mif2] + -1/24 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,0] * self.yu[0,mif2] + -1/24 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,0] * self.yu[0,mif2] + 1/96 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] * self.yu[1,mif2] + 1/96 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] * self.yu[1,mif2] + 1/96 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] * self.yu[1,mif2] + -1/24 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,1] * self.yu[1,mif2] + -1/24 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,1] * self.yu[1,mif2] + -1/24 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,1] * self.yu[1,mif2] + 1/96 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] * self.yu[2,mif2] + 1/96 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] * self.yu[2,mif2] + 1/96 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] * self.yu[2,mif2] + -1/24 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,2] * self.yu[2,mif2] + -1/24 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,2] * self.yu[2,mif2] + -1/24 * self.g1 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,2] * self.yu[2,mif2])

    def alphaOud1(self, mif1,mif2,mif3,mif4):
        return 1/2160 * (self.g1)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4)

    def alphaOud8(self, mif1,mif2,mif3,mif4):
        return -1/320 * (self.g3)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4)

    def alphaOuG(self, mif1,mif2):
        return (-1/128 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] * self.yu[0,mif2] + -1/128 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] * self.yu[0,mif2] + -1/128 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] * self.yu[0,mif2] + 1/32 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,0] * self.yu[0,mif2] + 1/32 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,0] * self.yu[0,mif2] + 1/32 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,0] * self.yu[0,mif2] + -1/128 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] * self.yu[1,mif2] + -1/128 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] * self.yu[1,mif2] + -1/128 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] * self.yu[1,mif2] + 1/32 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,1] * self.yu[1,mif2] + 1/32 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,1] * self.yu[1,mif2] + 1/32 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,1] * self.yu[1,mif2] + -1/128 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] * self.yu[2,mif2] + -1/128 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] * self.yu[2,mif2] + -1/128 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] * self.yu[2,mif2] + 1/32 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,2] * self.yu[2,mif2] + 1/32 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,2] * self.yu[2,mif2] + 1/32 * self.g3 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,2] * self.yu[2,mif2])

    def alphaOuH(self, mif1,mif2):
        return (1/32 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] * self.yu[0,mif2] + 3/64 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] * self.yu[0,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[0,0] * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] * self.yu[0,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[0,1] * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] * self.yu[0,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[0,2] * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] * self.yu[0,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[0,0] * self.yqlzeta[0,1] * self.yqlzetabar[mif1,0] * self.yu[0,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[0,1] * self.yqlzeta[0,1] * self.yqlzetabar[mif1,0] * self.yu[0,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[0,2] * self.yqlzeta[0,1] * self.yqlzetabar[mif1,0] * self.yu[0,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[0,0] * self.yqlzeta[0,2] * self.yqlzetabar[mif1,0] * self.yu[0,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[0,1] * self.yqlzeta[0,2] * self.yqlzetabar[mif1,0] * self.yu[0,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[0,2] * self.yqlzeta[0,2] * self.yqlzetabar[mif1,0] * self.yu[0,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[1,0] * self.yqlzeta[0,0] * self.yqlzetabar[mif1,1] * self.yu[0,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[1,1] * self.yqlzeta[0,0] * self.yqlzetabar[mif1,1] * self.yu[0,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[1,2] * self.yqlzeta[0,0] * self.yqlzetabar[mif1,1] * self.yu[0,mif2] + 1/32 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] * self.yu[0,mif2] + 3/64 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] * self.yu[0,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[1,0] * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] * self.yu[0,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[1,1] * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] * self.yu[0,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[1,2] * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] * self.yu[0,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[1,0] * self.yqlzeta[0,2] * self.yqlzetabar[mif1,1] * self.yu[0,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[1,1] * self.yqlzeta[0,2] * self.yqlzetabar[mif1,1] * self.yu[0,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[1,2] * self.yqlzeta[0,2] * self.yqlzetabar[mif1,1] * self.yu[0,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[2,0] * self.yqlzeta[0,0] * self.yqlzetabar[mif1,2] * self.yu[0,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[2,1] * self.yqlzeta[0,0] * self.yqlzetabar[mif1,2] * self.yu[0,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[2,2] * self.yqlzeta[0,0] * self.yqlzetabar[mif1,2] * self.yu[0,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[2,0] * self.yqlzeta[0,1] * self.yqlzetabar[mif1,2] * self.yu[0,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[2,1] * self.yqlzeta[0,1] * self.yqlzetabar[mif1,2] * self.yu[0,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[2,2] * self.yqlzeta[0,1] * self.yqlzetabar[mif1,2] * self.yu[0,mif2] + 1/32 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] * self.yu[0,mif2] + 3/64 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] * self.yu[0,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[2,0] * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] * self.yu[0,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[2,1] * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] * self.yu[0,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[2,2] * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] * self.yu[0,mif2] + -1/4 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,0] * self.yu[0,mif2] + 3/8 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,0] * self.yu[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,0] * self.yu[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,0] * self.yu[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,0] * self.yu[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,0] * self.yu[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,0] * self.yu[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,0] * self.yu[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,0] * self.yu[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,0] * self.yu[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,0] * self.yu[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,0] * self.yu[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,0] * self.yu[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,0] * self.yu[0,mif2] + -1/4 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,0] * self.yu[0,mif2] + 3/8 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,0] * self.yu[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,0] * self.yu[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,0] * self.yu[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,0] * self.yu[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,0] * self.yu[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,0] * self.yu[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,0] * self.yu[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,0] * self.yu[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,0] * self.yu[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,0] * self.yu[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,0] * self.yu[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,0] * self.yu[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,0] * self.yu[0,mif2] + -1/4 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,0] * self.yu[0,mif2] + 3/8 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,0] * self.yu[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,0] * self.yu[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,0] * self.yu[0,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,0] * self.yu[0,mif2] + 1/32 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] * self.yu[1,mif2] + 3/64 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] * self.yu[1,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[0,0] * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] * self.yu[1,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[0,1] * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] * self.yu[1,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[0,2] * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] * self.yu[1,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[0,0] * self.yqlzeta[1,1] * self.yqlzetabar[mif1,0] * self.yu[1,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[0,1] * self.yqlzeta[1,1] * self.yqlzetabar[mif1,0] * self.yu[1,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[0,2] * self.yqlzeta[1,1] * self.yqlzetabar[mif1,0] * self.yu[1,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[0,0] * self.yqlzeta[1,2] * self.yqlzetabar[mif1,0] * self.yu[1,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[0,1] * self.yqlzeta[1,2] * self.yqlzetabar[mif1,0] * self.yu[1,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[0,2] * self.yqlzeta[1,2] * self.yqlzetabar[mif1,0] * self.yu[1,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[1,0] * self.yqlzeta[1,0] * self.yqlzetabar[mif1,1] * self.yu[1,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[1,1] * self.yqlzeta[1,0] * self.yqlzetabar[mif1,1] * self.yu[1,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[1,2] * self.yqlzeta[1,0] * self.yqlzetabar[mif1,1] * self.yu[1,mif2] + 1/32 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] * self.yu[1,mif2] + 3/64 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] * self.yu[1,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[1,0] * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] * self.yu[1,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[1,1] * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] * self.yu[1,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[1,2] * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] * self.yu[1,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[1,0] * self.yqlzeta[1,2] * self.yqlzetabar[mif1,1] * self.yu[1,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[1,1] * self.yqlzeta[1,2] * self.yqlzetabar[mif1,1] * self.yu[1,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[1,2] * self.yqlzeta[1,2] * self.yqlzetabar[mif1,1] * self.yu[1,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[2,0] * self.yqlzeta[1,0] * self.yqlzetabar[mif1,2] * self.yu[1,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[2,1] * self.yqlzeta[1,0] * self.yqlzetabar[mif1,2] * self.yu[1,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[2,2] * self.yqlzeta[1,0] * self.yqlzetabar[mif1,2] * self.yu[1,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[2,0] * self.yqlzeta[1,1] * self.yqlzetabar[mif1,2] * self.yu[1,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[2,1] * self.yqlzeta[1,1] * self.yqlzetabar[mif1,2] * self.yu[1,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[2,2] * self.yqlzeta[1,1] * self.yqlzetabar[mif1,2] * self.yu[1,mif2] + 1/32 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] * self.yu[1,mif2] + 3/64 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] * self.yu[1,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[2,0] * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] * self.yu[1,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[2,1] * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] * self.yu[1,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[2,2] * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] * self.yu[1,mif2] + -1/4 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,1] * self.yu[1,mif2] + 3/8 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,1] * self.yu[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,1] * self.yu[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,1] * self.yu[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,1] * self.yu[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,1] * self.yu[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,1] * self.yu[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,1] * self.yu[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,1] * self.yu[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,1] * self.yu[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,1] * self.yu[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,1] * self.yu[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,1] * self.yu[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,1] * self.yu[1,mif2] + -1/4 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,1] * self.yu[1,mif2] + 3/8 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,1] * self.yu[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,1] * self.yu[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,1] * self.yu[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,1] * self.yu[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,1] * self.yu[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,1] * self.yu[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,1] * self.yu[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,1] * self.yu[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,1] * self.yu[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,1] * self.yu[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,1] * self.yu[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,1] * self.yu[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,1] * self.yu[1,mif2] + -1/4 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,1] * self.yu[1,mif2] + 3/8 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,1] * self.yu[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,1] * self.yu[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,1] * self.yu[1,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,1] * self.yu[1,mif2] + 1/32 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] * self.yu[2,mif2] + 3/64 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] * self.yu[2,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[0,0] * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] * self.yu[2,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[0,1] * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] * self.yu[2,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[0,2] * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] * self.yu[2,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[0,0] * self.yqlzeta[2,1] * self.yqlzetabar[mif1,0] * self.yu[2,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[0,1] * self.yqlzeta[2,1] * self.yqlzetabar[mif1,0] * self.yu[2,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[0,2] * self.yqlzeta[2,1] * self.yqlzetabar[mif1,0] * self.yu[2,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[0,0] * self.yqlzeta[2,2] * self.yqlzetabar[mif1,0] * self.yu[2,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[0,1] * self.yqlzeta[2,2] * self.yqlzetabar[mif1,0] * self.yu[2,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[0,2] * self.yqlzeta[2,2] * self.yqlzetabar[mif1,0] * self.yu[2,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[1,0] * self.yqlzeta[2,0] * self.yqlzetabar[mif1,1] * self.yu[2,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[1,1] * self.yqlzeta[2,0] * self.yqlzetabar[mif1,1] * self.yu[2,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[1,2] * self.yqlzeta[2,0] * self.yqlzetabar[mif1,1] * self.yu[2,mif2] + 1/32 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] * self.yu[2,mif2] + 3/64 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] * self.yu[2,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[1,0] * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] * self.yu[2,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[1,1] * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] * self.yu[2,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[1,2] * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] * self.yu[2,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[1,0] * self.yqlzeta[2,2] * self.yqlzetabar[mif1,1] * self.yu[2,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[1,1] * self.yqlzeta[2,2] * self.yqlzetabar[mif1,1] * self.yu[2,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[1,2] * self.yqlzeta[2,2] * self.yqlzetabar[mif1,1] * self.yu[2,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,0] * self.ylbar[2,0] * self.yqlzeta[2,0] * self.yqlzetabar[mif1,2] * self.yu[2,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,1] * self.ylbar[2,1] * self.yqlzeta[2,0] * self.yqlzetabar[mif1,2] * self.yu[2,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[0,2] * self.ylbar[2,2] * self.yqlzeta[2,0] * self.yqlzetabar[mif1,2] * self.yu[2,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,0] * self.ylbar[2,0] * self.yqlzeta[2,1] * self.yqlzetabar[mif1,2] * self.yu[2,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,1] * self.ylbar[2,1] * self.yqlzeta[2,1] * self.yqlzetabar[mif1,2] * self.yu[2,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[1,2] * self.ylbar[2,2] * self.yqlzeta[2,1] * self.yqlzetabar[mif1,2] * self.yu[2,mif2] + 1/32 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] * self.yu[2,mif2] + 3/64 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] * self.yu[2,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,0] * self.ylbar[2,0] * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] * self.yu[2,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,1] * self.ylbar[2,1] * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] * self.yu[2,mif2] + -1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yl[2,2] * self.ylbar[2,2] * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] * self.yu[2,mif2] + -1/4 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,2] * self.yu[2,mif2] + 3/8 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,2] * self.yu[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,2] * self.yu[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,2] * self.yu[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[0,2] * self.yu[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,2] * self.yu[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,2] * self.yu[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[0,2] * self.yu[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,2] * self.yu[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,2] * self.yu[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[0,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[0,2] * self.yu[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,2] * self.yu[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,2] * self.yu[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[1,2] * self.yu[2,mif2] + -1/4 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,2] * self.yu[2,mif2] + 3/8 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,2] * self.yu[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,2] * self.yu[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,2] * self.yu[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[1,2] * self.yu[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,2] * self.yu[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,2] * self.yu[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[1,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[1,2] * self.yu[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[0,0] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,2] * self.yu[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[0,1] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,2] * self.yu[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[0,2] * self.yqqzeta[0,mif1] * self.yqqzetabar[2,2] * self.yu[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[1,0] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,2] * self.yu[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[1,1] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,2] * self.yu[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[1,2] * self.yqqzeta[1,mif1] * self.yqqzetabar[2,2] * self.yu[2,mif2] + -1/4 * (2)**(-1/2) * self.lambdaHatPrimezeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,2] * self.yu[2,mif2] + 3/8 * self.lambdaHatzeta * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,2] * self.yu[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,0] * self.ydbar[2,0] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,2] * self.yu[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,1] * self.ydbar[2,1] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,2] * self.yu[2,mif2] + -1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yd[2,2] * self.ydbar[2,2] * self.yqqzeta[2,mif1] * self.yqqzetabar[2,2] * self.yu[2,mif2] + -1/320 * (self.g2)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yu[mif1,mif2] + 1/32 * (self.lambdaHatPrimezeta)**(2) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yu[mif1,mif2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,0] * self.yu[0,0] * self.yu[0,mif2] * self.yubar[0,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,0] * self.yu[0,mif2] * self.yu[1,0] * self.yubar[0,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,1] * self.yu[0,0] * self.yu[1,mif2] * self.yubar[0,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,1] * self.yu[1,0] * self.yu[1,mif2] * self.yubar[0,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,0] * self.yu[0,mif2] * self.yu[2,0] * self.yubar[0,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,1] * self.yu[1,mif2] * self.yu[2,0] * self.yubar[0,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,2] * self.yu[0,0] * self.yu[2,mif2] * self.yubar[0,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,2] * self.yu[1,0] * self.yu[2,mif2] * self.yubar[0,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,2] * self.yu[2,0] * self.yu[2,mif2] * self.yubar[0,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[0,0] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[0,1] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[0,2] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzetabar[0,0] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzetabar[1,0] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzetabar[2,0] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[0,0] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[0,1] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[0,2] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzetabar[0,1] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzetabar[1,1] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzetabar[2,1] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[0,0] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[0,1] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[0,2] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzetabar[0,2] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzetabar[1,2] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[0,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzetabar[2,2] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[0,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,0] * self.yu[0,1] * self.yu[0,mif2] * self.yubar[0,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,0] * self.yu[0,mif2] * self.yu[1,1] * self.yubar[0,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,1] * self.yu[0,1] * self.yu[1,mif2] * self.yubar[0,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,1] * self.yu[1,1] * self.yu[1,mif2] * self.yubar[0,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,0] * self.yu[0,mif2] * self.yu[2,1] * self.yubar[0,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,1] * self.yu[1,mif2] * self.yu[2,1] * self.yubar[0,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,2] * self.yu[0,1] * self.yu[2,mif2] * self.yubar[0,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,2] * self.yu[1,1] * self.yu[2,mif2] * self.yubar[0,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,2] * self.yu[2,1] * self.yu[2,mif2] * self.yubar[0,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[0,0] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[0,1] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[0,2] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzetabar[0,0] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzetabar[1,0] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzetabar[2,0] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[0,0] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[0,1] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[0,2] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzetabar[0,1] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzetabar[1,1] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzetabar[2,1] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[0,0] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[0,1] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[0,2] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzetabar[0,2] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzetabar[1,2] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[0,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzetabar[2,2] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[0,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,0] * self.yu[0,2] * self.yu[0,mif2] * self.yubar[0,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,0] * self.yu[0,mif2] * self.yu[1,2] * self.yubar[0,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,1] * self.yu[0,2] * self.yu[1,mif2] * self.yubar[0,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,1] * self.yu[1,2] * self.yu[1,mif2] * self.yubar[0,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,0] * self.yu[0,mif2] * self.yu[2,2] * self.yubar[0,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,1] * self.yu[1,mif2] * self.yu[2,2] * self.yubar[0,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,2] * self.yu[0,2] * self.yu[2,mif2] * self.yubar[0,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[1,2] * self.yu[1,2] * self.yu[2,mif2] * self.yubar[0,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[2,2] * self.yu[2,2] * self.yu[2,mif2] * self.yubar[0,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[0,0] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[0,1] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[0,2] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzetabar[0,0] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzetabar[1,0] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzetabar[2,0] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[0,0] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[0,1] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[0,2] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzetabar[0,1] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzetabar[1,1] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzetabar[2,1] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[0,0] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[0,1] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[0,2] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,0] * self.yqqzetabar[0,2] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,0] * self.yqqzetabar[1,2] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[0,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,0] * self.yqqzetabar[2,2] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[0,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,0] * self.yu[0,0] * self.yu[0,mif2] * self.yubar[1,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,0] * self.yu[0,mif2] * self.yu[1,0] * self.yubar[1,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,1] * self.yu[0,0] * self.yu[1,mif2] * self.yubar[1,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,1] * self.yu[1,0] * self.yu[1,mif2] * self.yubar[1,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,0] * self.yu[0,mif2] * self.yu[2,0] * self.yubar[1,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,1] * self.yu[1,mif2] * self.yu[2,0] * self.yubar[1,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,2] * self.yu[0,0] * self.yu[2,mif2] * self.yubar[1,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,2] * self.yu[1,0] * self.yu[2,mif2] * self.yubar[1,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,2] * self.yu[2,0] * self.yu[2,mif2] * self.yubar[1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[1,0] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[1,1] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[1,2] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzetabar[0,0] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzetabar[1,0] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzetabar[2,0] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[1,0] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[1,1] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[1,2] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzetabar[0,1] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzetabar[1,1] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzetabar[2,1] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[1,0] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[1,1] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[1,2] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzetabar[0,2] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzetabar[1,2] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[1,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzetabar[2,2] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[1,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,0] * self.yu[0,1] * self.yu[0,mif2] * self.yubar[1,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,0] * self.yu[0,mif2] * self.yu[1,1] * self.yubar[1,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,1] * self.yu[0,1] * self.yu[1,mif2] * self.yubar[1,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,1] * self.yu[1,1] * self.yu[1,mif2] * self.yubar[1,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,0] * self.yu[0,mif2] * self.yu[2,1] * self.yubar[1,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,1] * self.yu[1,mif2] * self.yu[2,1] * self.yubar[1,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,2] * self.yu[0,1] * self.yu[2,mif2] * self.yubar[1,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,2] * self.yu[1,1] * self.yu[2,mif2] * self.yubar[1,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,2] * self.yu[2,1] * self.yu[2,mif2] * self.yubar[1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[1,0] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[1,1] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[1,2] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzetabar[0,0] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzetabar[1,0] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzetabar[2,0] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[1,0] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[1,1] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[1,2] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzetabar[0,1] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzetabar[1,1] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzetabar[2,1] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[1,0] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[1,1] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[1,2] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzetabar[0,2] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzetabar[1,2] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[1,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzetabar[2,2] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[1,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,0] * self.yu[0,2] * self.yu[0,mif2] * self.yubar[1,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,0] * self.yu[0,mif2] * self.yu[1,2] * self.yubar[1,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,1] * self.yu[0,2] * self.yu[1,mif2] * self.yubar[1,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,1] * self.yu[1,2] * self.yu[1,mif2] * self.yubar[1,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,0] * self.yu[0,mif2] * self.yu[2,2] * self.yubar[1,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,1] * self.yu[1,mif2] * self.yu[2,2] * self.yubar[1,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[0,2] * self.yu[0,2] * self.yu[2,mif2] * self.yubar[1,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,2] * self.yu[1,2] * self.yu[2,mif2] * self.yubar[1,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[2,2] * self.yu[2,2] * self.yu[2,mif2] * self.yubar[1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[1,0] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[1,1] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[1,2] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzetabar[0,0] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzetabar[1,0] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzetabar[2,0] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[1,0] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[1,1] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[1,2] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzetabar[0,1] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzetabar[1,1] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzetabar[2,1] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[1,0] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[1,1] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[1,2] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,1] * self.yqqzetabar[0,2] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,1] * self.yqqzetabar[1,2] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[1,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,1] * self.yqqzetabar[2,2] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[1,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,0] * self.yu[0,0] * self.yu[0,mif2] * self.yubar[2,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,0] * self.yu[0,mif2] * self.yu[1,0] * self.yubar[2,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,1] * self.yu[0,0] * self.yu[1,mif2] * self.yubar[2,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,1] * self.yu[1,0] * self.yu[1,mif2] * self.yubar[2,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,0] * self.yu[0,mif2] * self.yu[2,0] * self.yubar[2,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,1] * self.yu[1,mif2] * self.yu[2,0] * self.yubar[2,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,2] * self.yu[0,0] * self.yu[2,mif2] * self.yubar[2,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,2] * self.yu[1,0] * self.yu[2,mif2] * self.yubar[2,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,2] * self.yu[2,0] * self.yu[2,mif2] * self.yubar[2,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[2,0] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[2,1] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[2,2] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzetabar[0,0] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzetabar[1,0] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzetabar[2,0] * self.yu[0,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[2,0] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[2,1] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[2,2] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzetabar[0,1] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzetabar[1,1] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzetabar[2,1] * self.yu[1,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[2,0] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[2,1] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[2,2] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzetabar[0,2] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzetabar[1,2] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[2,0] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzetabar[2,2] * self.yu[2,mif2] * self.yu[mif1,0] * self.yubar[2,0] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,0] * self.yu[0,1] * self.yu[0,mif2] * self.yubar[2,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,0] * self.yu[0,mif2] * self.yu[1,1] * self.yubar[2,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,1] * self.yu[0,1] * self.yu[1,mif2] * self.yubar[2,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,1] * self.yu[1,1] * self.yu[1,mif2] * self.yubar[2,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,0] * self.yu[0,mif2] * self.yu[2,1] * self.yubar[2,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,1] * self.yu[1,mif2] * self.yu[2,1] * self.yubar[2,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,2] * self.yu[0,1] * self.yu[2,mif2] * self.yubar[2,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,2] * self.yu[1,1] * self.yu[2,mif2] * self.yubar[2,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,2] * self.yu[2,1] * self.yu[2,mif2] * self.yubar[2,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[2,0] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[2,1] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[2,2] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzetabar[0,0] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzetabar[1,0] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzetabar[2,0] * self.yu[0,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[2,0] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[2,1] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[2,2] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzetabar[0,1] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzetabar[1,1] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzetabar[2,1] * self.yu[1,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[2,0] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[2,1] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[2,2] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzetabar[0,2] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzetabar[1,2] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[2,1] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzetabar[2,2] * self.yu[2,mif2] * self.yu[mif1,1] * self.yubar[2,1] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,0] * self.yu[0,2] * self.yu[0,mif2] * self.yubar[2,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,0] * self.yu[0,mif2] * self.yu[1,2] * self.yubar[2,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,1] * self.yu[0,2] * self.yu[1,mif2] * self.yubar[2,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,1] * self.yu[1,2] * self.yu[1,mif2] * self.yubar[2,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,0] * self.yu[0,mif2] * self.yu[2,2] * self.yubar[2,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,1] * self.yu[1,mif2] * self.yu[2,2] * self.yubar[2,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[0,2] * self.yu[0,2] * self.yu[2,mif2] * self.yubar[2,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[1,2] * self.yu[1,2] * self.yu[2,mif2] * self.yubar[2,2] + -1/4 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,2] * self.yu[2,2] * self.yu[2,mif2] * self.yubar[2,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[2,0] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[2,1] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[2,2] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzetabar[0,0] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzetabar[1,0] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzetabar[2,0] * self.yu[0,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[2,0] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[2,1] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[2,2] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzetabar[0,1] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzetabar[1,1] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzetabar[2,1] * self.yu[1,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[2,0] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[2,1] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/64 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[2,2] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,2] * self.yqqzetabar[0,2] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,2] * self.yqqzetabar[1,2] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[2,2] + 1/8 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,2] * self.yqqzetabar[2,2] * self.yu[2,mif2] * self.yu[mif1,2] * self.yubar[2,2])

    def alphaOuu(self, mif1,mif2,mif3,mif4):
        return (-1/1280 * (self.g3)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif4) * self.kronecker_delta(mif2,mif3) + -1/2160 * (self.g1)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4) + 1/3840 * (self.g3)**(4) * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.kronecker_delta(mif1,mif2) * self.kronecker_delta(mif3,mif4))

    def alphaOuW(self, mif1,mif2):
        return (-1/128 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,0] * self.yqlzetabar[mif1,0] * self.yu[0,mif2] + -1/128 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,1] * self.yqlzetabar[mif1,1] * self.yu[0,mif2] + -1/128 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[0,2] * self.yqlzetabar[mif1,2] * self.yu[0,mif2] + -1/16 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,0] * self.yu[0,mif2] + -1/16 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,0] * self.yu[0,mif2] + -1/16 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,0] * self.yu[0,mif2] + -1/128 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,0] * self.yqlzetabar[mif1,0] * self.yu[1,mif2] + -1/128 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,1] * self.yqlzetabar[mif1,1] * self.yu[1,mif2] + -1/128 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[1,2] * self.yqlzetabar[mif1,2] * self.yu[1,mif2] + -1/16 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,1] * self.yu[1,mif2] + -1/16 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,1] * self.yu[1,mif2] + -1/16 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,1] * self.yu[1,mif2] + -1/128 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,0] * self.yqlzetabar[mif1,0] * self.yu[2,mif2] + -1/128 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,1] * self.yqlzetabar[mif1,1] * self.yu[2,mif2] + -1/128 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqlzeta[2,2] * self.yqlzetabar[mif1,2] * self.yu[2,mif2] + -1/16 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[0,mif1] * self.yqqzetabar[0,2] * self.yu[2,mif2] + -1/16 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[1,mif1] * self.yqqzetabar[1,2] * self.yu[2,mif2] + -1/16 * self.g2 * (self.Mzeta)**(-2) * self.onelooporder * (np.pi)**(-2) * self.yqqzeta[2,mif1] * self.yqqzetabar[2,2] * self.yu[2,mif2])
